/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtcore_python.h"

#include "qcoreapplication_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <QTranslator>
#include <qbytearray.h>
#include <qcoreapplication.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qtranslator.h>


// Begin code injection
// ========================================================================
// START of custom code block [file: glue/qcoreapplication_init.cpp]
// Global variables used to store argc and argv values
static int QCoreApplicationArgCount;
static char** QCoreApplicationArgValues;

int Sbk_QCoreApplication_Init(PyObject* self, PyObject* args, PyObject*)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QCoreApplication >()))
        return -1;


    if (QCoreApplication::instance()) {
        PyErr_SetString(PyExc_RuntimeError, "A QCoreApplication instance already exists.");
        return -1;
    }

    int numArgs = PyTuple_GET_SIZE(args);
    if (numArgs != 1) {
        PyErr_BadArgument();
        return -1;
    }

    if (!Shiboken::sequenceToArgcArgv(PyTuple_GET_ITEM(args, 0), &QCoreApplicationArgCount, &QCoreApplicationArgValues, "PySideApp")) {
        PyErr_BadArgument();
        return -1;
    }

    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    QCoreApplicationWrapper* cptr = new QCoreApplicationWrapper(QCoreApplicationArgCount, QCoreApplicationArgValues);
    Shiboken::Object::setCppPointer(sbkSelf,
                                     Shiboken::SbkType<QCoreApplication>(),
                                     cptr);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::Object::releaseOwnership(sbkSelf);

    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::Signal::updateSourceObject(self);
    cptr->metaObject();

    PySide::registerCleanupFunction(&PySide::destroyQCoreApplication);
    Py_INCREF(self);
    return 1;
}

// END of custom code block [file: glue/qcoreapplication_init.cpp]
// ========================================================================

// End of code injection

// Native ---------------------------------------------------------

QCoreApplicationWrapper::QCoreApplicationWrapper(int & argc, char ** argv) : QCoreApplication(argc, argv) {
    // ... middle
}

void QCoreApplicationWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QCoreApplicationWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QCoreApplicationWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QCoreApplicationWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QCoreApplicationWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCoreApplication::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCoreApplication.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QCoreApplicationWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCoreApplication.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QCoreApplicationWrapper::notify(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "notify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCoreApplication::notify(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCoreApplication.notify", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QCoreApplicationWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QCoreApplicationWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QCoreApplicationWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QCoreApplication::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QCoreApplicationWrapper::~QCoreApplicationWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject* Sbk_QCoreApplicationFunc_addLibraryPath(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addLibraryPath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // addLibraryPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_addLibraryPath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addLibraryPath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication::addLibraryPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_addLibraryPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QCoreApplication.addLibraryPath", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_applicationDirPath(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // applicationDirPath()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QCoreApplication::applicationDirPath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_applicationFilePath(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // applicationFilePath()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QCoreApplication::applicationFilePath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_applicationName(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // applicationName()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QCoreApplication::applicationName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_applicationPid(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // applicationPid()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = QCoreApplication::applicationPid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_applicationVersion(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // applicationVersion()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QCoreApplication::applicationVersion();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_arguments(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // arguments()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = QCoreApplication::arguments();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_closingDown(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // closingDown()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QCoreApplication::closingDown();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_event(PyObject* self, PyObject* arg)
{
    QCoreApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCoreApplication* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QCoreApplication::event(cppArg0) : cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCoreApplicationFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QCoreApplication.event", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_exec_(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // exec()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QCoreApplication::exec();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_exit(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QCoreApplication.exit(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:exit", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: exit(int)
    if (numArgs == 0) {
        overloadId = 0; // exit(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // exit(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_exit_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "retcode");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "retcode";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QCoreApplicationFunc_exit_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QCoreApplication.exit(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // exit(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication::exit(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_exit_TypeError:
        const char* overloads[] = {"int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QCoreApplication.exit", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_flush(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // flush()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication::flush();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QCoreApplicationFunc_hasPendingEvents(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasPendingEvents()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QCoreApplication::hasPendingEvents();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_installTranslator(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: installTranslator(QTranslator*)
    if (Shiboken::Converter< ::QTranslator * >::isConvertible(arg)) {
        overloadId = 0; // installTranslator(QTranslator*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_installTranslator_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTranslator * cppArg0 = Shiboken::Converter<QTranslator * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // installTranslator(QTranslator*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication::installTranslator(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_installTranslator_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTranslator", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QCoreApplication.installTranslator", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_instance(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // instance()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication * cppResult = QCoreApplication::instance();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QCoreApplication * >::toPython(cppResult);

                // Ownership transferences.
                Shiboken::Object::invalidate(pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_libraryPaths(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // libraryPaths()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = QCoreApplication::libraryPaths();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_notify(PyObject* self, PyObject* args)
{
    QCoreApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCoreApplication* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "notify", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: notify(QObject*,QEvent*)
    if (numArgs == 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // notify(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_notify_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QEvent * cppArg1 = Shiboken::Converter<QEvent * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // notify(QObject*,QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QCoreApplication::notify(cppArg0, cppArg1) : cppSelf->notify(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCoreApplicationFunc_notify_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QCoreApplication.notify", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_organizationDomain(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // organizationDomain()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QCoreApplication::organizationDomain();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_organizationName(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // organizationName()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QCoreApplication::organizationName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_postEvent(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "postEvent", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: postEvent(QObject*,QEvent*)
    // 1: postEvent(QObject*,QEvent*,int)
    if (numArgs >= 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QEvent * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // postEvent(QObject*,QEvent*)
        } else if (numArgs == 3 && SbkNumber_Check(pyargs[2])) {
            overloadId = 1; // postEvent(QObject*,QEvent*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_postEvent_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // postEvent(QObject*,QEvent*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QEvent * cppArg1 = Shiboken::Converter<QEvent * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // postEvent(QObject*,QEvent*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QCoreApplication::postEvent(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

                    // Ownership transferences.
                    Shiboken::Object::releaseOwnership(pyargs[1]);
                }
                break;
            }
            case 1: // postEvent(QObject*,QEvent*,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QEvent * cppArg1 = Shiboken::Converter<QEvent * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // postEvent(QObject*,QEvent*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QCoreApplication::postEvent(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

                    // Ownership transferences.
                    Shiboken::Object::releaseOwnership(pyargs[1]);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_postEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QEvent", "PySide.QtCore.QObject, PySide.QtCore.QEvent, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QCoreApplication.postEvent", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_processEvents(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QCoreApplication.processEvents(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:processEvents", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: processEvents(QFlags<QEventLoop::ProcessEventsFlag>)
    // 1: processEvents(QFlags<QEventLoop::ProcessEventsFlag>,int)
    if (numArgs == 0) {
        overloadId = 0; // processEvents(QFlags<QEventLoop::ProcessEventsFlag>)
    } else if (Shiboken::Converter< ::QFlags<QEventLoop::ProcessEventsFlag> >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // processEvents(QFlags<QEventLoop::ProcessEventsFlag>)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // processEvents(QFlags<QEventLoop::ProcessEventsFlag>,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_processEvents_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // processEvents(QFlags<QEventLoop::ProcessEventsFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<QEventLoop::ProcessEventsFlag> >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QCoreApplicationFunc_processEvents_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QCoreApplication.processEvents(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QFlags<QEventLoop::ProcessEventsFlag> cppArg0 = pyargs[0] ? Shiboken::Converter<QFlags<QEventLoop::ProcessEventsFlag> >::toCpp(pyargs[0]) : QEventLoop::AllEvents;

                if(!PyErr_Occurred()) {
                    // processEvents(QFlags<QEventLoop::ProcessEventsFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QCoreApplication::processEvents(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // processEvents(QFlags<QEventLoop::ProcessEventsFlag>,int)
            {
                QFlags<QEventLoop::ProcessEventsFlag> cppArg0 = Shiboken::Converter<QFlags<QEventLoop::ProcessEventsFlag> >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // processEvents(QFlags<QEventLoop::ProcessEventsFlag>,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QCoreApplication::processEvents(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_processEvents_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEventLoop.ProcessEventsFlags = QEventLoop.AllEvents", "PySide.QtCore.QEventLoop.ProcessEventsFlags, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QCoreApplication.processEvents", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_quit(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // quit()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication::quit();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QCoreApplicationFunc_removeLibraryPath(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeLibraryPath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // removeLibraryPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_removeLibraryPath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeLibraryPath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication::removeLibraryPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_removeLibraryPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QCoreApplication.removeLibraryPath", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_removePostedEvents(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "removePostedEvents", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: removePostedEvents(QObject*)
    // 1: removePostedEvents(QObject*,int)
    if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // removePostedEvents(QObject*)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // removePostedEvents(QObject*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_removePostedEvents_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // removePostedEvents(QObject*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // removePostedEvents(QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QCoreApplication::removePostedEvents(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // removePostedEvents(QObject*,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // removePostedEvents(QObject*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QCoreApplication::removePostedEvents(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_removePostedEvents_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", "PySide.QtCore.QObject, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QCoreApplication.removePostedEvents", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_removeTranslator(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeTranslator(QTranslator*)
    if (Shiboken::Converter< ::QTranslator * >::isConvertible(arg)) {
        overloadId = 0; // removeTranslator(QTranslator*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_removeTranslator_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTranslator * cppArg0 = Shiboken::Converter<QTranslator * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeTranslator(QTranslator*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication::removeTranslator(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_removeTranslator_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTranslator", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QCoreApplication.removeTranslator", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_sendEvent(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sendEvent", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: sendEvent(QObject*,QEvent*)
    if (numArgs == 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // sendEvent(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_sendEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QEvent * cppArg1 = Shiboken::Converter<QEvent * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // sendEvent(QObject*,QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QCoreApplication::sendEvent(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCoreApplicationFunc_sendEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QCoreApplication.sendEvent", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_sendPostedEvents(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs == 1)
        goto Sbk_QCoreApplicationFunc_sendPostedEvents_TypeError;

    if (!PyArg_UnpackTuple(args, "sendPostedEvents", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: sendPostedEvents()
    // 1: sendPostedEvents(QObject*,int)
    if (numArgs == 0) {
        overloadId = 0; // sendPostedEvents()
    } else if (numArgs == 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // sendPostedEvents(QObject*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_sendPostedEvents_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // sendPostedEvents()
            {

                if(!PyErr_Occurred()) {
                    // sendPostedEvents()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QCoreApplication::sendPostedEvents();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // sendPostedEvents(QObject*,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // sendPostedEvents(QObject*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QCoreApplication::sendPostedEvents(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_sendPostedEvents_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QCoreApplication.sendPostedEvents", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_setApplicationName(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setApplicationName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setApplicationName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_setApplicationName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setApplicationName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication::setApplicationName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_setApplicationName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QCoreApplication.setApplicationName", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_setApplicationVersion(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setApplicationVersion(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setApplicationVersion(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_setApplicationVersion_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setApplicationVersion(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication::setApplicationVersion(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_setApplicationVersion_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QCoreApplication.setApplicationVersion", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_setAttribute(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QCoreApplication.setAttribute(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QCoreApplication.setAttribute(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setAttribute", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAttribute(Qt::ApplicationAttribute,bool)
    if (Shiboken::Converter< ::Qt::ApplicationAttribute >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setAttribute(Qt::ApplicationAttribute,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setAttribute(Qt::ApplicationAttribute,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_setAttribute_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "on");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "on";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QCoreApplicationFunc_setAttribute_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QCoreApplication.setAttribute(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::ApplicationAttribute cppArg0 = Shiboken::Converter<Qt::ApplicationAttribute >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // setAttribute(Qt::ApplicationAttribute,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication::setAttribute(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_setAttribute_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ApplicationAttribute, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QCoreApplication.setAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_setLibraryPaths(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLibraryPaths(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setLibraryPaths(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_setLibraryPaths_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLibraryPaths(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication::setLibraryPaths(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_setLibraryPaths_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QCoreApplication.setLibraryPaths", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_setOrganizationDomain(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOrganizationDomain(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setOrganizationDomain(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_setOrganizationDomain_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOrganizationDomain(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication::setOrganizationDomain(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_setOrganizationDomain_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QCoreApplication.setOrganizationDomain", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_setOrganizationName(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOrganizationName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setOrganizationName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_setOrganizationName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOrganizationName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCoreApplication::setOrganizationName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCoreApplicationFunc_setOrganizationName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QCoreApplication.setOrganizationName", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_startingUp(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // startingUp()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QCoreApplication::startingUp();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCoreApplicationFunc_testAttribute(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testAttribute(Qt::ApplicationAttribute)
    if (Shiboken::Converter< ::Qt::ApplicationAttribute >::isConvertible(arg)) {
        overloadId = 0; // testAttribute(Qt::ApplicationAttribute)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_testAttribute_TypeError;

    // Call function/method
    {
        {
            Qt::ApplicationAttribute cppArg0 = Shiboken::Converter<Qt::ApplicationAttribute >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // testAttribute(Qt::ApplicationAttribute)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QCoreApplication::testAttribute(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCoreApplicationFunc_testAttribute_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ApplicationAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QCoreApplication.testAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QCoreApplicationFunc_translate(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QCoreApplication.translate(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QCoreApplication.translate(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:translate", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: translate(const char*,const char*,const char*,QCoreApplication::Encoding)
    // 1: translate(const char*,const char*,const char*,QCoreApplication::Encoding,int)
    if (numArgs >= 2 && Shiboken::Converter< const char * >::isConvertible(pyargs[0]) && Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // translate(const char*,const char*,const char*,QCoreApplication::Encoding)
        } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // translate(const char*,const char*,const char*,QCoreApplication::Encoding)
            } else if (Shiboken::Converter< ::QCoreApplication::Encoding >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 0; // translate(const char*,const char*,const char*,QCoreApplication::Encoding)
                } else if (numArgs == 5 && SbkNumber_Check(pyargs[4])) {
                    overloadId = 1; // translate(const char*,const char*,const char*,QCoreApplication::Encoding,int)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCoreApplicationFunc_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(const char*,const char*,const char*,QCoreApplication::Encoding)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "disambiguation");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "disambiguation";
                        else if (Shiboken::Converter< const char * >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QCoreApplicationFunc_translate_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "encoding");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "encoding";
                        else if (Shiboken::Converter< ::QCoreApplication::Encoding >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QCoreApplicationFunc_translate_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QCoreApplication.translate(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                const char * cppArg2 = pyargs[2] ? Shiboken::Converter<const char * >::toCpp(pyargs[2]) : 0;
                QCoreApplication::Encoding cppArg3 = pyargs[3] ? Shiboken::Converter<QCoreApplication::Encoding >::toCpp(pyargs[3]) : QCoreApplication::CodecForTr;

                if(!PyErr_Occurred()) {
                    // translate(const char*,const char*,const char*,QCoreApplication::Encoding)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = QCoreApplication::translate(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // translate(const char*,const char*,const char*,QCoreApplication::Encoding,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                const char * cppArg2 = Shiboken::Converter<const char * >::toCpp(pyargs[2]);
                QCoreApplication::Encoding cppArg3 = Shiboken::Converter<QCoreApplication::Encoding >::toCpp(pyargs[3]);
                int cppArg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // translate(const char*,const char*,const char*,QCoreApplication::Encoding,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = QCoreApplication::translate(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCoreApplicationFunc_translate_TypeError:
        const char* overloads[] = {"str, str, str = None, PySide.QtCore.QCoreApplication.Encoding = CodecForTr", "str, str, str, PySide.QtCore.QCoreApplication.Encoding, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QCoreApplication.translate", overloads);
        return 0;
}

static PyMethodDef Sbk_QCoreApplication_methods[] = {
    {"addLibraryPath", (PyCFunction)Sbk_QCoreApplicationFunc_addLibraryPath, METH_O|METH_STATIC},
    {"applicationDirPath", (PyCFunction)Sbk_QCoreApplicationFunc_applicationDirPath, METH_NOARGS|METH_STATIC},
    {"applicationFilePath", (PyCFunction)Sbk_QCoreApplicationFunc_applicationFilePath, METH_NOARGS|METH_STATIC},
    {"applicationName", (PyCFunction)Sbk_QCoreApplicationFunc_applicationName, METH_NOARGS|METH_STATIC},
    {"applicationPid", (PyCFunction)Sbk_QCoreApplicationFunc_applicationPid, METH_NOARGS|METH_STATIC},
    {"applicationVersion", (PyCFunction)Sbk_QCoreApplicationFunc_applicationVersion, METH_NOARGS|METH_STATIC},
    {"arguments", (PyCFunction)Sbk_QCoreApplicationFunc_arguments, METH_NOARGS|METH_STATIC},
    {"closingDown", (PyCFunction)Sbk_QCoreApplicationFunc_closingDown, METH_NOARGS|METH_STATIC},
    {"event", (PyCFunction)Sbk_QCoreApplicationFunc_event, METH_O},
    {"exec_", (PyCFunction)Sbk_QCoreApplicationFunc_exec_, METH_NOARGS|METH_STATIC},
    {"exit", (PyCFunction)Sbk_QCoreApplicationFunc_exit, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"flush", (PyCFunction)Sbk_QCoreApplicationFunc_flush, METH_NOARGS|METH_STATIC},
    {"hasPendingEvents", (PyCFunction)Sbk_QCoreApplicationFunc_hasPendingEvents, METH_NOARGS|METH_STATIC},
    {"installTranslator", (PyCFunction)Sbk_QCoreApplicationFunc_installTranslator, METH_O|METH_STATIC},
    {"instance", (PyCFunction)Sbk_QCoreApplicationFunc_instance, METH_NOARGS|METH_STATIC},
    {"libraryPaths", (PyCFunction)Sbk_QCoreApplicationFunc_libraryPaths, METH_NOARGS|METH_STATIC},
    {"notify", (PyCFunction)Sbk_QCoreApplicationFunc_notify, METH_VARARGS},
    {"organizationDomain", (PyCFunction)Sbk_QCoreApplicationFunc_organizationDomain, METH_NOARGS|METH_STATIC},
    {"organizationName", (PyCFunction)Sbk_QCoreApplicationFunc_organizationName, METH_NOARGS|METH_STATIC},
    {"postEvent", (PyCFunction)Sbk_QCoreApplicationFunc_postEvent, METH_VARARGS|METH_STATIC},
    {"processEvents", (PyCFunction)Sbk_QCoreApplicationFunc_processEvents, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"quit", (PyCFunction)Sbk_QCoreApplicationFunc_quit, METH_NOARGS|METH_STATIC},
    {"removeLibraryPath", (PyCFunction)Sbk_QCoreApplicationFunc_removeLibraryPath, METH_O|METH_STATIC},
    {"removePostedEvents", (PyCFunction)Sbk_QCoreApplicationFunc_removePostedEvents, METH_VARARGS|METH_STATIC},
    {"removeTranslator", (PyCFunction)Sbk_QCoreApplicationFunc_removeTranslator, METH_O|METH_STATIC},
    {"sendEvent", (PyCFunction)Sbk_QCoreApplicationFunc_sendEvent, METH_VARARGS|METH_STATIC},
    {"sendPostedEvents", (PyCFunction)Sbk_QCoreApplicationFunc_sendPostedEvents, METH_VARARGS|METH_STATIC},
    {"setApplicationName", (PyCFunction)Sbk_QCoreApplicationFunc_setApplicationName, METH_O|METH_STATIC},
    {"setApplicationVersion", (PyCFunction)Sbk_QCoreApplicationFunc_setApplicationVersion, METH_O|METH_STATIC},
    {"setAttribute", (PyCFunction)Sbk_QCoreApplicationFunc_setAttribute, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"setLibraryPaths", (PyCFunction)Sbk_QCoreApplicationFunc_setLibraryPaths, METH_O|METH_STATIC},
    {"setOrganizationDomain", (PyCFunction)Sbk_QCoreApplicationFunc_setOrganizationDomain, METH_O|METH_STATIC},
    {"setOrganizationName", (PyCFunction)Sbk_QCoreApplicationFunc_setOrganizationName, METH_O|METH_STATIC},
    {"startingUp", (PyCFunction)Sbk_QCoreApplicationFunc_startingUp, METH_NOARGS|METH_STATIC},
    {"testAttribute", (PyCFunction)Sbk_QCoreApplicationFunc_testAttribute, METH_O|METH_STATIC},
    {"translate", (PyCFunction)Sbk_QCoreApplicationFunc_translate, METH_VARARGS|METH_KEYWORDS|METH_STATIC},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QCoreApplication_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QCoreApplication",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QCoreApplication_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QCoreApplication_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QCoreApplication_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QCoreApplication*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QCoreApplication_Type;
    return 0;
}


void init_QCoreApplication(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QCOREAPPLICATION_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QCoreApplication_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QCoreApplication_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QCoreApplication_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QCoreApplication_Type, &QCoreApplication::staticMetaObject);
    Sbk_QCoreApplication_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QCoreApplication_Type, &Shiboken::callCppDestructor<QCoreApplication >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QCoreApplication_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QCoreApplication_Type, &Sbk_QCoreApplication_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QCoreApplication_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QCoreApplication_Type, "QCoreApplication*");
    PyModule_AddObject(module, "QCoreApplication",
        ((PyObject*)&Sbk_QCoreApplication_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Encoding
    PyTypeObject* SbkPySide_QtCore_QCoreApplication_Encoding = Shiboken::Enum::newType("PySide.QtCore.QCoreApplication.Encoding");
    SbkPySide_QtCoreTypes[SBK_QCOREAPPLICATION_ENCODING_IDX] = SbkPySide_QtCore_QCoreApplication_Encoding;
    if (PyType_Ready(SbkPySide_QtCore_QCoreApplication_Encoding) < 0)
        return;
    PyDict_SetItemString(Sbk_QCoreApplication_Type.super.ht_type.tp_dict,
            "Encoding",((PyObject*)SbkPySide_QtCore_QCoreApplication_Encoding));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QCoreApplication_Encoding,(long) QCoreApplication::CodecForTr, "CodecForTr");
    PyDict_SetItemString(Sbk_QCoreApplication_Type.super.ht_type.tp_dict,"CodecForTr", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QCoreApplication_Encoding->tp_dict,"CodecForTr", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QCoreApplication_Encoding,(long) QCoreApplication::UnicodeUTF8, "UnicodeUTF8");
    PyDict_SetItemString(Sbk_QCoreApplication_Type.super.ht_type.tp_dict,"UnicodeUTF8", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QCoreApplication_Encoding->tp_dict,"UnicodeUTF8", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QCoreApplication_Encoding,(long) QCoreApplication::DefaultCodec, "DefaultCodec");
    PyDict_SetItemString(Sbk_QCoreApplication_Type.super.ht_type.tp_dict,"DefaultCodec", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QCoreApplication_Encoding->tp_dict,"DefaultCodec", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QCoreApplication::Encoding");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QCoreApplication$ConcreteWrapper::Encoding");
    // end of enum Encoding

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("unixSignal", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QCoreApplication_Type, "unixSignal", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("aboutToQuit", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QCoreApplication_Type, "aboutToQuit", signal_item);
    Py_DECREF((PyObject*) signal_item);



    Shiboken::TypeResolver::createObjectTypeResolver<QCoreApplication >("QCoreApplication*");
    Shiboken::TypeResolver::createObjectTypeResolver<QCoreApplication >("QCoreApplication$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QCoreApplication >(typeid(QCoreApplication).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QCoreApplication >(typeid(QCoreApplicationWrapper).name());
    PySide::initQtMetaType< ::QCoreApplication* >();
    qRegisterMetaType< ::QCoreApplication::Encoding >("QCoreApplication::Encoding");
}


