/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qcryptographichash_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qcryptographichash.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCryptographicHash_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QCryptographicHash >()))
        return -1;

    QCryptographicHash* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QCryptographicHash", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QCryptographicHash(QCryptographicHash::Algorithm)
    if (numArgs == 1 && Shiboken::Converter< ::QCryptographicHash::Algorithm >::isConvertible(pyargs[0])) {
        overloadId = 0; // QCryptographicHash(QCryptographicHash::Algorithm)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCryptographicHash_Init_TypeError;

    // Call function/method
    {
        {
            QCryptographicHash::Algorithm cppArg0 = Shiboken::Converter<QCryptographicHash::Algorithm >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
                // QCryptographicHash(QCryptographicHash::Algorithm)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QCryptographicHash(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QCryptographicHash >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QCryptographicHash_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QCryptographicHash_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QCryptographicHash.Algorithm", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QCryptographicHash", overloads);
        return -1;
}

static PyObject* Sbk_QCryptographicHashFunc_addData(PyObject* self, PyObject* arg)
{
    QCryptographicHash* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCryptographicHash* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addData(QByteArray)
    // 1: addData(const char*,int)
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 1; // addData(const char*,int)
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // addData(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCryptographicHashFunc_addData_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addData(QByteArray)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // addData(QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addData(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // addData(const char*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // addData(const char*,int)
                    // Begin code injection

                    cppSelf->addData(PyString_AS_STRING(arg), PyString_GET_SIZE(arg));

                    // End of code injection


                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCryptographicHashFunc_addData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "str, int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QCryptographicHash.addData", overloads);
        return 0;
}

static PyObject* Sbk_QCryptographicHashFunc_hash(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "hash", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: hash(QByteArray,QCryptographicHash::Algorithm)
    if (numArgs == 2 && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QCryptographicHash::Algorithm >::isConvertible(pyargs[1])) {
        overloadId = 0; // hash(QByteArray,QCryptographicHash::Algorithm)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCryptographicHashFunc_hash_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
            QCryptographicHash::Algorithm cppArg1 = Shiboken::Converter<QCryptographicHash::Algorithm >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // hash(QByteArray,QCryptographicHash::Algorithm)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = QCryptographicHash::hash(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCryptographicHashFunc_hash_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtCore.QCryptographicHash.Algorithm", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QCryptographicHash.hash", overloads);
        return 0;
}

static PyObject* Sbk_QCryptographicHashFunc_reset(PyObject* self)
{
    QCryptographicHash* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCryptographicHash* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // reset()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->reset();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QCryptographicHashFunc_result(PyObject* self)
{
    QCryptographicHash* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCryptographicHash* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // result()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = const_cast<const QCryptographicHash*>(cppSelf)->result();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QCryptographicHash_methods[] = {
    {"addData", (PyCFunction)Sbk_QCryptographicHashFunc_addData, METH_O},
    {"hash", (PyCFunction)Sbk_QCryptographicHashFunc_hash, METH_VARARGS|METH_STATIC},
    {"reset", (PyCFunction)Sbk_QCryptographicHashFunc_reset, METH_NOARGS},
    {"result", (PyCFunction)Sbk_QCryptographicHashFunc_result, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QCryptographicHash_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QCryptographicHash",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QCryptographicHash_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QCryptographicHash_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QCryptographicHash(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QCRYPTOGRAPHICHASH_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QCryptographicHash_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QCryptographicHash_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QCryptographicHash_Type, &Shiboken::callCppDestructor<QCryptographicHash >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QCryptographicHash_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QCryptographicHash_Type, "QCryptographicHash*");
    PyModule_AddObject(module, "QCryptographicHash",
        ((PyObject*)&Sbk_QCryptographicHash_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Algorithm
    PyTypeObject* SbkPySide_QtCore_QCryptographicHash_Algorithm = Shiboken::Enum::newType("PySide.QtCore.QCryptographicHash.Algorithm");
    SbkPySide_QtCoreTypes[SBK_QCRYPTOGRAPHICHASH_ALGORITHM_IDX] = SbkPySide_QtCore_QCryptographicHash_Algorithm;
    if (PyType_Ready(SbkPySide_QtCore_QCryptographicHash_Algorithm) < 0)
        return;
    PyDict_SetItemString(Sbk_QCryptographicHash_Type.super.ht_type.tp_dict,
            "Algorithm",((PyObject*)SbkPySide_QtCore_QCryptographicHash_Algorithm));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QCryptographicHash_Algorithm,(long) QCryptographicHash::Md4, "Md4");
    PyDict_SetItemString(Sbk_QCryptographicHash_Type.super.ht_type.tp_dict,"Md4", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QCryptographicHash_Algorithm->tp_dict,"Md4", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QCryptographicHash_Algorithm,(long) QCryptographicHash::Md5, "Md5");
    PyDict_SetItemString(Sbk_QCryptographicHash_Type.super.ht_type.tp_dict,"Md5", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QCryptographicHash_Algorithm->tp_dict,"Md5", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QCryptographicHash_Algorithm,(long) QCryptographicHash::Sha1, "Sha1");
    PyDict_SetItemString(Sbk_QCryptographicHash_Type.super.ht_type.tp_dict,"Sha1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QCryptographicHash_Algorithm->tp_dict,"Sha1", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QCryptographicHash::Algorithm");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Algorithm");
    // end of enum Algorithm


    Shiboken::TypeResolver::createObjectTypeResolver<QCryptographicHash >("QCryptographicHash*");
    Shiboken::TypeResolver::createObjectTypeResolver<QCryptographicHash >(typeid(QCryptographicHash).name());
    PySide::initQtMetaType< ::QCryptographicHash* >();
    qRegisterMetaType< ::QCryptographicHash::Algorithm >("QCryptographicHash::Algorithm");
}

