/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qreadwritelock_wrapper.h"

// Extra includes
#include <qreadwritelock.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QReadWriteLock_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QReadWriteLock >()))
        return -1;

    QReadWriteLock* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QReadWriteLock", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QReadWriteLock()
    // 1: QReadWriteLock(QReadWriteLock::RecursionMode)
    if (numArgs == 0) {
        overloadId = 0; // QReadWriteLock()
    } else if (numArgs == 1 && Shiboken::Converter< ::QReadWriteLock::RecursionMode >::isConvertible(pyargs[0])) {
        overloadId = 1; // QReadWriteLock(QReadWriteLock::RecursionMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QReadWriteLock_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QReadWriteLock()
            {

                if(!PyErr_Occurred()) {
                    // QReadWriteLock()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QReadWriteLock();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QReadWriteLock(QReadWriteLock::RecursionMode)
            {
                QReadWriteLock::RecursionMode cppArg0 = Shiboken::Converter<QReadWriteLock::RecursionMode >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QReadWriteLock(QReadWriteLock::RecursionMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QReadWriteLock(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QReadWriteLock >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QReadWriteLock_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QReadWriteLock_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QReadWriteLock.RecursionMode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QReadWriteLock", overloads);
        return -1;
}

static PyObject* Sbk_QReadWriteLockFunc_lockForRead(PyObject* self)
{
    QReadWriteLock* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QReadWriteLock* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lockForRead()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->lockForRead();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QReadWriteLockFunc_lockForWrite(PyObject* self)
{
    QReadWriteLock* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QReadWriteLock* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lockForWrite()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->lockForWrite();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QReadWriteLockFunc_tryLockForRead(PyObject* self, PyObject* args)
{
    QReadWriteLock* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QReadWriteLock* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "tryLockForRead", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: tryLockForRead()
    // 1: tryLockForRead(int)
    if (numArgs == 0) {
        overloadId = 0; // tryLockForRead()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 1; // tryLockForRead(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QReadWriteLockFunc_tryLockForRead_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // tryLockForRead()
            {

                if(!PyErr_Occurred()) {
                    // tryLockForRead()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->tryLockForRead();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // tryLockForRead(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // tryLockForRead(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->tryLockForRead(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QReadWriteLockFunc_tryLockForRead_TypeError:
        const char* overloads[] = {"", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QReadWriteLock.tryLockForRead", overloads);
        return 0;
}

static PyObject* Sbk_QReadWriteLockFunc_tryLockForWrite(PyObject* self, PyObject* args)
{
    QReadWriteLock* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QReadWriteLock* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "tryLockForWrite", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: tryLockForWrite()
    // 1: tryLockForWrite(int)
    if (numArgs == 0) {
        overloadId = 0; // tryLockForWrite()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 1; // tryLockForWrite(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QReadWriteLockFunc_tryLockForWrite_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // tryLockForWrite()
            {

                if(!PyErr_Occurred()) {
                    // tryLockForWrite()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->tryLockForWrite();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // tryLockForWrite(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // tryLockForWrite(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->tryLockForWrite(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QReadWriteLockFunc_tryLockForWrite_TypeError:
        const char* overloads[] = {"", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QReadWriteLock.tryLockForWrite", overloads);
        return 0;
}

static PyObject* Sbk_QReadWriteLockFunc_unlock(PyObject* self)
{
    QReadWriteLock* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QReadWriteLock* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // unlock()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->unlock();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_QReadWriteLock_methods[] = {
    {"lockForRead", (PyCFunction)Sbk_QReadWriteLockFunc_lockForRead, METH_NOARGS},
    {"lockForWrite", (PyCFunction)Sbk_QReadWriteLockFunc_lockForWrite, METH_NOARGS},
    {"tryLockForRead", (PyCFunction)Sbk_QReadWriteLockFunc_tryLockForRead, METH_VARARGS},
    {"tryLockForWrite", (PyCFunction)Sbk_QReadWriteLockFunc_tryLockForWrite, METH_VARARGS},
    {"unlock", (PyCFunction)Sbk_QReadWriteLockFunc_unlock, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QReadWriteLock_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QReadWriteLock",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QReadWriteLock_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QReadWriteLock_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QReadWriteLock(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QREADWRITELOCK_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QReadWriteLock_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QReadWriteLock_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QReadWriteLock_Type, &Shiboken::callCppDestructor<QReadWriteLock >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QReadWriteLock_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QReadWriteLock_Type, "QReadWriteLock*");
    PyModule_AddObject(module, "QReadWriteLock",
        ((PyObject*)&Sbk_QReadWriteLock_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: RecursionMode
    PyTypeObject* SbkPySide_QtCore_QReadWriteLock_RecursionMode = Shiboken::Enum::newType("PySide.QtCore.QReadWriteLock.RecursionMode");
    SbkPySide_QtCoreTypes[SBK_QREADWRITELOCK_RECURSIONMODE_IDX] = SbkPySide_QtCore_QReadWriteLock_RecursionMode;
    if (PyType_Ready(SbkPySide_QtCore_QReadWriteLock_RecursionMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QReadWriteLock_Type.super.ht_type.tp_dict,
            "RecursionMode",((PyObject*)SbkPySide_QtCore_QReadWriteLock_RecursionMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QReadWriteLock_RecursionMode,(long) QReadWriteLock::NonRecursive, "NonRecursive");
    PyDict_SetItemString(Sbk_QReadWriteLock_Type.super.ht_type.tp_dict,"NonRecursive", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QReadWriteLock_RecursionMode->tp_dict,"NonRecursive", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QReadWriteLock_RecursionMode,(long) QReadWriteLock::Recursive, "Recursive");
    PyDict_SetItemString(Sbk_QReadWriteLock_Type.super.ht_type.tp_dict,"Recursive", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QReadWriteLock_RecursionMode->tp_dict,"Recursive", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QReadWriteLock::RecursionMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::RecursionMode");
    // end of enum RecursionMode


    Shiboken::TypeResolver::createObjectTypeResolver<QReadWriteLock >("QReadWriteLock*");
    Shiboken::TypeResolver::createObjectTypeResolver<QReadWriteLock >(typeid(QReadWriteLock).name());
    PySide::initQtMetaType< ::QReadWriteLock* >();
    qRegisterMetaType< ::QReadWriteLock::RecursionMode >("QReadWriteLock::RecursionMode");
}

