/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtcore_python.h"

#include "qstate_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractstate.h>
#include <qabstracttransition.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsignaltransition.h>
#include <qstate.h>
#include <qstatemachine.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QStateWrapper::QStateWrapper(QState * parent) : QState(parent) {
    // ... middle
}

QStateWrapper::QStateWrapper(QState::ChildMode childMode, QState * parent) : QState(childMode, parent) {
    // ... middle
}

void QStateWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QStateWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStateWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QStateWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QStateWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QState::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QState.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QStateWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QState.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QStateWrapper::onEntry(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "onEntry"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QState::onEntry(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStateWrapper::onExit(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "onExit"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QState::onExit(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStateWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QStateWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QStateWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QState::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QStateWrapper::~QStateWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QState_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QState >()))
        return -1;

    QStateWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QState", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QState(QState*)
    // 1: QState(QState::ChildMode,QState*)
    if (numArgs == 0) {
        overloadId = 0; // QState(QState*)
    } else if (Shiboken::Converter< ::QState::ChildMode >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QState(QState::ChildMode,QState*)
        } else if (Shiboken::Converter< ::QState * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QState(QState::ChildMode,QState*)
        }
    } else if (Shiboken::Converter< ::QState * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QState(QState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QState_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QState(QState*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QState * >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QState_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QState(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QState * cppArg0 = pyargs[0] ? Shiboken::Converter<QState * >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                    // QState(QState*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStateWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QState(QState::ChildMode,QState*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QState * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QState_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QState(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QState::ChildMode cppArg0 = Shiboken::Converter<QState::ChildMode >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QState * cppArg1 = pyargs[1] ? Shiboken::Converter<QState * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // QState(QState::ChildMode,QState*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStateWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[1], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QState >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QState_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QState_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QState = None", "PySide.QtCore.QState.ChildMode, PySide.QtCore.QState = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QState", overloads);
        return -1;
}

static PyObject* Sbk_QStateFunc_addTransition(PyObject* self, PyObject* args)
{
    QState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QState* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addTransition", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addTransition(PyObject*,QAbstractState*)
    // 1: addTransition(QAbstractState*)
    // 2: addTransition(QAbstractTransition*)
    // 3: addTransition(QObject*,const char*,QAbstractState*)
    if (numArgs == 3 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< const char * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QAbstractState * >::isConvertible(pyargs[2])) {
        overloadId = 3; // addTransition(QObject*,const char*,QAbstractState*)
    } else if (numArgs == 1 && Shiboken::Converter< ::QAbstractTransition * >::isConvertible(pyargs[0])) {
        overloadId = 2; // addTransition(QAbstractTransition*)
    } else if (numArgs == 1 && Shiboken::Converter< ::QAbstractState * >::isConvertible(pyargs[0])) {
        overloadId = 1; // addTransition(QAbstractState*)
    } else if (numArgs == 2 && PyObject_Check(pyargs[0]) && Shiboken::Converter< ::QAbstractState * >::isConvertible(pyargs[1])) {
        overloadId = 0; // addTransition(PyObject*,QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateFunc_addTransition_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addTransition(PyObject*,QAbstractState*)
            {
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QAbstractState * cppArg1 = Shiboken::Converter<QAbstractState * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // addTransition(PyObject*,QAbstractState*)
                    // Begin code injection

                    // Obviously the label used by the following goto is a very awkward solution,
                    // since it refers to a name very tied to the generator implementation.
                    // Check bug #362 for more information on this
                    // http://bugs.openbossa.org/show_bug.cgi?id=362
                    if (!PyObject_TypeCheck(pyargs[0], &PySideSignalInstanceType))
                        goto Sbk_QStateFunc_addTransition_TypeError;
                    PySideSignalInstance* signalInstance = reinterpret_cast<PySideSignalInstance*>(pyargs[0]);
                    QObject* sender = Shiboken::Converter<QObject* >::toCpp(PySide::Signal::getObject(signalInstance));
                    pyResult = Shiboken::Converter<QSignalTransition* >::toPython(cppSelf->addTransition(sender, PySide::Signal::getSignature(signalInstance), cppArg1));

                    // End of code injection


                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // addTransition(QAbstractState*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QAbstractState * cppArg0 = Shiboken::Converter<QAbstractState * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // addTransition(QAbstractState*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QAbstractTransition * cppResult = cppSelf->addTransition(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QAbstractTransition * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyargs[0]);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 2: // addTransition(QAbstractTransition*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QAbstractTransition * cppArg0 = Shiboken::Converter<QAbstractTransition * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // addTransition(QAbstractTransition*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addTransition(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[0]);
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 3: // addTransition(QObject*,const char*,QAbstractState*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QAbstractState * cppArg2 = Shiboken::Converter<QAbstractState * >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // addTransition(QObject*,const char*,QAbstractState*)
                    // Begin code injection

                    QString signalName(cppArg1);
                    if (PySide::SignalManager::registerMetaMethod(cppArg0, signalName.mid(1).toAscii().data(), QMetaMethod::Signal)) {
                      pyResult = Shiboken::Converter<QSignalTransition* >::toPython(cppSelf->addTransition(cppArg0, cppArg1, cppArg2));
                    } else {
                      Py_INCREF(Py_None);
                      pyResult = Py_None;
                    }

                    // End of code injection


                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStateFunc_addTransition_TypeError:
        const char* overloads[] = {"PyObject, PySide.QtCore.QAbstractState", "PySide.QtCore.QAbstractState", "PySide.QtCore.QAbstractTransition", "PySide.QtCore.QObject, str, PySide.QtCore.QAbstractState", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QState.addTransition", overloads);
        return 0;
}

static PyObject* Sbk_QStateFunc_assignProperty(PyObject* self, PyObject* args)
{
    QState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QState* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "assignProperty", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: assignProperty(QObject*,const char*,QVariant)
    if (numArgs == 3 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< const char * >::isConvertible(pyargs[1]) && Shiboken::Converter< QVariant >::isConvertible(pyargs[2])) {
        overloadId = 0; // assignProperty(QObject*,const char*,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateFunc_assignProperty_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
            const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
            QVariant cppArg2 = Shiboken::Converter<QVariant >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // assignProperty(QObject*,const char*,QVariant)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->assignProperty(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateFunc_assignProperty_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, str, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QState.assignProperty", overloads);
        return 0;
}

static PyObject* Sbk_QStateFunc_childMode(PyObject* self)
{
    QState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // childMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QState::ChildMode cppResult = const_cast<const QState*>(cppSelf)->childMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QState::ChildMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateFunc_errorState(PyObject* self)
{
    QState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorState()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractState * cppResult = const_cast<const QState*>(cppSelf)->errorState();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractState * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateFunc_event(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QState* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QState::event(cppArg0) : cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStateFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.event", overloads);
        return 0;
}

static PyObject* Sbk_QStateFunc_initialState(PyObject* self)
{
    QState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // initialState()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractState * cppResult = const_cast<const QState*>(cppSelf)->initialState();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractState * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateFunc_onEntry(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: onEntry(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // onEntry(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateFunc_onEntry_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // onEntry(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QState::onEntry(cppArg0) : cppSelf->onEntry(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateFunc_onEntry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.onEntry", overloads);
        return 0;
}

static PyObject* Sbk_QStateFunc_onExit(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: onExit(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // onExit(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateFunc_onExit_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // onExit(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QState::onExit(cppArg0) : cppSelf->onExit(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateFunc_onExit_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.onExit", overloads);
        return 0;
}

static PyObject* Sbk_QStateFunc_removeTransition(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeTransition(QAbstractTransition*)
    if (Shiboken::Converter< ::QAbstractTransition * >::isConvertible(arg)) {
        overloadId = 0; // removeTransition(QAbstractTransition*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateFunc_removeTransition_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractTransition * cppArg0 = Shiboken::Converter<QAbstractTransition * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeTransition(QAbstractTransition*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeTransition(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(Py_None, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateFunc_removeTransition_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractTransition", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.removeTransition", overloads);
        return 0;
}

static PyObject* Sbk_QStateFunc_setChildMode(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setChildMode(QState::ChildMode)
    if (Shiboken::Converter< ::QState::ChildMode >::isConvertible(arg)) {
        overloadId = 0; // setChildMode(QState::ChildMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateFunc_setChildMode_TypeError;

    // Call function/method
    {
        {
            QState::ChildMode cppArg0 = Shiboken::Converter<QState::ChildMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setChildMode(QState::ChildMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setChildMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateFunc_setChildMode_TypeError:
        const char* overloads[] = {"PySide.QtCore.QState.ChildMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.setChildMode", overloads);
        return 0;
}

static PyObject* Sbk_QStateFunc_setErrorState(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setErrorState(QAbstractState*)
    if (Shiboken::Converter< ::QAbstractState * >::isConvertible(arg)) {
        overloadId = 0; // setErrorState(QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateFunc_setErrorState_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractState * cppArg0 = Shiboken::Converter<QAbstractState * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setErrorState(QAbstractState*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setErrorState(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateFunc_setErrorState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.setErrorState", overloads);
        return 0;
}

static PyObject* Sbk_QStateFunc_setInitialState(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInitialState(QAbstractState*)
    if (Shiboken::Converter< ::QAbstractState * >::isConvertible(arg)) {
        overloadId = 0; // setInitialState(QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateFunc_setInitialState_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractState * cppArg0 = Shiboken::Converter<QAbstractState * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setInitialState(QAbstractState*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setInitialState(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateFunc_setInitialState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.setInitialState", overloads);
        return 0;
}

static PyMethodDef Sbk_QState_methods[] = {
    {"addTransition", (PyCFunction)Sbk_QStateFunc_addTransition, METH_VARARGS},
    {"assignProperty", (PyCFunction)Sbk_QStateFunc_assignProperty, METH_VARARGS},
    {"childMode", (PyCFunction)Sbk_QStateFunc_childMode, METH_NOARGS},
    {"errorState", (PyCFunction)Sbk_QStateFunc_errorState, METH_NOARGS},
    {"event", (PyCFunction)Sbk_QStateFunc_event, METH_O},
    {"initialState", (PyCFunction)Sbk_QStateFunc_initialState, METH_NOARGS},
    {"onEntry", (PyCFunction)Sbk_QStateFunc_onEntry, METH_O},
    {"onExit", (PyCFunction)Sbk_QStateFunc_onExit, METH_O},
    {"removeTransition", (PyCFunction)Sbk_QStateFunc_removeTransition, METH_O},
    {"setChildMode", (PyCFunction)Sbk_QStateFunc_setChildMode, METH_O},
    {"setErrorState", (PyCFunction)Sbk_QStateFunc_setErrorState, METH_O},
    {"setInitialState", (PyCFunction)Sbk_QStateFunc_setInitialState, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QState_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QState",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QState_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QState_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QState_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QState*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QState_Type;
    return 0;
}


void init_QState(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QSTATE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QState_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QState_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QState_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QState_Type, &QState::staticMetaObject);    Sbk_QState_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QABSTRACTSTATE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QState_Type, &Shiboken::callCppDestructor<QState >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QState_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QState_Type, &Sbk_QState_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTSTATE_IDX]), &Sbk_QState_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QState_Type, "QState*");
    PyModule_AddObject(module, "QState",
        ((PyObject*)&Sbk_QState_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ChildMode
    PyTypeObject* SbkPySide_QtCore_QState_ChildMode = Shiboken::Enum::newType("PySide.QtCore.QState.ChildMode");
    SbkPySide_QtCoreTypes[SBK_QSTATE_CHILDMODE_IDX] = SbkPySide_QtCore_QState_ChildMode;
    if (PyType_Ready(SbkPySide_QtCore_QState_ChildMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QState_Type.super.ht_type.tp_dict,
            "ChildMode",((PyObject*)SbkPySide_QtCore_QState_ChildMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QState_ChildMode,(long) QState::ExclusiveStates, "ExclusiveStates");
    PyDict_SetItemString(Sbk_QState_Type.super.ht_type.tp_dict,"ExclusiveStates", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QState_ChildMode->tp_dict,"ExclusiveStates", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QState_ChildMode,(long) QState::ParallelStates, "ParallelStates");
    PyDict_SetItemString(Sbk_QState_Type.super.ht_type.tp_dict,"ParallelStates", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QState_ChildMode->tp_dict,"ParallelStates", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QState::ChildMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ChildMode");
    // end of enum ChildMode

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("propertiesAssigned", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QState_Type, "propertiesAssigned", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("finished", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QState_Type, "finished", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QState >("QState*");
    Shiboken::TypeResolver::createObjectTypeResolver<QState >(typeid(QState).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QState >(typeid(QStateWrapper).name());
    PySide::initQtMetaType< ::QState* >();
    qRegisterMetaType< ::QState::ChildMode >("QState::ChildMode");
}

