/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qtextboundaryfinder_wrapper.h"

// Extra includes
#include <qtextboundaryfinder.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextBoundaryFinder_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextBoundaryFinder >()))
        return -1;

    QTextBoundaryFinder* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextBoundaryFinder", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QTextBoundaryFinder()
    // 1: QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType,QString)
    // 2: QTextBoundaryFinder(QTextBoundaryFinder)
    if (numArgs == 0) {
        overloadId = 0; // QTextBoundaryFinder()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextBoundaryFinder >::isConvertible(pyargs[0])) {
        overloadId = 2; // QTextBoundaryFinder(QTextBoundaryFinder)
    } else if (numArgs == 2 && Shiboken::Converter< ::QTextBoundaryFinder::BoundaryType >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 1; // QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBoundaryFinder_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextBoundaryFinder()
            {

                if(!PyErr_Occurred()) {
                    // QTextBoundaryFinder()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextBoundaryFinder();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType,QString)
            {
                QTextBoundaryFinder::BoundaryType cppArg0 = Shiboken::Converter<QTextBoundaryFinder::BoundaryType >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextBoundaryFinder(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QTextBoundaryFinder(QTextBoundaryFinder)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextBoundaryFinder cppArg0 = Shiboken::Converter<QTextBoundaryFinder >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextBoundaryFinder(QTextBoundaryFinder)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextBoundaryFinder(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextBoundaryFinder >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextBoundaryFinder_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextBoundaryFinder_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QTextBoundaryFinder.BoundaryType, QString", "PySide.QtCore.QTextBoundaryFinder", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTextBoundaryFinder", overloads);
        return -1;
}

static PyObject* Sbk_QTextBoundaryFinderFunc_boundaryReasons(PyObject* self)
{
    QTextBoundaryFinder* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBoundaryFinder* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // boundaryReasons()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QTextBoundaryFinder::BoundaryReason> cppResult = const_cast<const QTextBoundaryFinder*>(cppSelf)->boundaryReasons();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QTextBoundaryFinder::BoundaryReason> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBoundaryFinderFunc_isAtBoundary(PyObject* self)
{
    QTextBoundaryFinder* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBoundaryFinder* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isAtBoundary()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextBoundaryFinder*>(cppSelf)->isAtBoundary();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBoundaryFinderFunc_isValid(PyObject* self)
{
    QTextBoundaryFinder* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBoundaryFinder* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextBoundaryFinder*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBoundaryFinderFunc_position(PyObject* self)
{
    QTextBoundaryFinder* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBoundaryFinder* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // position()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextBoundaryFinder*>(cppSelf)->position();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBoundaryFinderFunc_setPosition(PyObject* self, PyObject* arg)
{
    QTextBoundaryFinder* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBoundaryFinder* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPosition(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPosition(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBoundaryFinderFunc_setPosition_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPosition(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPosition(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextBoundaryFinderFunc_setPosition_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextBoundaryFinder.setPosition", overloads);
        return 0;
}

static PyObject* Sbk_QTextBoundaryFinderFunc_string(PyObject* self)
{
    QTextBoundaryFinder* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBoundaryFinder* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // string()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextBoundaryFinder*>(cppSelf)->string();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBoundaryFinderFunc_toEnd(PyObject* self)
{
    QTextBoundaryFinder* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBoundaryFinder* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toEnd()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->toEnd();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextBoundaryFinderFunc_toNextBoundary(PyObject* self)
{
    QTextBoundaryFinder* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBoundaryFinder* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toNextBoundary()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->toNextBoundary();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBoundaryFinderFunc_toPreviousBoundary(PyObject* self)
{
    QTextBoundaryFinder* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBoundaryFinder* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toPreviousBoundary()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->toPreviousBoundary();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBoundaryFinderFunc_toStart(PyObject* self)
{
    QTextBoundaryFinder* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBoundaryFinder* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toStart()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->toStart();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextBoundaryFinderFunc_type(PyObject* self)
{
    QTextBoundaryFinder* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBoundaryFinder* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // type()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextBoundaryFinder::BoundaryType cppResult = const_cast<const QTextBoundaryFinder*>(cppSelf)->type();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextBoundaryFinder::BoundaryType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QTextBoundaryFinder___copy__(PyObject *self)
{
        QTextBoundaryFinder* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextBoundaryFinder*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextBoundaryFinder* copy = new QTextBoundaryFinder(*cppSelf);
        pyResult = Shiboken::Converter<QTextBoundaryFinder*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextBoundaryFinder_methods[] = {
    {"boundaryReasons", (PyCFunction)Sbk_QTextBoundaryFinderFunc_boundaryReasons, METH_NOARGS},
    {"isAtBoundary", (PyCFunction)Sbk_QTextBoundaryFinderFunc_isAtBoundary, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QTextBoundaryFinderFunc_isValid, METH_NOARGS},
    {"position", (PyCFunction)Sbk_QTextBoundaryFinderFunc_position, METH_NOARGS},
    {"setPosition", (PyCFunction)Sbk_QTextBoundaryFinderFunc_setPosition, METH_O},
    {"string", (PyCFunction)Sbk_QTextBoundaryFinderFunc_string, METH_NOARGS},
    {"toEnd", (PyCFunction)Sbk_QTextBoundaryFinderFunc_toEnd, METH_NOARGS},
    {"toNextBoundary", (PyCFunction)Sbk_QTextBoundaryFinderFunc_toNextBoundary, METH_NOARGS},
    {"toPreviousBoundary", (PyCFunction)Sbk_QTextBoundaryFinderFunc_toPreviousBoundary, METH_NOARGS},
    {"toStart", (PyCFunction)Sbk_QTextBoundaryFinderFunc_toStart, METH_NOARGS},
    {"type", (PyCFunction)Sbk_QTextBoundaryFinderFunc_type, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTextBoundaryFinder___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextBoundaryFinder_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QTextBoundaryFinder",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextBoundaryFinder_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextBoundaryFinder_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextBoundaryFinder::BoundaryReasons >::toPython(
        Shiboken::Converter<QTextBoundaryFinder::BoundaryReasons>::toCpp(self)
        & Shiboken::Converter< QTextBoundaryFinder::BoundaryReasons >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextBoundaryFinder::BoundaryReasons >::toPython(
        Shiboken::Converter<QTextBoundaryFinder::BoundaryReasons>::toCpp(self)
        | Shiboken::Converter< QTextBoundaryFinder::BoundaryReasons >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextBoundaryFinder::BoundaryReasons >::toPython(
        Shiboken::Converter<QTextBoundaryFinder::BoundaryReasons>::toCpp(self)
        ^ Shiboken::Converter< QTextBoundaryFinder::BoundaryReasons >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextBoundaryFinder::BoundaryReasons >::toPython(
        ~Shiboken::Converter<QTextBoundaryFinder::BoundaryReasons >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReasons_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "BoundaryReasons",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QTextBoundaryFinder(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QTEXTBOUNDARYFINDER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextBoundaryFinder_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextBoundaryFinder_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextBoundaryFinder_Type, &Shiboken::callCppDestructor<QTextBoundaryFinder >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextBoundaryFinder_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextBoundaryFinder_Type, "QTextBoundaryFinder");
    PyModule_AddObject(module, "QTextBoundaryFinder",
        ((PyObject*)&Sbk_QTextBoundaryFinder_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: BoundaryReason
    PyTypeObject* SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason = Shiboken::Enum::newType("PySide.QtCore.QTextBoundaryFinder.BoundaryReason");
    SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason->tp_as_number = &SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason_as_number;
    SbkPySide_QtCoreTypes[SBK_QTEXTBOUNDARYFINDER_BOUNDARYREASON_IDX] = SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason;
    if (PyType_Ready(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextBoundaryFinder_Type.super.ht_type.tp_dict,
            "BoundaryReason",((PyObject*)SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason));

    // init flags class: QFlags<QTextBoundaryFinder::BoundaryReason>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QTEXTBOUNDARYFINDER_BOUNDARYREASON__IDX] = &SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReasons_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReasons_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextBoundaryFinder_Type.super.ht_type.tp_dict,
            "BoundaryReasons",((PyObject*)&SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReasons_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason,(long) QTextBoundaryFinder::NotAtBoundary, "NotAtBoundary");
    PyDict_SetItemString(Sbk_QTextBoundaryFinder_Type.super.ht_type.tp_dict,"NotAtBoundary", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason->tp_dict,"NotAtBoundary", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason,(long) QTextBoundaryFinder::StartWord, "StartWord");
    PyDict_SetItemString(Sbk_QTextBoundaryFinder_Type.super.ht_type.tp_dict,"StartWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason->tp_dict,"StartWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason,(long) QTextBoundaryFinder::EndWord, "EndWord");
    PyDict_SetItemString(Sbk_QTextBoundaryFinder_Type.super.ht_type.tp_dict,"EndWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryReason->tp_dict,"EndWord", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextBoundaryFinder::BoundaryReason");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::BoundaryReason");
    // end of enum BoundaryReason

    // init enum: BoundaryType
    PyTypeObject* SbkPySide_QtCore_QTextBoundaryFinder_BoundaryType = Shiboken::Enum::newType("PySide.QtCore.QTextBoundaryFinder.BoundaryType");
    SbkPySide_QtCoreTypes[SBK_QTEXTBOUNDARYFINDER_BOUNDARYTYPE_IDX] = SbkPySide_QtCore_QTextBoundaryFinder_BoundaryType;
    if (PyType_Ready(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryType) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextBoundaryFinder_Type.super.ht_type.tp_dict,
            "BoundaryType",((PyObject*)SbkPySide_QtCore_QTextBoundaryFinder_BoundaryType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryType,(long) QTextBoundaryFinder::Grapheme, "Grapheme");
    PyDict_SetItemString(Sbk_QTextBoundaryFinder_Type.super.ht_type.tp_dict,"Grapheme", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryType->tp_dict,"Grapheme", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryType,(long) QTextBoundaryFinder::Word, "Word");
    PyDict_SetItemString(Sbk_QTextBoundaryFinder_Type.super.ht_type.tp_dict,"Word", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryType->tp_dict,"Word", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryType,(long) QTextBoundaryFinder::Line, "Line");
    PyDict_SetItemString(Sbk_QTextBoundaryFinder_Type.super.ht_type.tp_dict,"Line", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryType->tp_dict,"Line", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryType,(long) QTextBoundaryFinder::Sentence, "Sentence");
    PyDict_SetItemString(Sbk_QTextBoundaryFinder_Type.super.ht_type.tp_dict,"Sentence", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextBoundaryFinder_BoundaryType->tp_dict,"Sentence", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextBoundaryFinder::BoundaryType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::BoundaryType");
    // end of enum BoundaryType


    Shiboken::TypeResolver::createValueTypeResolver<QTextBoundaryFinder >("QTextBoundaryFinder");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextBoundaryFinder >("QTextBoundaryFinder*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextBoundaryFinder >(typeid(QTextBoundaryFinder).name());
    PySide::initQtMetaType< ::QTextBoundaryFinder >();
    qRegisterMetaType< ::QTextBoundaryFinder::BoundaryReason >("QTextBoundaryFinder::BoundaryReason");
    qRegisterMetaType< ::QTextBoundaryFinder::BoundaryReasons >("QTextBoundaryFinder::BoundaryReasons");
    qRegisterMetaType< ::QTextBoundaryFinder::BoundaryType >("QTextBoundaryFinder::BoundaryType");
}

