/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qxmlstreamattributes_wrapper.h"

// Extra includes
#include <QVector>
#include <qxmlstream.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlStreamAttributes_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlStreamAttributes >()))
        return -1;

    QXmlStreamAttributes* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlStreamAttributes", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlStreamAttributes()
    // 1: QXmlStreamAttributes(QXmlStreamAttributes)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamAttributes()
    } else if (numArgs == 1 && Shiboken::Converter< ::QXmlStreamAttributes >::isConvertible(pyargs[0])) {
        overloadId = 1; // QXmlStreamAttributes(QXmlStreamAttributes)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributes_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlStreamAttributes()
            {

                if(!PyErr_Occurred()) {
                    // QXmlStreamAttributes()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlStreamAttributes();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QXmlStreamAttributes(QXmlStreamAttributes)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QXmlStreamAttributes cppArg0 = Shiboken::Converter<QXmlStreamAttributes >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QXmlStreamAttributes(QXmlStreamAttributes)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlStreamAttributes(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlStreamAttributes >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QXmlStreamAttributes_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QXmlStreamAttributes_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QXmlStreamAttributes", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes", overloads);
        return -1;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_append(PyObject* self, PyObject* args)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "append", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: append(QString,QString,QString)
    // 1: append(QString,QString)
    // 2: append(QXmlStreamAttribute)
    if (numArgs == 1 && Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(pyargs[0])) {
        overloadId = 2; // append(QXmlStreamAttribute)
    } else if (numArgs >= 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // append(QString,QString)
        } else if (numArgs == 3 && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
            overloadId = 0; // append(QString,QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_append_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // append(QString,QString,QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // append(QString,QString,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->append(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // append(QString,QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // append(QString,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->append(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // append(QXmlStreamAttribute)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QXmlStreamAttribute cppArg0 = Shiboken::Converter<QXmlStreamAttribute >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // append(QXmlStreamAttribute)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->append(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamAttributesFunc_append_TypeError:
        const char* overloads[] = {"QString, QString, QString", "QString, QString", "PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.append", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_capacity(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // capacity()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->capacity();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_clear(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_constData(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // constData()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QXmlStreamAttribute * cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->constData();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlStreamAttribute * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_count(PyObject* self, PyObject* args)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "count", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: count()const
    // 1: count(QXmlStreamAttribute)const
    if (numArgs == 0) {
        overloadId = 0; // count()const
    } else if (numArgs == 1 && Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(pyargs[0])) {
        overloadId = 1; // count(QXmlStreamAttribute)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_count_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // count()const
            {

                if(!PyErr_Occurred()) {
                    // count()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->count();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // count(QXmlStreamAttribute)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QXmlStreamAttribute cppArg0 = Shiboken::Converter<QXmlStreamAttribute >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // count(QXmlStreamAttribute)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->count(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamAttributesFunc_count_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.count", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_data(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // data()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlStreamAttribute * cppResult = cppSelf->data();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlStreamAttribute * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_empty(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // empty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->empty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_endsWith(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: endsWith(QXmlStreamAttribute)const
    if (Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(arg)) {
        overloadId = 0; // endsWith(QXmlStreamAttribute)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_endsWith_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlStreamAttribute cppArg0 = Shiboken::Converter<QXmlStreamAttribute >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // endsWith(QXmlStreamAttribute)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->endsWith(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamAttributesFunc_endsWith_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.endsWith", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_erase(PyObject* self, PyObject* args)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "erase", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: erase(QXmlStreamAttribute*,QXmlStreamAttribute*)
    if (numArgs == 2 && Shiboken::Converter< ::QXmlStreamAttribute * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QXmlStreamAttribute * >::isConvertible(pyargs[1])) {
        overloadId = 0; // erase(QXmlStreamAttribute*,QXmlStreamAttribute*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_erase_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QXmlStreamAttribute * cppArg0 = Shiboken::Converter<QXmlStreamAttribute * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QXmlStreamAttribute * cppArg1 = Shiboken::Converter<QXmlStreamAttribute * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // erase(QXmlStreamAttribute*,QXmlStreamAttribute*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlStreamAttribute * cppResult = cppSelf->erase(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlStreamAttribute * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamAttributesFunc_erase_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttribute, PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.erase", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_first(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // first()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlStreamAttribute & cppResult = cppSelf->first();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlStreamAttribute & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_front(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // front()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlStreamAttribute & cppResult = cppSelf->front();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlStreamAttribute & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_hasAttribute(PyObject* self, PyObject* args)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "hasAttribute", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: hasAttribute(QString,QString)const
    // 1: hasAttribute(QString)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // hasAttribute(QString)const
        } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // hasAttribute(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_hasAttribute_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // hasAttribute(QString,QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // hasAttribute(QString,QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->hasAttribute(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // hasAttribute(QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // hasAttribute(QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->hasAttribute(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamAttributesFunc_hasAttribute_TypeError:
        const char* overloads[] = {"QString, QString", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.hasAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_indexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.indexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.indexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:indexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: indexOf(QXmlStreamAttribute,int)const
    if (Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexOf(QXmlStreamAttribute,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // indexOf(QXmlStreamAttribute,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_indexOf_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QXmlStreamAttributesFunc_indexOf_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.indexOf(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QXmlStreamAttribute cppArg0 = Shiboken::Converter<QXmlStreamAttribute >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // indexOf(QXmlStreamAttribute,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->indexOf(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamAttributesFunc_indexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttribute, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.indexOf", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_insert(PyObject* self, PyObject* args)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insert", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: insert(QXmlStreamAttribute*,int,QXmlStreamAttribute)
    // 1: insert(int,QXmlStreamAttribute)
    // 2: insert(int,int,QXmlStreamAttribute)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(pyargs[2])) {
            overloadId = 2; // insert(int,int,QXmlStreamAttribute)
        } else if (numArgs == 2 && Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(pyargs[1])) {
            overloadId = 1; // insert(int,QXmlStreamAttribute)
        }
    } else if (numArgs == 3 && Shiboken::Converter< ::QXmlStreamAttribute * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(pyargs[2])) {
        overloadId = 0; // insert(QXmlStreamAttribute*,int,QXmlStreamAttribute)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_insert_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insert(QXmlStreamAttribute*,int,QXmlStreamAttribute)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QXmlStreamAttribute * cppArg0 = Shiboken::Converter<QXmlStreamAttribute * >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QXmlStreamAttribute cppArg2 = Shiboken::Converter<QXmlStreamAttribute >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // insert(QXmlStreamAttribute*,int,QXmlStreamAttribute)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QXmlStreamAttribute * cppResult = cppSelf->insert(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QXmlStreamAttribute * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // insert(int,QXmlStreamAttribute)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QXmlStreamAttribute cppArg1 = Shiboken::Converter<QXmlStreamAttribute >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // insert(int,QXmlStreamAttribute)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insert(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 2: // insert(int,int,QXmlStreamAttribute)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QXmlStreamAttribute cppArg2 = Shiboken::Converter<QXmlStreamAttribute >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // insert(int,int,QXmlStreamAttribute)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insert(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamAttributesFunc_insert_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttribute, int, PySide.QtCore.QXmlStreamAttribute", "int, PySide.QtCore.QXmlStreamAttribute", "int, int, PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.insert", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_isEmpty(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_last(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // last()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlStreamAttribute & cppResult = cppSelf->last();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlStreamAttribute & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_lastIndexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.lastIndexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.lastIndexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:lastIndexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: lastIndexOf(QXmlStreamAttribute,int)const
    if (Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // lastIndexOf(QXmlStreamAttribute,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // lastIndexOf(QXmlStreamAttribute,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_lastIndexOf_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QXmlStreamAttributesFunc_lastIndexOf_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.lastIndexOf(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QXmlStreamAttribute cppArg0 = Shiboken::Converter<QXmlStreamAttribute >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
                // lastIndexOf(QXmlStreamAttribute,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->lastIndexOf(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamAttributesFunc_lastIndexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttribute, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.lastIndexOf", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_prepend(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: prepend(QXmlStreamAttribute)
    if (Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(arg)) {
        overloadId = 0; // prepend(QXmlStreamAttribute)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_prepend_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlStreamAttribute cppArg0 = Shiboken::Converter<QXmlStreamAttribute >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // prepend(QXmlStreamAttribute)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->prepend(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamAttributesFunc_prepend_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.prepend", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_remove(PyObject* self, PyObject* args)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "remove", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: remove(int)
    // 1: remove(int,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // remove(int)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // remove(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_remove_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // remove(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // remove(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->remove(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // remove(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // remove(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->remove(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamAttributesFunc_remove_TypeError:
        const char* overloads[] = {"int", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.remove", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_replace(PyObject* self, PyObject* args)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replace", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: replace(int,QXmlStreamAttribute)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(pyargs[1])) {
        overloadId = 0; // replace(int,QXmlStreamAttribute)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_replace_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QXmlStreamAttribute cppArg1 = Shiboken::Converter<QXmlStreamAttribute >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // replace(int,QXmlStreamAttribute)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->replace(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamAttributesFunc_replace_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.replace", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_reserve(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: reserve(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // reserve(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_reserve_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // reserve(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->reserve(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamAttributesFunc_reserve_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.reserve", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_resize(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // resize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_resize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // resize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamAttributesFunc_resize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.resize", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_setSharable(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSharable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSharable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_setSharable_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSharable(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSharable(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamAttributesFunc_setSharable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.setSharable", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_size(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_squeeze(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // squeeze()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->squeeze();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_startsWith(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: startsWith(QXmlStreamAttribute)const
    if (Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(arg)) {
        overloadId = 0; // startsWith(QXmlStreamAttribute)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_startsWith_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlStreamAttribute cppArg0 = Shiboken::Converter<QXmlStreamAttribute >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // startsWith(QXmlStreamAttribute)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->startsWith(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamAttributesFunc_startsWith_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.startsWith", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc_value(PyObject* self, PyObject* args)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "value", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: value(QString,QString)const
    // 1: value(QString)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // value(QString)const
        } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // value(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc_value_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // value(QString,QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // value(QString,QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QStringRef cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->value(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
                }
                break;
            }
            case 1: // value(QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // value(QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QStringRef cppResult = const_cast<const QXmlStreamAttributes*>(cppSelf)->value(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamAttributesFunc_value_TypeError:
        const char* overloads[] = {"QString, QString", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.value", overloads);
        return 0;
}

static PyObject *Sbk_QXmlStreamAttributes___copy__(PyObject *self)
{
        QXmlStreamAttributes* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QXmlStreamAttributes*>::toCpp(self);
        PyObject* pyResult = 0;
        QXmlStreamAttributes* copy = new QXmlStreamAttributes(*cppSelf);
        pyResult = Shiboken::Converter<QXmlStreamAttributes*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QXmlStreamAttributes_methods[] = {
    {"append", (PyCFunction)Sbk_QXmlStreamAttributesFunc_append, METH_VARARGS},
    {"capacity", (PyCFunction)Sbk_QXmlStreamAttributesFunc_capacity, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QXmlStreamAttributesFunc_clear, METH_NOARGS},
    {"constData", (PyCFunction)Sbk_QXmlStreamAttributesFunc_constData, METH_NOARGS},
    {"count", (PyCFunction)Sbk_QXmlStreamAttributesFunc_count, METH_VARARGS},
    {"data", (PyCFunction)Sbk_QXmlStreamAttributesFunc_data, METH_NOARGS},
    {"empty", (PyCFunction)Sbk_QXmlStreamAttributesFunc_empty, METH_NOARGS},
    {"endsWith", (PyCFunction)Sbk_QXmlStreamAttributesFunc_endsWith, METH_O},
    {"erase", (PyCFunction)Sbk_QXmlStreamAttributesFunc_erase, METH_VARARGS},
    {"first", (PyCFunction)Sbk_QXmlStreamAttributesFunc_first, METH_NOARGS},
    {"front", (PyCFunction)Sbk_QXmlStreamAttributesFunc_front, METH_NOARGS},
    {"hasAttribute", (PyCFunction)Sbk_QXmlStreamAttributesFunc_hasAttribute, METH_VARARGS},
    {"indexOf", (PyCFunction)Sbk_QXmlStreamAttributesFunc_indexOf, METH_VARARGS|METH_KEYWORDS},
    {"insert", (PyCFunction)Sbk_QXmlStreamAttributesFunc_insert, METH_VARARGS},
    {"isEmpty", (PyCFunction)Sbk_QXmlStreamAttributesFunc_isEmpty, METH_NOARGS},
    {"last", (PyCFunction)Sbk_QXmlStreamAttributesFunc_last, METH_NOARGS},
    {"lastIndexOf", (PyCFunction)Sbk_QXmlStreamAttributesFunc_lastIndexOf, METH_VARARGS|METH_KEYWORDS},
    {"prepend", (PyCFunction)Sbk_QXmlStreamAttributesFunc_prepend, METH_O},
    {"remove", (PyCFunction)Sbk_QXmlStreamAttributesFunc_remove, METH_VARARGS},
    {"replace", (PyCFunction)Sbk_QXmlStreamAttributesFunc_replace, METH_VARARGS},
    {"reserve", (PyCFunction)Sbk_QXmlStreamAttributesFunc_reserve, METH_O},
    {"resize", (PyCFunction)Sbk_QXmlStreamAttributesFunc_resize, METH_O},
    {"setSharable", (PyCFunction)Sbk_QXmlStreamAttributesFunc_setSharable, METH_O},
    {"size", (PyCFunction)Sbk_QXmlStreamAttributesFunc_size, METH_NOARGS},
    {"squeeze", (PyCFunction)Sbk_QXmlStreamAttributesFunc_squeeze, METH_NOARGS},
    {"startsWith", (PyCFunction)Sbk_QXmlStreamAttributesFunc_startsWith, METH_O},
    {"value", (PyCFunction)Sbk_QXmlStreamAttributesFunc_value, METH_VARARGS},

    {"__copy__", (PyCFunction)Sbk_QXmlStreamAttributes___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QXmlStreamAttributesFunc___add__(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QXmlStreamAttributes >::checkType(arg) && !Shiboken::Converter< ::QXmlStreamAttributes >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QVector<QXmlStreamAttribute>)const
    if (!isReverse && Shiboken::Converter< ::QVector<QXmlStreamAttribute > >::isConvertible(arg)) {
        overloadId = 0; // operator+(QVector<QXmlStreamAttribute>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc___add___TypeError;

    // Call function/method
    {
        {
            QVector<QXmlStreamAttribute > cppArg0 = Shiboken::Converter<QVector<QXmlStreamAttribute > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+(QVector<QXmlStreamAttribute>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QXmlStreamAttribute > cppResult = (*cppSelf) + cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QXmlStreamAttribute > >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamAttributesFunc___add___TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.__add__", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc___iadd__(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QXmlStreamAttributes >::checkType(arg) && !Shiboken::Converter< ::QXmlStreamAttributes >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QVector<QXmlStreamAttribute>)
    // 1: operator+=(QXmlStreamAttribute)
    if (!isReverse && Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(arg)) {
        overloadId = 1; // operator+=(QXmlStreamAttribute)
    } else if (!isReverse && Shiboken::Converter< ::QVector<QXmlStreamAttribute > >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QVector<QXmlStreamAttribute>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc___iadd___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator+=(QVector<QXmlStreamAttribute>)
            {
                QVector<QXmlStreamAttribute > cppArg0 = Shiboken::Converter<QVector<QXmlStreamAttribute > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator+=(QVector<QXmlStreamAttribute>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (*cppSelf) += cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // operator+=(QXmlStreamAttribute)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QXmlStreamAttribute cppArg0 = Shiboken::Converter<QXmlStreamAttribute >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator+=(QXmlStreamAttribute)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (*cppSelf) += (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QXmlStreamAttributesFunc___iadd___TypeError:
        const char* overloads[] = {"list", "PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.__iadd__", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamAttributesFunc___lshift__(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QXmlStreamAttributes >::checkType(arg) && !Shiboken::Converter< ::QXmlStreamAttributes >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QVector<QXmlStreamAttribute>)
    // 1: operator<<(QXmlStreamAttribute)
    if (!isReverse && Shiboken::Converter< ::QXmlStreamAttribute >::isConvertible(arg)) {
        overloadId = 1; // operator<<(QXmlStreamAttribute)
    } else if (!isReverse && Shiboken::Converter< ::QVector<QXmlStreamAttribute > >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QVector<QXmlStreamAttribute>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamAttributesFunc___lshift___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator<<(QVector<QXmlStreamAttribute>)
            {
                QVector<QXmlStreamAttribute > cppArg0 = Shiboken::Converter<QVector<QXmlStreamAttribute > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QVector<QXmlStreamAttribute>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVector<QXmlStreamAttribute > & cppResult = (*cppSelf) << cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector<QXmlStreamAttribute > >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator<<(QXmlStreamAttribute)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QXmlStreamAttribute cppArg0 = Shiboken::Converter<QXmlStreamAttribute >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QXmlStreamAttribute)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVector<QXmlStreamAttribute > & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector<QXmlStreamAttribute > >::toPython(cppResult);
                }
                break;
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamAttributesFunc___lshift___TypeError:
        const char* overloads[] = {"list", "PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.__lshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QXmlStreamAttributes_as_number = {
    /*nb_add*/                  (binaryfunc)Sbk_QXmlStreamAttributesFunc___add__,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QXmlStreamAttributesFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)Sbk_QXmlStreamAttributesFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

Py_ssize_t Sbk_QXmlStreamAttributes__len__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;

    QXmlStreamAttributes &cppSelf = Shiboken::Converter<QXmlStreamAttributes& >::toCpp(self);
    return cppSelf.size();
}
PyObject* Sbk_QXmlStreamAttributes__getitem__(PyObject* self, Py_ssize_t _i)
{
    if (!Shiboken::Object::isValid(self))
        return 0;

    QXmlStreamAttributes &cppSelf = Shiboken::Converter<QXmlStreamAttributes& >::toCpp(self);
    if (_i < 0 || _i >= (Py_ssize_t) cppSelf.size()) {
        PyErr_SetString(PyExc_IndexError, "index out of bounds");
        return 0;
    }
    QXmlStreamAttributes::iterator _item = cppSelf.begin();
    for(Py_ssize_t pos=0; pos < _i; pos++) _item++;
    return Shiboken::Converter<QXmlStreamAttributes::value_type>::toPython(*_item);
}
int Sbk_QXmlStreamAttributes__setitem__(PyObject* self, Py_ssize_t _i, PyObject* _value)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    QXmlStreamAttributes &cppSelf = Shiboken::Converter<QXmlStreamAttributes& >::toCpp(self);
    if (_i < 0 || _i >= (Py_ssize_t) cppSelf.size()) {
        PyErr_SetString(PyExc_IndexError, "list assignment index out of range");
        return -1;
    }
    QXmlStreamAttributes::iterator _item = cppSelf.begin();
    for(Py_ssize_t pos=0; pos < _i; pos++) _item++;
    QXmlStreamAttributes::value_type cppValue = Shiboken::Converter<QXmlStreamAttributes::value_type>::toCpp(_value);
    *_item = cppValue;
    return 0;
}
static PySequenceMethods PyQXmlStreamAttributes_as_sequence = {
    /*sq_length*/ Sbk_QXmlStreamAttributes__len__,
    /*sq_concat*/ 0,
    /*sq_repeat*/ 0,
    /*sq_item*/ Sbk_QXmlStreamAttributes__getitem__,
    /*sq_slice*/ 0,
    /*sq_ass_item*/ Sbk_QXmlStreamAttributes__setitem__,
    /*sq_ass_slice*/ 0,
    /*sq_contains*/ 0,
    /*sq_inplace_concat*/ 0,
    /*sq_inplace_repeat*/ 0
};

// Rich comparison
static PyObject* Sbk_QXmlStreamAttributes_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QXmlStreamAttributes& cppSelf = *Shiboken::Converter< QXmlStreamAttributes* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QVector<QXmlStreamAttribute > >::isConvertible(arg)) {
                // operator!=(const QVector<QXmlStreamAttribute > & v) const
                QVector<QXmlStreamAttribute > cppArg0 = Shiboken::Converter< ::QVector<QXmlStreamAttribute > >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QXmlStreamAttributes_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QVector<QXmlStreamAttribute > >::isConvertible(arg)) {
                // operator==(const QVector<QXmlStreamAttribute > & v) const
                QVector<QXmlStreamAttribute > cppArg0 = Shiboken::Converter< ::QVector<QXmlStreamAttribute > >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QXmlStreamAttributes_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QXmlStreamAttributes_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QXmlStreamAttributes_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlStreamAttributes_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QXmlStreamAttributes",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QXmlStreamAttributes_as_number,
    /*tp_as_sequence*/      &PyQXmlStreamAttributes_as_sequence,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QXmlStreamAttributes_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlStreamAttributes_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlStreamAttributes_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QXmlStreamAttributes(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMATTRIBUTES_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlStreamAttributes_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QXmlStreamAttributes_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QXmlStreamAttributes_Type, &Shiboken::callCppDestructor<QXmlStreamAttributes >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QXmlStreamAttributes_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QXmlStreamAttributes_Type, "QXmlStreamAttributes");
    PyModule_AddObject(module, "QXmlStreamAttributes",
        ((PyObject*)&Sbk_QXmlStreamAttributes_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QXmlStreamAttributes >("QXmlStreamAttributes");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamAttributes >("QXmlStreamAttributes*");
    Shiboken::TypeResolver::createValueTypeResolver<QXmlStreamAttributes >(typeid(QXmlStreamAttributes).name());
    PySide::initQtMetaType< ::QXmlStreamAttributes >();
}

