/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qdoublevalidator_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qlocale.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvalidator.h>


// Native ---------------------------------------------------------

QDoubleValidatorWrapper::QDoubleValidatorWrapper(QObject * parent) : QDoubleValidator(parent) {
    // ... middle
}

QDoubleValidatorWrapper::QDoubleValidatorWrapper(double bottom, double top, int decimals, QObject * parent) : QDoubleValidator(bottom, top, decimals, parent) {
    // ... middle
}

void QDoubleValidatorWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QDoubleValidatorWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QDoubleValidatorWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QDoubleValidatorWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QDoubleValidatorWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDoubleValidator.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QDoubleValidatorWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDoubleValidator.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QDoubleValidatorWrapper::fixup(QString & arg__1) const
{

    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "fixup"));
    if (py_override.isNull()) {

        gil.release();
        return this->::QValidator::fixup(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QString >::toPython(arg__1)
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }

}

void QDoubleValidatorWrapper::setRange(double bottom, double top, int decimals)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setRange"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDoubleValidator::setRange(bottom, top, decimals);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(ddi)",
        bottom,
        top,
        decimals
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QDoubleValidatorWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QValidator::State QDoubleValidatorWrapper::validate(QString & arg__1, int & arg__2) const
{

    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QValidator::State();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "validate"));
    if (py_override.isNull()) {

        gil.release();
        return this->::QDoubleValidator::validate(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QString >::toPython(arg__1),
        Shiboken::Converter< int >::toPython(arg__2)
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QValidator::State();
    }
    // Begin code injection

    QValidator::State cppResult;

    if (PySequence_Check(pyResult)) {
        Shiboken::AutoDecRef seq(PySequence_Fast(pyResult, 0));
        int size = PySequence_Fast_GET_SIZE(seq.object());

        if (size > 1) {
            if (Shiboken::Converter<QString>::isConvertible(PySequence_Fast_GET_ITEM(seq.object(), 1)))
                arg__1 = Shiboken::Converter<QString >::toCpp(PySequence_Fast_GET_ITEM(seq.object(), 1));
            else
                qWarning("QDoubleValidator::validate: Second tuple element is not convertible to unicode.");
        }

        if (size > 2) {
            if (Shiboken::Converter<int>::isConvertible(PySequence_Fast_GET_ITEM(seq.object(), 2)))
                arg__2 = Shiboken::Converter<int >::toCpp(PySequence_Fast_GET_ITEM(seq.object(), 2));
            else
                qWarning("QDoubleValidator::validate: Second tuple element is not convertible to int.");
        }
        pyResult = PySequence_Fast_GET_ITEM(seq.object(), 0);
        Py_INCREF(pyResult); // we need to incref, because "pyResult = ..." will decref the tuple and the tuple will be decrefed again at the end of this scope.
    }

    // check retrun value
    if (Shiboken::Converter<QValidator::State>::isConvertible(pyResult)) {
        cppResult = Shiboken::Converter<QValidator::State >::toCpp(pyResult);
    } else {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.",
                    "QValidator.validate",
                    "PySide.QtGui.QValidator.State, (PySide.QtGui.QValidator.State,), (PySide.QtGui.QValidator.State, unicode) or (PySide.QtGui.QValidator.State, unicode, int)",
                    pyResult->ob_type->tp_name);
        return QValidator::State();
    }

    // End of code injection

    return cppResult;
}

const QMetaObject* QDoubleValidatorWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QDoubleValidatorWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QDoubleValidator::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QDoubleValidatorWrapper::~QDoubleValidatorWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDoubleValidator_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDoubleValidator >()))
        return -1;

    QDoubleValidatorWrapper* cptr = 0;
    int overloadId = -1;
    const char** argNames = 0;
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QDoubleValidator_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QDoubleValidator", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QDoubleValidator(QObject*)
    // 1: QDoubleValidator(double,double,int,QObject*)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[3])) {
        overloadId = 1; // QDoubleValidator(double,double,int,QObject*)
    } else if (numArgs == 1 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QDoubleValidator(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDoubleValidator_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDoubleValidator(QObject*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDoubleValidator(QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDoubleValidatorWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QDoubleValidator(double,double,int,QObject*)
            {
                double cppArg0 = Shiboken::Converter<double >::toCpp(pyargs[0]);
                double cppArg1 = Shiboken::Converter<double >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return -1;
                QObject * cppArg3 = Shiboken::Converter<QObject * >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // QDoubleValidator(double,double,int,QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDoubleValidatorWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[3], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDoubleValidator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDoubleValidator_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 0))
        return -1;


    return 1;

    Sbk_QDoubleValidator_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", "float, float, int, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QDoubleValidator", overloads);
        return -1;
}

static PyObject* Sbk_QDoubleValidatorFunc_bottom(PyObject* self)
{
    QDoubleValidator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDoubleValidator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bottom()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                double cppResult = const_cast<const QDoubleValidator*>(cppSelf)->bottom();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDoubleValidatorFunc_decimals(PyObject* self)
{
    QDoubleValidator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDoubleValidator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // decimals()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QDoubleValidator*>(cppSelf)->decimals();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDoubleValidatorFunc_notation(PyObject* self)
{
    QDoubleValidator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDoubleValidator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // notation()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDoubleValidator::Notation cppResult = const_cast<const QDoubleValidator*>(cppSelf)->notation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDoubleValidator::Notation >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDoubleValidatorFunc_setBottom(PyObject* self, PyObject* arg)
{
    QDoubleValidator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDoubleValidator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottom(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBottom(double)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDoubleValidatorFunc_setBottom_TypeError;

    // Call function/method
    {
        {
            double cppArg0 = Shiboken::Converter<double >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBottom(double)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBottom(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDoubleValidatorFunc_setBottom_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDoubleValidator.setBottom", overloads);
        return 0;
}

static PyObject* Sbk_QDoubleValidatorFunc_setDecimals(PyObject* self, PyObject* arg)
{
    QDoubleValidator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDoubleValidator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDecimals(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDecimals(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDoubleValidatorFunc_setDecimals_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDecimals(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDecimals(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDoubleValidatorFunc_setDecimals_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDoubleValidator.setDecimals", overloads);
        return 0;
}

static PyObject* Sbk_QDoubleValidatorFunc_setNotation(PyObject* self, PyObject* arg)
{
    QDoubleValidator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDoubleValidator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNotation(QDoubleValidator::Notation)
    if (Shiboken::Converter< ::QDoubleValidator::Notation >::isConvertible(arg)) {
        overloadId = 0; // setNotation(QDoubleValidator::Notation)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDoubleValidatorFunc_setNotation_TypeError;

    // Call function/method
    {
        {
            QDoubleValidator::Notation cppArg0 = Shiboken::Converter<QDoubleValidator::Notation >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNotation(QDoubleValidator::Notation)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNotation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDoubleValidatorFunc_setNotation_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDoubleValidator.Notation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDoubleValidator.setNotation", overloads);
        return 0;
}

static PyObject* Sbk_QDoubleValidatorFunc_setRange(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDoubleValidator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDoubleValidator* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QDoubleValidator.setRange(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QDoubleValidator.setRange(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setRange", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setRange(double,double,int)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // setRange(double,double,int)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // setRange(double,double,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDoubleValidatorFunc_setRange_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "decimals");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "decimals";
                    else if (SbkNumber_Check(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QDoubleValidatorFunc_setRange_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QDoubleValidator.setRange(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            double cppArg0 = Shiboken::Converter<double >::toCpp(pyargs[0]);
            double cppArg1 = Shiboken::Converter<double >::toCpp(pyargs[1]);
            int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
                // setRange(double,double,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QDoubleValidator::setRange(cppArg0, cppArg1, cppArg2) : cppSelf->setRange(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDoubleValidatorFunc_setRange_TypeError:
        const char* overloads[] = {"float, float, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QDoubleValidator.setRange", overloads);
        return 0;
}

static PyObject* Sbk_QDoubleValidatorFunc_setTop(PyObject* self, PyObject* arg)
{
    QDoubleValidator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDoubleValidator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTop(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTop(double)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDoubleValidatorFunc_setTop_TypeError;

    // Call function/method
    {
        {
            double cppArg0 = Shiboken::Converter<double >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTop(double)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTop(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDoubleValidatorFunc_setTop_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDoubleValidator.setTop", overloads);
        return 0;
}

static PyObject* Sbk_QDoubleValidatorFunc_top(PyObject* self)
{
    QDoubleValidator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDoubleValidator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // top()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                double cppResult = const_cast<const QDoubleValidator*>(cppSelf)->top();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDoubleValidatorFunc_validate(PyObject* self, PyObject* args)
{
    QDoubleValidator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDoubleValidator* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "validate", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: validate(QString&,int&)const
    if (numArgs == 2 && Shiboken::Converter< ::QString & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // validate(QString&,int&)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDoubleValidatorFunc_validate_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // validate(QString&,int&)const


                // Begin code injection

                // TEMPLATE - return_tuple_QValidator_QString_int - START
                QValidator::State retval_ = QValidator::State(cppSelf->validate(cppArg0, cppArg1));
                pyResult = Shiboken::makeTuple(retval_, cppArg0, cppArg1);
                // TEMPLATE - return_tuple_QValidator_QString_int - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDoubleValidatorFunc_validate_TypeError:
        const char* overloads[] = {"QString, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QDoubleValidator.validate", overloads);
        return 0;
}

static PyMethodDef Sbk_QDoubleValidator_methods[] = {
    {"bottom", (PyCFunction)Sbk_QDoubleValidatorFunc_bottom, METH_NOARGS},
    {"decimals", (PyCFunction)Sbk_QDoubleValidatorFunc_decimals, METH_NOARGS},
    {"notation", (PyCFunction)Sbk_QDoubleValidatorFunc_notation, METH_NOARGS},
    {"setBottom", (PyCFunction)Sbk_QDoubleValidatorFunc_setBottom, METH_O},
    {"setDecimals", (PyCFunction)Sbk_QDoubleValidatorFunc_setDecimals, METH_O},
    {"setNotation", (PyCFunction)Sbk_QDoubleValidatorFunc_setNotation, METH_O},
    {"setRange", (PyCFunction)Sbk_QDoubleValidatorFunc_setRange, METH_VARARGS|METH_KEYWORDS},
    {"setTop", (PyCFunction)Sbk_QDoubleValidatorFunc_setTop, METH_O},
    {"top", (PyCFunction)Sbk_QDoubleValidatorFunc_top, METH_NOARGS},
    {"validate", (PyCFunction)Sbk_QDoubleValidatorFunc_validate, METH_VARARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDoubleValidator_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QDoubleValidator",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDoubleValidator_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDoubleValidator_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QDoubleValidator_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QDoubleValidator*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QDoubleValidator_Type;
    return 0;
}


void init_QDoubleValidator(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QDOUBLEVALIDATOR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDoubleValidator_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDoubleValidator_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QDoubleValidator_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QDoubleValidator_Type, &QDoubleValidator::staticMetaObject);    Sbk_QDoubleValidator_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QVALIDATOR_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDoubleValidator_Type, &Shiboken::callCppDestructor<QDoubleValidator >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDoubleValidator_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QDoubleValidator_Type, &Sbk_QDoubleValidator_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QVALIDATOR_IDX]), &Sbk_QDoubleValidator_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QDoubleValidator_Type, "QDoubleValidator*");
    PyModule_AddObject(module, "QDoubleValidator",
        ((PyObject*)&Sbk_QDoubleValidator_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Notation
    PyTypeObject* SbkPySide_QtGui_QDoubleValidator_Notation = Shiboken::Enum::newType("PySide.QtGui.QDoubleValidator.Notation");
    SbkPySide_QtGuiTypes[SBK_QDOUBLEVALIDATOR_NOTATION_IDX] = SbkPySide_QtGui_QDoubleValidator_Notation;
    if (PyType_Ready(SbkPySide_QtGui_QDoubleValidator_Notation) < 0)
        return;
    PyDict_SetItemString(Sbk_QDoubleValidator_Type.super.ht_type.tp_dict,
            "Notation",((PyObject*)SbkPySide_QtGui_QDoubleValidator_Notation));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QDoubleValidator_Notation,(long) QDoubleValidator::StandardNotation, "StandardNotation");
    PyDict_SetItemString(Sbk_QDoubleValidator_Type.super.ht_type.tp_dict,"StandardNotation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QDoubleValidator_Notation->tp_dict,"StandardNotation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QDoubleValidator_Notation,(long) QDoubleValidator::ScientificNotation, "ScientificNotation");
    PyDict_SetItemString(Sbk_QDoubleValidator_Type.super.ht_type.tp_dict,"ScientificNotation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QDoubleValidator_Notation->tp_dict,"ScientificNotation", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDoubleValidator::Notation");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Notation");
    // end of enum Notation


    Shiboken::TypeResolver::createObjectTypeResolver<QDoubleValidator >("QDoubleValidator*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDoubleValidator >(typeid(QDoubleValidator).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDoubleValidator >(typeid(QDoubleValidatorWrapper).name());
    PySide::initQtMetaType< ::QDoubleValidator* >();
    qRegisterMetaType< ::QDoubleValidator::Notation >("QDoubleValidator::Notation");
}

