/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qfileiconprovider_wrapper.h"

// Extra includes
#include <qfileiconprovider.h>
#include <qfileinfo.h>
#include <qicon.h>


// Native ---------------------------------------------------------

QFileIconProviderWrapper::QFileIconProviderWrapper() : QFileIconProvider() {
    // ... middle
}

QIcon QFileIconProviderWrapper::icon(QFileIconProvider::IconType type) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QIcon();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "icon"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFileIconProvider::icon(type);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFileIconProvider::IconType >::toPython(type)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QIcon();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QIcon >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileIconProvider.icon", Shiboken::SbkType<QIcon >()->tp_name, pyResult->ob_type->tp_name);
        return QIcon();
    }
    QIcon cppResult(Shiboken::Converter< ::QIcon >::toCpp(pyResult));
    return cppResult;
}

QIcon QFileIconProviderWrapper::icon(const QFileInfo & info) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QIcon();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "icon"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFileIconProvider::icon(info);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFileInfo >::toPython(info)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QIcon();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QIcon >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileIconProvider.icon", Shiboken::SbkType<QIcon >()->tp_name, pyResult->ob_type->tp_name);
        return QIcon();
    }
    QIcon cppResult(Shiboken::Converter< ::QIcon >::toCpp(pyResult));
    return cppResult;
}

QString QFileIconProviderWrapper::type(const QFileInfo & info) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QString();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "type"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFileIconProvider::type(info);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFileInfo >::toPython(info)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileIconProvider.type", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

QFileIconProviderWrapper::~QFileIconProviderWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFileIconProvider_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QFileIconProvider >()))
        return -1;

    QFileIconProviderWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QFileIconProvider()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QFileIconProviderWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QFileIconProvider >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QFileIconProviderFunc_icon(PyObject* self, PyObject* arg)
{
    QFileIconProvider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileIconProvider* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: icon(QFileIconProvider::IconType)const
    // 1: icon(QFileInfo)const
    if (Shiboken::Converter< ::QFileInfo >::isConvertible(arg)) {
        overloadId = 1; // icon(QFileInfo)const
    } else if (Shiboken::Converter< ::QFileIconProvider::IconType >::isConvertible(arg)) {
        overloadId = 0; // icon(QFileIconProvider::IconType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileIconProviderFunc_icon_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // icon(QFileIconProvider::IconType)const
            {
                QFileIconProvider::IconType cppArg0 = Shiboken::Converter<QFileIconProvider::IconType >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // icon(QFileIconProvider::IconType)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QIcon cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QFileIconProvider*>(cppSelf)->::QFileIconProvider::icon(cppArg0) : const_cast<const QFileIconProvider*>(cppSelf)->icon(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
                }
                break;
            }
            case 1: // icon(QFileInfo)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QFileInfo cppArg0 = Shiboken::Converter<QFileInfo >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // icon(QFileInfo)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QIcon cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QFileIconProvider*>(cppSelf)->::QFileIconProvider::icon(cppArg0) : const_cast<const QFileIconProvider*>(cppSelf)->icon(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFileIconProviderFunc_icon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileIconProvider.IconType", "PySide.QtCore.QFileInfo", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileIconProvider.icon", overloads);
        return 0;
}

static PyObject* Sbk_QFileIconProviderFunc_type(PyObject* self, PyObject* arg)
{
    QFileIconProvider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileIconProvider* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: type(QFileInfo)const
    if (Shiboken::Converter< ::QFileInfo >::isConvertible(arg)) {
        overloadId = 0; // type(QFileInfo)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileIconProviderFunc_type_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFileInfo cppArg0 = Shiboken::Converter<QFileInfo >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // type(QFileInfo)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QFileIconProvider*>(cppSelf)->::QFileIconProvider::type(cppArg0) : const_cast<const QFileIconProvider*>(cppSelf)->type(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFileIconProviderFunc_type_TypeError:
        const char* overloads[] = {"PySide.QtCore.QFileInfo", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileIconProvider.type", overloads);
        return 0;
}

static PyMethodDef Sbk_QFileIconProvider_methods[] = {
    {"icon", (PyCFunction)Sbk_QFileIconProviderFunc_icon, METH_O},
    {"type", (PyCFunction)Sbk_QFileIconProviderFunc_type, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QFileIconProvider_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QFileIconProvider",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QFileIconProvider_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QFileIconProvider_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QFileIconProvider(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFILEICONPROVIDER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QFileIconProvider_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QFileIconProvider_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QFileIconProvider_Type, &Shiboken::callCppDestructor<QFileIconProvider >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QFileIconProvider_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QFileIconProvider_Type, "QFileIconProvider*");
    PyModule_AddObject(module, "QFileIconProvider",
        ((PyObject*)&Sbk_QFileIconProvider_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: IconType
    PyTypeObject* SbkPySide_QtGui_QFileIconProvider_IconType = Shiboken::Enum::newType("PySide.QtGui.QFileIconProvider.IconType");
    SbkPySide_QtGuiTypes[SBK_QFILEICONPROVIDER_ICONTYPE_IDX] = SbkPySide_QtGui_QFileIconProvider_IconType;
    if (PyType_Ready(SbkPySide_QtGui_QFileIconProvider_IconType) < 0)
        return;
    PyDict_SetItemString(Sbk_QFileIconProvider_Type.super.ht_type.tp_dict,
            "IconType",((PyObject*)SbkPySide_QtGui_QFileIconProvider_IconType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileIconProvider_IconType,(long) QFileIconProvider::Computer, "Computer");
    PyDict_SetItemString(Sbk_QFileIconProvider_Type.super.ht_type.tp_dict,"Computer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileIconProvider_IconType->tp_dict,"Computer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileIconProvider_IconType,(long) QFileIconProvider::Desktop, "Desktop");
    PyDict_SetItemString(Sbk_QFileIconProvider_Type.super.ht_type.tp_dict,"Desktop", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileIconProvider_IconType->tp_dict,"Desktop", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileIconProvider_IconType,(long) QFileIconProvider::Trashcan, "Trashcan");
    PyDict_SetItemString(Sbk_QFileIconProvider_Type.super.ht_type.tp_dict,"Trashcan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileIconProvider_IconType->tp_dict,"Trashcan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileIconProvider_IconType,(long) QFileIconProvider::Network, "Network");
    PyDict_SetItemString(Sbk_QFileIconProvider_Type.super.ht_type.tp_dict,"Network", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileIconProvider_IconType->tp_dict,"Network", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileIconProvider_IconType,(long) QFileIconProvider::Drive, "Drive");
    PyDict_SetItemString(Sbk_QFileIconProvider_Type.super.ht_type.tp_dict,"Drive", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileIconProvider_IconType->tp_dict,"Drive", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileIconProvider_IconType,(long) QFileIconProvider::Folder, "Folder");
    PyDict_SetItemString(Sbk_QFileIconProvider_Type.super.ht_type.tp_dict,"Folder", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileIconProvider_IconType->tp_dict,"Folder", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileIconProvider_IconType,(long) QFileIconProvider::File, "File");
    PyDict_SetItemString(Sbk_QFileIconProvider_Type.super.ht_type.tp_dict,"File", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileIconProvider_IconType->tp_dict,"File", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFileIconProvider::IconType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::IconType");
    // end of enum IconType


    Shiboken::TypeResolver::createObjectTypeResolver<QFileIconProvider >("QFileIconProvider*");
    Shiboken::TypeResolver::createObjectTypeResolver<QFileIconProvider >(typeid(QFileIconProvider).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QFileIconProvider >(typeid(QFileIconProviderWrapper).name());
    PySide::initQtMetaType< ::QFileIconProvider* >();
    qRegisterMetaType< ::QFileIconProvider::IconType >("QFileIconProvider::IconType");
}

