/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qfileopenevent_wrapper.h"

// Extra includes
#include <qurl.h>


// Native ---------------------------------------------------------

QFileOpenEventWrapper::QFileOpenEventWrapper(const QString & file) : QFileOpenEvent(file) {
    // ... middle
}

QFileOpenEventWrapper::QFileOpenEventWrapper(const QUrl & url) : QFileOpenEvent(url) {
    // ... middle
}

QFileOpenEventWrapper::~QFileOpenEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFileOpenEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QFileOpenEvent >()))
        return -1;

    QFileOpenEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QFileOpenEvent", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QFileOpenEvent(QString)
    // 1: QFileOpenEvent(QUrl)
    if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 0; // QFileOpenEvent(QString)
    } else if (numArgs == 1 && Shiboken::Converter< ::QUrl >::isConvertible(pyargs[0])) {
        overloadId = 1; // QFileOpenEvent(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileOpenEvent_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QFileOpenEvent(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QFileOpenEvent(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QFileOpenEventWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QFileOpenEvent(QUrl)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QFileOpenEvent(QUrl)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QFileOpenEventWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QFileOpenEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QFileOpenEvent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QFileOpenEvent_Init_TypeError:
        const char* overloads[] = {"QString", "PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileOpenEvent", overloads);
        return -1;
}

static PyObject* Sbk_QFileOpenEventFunc_file(PyObject* self)
{
    QFileOpenEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileOpenEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // file()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QFileOpenEvent*>(cppSelf)->file();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileOpenEventFunc_url(PyObject* self)
{
    QFileOpenEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileOpenEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // url()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = const_cast<const QFileOpenEvent*>(cppSelf)->url();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QFileOpenEvent_methods[] = {
    {"file", (PyCFunction)Sbk_QFileOpenEventFunc_file, METH_NOARGS},
    {"url", (PyCFunction)Sbk_QFileOpenEventFunc_url, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QFileOpenEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QFileOpenEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QFileOpenEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QFileOpenEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QFileOpenEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
     if ( reinterpret_cast<QFileOpenEvent*>(cptr)->type() == QEvent::FileOpen)
        return &Sbk_QFileOpenEvent_Type;
    return 0;
}


void init_QFileOpenEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFILEOPENEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QFileOpenEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QFileOpenEvent_Type);
    Sbk_QFileOpenEvent_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QEVENT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QFileOpenEvent_Type, &Shiboken::callCppDestructor<QFileOpenEvent >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QFileOpenEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QFileOpenEvent_Type, &Sbk_QFileOpenEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX]), &Sbk_QFileOpenEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QFileOpenEvent_Type, "QFileOpenEvent*");
    PyModule_AddObject(module, "QFileOpenEvent",
        ((PyObject*)&Sbk_QFileOpenEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QFileOpenEvent >("QFileOpenEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QFileOpenEvent >(typeid(QFileOpenEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QFileOpenEvent >(typeid(QFileOpenEventWrapper).name());
    PySide::initQtMetaType< ::QFileOpenEvent* >();
}

