/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qformlayout_wrapper.h"

// Extra includes
#include "glue/qlayout_help_functions.h"
#include <qcoreevent.h>
#include <qlayout.h>
#include <qlayoutitem.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qrect.h>
#include <qsize.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QFormLayoutWrapper::QFormLayoutWrapper(QWidget * parent) : QFormLayout(parent) {
    // ... middle
}

void QFormLayoutWrapper::addItem(QLayoutItem * item)
{

    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "addItem"));
    if (py_override.isNull()) {

        gil.release();
        return this->::QFormLayout::addItem(item);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QLayoutItem * >::toPython(item)
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }

}

void QFormLayoutWrapper::childEvent(QChildEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::childEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QFormLayoutWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QFormLayoutWrapper::count() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "count"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFormLayout::count();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.count", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QFormLayoutWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QFormLayoutWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QFormLayoutWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QFormLayoutWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QFlags<Qt::Orientation> QFormLayoutWrapper::expandingDirections() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QFlags<Qt::Orientation>();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "expandingDirections"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFormLayout::expandingDirections();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<Qt::Orientation>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QFlags<Qt::Orientation> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.expandingDirections", Shiboken::SbkType<QFlags<Qt::Orientation> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<Qt::Orientation>();
    }
    QFlags<Qt::Orientation> cppResult(Shiboken::Converter< ::QFlags<Qt::Orientation> >::toCpp(pyResult));
    return cppResult;
}

QRect QFormLayoutWrapper::geometry() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QRect();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "geometry"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::geometry();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.geometry", Shiboken::SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter< ::QRect >::toCpp(pyResult));
    return cppResult;
}

bool QFormLayoutWrapper::hasHeightForWidth() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hasHeightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFormLayout::hasHeightForWidth();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.hasHeightForWidth", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

int QFormLayoutWrapper::heightForWidth(int width) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFormLayout::heightForWidth(width);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        width
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

int QFormLayoutWrapper::indexOf(QWidget * arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "indexOf"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::indexOf(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWidget * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.indexOf", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QFormLayoutWrapper::invalidate()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "invalidate"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFormLayout::invalidate();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QFormLayoutWrapper::isEmpty() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isEmpty"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::isEmpty();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.isEmpty", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QLayoutItem * QFormLayoutWrapper::itemAt(int index) const
{

    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "itemAt"));
    if (py_override.isNull()) {

        gil.release();
        return this->::QFormLayout::itemAt(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        index
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QLayoutItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.itemAt", Shiboken::SbkType<QLayoutItem >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayoutItem * cppResult(Shiboken::Converter< ::QLayoutItem * >::toCpp(pyResult));

    return cppResult;
}

QLayout * QFormLayoutWrapper::layout()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "layout"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::layout();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QLayout * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.layout", Shiboken::SbkType<QLayout >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayout * cppResult(Shiboken::Converter< ::QLayout * >::toCpp(pyResult));
    return cppResult;
}

QSize QFormLayoutWrapper::maximumSize() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "maximumSize"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::maximumSize();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.maximumSize", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

int QFormLayoutWrapper::minimumHeightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumHeightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::minimumHeightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.minimumHeightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QSize QFormLayoutWrapper::minimumSize() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumSize"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFormLayout::minimumSize();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.minimumSize", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QFormLayoutWrapper::setGeometry(const QRect & rect)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setGeometry"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFormLayout::setGeometry(rect);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QRect >::toPython(rect)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QSize QFormLayoutWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFormLayout::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.sizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

QSpacerItem * QFormLayoutWrapper::spacerItem()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "spacerItem"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::spacerItem();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSpacerItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.spacerItem", Shiboken::SbkType<QSpacerItem >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QSpacerItem * cppResult(Shiboken::Converter< ::QSpacerItem * >::toCpp(pyResult));
    return cppResult;
}

QLayoutItem * QFormLayoutWrapper::takeAt(int index)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "takeAt"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFormLayout::takeAt(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        index
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QLayoutItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.takeAt", Shiboken::SbkType<QLayoutItem >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayoutItem * cppResult(Shiboken::Converter< ::QLayoutItem * >::toCpp(pyResult));
    return cppResult;
}

void QFormLayoutWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QWidget * QFormLayoutWrapper::widget()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "widget"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::widget();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QWidget * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.widget", Shiboken::SbkType<QWidget >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QWidget * cppResult(Shiboken::Converter< ::QWidget * >::toCpp(pyResult));
    return cppResult;
}

const QMetaObject* QFormLayoutWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QFormLayoutWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QFormLayout::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QFormLayoutWrapper::~QFormLayoutWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFormLayout_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QFormLayout >()))
        return -1;

    QFormLayoutWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QFormLayout", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QFormLayout(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QFormLayout(QWidget*)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QFormLayout(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayout_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QFormLayout_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFormLayout(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QFormLayout(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QFormLayoutWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QFormLayout >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QFormLayout_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QFormLayout_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFormLayout", overloads);
        return -1;
}

static PyObject* Sbk_QFormLayoutFunc_addItem(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addItem(QLayoutItem*)
    if (Shiboken::Converter< ::QLayoutItem * >::isConvertible(arg)) {
        overloadId = 0; // addItem(QLayoutItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_addItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QLayoutItem * cppArg0 = Shiboken::Converter<QLayoutItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addItem(QLayoutItem*)
                // Begin code injection

                addLayoutOwnership(cppSelf, cppArg0);

                // End of code injection

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QFormLayout::addItem(cppArg0) : cppSelf->addItem(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFormLayoutFunc_addItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayoutItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.addItem", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_addRow(PyObject* self, PyObject* args)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addRow", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addRow(QLayout*)
    // 1: addRow(QWidget*,QLayout*)
    // 2: addRow(QWidget*,QWidget*)
    // 3: addRow(QWidget*)
    // 4: addRow(QString,QLayout*)
    // 5: addRow(QString,QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // addRow(QWidget*)
        } else if (numArgs == 2 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[1])) {
            overloadId = 2; // addRow(QWidget*,QWidget*)
        } else if (numArgs == 2 && Shiboken::Converter< ::QLayout * >::isConvertible(pyargs[1])) {
            overloadId = 1; // addRow(QWidget*,QLayout*)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QLayout * >::isConvertible(pyargs[0])) {
        overloadId = 0; // addRow(QLayout*)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[1])) {
            overloadId = 5; // addRow(QString,QWidget*)
        } else if (numArgs == 2 && Shiboken::Converter< ::QLayout * >::isConvertible(pyargs[1])) {
            overloadId = 4; // addRow(QString,QLayout*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_addRow_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addRow(QLayout*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QLayout * cppArg0 = Shiboken::Converter<QLayout * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // addRow(QLayout*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRow(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[0]);
                }
                break;
            }
            case 1: // addRow(QWidget*,QLayout*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QLayout * cppArg1 = Shiboken::Converter<QLayout * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // addRow(QWidget*,QLayout*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRow(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[0]);
                    Shiboken::Object::setParent(self, pyargs[1]);
                }
                break;
            }
            case 2: // addRow(QWidget*,QWidget*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QWidget * cppArg1 = Shiboken::Converter<QWidget * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // addRow(QWidget*,QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRow(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[0]);
                    Shiboken::Object::setParent(self, pyargs[1]);
                }
                break;
            }
            case 3: // addRow(QWidget*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // addRow(QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRow(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[0]);
                }
                break;
            }
            case 4: // addRow(QString,QLayout*)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QLayout * cppArg1 = Shiboken::Converter<QLayout * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // addRow(QString,QLayout*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRow(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[1]);
                }
                break;
            }
            case 5: // addRow(QString,QWidget*)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QWidget * cppArg1 = Shiboken::Converter<QWidget * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // addRow(QString,QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRow(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[1]);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFormLayoutFunc_addRow_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayout", "PySide.QtGui.QWidget, PySide.QtGui.QLayout", "PySide.QtGui.QWidget, PySide.QtGui.QWidget", "PySide.QtGui.QWidget", "QString, PySide.QtGui.QLayout", "QString, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFormLayout.addRow", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_count(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // count()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QFormLayout*>(cppSelf)->::QFormLayout::count() : const_cast<const QFormLayout*>(cppSelf)->count());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFormLayoutFunc_expandingDirections(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // expandingDirections()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::Orientation> cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QFormLayout*>(cppSelf)->::QFormLayout::expandingDirections() : const_cast<const QFormLayout*>(cppSelf)->expandingDirections());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::Orientation> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFormLayoutFunc_fieldGrowthPolicy(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fieldGrowthPolicy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFormLayout::FieldGrowthPolicy cppResult = const_cast<const QFormLayout*>(cppSelf)->fieldGrowthPolicy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFormLayout::FieldGrowthPolicy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFormLayoutFunc_formAlignment(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // formAlignment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::AlignmentFlag> cppResult = const_cast<const QFormLayout*>(cppSelf)->formAlignment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFormLayoutFunc_hasHeightForWidth(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasHeightForWidth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QFormLayout*>(cppSelf)->::QFormLayout::hasHeightForWidth() : const_cast<const QFormLayout*>(cppSelf)->hasHeightForWidth());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFormLayoutFunc_heightForWidth(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: heightForWidth(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // heightForWidth(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_heightForWidth_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // heightForWidth(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QFormLayout*>(cppSelf)->::QFormLayout::heightForWidth(cppArg0) : const_cast<const QFormLayout*>(cppSelf)->heightForWidth(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFormLayoutFunc_heightForWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.heightForWidth", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_horizontalSpacing(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // horizontalSpacing()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QFormLayout*>(cppSelf)->horizontalSpacing();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFormLayoutFunc_insertRow(PyObject* self, PyObject* args)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertRow", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: insertRow(int,QLayout*)
    // 1: insertRow(int,QWidget*,QLayout*)
    // 2: insertRow(int,QWidget*,QWidget*)
    // 3: insertRow(int,QWidget*)
    // 4: insertRow(int,QString,QLayout*)
    // 5: insertRow(int,QString,QWidget*)
    if (SbkNumber_Check(pyargs[0])) {
        if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 3; // insertRow(int,QWidget*)
            } else if (numArgs == 3 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
                overloadId = 2; // insertRow(int,QWidget*,QWidget*)
            } else if (numArgs == 3 && Shiboken::Converter< ::QLayout * >::isConvertible(pyargs[2])) {
                overloadId = 1; // insertRow(int,QWidget*,QLayout*)
            }
        } else if (numArgs == 2 && Shiboken::Converter< ::QLayout * >::isConvertible(pyargs[1])) {
            overloadId = 0; // insertRow(int,QLayout*)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 3 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
                overloadId = 5; // insertRow(int,QString,QWidget*)
            } else if (numArgs == 3 && Shiboken::Converter< ::QLayout * >::isConvertible(pyargs[2])) {
                overloadId = 4; // insertRow(int,QString,QLayout*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_insertRow_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertRow(int,QLayout*)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QLayout * cppArg1 = Shiboken::Converter<QLayout * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // insertRow(int,QLayout*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertRow(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[1]);
                }
                break;
            }
            case 1: // insertRow(int,QWidget*,QLayout*)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QWidget * cppArg1 = Shiboken::Converter<QWidget * >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QLayout * cppArg2 = Shiboken::Converter<QLayout * >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // insertRow(int,QWidget*,QLayout*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertRow(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[1]);
                    Shiboken::Object::setParent(self, pyargs[2]);
                }
                break;
            }
            case 2: // insertRow(int,QWidget*,QWidget*)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QWidget * cppArg1 = Shiboken::Converter<QWidget * >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QWidget * cppArg2 = Shiboken::Converter<QWidget * >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // insertRow(int,QWidget*,QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertRow(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[1]);
                    Shiboken::Object::setParent(self, pyargs[2]);
                }
                break;
            }
            case 3: // insertRow(int,QWidget*)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QWidget * cppArg1 = Shiboken::Converter<QWidget * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // insertRow(int,QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertRow(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[1]);
                }
                break;
            }
            case 4: // insertRow(int,QString,QLayout*)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QLayout * cppArg2 = Shiboken::Converter<QLayout * >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // insertRow(int,QString,QLayout*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertRow(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[2]);
                }
                break;
            }
            case 5: // insertRow(int,QString,QWidget*)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QWidget * cppArg2 = Shiboken::Converter<QWidget * >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // insertRow(int,QString,QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertRow(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[2]);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFormLayoutFunc_insertRow_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QLayout", "int, PySide.QtGui.QWidget, PySide.QtGui.QLayout", "int, PySide.QtGui.QWidget, PySide.QtGui.QWidget", "int, PySide.QtGui.QWidget", "int, QString, PySide.QtGui.QLayout", "int, QString, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFormLayout.insertRow", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_invalidate(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // invalidate()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QFormLayout::invalidate() : cppSelf->invalidate());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QFormLayoutFunc_itemAt(PyObject* self, PyObject* args)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemAt", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: itemAt(int)const
    // 1: itemAt(int,QFormLayout::ItemRole)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // itemAt(int)const
        } else if (numArgs == 2 && Shiboken::Converter< ::QFormLayout::ItemRole >::isConvertible(pyargs[1])) {
            overloadId = 1; // itemAt(int,QFormLayout::ItemRole)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_itemAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // itemAt(int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // itemAt(int)const

                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QLayoutItem * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QFormLayout*>(cppSelf)->::QFormLayout::itemAt(cppArg0) : const_cast<const QFormLayout*>(cppSelf)->itemAt(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QLayoutItem * >::toPython(cppResult);

                    // Begin code injection

                    addLayoutOwnership(cppSelf, cppResult);

                    // End of code injection

                    // Ownership transferences.
                }
                break;
            }
            case 1: // itemAt(int,QFormLayout::ItemRole)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QFormLayout::ItemRole cppArg1 = Shiboken::Converter<QFormLayout::ItemRole >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // itemAt(int,QFormLayout::ItemRole)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QLayoutItem * cppResult = const_cast<const QFormLayout*>(cppSelf)->itemAt(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QLayoutItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFormLayoutFunc_itemAt_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtGui.QFormLayout.ItemRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFormLayout.itemAt", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_labelAlignment(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // labelAlignment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::AlignmentFlag> cppResult = const_cast<const QFormLayout*>(cppSelf)->labelAlignment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFormLayoutFunc_labelForField(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: labelForField(QLayout*)const
    // 1: labelForField(QWidget*)const
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 1; // labelForField(QWidget*)const
    } else if (Shiboken::Converter< ::QLayout * >::isConvertible(arg)) {
        overloadId = 0; // labelForField(QLayout*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_labelForField_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // labelForField(QLayout*)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QLayout * cppArg0 = Shiboken::Converter<QLayout * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // labelForField(QLayout*)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QWidget * cppResult = const_cast<const QFormLayout*>(cppSelf)->labelForField(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // labelForField(QWidget*)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // labelForField(QWidget*)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QWidget * cppResult = const_cast<const QFormLayout*>(cppSelf)->labelForField(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFormLayoutFunc_labelForField_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayout", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.labelForField", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_minimumSize(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // minimumSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QFormLayout*>(cppSelf)->::QFormLayout::minimumSize() : const_cast<const QFormLayout*>(cppSelf)->minimumSize());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFormLayoutFunc_rowCount(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rowCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QFormLayout*>(cppSelf)->rowCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFormLayoutFunc_rowWrapPolicy(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rowWrapPolicy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFormLayout::RowWrapPolicy cppResult = const_cast<const QFormLayout*>(cppSelf)->rowWrapPolicy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFormLayout::RowWrapPolicy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFormLayoutFunc_setFieldGrowthPolicy(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy)
    if (Shiboken::Converter< ::QFormLayout::FieldGrowthPolicy >::isConvertible(arg)) {
        overloadId = 0; // setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_setFieldGrowthPolicy_TypeError;

    // Call function/method
    {
        {
            QFormLayout::FieldGrowthPolicy cppArg0 = Shiboken::Converter<QFormLayout::FieldGrowthPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFieldGrowthPolicy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFormLayoutFunc_setFieldGrowthPolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFormLayout.FieldGrowthPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setFieldGrowthPolicy", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_setFormAlignment(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFormAlignment(QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(arg)) {
        overloadId = 0; // setFormAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_setFormAlignment_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::AlignmentFlag> cppArg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFormAlignment(QFlags<Qt::AlignmentFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFormAlignment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFormLayoutFunc_setFormAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setFormAlignment", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_setGeometry(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometry(QRect)
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // setGeometry(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_setGeometry_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGeometry(QRect)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QFormLayout::setGeometry(cppArg0) : cppSelf->setGeometry(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFormLayoutFunc_setGeometry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setGeometry", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_setHorizontalSpacing(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHorizontalSpacing(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHorizontalSpacing(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_setHorizontalSpacing_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHorizontalSpacing(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHorizontalSpacing(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFormLayoutFunc_setHorizontalSpacing_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setHorizontalSpacing", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_setLabelAlignment(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLabelAlignment(QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(arg)) {
        overloadId = 0; // setLabelAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_setLabelAlignment_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::AlignmentFlag> cppArg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLabelAlignment(QFlags<Qt::AlignmentFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLabelAlignment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFormLayoutFunc_setLabelAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setLabelAlignment", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_setLayout(PyObject* self, PyObject* args)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setLayout", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setLayout(int,QFormLayout::ItemRole,QLayout*)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QFormLayout::ItemRole >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QLayout * >::isConvertible(pyargs[2])) {
        overloadId = 0; // setLayout(int,QFormLayout::ItemRole,QLayout*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_setLayout_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QFormLayout::ItemRole cppArg1 = Shiboken::Converter<QFormLayout::ItemRole >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QLayout * cppArg2 = Shiboken::Converter<QLayout * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // setLayout(int,QFormLayout::ItemRole,QLayout*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLayout(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[2]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFormLayoutFunc_setLayout_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QFormLayout.ItemRole, PySide.QtGui.QLayout", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFormLayout.setLayout", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_setRowWrapPolicy(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRowWrapPolicy(QFormLayout::RowWrapPolicy)
    if (Shiboken::Converter< ::QFormLayout::RowWrapPolicy >::isConvertible(arg)) {
        overloadId = 0; // setRowWrapPolicy(QFormLayout::RowWrapPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_setRowWrapPolicy_TypeError;

    // Call function/method
    {
        {
            QFormLayout::RowWrapPolicy cppArg0 = Shiboken::Converter<QFormLayout::RowWrapPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRowWrapPolicy(QFormLayout::RowWrapPolicy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRowWrapPolicy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFormLayoutFunc_setRowWrapPolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFormLayout.RowWrapPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setRowWrapPolicy", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_setSpacing(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSpacing(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSpacing(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_setSpacing_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSpacing(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSpacing(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFormLayoutFunc_setSpacing_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setSpacing", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_setVerticalSpacing(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVerticalSpacing(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVerticalSpacing(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_setVerticalSpacing_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVerticalSpacing(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setVerticalSpacing(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFormLayoutFunc_setVerticalSpacing_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setVerticalSpacing", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_setWidget(PyObject* self, PyObject* args)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setWidget", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setWidget(int,QFormLayout::ItemRole,QWidget*)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QFormLayout::ItemRole >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
        overloadId = 0; // setWidget(int,QFormLayout::ItemRole,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_setWidget_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QFormLayout::ItemRole cppArg1 = Shiboken::Converter<QFormLayout::ItemRole >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QWidget * cppArg2 = Shiboken::Converter<QWidget * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // setWidget(int,QFormLayout::ItemRole,QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWidget(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[2]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFormLayoutFunc_setWidget_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QFormLayout.ItemRole, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFormLayout.setWidget", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_sizeHint(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sizeHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QFormLayout*>(cppSelf)->::QFormLayout::sizeHint() : const_cast<const QFormLayout*>(cppSelf)->sizeHint());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFormLayoutFunc_spacing(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // spacing()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QFormLayout*>(cppSelf)->spacing();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFormLayoutFunc_takeAt(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: takeAt(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // takeAt(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFormLayoutFunc_takeAt_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // takeAt(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLayoutItem * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QFormLayout::takeAt(cppArg0) : cppSelf->takeAt(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLayoutItem * >::toPython(cppResult);
                Shiboken::Object::setParent(Py_None, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFormLayoutFunc_takeAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.takeAt", overloads);
        return 0;
}

static PyObject* Sbk_QFormLayoutFunc_verticalSpacing(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // verticalSpacing()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QFormLayout*>(cppSelf)->verticalSpacing();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QFormLayout_methods[] = {
    {"addItem", (PyCFunction)Sbk_QFormLayoutFunc_addItem, METH_O},
    {"addRow", (PyCFunction)Sbk_QFormLayoutFunc_addRow, METH_VARARGS},
    {"count", (PyCFunction)Sbk_QFormLayoutFunc_count, METH_NOARGS},
    {"expandingDirections", (PyCFunction)Sbk_QFormLayoutFunc_expandingDirections, METH_NOARGS},
    {"fieldGrowthPolicy", (PyCFunction)Sbk_QFormLayoutFunc_fieldGrowthPolicy, METH_NOARGS},
    {"formAlignment", (PyCFunction)Sbk_QFormLayoutFunc_formAlignment, METH_NOARGS},
    {"hasHeightForWidth", (PyCFunction)Sbk_QFormLayoutFunc_hasHeightForWidth, METH_NOARGS},
    {"heightForWidth", (PyCFunction)Sbk_QFormLayoutFunc_heightForWidth, METH_O},
    {"horizontalSpacing", (PyCFunction)Sbk_QFormLayoutFunc_horizontalSpacing, METH_NOARGS},
    {"insertRow", (PyCFunction)Sbk_QFormLayoutFunc_insertRow, METH_VARARGS},
    {"invalidate", (PyCFunction)Sbk_QFormLayoutFunc_invalidate, METH_NOARGS},
    {"itemAt", (PyCFunction)Sbk_QFormLayoutFunc_itemAt, METH_VARARGS},
    {"labelAlignment", (PyCFunction)Sbk_QFormLayoutFunc_labelAlignment, METH_NOARGS},
    {"labelForField", (PyCFunction)Sbk_QFormLayoutFunc_labelForField, METH_O},
    {"minimumSize", (PyCFunction)Sbk_QFormLayoutFunc_minimumSize, METH_NOARGS},
    {"rowCount", (PyCFunction)Sbk_QFormLayoutFunc_rowCount, METH_NOARGS},
    {"rowWrapPolicy", (PyCFunction)Sbk_QFormLayoutFunc_rowWrapPolicy, METH_NOARGS},
    {"setFieldGrowthPolicy", (PyCFunction)Sbk_QFormLayoutFunc_setFieldGrowthPolicy, METH_O},
    {"setFormAlignment", (PyCFunction)Sbk_QFormLayoutFunc_setFormAlignment, METH_O},
    {"setGeometry", (PyCFunction)Sbk_QFormLayoutFunc_setGeometry, METH_O},
    {"setHorizontalSpacing", (PyCFunction)Sbk_QFormLayoutFunc_setHorizontalSpacing, METH_O},
    {"setLabelAlignment", (PyCFunction)Sbk_QFormLayoutFunc_setLabelAlignment, METH_O},
    {"setLayout", (PyCFunction)Sbk_QFormLayoutFunc_setLayout, METH_VARARGS},
    {"setRowWrapPolicy", (PyCFunction)Sbk_QFormLayoutFunc_setRowWrapPolicy, METH_O},
    {"setSpacing", (PyCFunction)Sbk_QFormLayoutFunc_setSpacing, METH_O},
    {"setVerticalSpacing", (PyCFunction)Sbk_QFormLayoutFunc_setVerticalSpacing, METH_O},
    {"setWidget", (PyCFunction)Sbk_QFormLayoutFunc_setWidget, METH_VARARGS},
    {"sizeHint", (PyCFunction)Sbk_QFormLayoutFunc_sizeHint, METH_NOARGS},
    {"spacing", (PyCFunction)Sbk_QFormLayoutFunc_spacing, METH_NOARGS},
    {"takeAt", (PyCFunction)Sbk_QFormLayoutFunc_takeAt, METH_O},
    {"verticalSpacing", (PyCFunction)Sbk_QFormLayoutFunc_verticalSpacing, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static void* Sbk_QFormLayoutSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QFormLayout* me = reinterpret_cast<QFormLayout*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX]))
        return static_cast<QLayout*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUTITEM_IDX]))
        return static_cast<QLayoutItem*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QFormLayout_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QFormLayout",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QFormLayout_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QFormLayout_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QFormLayout_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QFormLayout*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QFormLayout_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QLayoutItem >()) && dynamic_cast<QFormLayout*>(reinterpret_cast<QLayoutItem*>(cptr)))
        return &Sbk_QFormLayout_Type;
    return 0;
}


void init_QFormLayout(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFORMLAYOUT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QFormLayout_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QFormLayout_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QFormLayout_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QFormLayout_Type, &QFormLayout::staticMetaObject);    Sbk_QFormLayout_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX];
    MultipleInheritanceInitFunction func;
    func = Shiboken::ObjectType::getMultipleIheritanceFunction(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX]));
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QFormLayout_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QFormLayout_Type, &Sbk_QFormLayoutSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QFormLayout_Type, &Shiboken::callCppDestructor<QFormLayout >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QFormLayout_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QFormLayout_Type, &Sbk_QFormLayout_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX]), &Sbk_QFormLayout_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QFormLayout_Type, "QFormLayout*");
    PyModule_AddObject(module, "QFormLayout",
        ((PyObject*)&Sbk_QFormLayout_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: FieldGrowthPolicy
    PyTypeObject* SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy = Shiboken::Enum::newType("PySide.QtGui.QFormLayout.FieldGrowthPolicy");
    SbkPySide_QtGuiTypes[SBK_QFORMLAYOUT_FIELDGROWTHPOLICY_IDX] = SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy;
    if (PyType_Ready(SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy) < 0)
        return;
    PyDict_SetItemString(Sbk_QFormLayout_Type.super.ht_type.tp_dict,
            "FieldGrowthPolicy",((PyObject*)SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy,(long) QFormLayout::FieldsStayAtSizeHint, "FieldsStayAtSizeHint");
    PyDict_SetItemString(Sbk_QFormLayout_Type.super.ht_type.tp_dict,"FieldsStayAtSizeHint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy->tp_dict,"FieldsStayAtSizeHint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy,(long) QFormLayout::ExpandingFieldsGrow, "ExpandingFieldsGrow");
    PyDict_SetItemString(Sbk_QFormLayout_Type.super.ht_type.tp_dict,"ExpandingFieldsGrow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy->tp_dict,"ExpandingFieldsGrow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy,(long) QFormLayout::AllNonFixedFieldsGrow, "AllNonFixedFieldsGrow");
    PyDict_SetItemString(Sbk_QFormLayout_Type.super.ht_type.tp_dict,"AllNonFixedFieldsGrow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy->tp_dict,"AllNonFixedFieldsGrow", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFormLayout::FieldGrowthPolicy");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FieldGrowthPolicy");
    // end of enum FieldGrowthPolicy

    // init enum: RowWrapPolicy
    PyTypeObject* SbkPySide_QtGui_QFormLayout_RowWrapPolicy = Shiboken::Enum::newType("PySide.QtGui.QFormLayout.RowWrapPolicy");
    SbkPySide_QtGuiTypes[SBK_QFORMLAYOUT_ROWWRAPPOLICY_IDX] = SbkPySide_QtGui_QFormLayout_RowWrapPolicy;
    if (PyType_Ready(SbkPySide_QtGui_QFormLayout_RowWrapPolicy) < 0)
        return;
    PyDict_SetItemString(Sbk_QFormLayout_Type.super.ht_type.tp_dict,
            "RowWrapPolicy",((PyObject*)SbkPySide_QtGui_QFormLayout_RowWrapPolicy));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFormLayout_RowWrapPolicy,(long) QFormLayout::DontWrapRows, "DontWrapRows");
    PyDict_SetItemString(Sbk_QFormLayout_Type.super.ht_type.tp_dict,"DontWrapRows", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_RowWrapPolicy->tp_dict,"DontWrapRows", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFormLayout_RowWrapPolicy,(long) QFormLayout::WrapLongRows, "WrapLongRows");
    PyDict_SetItemString(Sbk_QFormLayout_Type.super.ht_type.tp_dict,"WrapLongRows", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_RowWrapPolicy->tp_dict,"WrapLongRows", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFormLayout_RowWrapPolicy,(long) QFormLayout::WrapAllRows, "WrapAllRows");
    PyDict_SetItemString(Sbk_QFormLayout_Type.super.ht_type.tp_dict,"WrapAllRows", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_RowWrapPolicy->tp_dict,"WrapAllRows", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFormLayout::RowWrapPolicy");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::RowWrapPolicy");
    // end of enum RowWrapPolicy

    // init enum: ItemRole
    PyTypeObject* SbkPySide_QtGui_QFormLayout_ItemRole = Shiboken::Enum::newType("PySide.QtGui.QFormLayout.ItemRole");
    SbkPySide_QtGuiTypes[SBK_QFORMLAYOUT_ITEMROLE_IDX] = SbkPySide_QtGui_QFormLayout_ItemRole;
    if (PyType_Ready(SbkPySide_QtGui_QFormLayout_ItemRole) < 0)
        return;
    PyDict_SetItemString(Sbk_QFormLayout_Type.super.ht_type.tp_dict,
            "ItemRole",((PyObject*)SbkPySide_QtGui_QFormLayout_ItemRole));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFormLayout_ItemRole,(long) QFormLayout::LabelRole, "LabelRole");
    PyDict_SetItemString(Sbk_QFormLayout_Type.super.ht_type.tp_dict,"LabelRole", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_ItemRole->tp_dict,"LabelRole", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFormLayout_ItemRole,(long) QFormLayout::FieldRole, "FieldRole");
    PyDict_SetItemString(Sbk_QFormLayout_Type.super.ht_type.tp_dict,"FieldRole", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_ItemRole->tp_dict,"FieldRole", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFormLayout_ItemRole,(long) QFormLayout::SpanningRole, "SpanningRole");
    PyDict_SetItemString(Sbk_QFormLayout_Type.super.ht_type.tp_dict,"SpanningRole", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_ItemRole->tp_dict,"SpanningRole", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFormLayout::ItemRole");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ItemRole");
    // end of enum ItemRole


    Shiboken::TypeResolver::createObjectTypeResolver<QFormLayout >("QFormLayout*");
    Shiboken::TypeResolver::createObjectTypeResolver<QFormLayout >(typeid(QFormLayout).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QFormLayout >(typeid(QFormLayoutWrapper).name());
    PySide::initQtMetaType< ::QFormLayout* >();
    qRegisterMetaType< ::QFormLayout::FieldGrowthPolicy >("QFormLayout::FieldGrowthPolicy");
    qRegisterMetaType< ::QFormLayout::RowWrapPolicy >("QFormLayout::RowWrapPolicy");
    qRegisterMetaType< ::QFormLayout::ItemRole >("QFormLayout::ItemRole");
}

