/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qimagewriter_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qimage.h>
#include <qimagewriter.h>
#include <qiodevice.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QImageWriter_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QImageWriter >()))
        return -1;

    QImageWriter* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImageWriter(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QImageWriter", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QImageWriter()
    // 1: QImageWriter(QIODevice*,QByteArray)
    // 2: QImageWriter(QString,QByteArray)
    if (numArgs == 0) {
        overloadId = 0; // QImageWriter()
    } else if (numArgs == 2 && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[1])) {
        overloadId = 1; // QImageWriter(QIODevice*,QByteArray)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QImageWriter(QString,QByteArray)
        } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[1])) {
            overloadId = 2; // QImageWriter(QString,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageWriter_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QImageWriter()
            {

                if(!PyErr_Occurred()) {
                    // QImageWriter()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QImageWriter();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QImageWriter(QIODevice*,QByteArray)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QByteArray cppArg1 = Shiboken::Converter<QByteArray >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QImageWriter(QIODevice*,QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QImageWriter(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QImageWriter(QString,QByteArray)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QImageWriter_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImageWriter(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QByteArray cppArg1_tmp = QByteArray();
                QByteArray cppArg1 = pyargs[1] ? Shiboken::Converter<QByteArray >::toCpp(pyargs[1]) : cppArg1_tmp;

                if(!PyErr_Occurred()) {
                    // QImageWriter(QString,QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QImageWriter(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QImageWriter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QImageWriter_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QImageWriter_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QIODevice, PySide.QtCore.QByteArray", "QString, PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImageWriter", overloads);
        return -1;
}

static PyObject* Sbk_QImageWriterFunc_canWrite(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // canWrite()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QImageWriter*>(cppSelf)->canWrite();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageWriterFunc_compression(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // compression()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImageWriter*>(cppSelf)->compression();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageWriterFunc_device(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // device()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIODevice * cppResult = const_cast<const QImageWriter*>(cppSelf)->device();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIODevice * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageWriterFunc_error(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // error()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImageWriter::ImageWriterError cppResult = const_cast<const QImageWriter*>(cppSelf)->error();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImageWriter::ImageWriterError >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageWriterFunc_errorString(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QImageWriter*>(cppSelf)->errorString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageWriterFunc_fileName(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fileName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QImageWriter*>(cppSelf)->fileName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageWriterFunc_format(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // format()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = const_cast<const QImageWriter*>(cppSelf)->format();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageWriterFunc_gamma(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // gamma()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                float cppResult = const_cast<const QImageWriter*>(cppSelf)->gamma();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageWriterFunc_quality(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // quality()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImageWriter*>(cppSelf)->quality();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageWriterFunc_setCompression(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCompression(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCompression(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageWriterFunc_setCompression_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCompression(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCompression(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageWriterFunc_setCompression_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.setCompression", overloads);
        return 0;
}

static PyObject* Sbk_QImageWriterFunc_setDevice(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter< ::QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageWriterFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDevice(QIODevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDevice(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageWriterFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.setDevice", overloads);
        return 0;
}

static PyObject* Sbk_QImageWriterFunc_setFileName(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFileName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageWriterFunc_setFileName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFileName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFileName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageWriterFunc_setFileName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.setFileName", overloads);
        return 0;
}

static PyObject* Sbk_QImageWriterFunc_setFormat(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFormat(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // setFormat(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageWriterFunc_setFormat_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFormat(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageWriterFunc_setFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.setFormat", overloads);
        return 0;
}

static PyObject* Sbk_QImageWriterFunc_setGamma(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGamma(float)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGamma(float)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageWriterFunc_setGamma_TypeError;

    // Call function/method
    {
        {
            float cppArg0 = Shiboken::Converter<float >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGamma(float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setGamma(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageWriterFunc_setGamma_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.setGamma", overloads);
        return 0;
}

static PyObject* Sbk_QImageWriterFunc_setQuality(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setQuality(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setQuality(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageWriterFunc_setQuality_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setQuality(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setQuality(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageWriterFunc_setQuality_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.setQuality", overloads);
        return 0;
}

static PyObject* Sbk_QImageWriterFunc_setText(PyObject* self, PyObject* args)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setText", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setText(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setText(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageWriterFunc_setText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setText(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setText(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageWriterFunc_setText_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImageWriter.setText", overloads);
        return 0;
}

static PyObject* Sbk_QImageWriterFunc_supportedImageFormats(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // supportedImageFormats()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QByteArray > cppResult = QImageWriter::supportedImageFormats();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QByteArray > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageWriterFunc_supportsOption(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: supportsOption(QImageIOHandler::ImageOption)const
    if (Shiboken::Converter< ::QImageIOHandler::ImageOption >::isConvertible(arg)) {
        overloadId = 0; // supportsOption(QImageIOHandler::ImageOption)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageWriterFunc_supportsOption_TypeError;

    // Call function/method
    {
        {
            QImageIOHandler::ImageOption cppArg0 = Shiboken::Converter<QImageIOHandler::ImageOption >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // supportsOption(QImageIOHandler::ImageOption)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QImageWriter*>(cppSelf)->supportsOption(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageWriterFunc_supportsOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImageIOHandler.ImageOption", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.supportsOption", overloads);
        return 0;
}

static PyObject* Sbk_QImageWriterFunc_write(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: write(QImage)
    if (Shiboken::Converter< ::QImage >::isConvertible(arg)) {
        overloadId = 0; // write(QImage)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageWriterFunc_write_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QImage cppArg0 = Shiboken::Converter<QImage >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // write(QImage)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->write(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageWriterFunc_write_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.write", overloads);
        return 0;
}

static PyMethodDef Sbk_QImageWriter_methods[] = {
    {"canWrite", (PyCFunction)Sbk_QImageWriterFunc_canWrite, METH_NOARGS},
    {"compression", (PyCFunction)Sbk_QImageWriterFunc_compression, METH_NOARGS},
    {"device", (PyCFunction)Sbk_QImageWriterFunc_device, METH_NOARGS},
    {"error", (PyCFunction)Sbk_QImageWriterFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QImageWriterFunc_errorString, METH_NOARGS},
    {"fileName", (PyCFunction)Sbk_QImageWriterFunc_fileName, METH_NOARGS},
    {"format", (PyCFunction)Sbk_QImageWriterFunc_format, METH_NOARGS},
    {"gamma", (PyCFunction)Sbk_QImageWriterFunc_gamma, METH_NOARGS},
    {"quality", (PyCFunction)Sbk_QImageWriterFunc_quality, METH_NOARGS},
    {"setCompression", (PyCFunction)Sbk_QImageWriterFunc_setCompression, METH_O},
    {"setDevice", (PyCFunction)Sbk_QImageWriterFunc_setDevice, METH_O},
    {"setFileName", (PyCFunction)Sbk_QImageWriterFunc_setFileName, METH_O},
    {"setFormat", (PyCFunction)Sbk_QImageWriterFunc_setFormat, METH_O},
    {"setGamma", (PyCFunction)Sbk_QImageWriterFunc_setGamma, METH_O},
    {"setQuality", (PyCFunction)Sbk_QImageWriterFunc_setQuality, METH_O},
    {"setText", (PyCFunction)Sbk_QImageWriterFunc_setText, METH_VARARGS},
    {"supportedImageFormats", (PyCFunction)Sbk_QImageWriterFunc_supportedImageFormats, METH_NOARGS|METH_STATIC},
    {"supportsOption", (PyCFunction)Sbk_QImageWriterFunc_supportsOption, METH_O},
    {"write", (PyCFunction)Sbk_QImageWriterFunc_write, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QImageWriter_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QImageWriter",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QImageWriter_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QImageWriter_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QImageWriter(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QIMAGEWRITER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QImageWriter_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QImageWriter_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QImageWriter_Type, &Shiboken::callCppDestructor<QImageWriter >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QImageWriter_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QImageWriter_Type, "QImageWriter*");
    PyModule_AddObject(module, "QImageWriter",
        ((PyObject*)&Sbk_QImageWriter_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ImageWriterError
    PyTypeObject* SbkPySide_QtGui_QImageWriter_ImageWriterError = Shiboken::Enum::newType("PySide.QtGui.QImageWriter.ImageWriterError");
    SbkPySide_QtGuiTypes[SBK_QIMAGEWRITER_IMAGEWRITERERROR_IDX] = SbkPySide_QtGui_QImageWriter_ImageWriterError;
    if (PyType_Ready(SbkPySide_QtGui_QImageWriter_ImageWriterError) < 0)
        return;
    PyDict_SetItemString(Sbk_QImageWriter_Type.super.ht_type.tp_dict,
            "ImageWriterError",((PyObject*)SbkPySide_QtGui_QImageWriter_ImageWriterError));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImageWriter_ImageWriterError,(long) QImageWriter::UnknownError, "UnknownError");
    PyDict_SetItemString(Sbk_QImageWriter_Type.super.ht_type.tp_dict,"UnknownError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImageWriter_ImageWriterError->tp_dict,"UnknownError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImageWriter_ImageWriterError,(long) QImageWriter::DeviceError, "DeviceError");
    PyDict_SetItemString(Sbk_QImageWriter_Type.super.ht_type.tp_dict,"DeviceError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImageWriter_ImageWriterError->tp_dict,"DeviceError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImageWriter_ImageWriterError,(long) QImageWriter::UnsupportedFormatError, "UnsupportedFormatError");
    PyDict_SetItemString(Sbk_QImageWriter_Type.super.ht_type.tp_dict,"UnsupportedFormatError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImageWriter_ImageWriterError->tp_dict,"UnsupportedFormatError", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QImageWriter::ImageWriterError");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ImageWriterError");
    // end of enum ImageWriterError


    Shiboken::TypeResolver::createObjectTypeResolver<QImageWriter >("QImageWriter*");
    Shiboken::TypeResolver::createObjectTypeResolver<QImageWriter >(typeid(QImageWriter).name());
    PySide::initQtMetaType< ::QImageWriter* >();
    qRegisterMetaType< ::QImageWriter::ImageWriterError >("QImageWriter::ImageWriterError");
}

