/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qinputmethodevent_wrapper.h"
#include "qinputmethodevent_attribute_wrapper.h"

// Extra includes
#include <QInputMethodEvent>
#include <QList>
#include <qevent.h>


// Native ---------------------------------------------------------

QInputMethodEventWrapper::QInputMethodEventWrapper() : QInputMethodEvent() {
    // ... middle
}

QInputMethodEventWrapper::QInputMethodEventWrapper(const QString & preeditText, const QList<QInputMethodEvent::Attribute > & attributes) : QInputMethodEvent(preeditText, attributes) {
    // ... middle
}

QInputMethodEventWrapper::~QInputMethodEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QInputMethodEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QInputMethodEvent >()))
        return -1;

    QInputMethodEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QInputMethodEvent", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QInputMethodEvent()
    // 1: QInputMethodEvent(QInputMethodEvent)
    // 2: QInputMethodEvent(QString,QList<QInputMethodEvent::Attribute>)
    if (numArgs == 0) {
        overloadId = 0; // QInputMethodEvent()
    } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QList<QInputMethodEvent::Attribute > >::isConvertible(pyargs[1])) {
        overloadId = 2; // QInputMethodEvent(QString,QList<QInputMethodEvent::Attribute>)
    } else if (numArgs == 1 && Shiboken::Converter< ::QInputMethodEvent >::isConvertible(pyargs[0])) {
        overloadId = 1; // QInputMethodEvent(QInputMethodEvent)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputMethodEvent_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QInputMethodEvent()
            {

                if(!PyErr_Occurred()) {
                    // QInputMethodEvent()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QInputMethodEventWrapper();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QInputMethodEvent(QInputMethodEvent)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                const QInputMethodEvent & cppArg0 = Shiboken::Converter<const QInputMethodEvent & >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QInputMethodEvent(QInputMethodEvent)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QInputMethodEventWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QInputMethodEvent(QString,QList<QInputMethodEvent::Attribute>)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QList<QInputMethodEvent::Attribute > cppArg1 = Shiboken::Converter<QList<QInputMethodEvent::Attribute > >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QInputMethodEvent(QString,QList<QInputMethodEvent::Attribute>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QInputMethodEventWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QInputMethodEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QInputMethodEvent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QInputMethodEvent_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QInputMethodEvent", "QString, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QInputMethodEvent", overloads);
        return -1;
}

static PyObject* Sbk_QInputMethodEventFunc_attributes(PyObject* self)
{
    QInputMethodEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputMethodEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // attributes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QList<QInputMethodEvent::Attribute > & cppResult = const_cast<const QInputMethodEvent*>(cppSelf)->attributes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QInputMethodEvent::Attribute > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputMethodEventFunc_commitString(PyObject* self)
{
    QInputMethodEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputMethodEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // commitString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QString & cppResult = const_cast<const QInputMethodEvent*>(cppSelf)->commitString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputMethodEventFunc_preeditString(PyObject* self)
{
    QInputMethodEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputMethodEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // preeditString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QString & cppResult = const_cast<const QInputMethodEvent*>(cppSelf)->preeditString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputMethodEventFunc_replacementLength(PyObject* self)
{
    QInputMethodEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputMethodEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // replacementLength()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QInputMethodEvent*>(cppSelf)->replacementLength();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputMethodEventFunc_replacementStart(PyObject* self)
{
    QInputMethodEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputMethodEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // replacementStart()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QInputMethodEvent*>(cppSelf)->replacementStart();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputMethodEventFunc_setCommitString(PyObject* self, PyObject* args, PyObject* kwds)
{
    QInputMethodEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputMethodEvent* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputMethodEvent.setCommitString(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputMethodEvent.setCommitString(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setCommitString", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setCommitString(QString,int,int)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setCommitString(QString,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // setCommitString(QString,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // setCommitString(QString,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputMethodEventFunc_setCommitString_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "replaceFrom");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "replaceFrom";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QInputMethodEventFunc_setCommitString_TypeError;
                }
                value = PyDict_GetItemString(kwds, "replaceLength");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "replaceLength";
                    else if (SbkNumber_Check(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QInputMethodEventFunc_setCommitString_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QInputMethodEvent.setCommitString(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;
            int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
                // setCommitString(QString,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCommitString(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputMethodEventFunc_setCommitString_TypeError:
        const char* overloads[] = {"QString, int = 0, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QInputMethodEvent.setCommitString", overloads);
        return 0;
}

static PyMethodDef Sbk_QInputMethodEvent_methods[] = {
    {"attributes", (PyCFunction)Sbk_QInputMethodEventFunc_attributes, METH_NOARGS},
    {"commitString", (PyCFunction)Sbk_QInputMethodEventFunc_commitString, METH_NOARGS},
    {"preeditString", (PyCFunction)Sbk_QInputMethodEventFunc_preeditString, METH_NOARGS},
    {"replacementLength", (PyCFunction)Sbk_QInputMethodEventFunc_replacementLength, METH_NOARGS},
    {"replacementStart", (PyCFunction)Sbk_QInputMethodEventFunc_replacementStart, METH_NOARGS},
    {"setCommitString", (PyCFunction)Sbk_QInputMethodEventFunc_setCommitString, METH_VARARGS|METH_KEYWORDS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QInputMethodEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QInputMethodEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QInputMethodEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QInputMethodEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QInputMethodEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
     if ( reinterpret_cast<QInputMethodEvent*>(cptr)->type() == QEvent::InputMethod)
        return &Sbk_QInputMethodEvent_Type;
    return 0;
}


void init_QInputMethodEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QINPUTMETHODEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QInputMethodEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QInputMethodEvent_Type);
    Sbk_QInputMethodEvent_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QEVENT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QInputMethodEvent_Type, &Shiboken::callCppDestructor<QInputMethodEvent >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QInputMethodEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QInputMethodEvent_Type, &Sbk_QInputMethodEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX]), &Sbk_QInputMethodEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QInputMethodEvent_Type, "QInputMethodEvent*");
    PyModule_AddObject(module, "QInputMethodEvent",
        ((PyObject*)&Sbk_QInputMethodEvent_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: AttributeType
    PyTypeObject* SbkPySide_QtGui_QInputMethodEvent_AttributeType = Shiboken::Enum::newType("PySide.QtGui.QInputMethodEvent.AttributeType");
    SbkPySide_QtGuiTypes[SBK_QINPUTMETHODEVENT_ATTRIBUTETYPE_IDX] = SbkPySide_QtGui_QInputMethodEvent_AttributeType;
    if (PyType_Ready(SbkPySide_QtGui_QInputMethodEvent_AttributeType) < 0)
        return;
    PyDict_SetItemString(Sbk_QInputMethodEvent_Type.super.ht_type.tp_dict,
            "AttributeType",((PyObject*)SbkPySide_QtGui_QInputMethodEvent_AttributeType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QInputMethodEvent_AttributeType,(long) QInputMethodEvent::TextFormat, "TextFormat");
    PyDict_SetItemString(Sbk_QInputMethodEvent_Type.super.ht_type.tp_dict,"TextFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QInputMethodEvent_AttributeType->tp_dict,"TextFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QInputMethodEvent_AttributeType,(long) QInputMethodEvent::Cursor, "Cursor");
    PyDict_SetItemString(Sbk_QInputMethodEvent_Type.super.ht_type.tp_dict,"Cursor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QInputMethodEvent_AttributeType->tp_dict,"Cursor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QInputMethodEvent_AttributeType,(long) QInputMethodEvent::Language, "Language");
    PyDict_SetItemString(Sbk_QInputMethodEvent_Type.super.ht_type.tp_dict,"Language", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QInputMethodEvent_AttributeType->tp_dict,"Language", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QInputMethodEvent_AttributeType,(long) QInputMethodEvent::Ruby, "Ruby");
    PyDict_SetItemString(Sbk_QInputMethodEvent_Type.super.ht_type.tp_dict,"Ruby", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QInputMethodEvent_AttributeType->tp_dict,"Ruby", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QInputMethodEvent_AttributeType,(long) QInputMethodEvent::Selection, "Selection");
    PyDict_SetItemString(Sbk_QInputMethodEvent_Type.super.ht_type.tp_dict,"Selection", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QInputMethodEvent_AttributeType->tp_dict,"Selection", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QInputMethodEvent::AttributeType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::AttributeType");
    // end of enum AttributeType


    Shiboken::TypeResolver::createObjectTypeResolver<QInputMethodEvent >("QInputMethodEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QInputMethodEvent >(typeid(QInputMethodEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QInputMethodEvent >(typeid(QInputMethodEventWrapper).name());
    PySide::initQtMetaType< ::QInputMethodEvent* >();
    qRegisterMetaType< ::QInputMethodEvent::AttributeType >("QInputMethodEvent::AttributeType");
}

