/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qitemselection_wrapper.h"

// Extra includes
#include <QList>
#include <QSet>
#include <QVector>
#include <qabstractitemmodel.h>
#include <qitemselectionmodel.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QItemSelection_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QItemSelection >()))
        return -1;

    QItemSelection* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QItemSelection", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QItemSelection()
    // 1: QItemSelection(QItemSelection)
    // 2: QItemSelection(QModelIndex,QModelIndex)
    if (numArgs == 0) {
        overloadId = 0; // QItemSelection()
    } else if (numArgs == 2 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 2; // QItemSelection(QModelIndex,QModelIndex)
    } else if (numArgs == 1 && Shiboken::Converter< ::QItemSelection >::isConvertible(pyargs[0])) {
        overloadId = 1; // QItemSelection(QItemSelection)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelection_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QItemSelection()
            {

                if(!PyErr_Occurred()) {
                    // QItemSelection()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QItemSelection();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QItemSelection(QItemSelection)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QItemSelection cppArg0 = Shiboken::Converter<QItemSelection >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QItemSelection(QItemSelection)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QItemSelection(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QItemSelection(QModelIndex,QModelIndex)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QModelIndex cppArg1 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QItemSelection(QModelIndex,QModelIndex)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QItemSelection(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QItemSelection >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QItemSelection_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QItemSelection_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QItemSelection", "PySide.QtCore.QModelIndex, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelection", overloads);
        return -1;
}

static PyObject* Sbk_QItemSelectionFunc_append(PyObject* self, PyObject* arg)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: append(QItemSelectionRange)
    // 1: append(QList<QItemSelectionRange>)
    if (Shiboken::Converter< ::QItemSelectionRange >::isConvertible(arg)) {
        overloadId = 0; // append(QItemSelectionRange)
    } else if (Shiboken::Converter< ::QList<QItemSelectionRange > >::isConvertible(arg)) {
        overloadId = 1; // append(QList<QItemSelectionRange>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_append_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // append(QItemSelectionRange)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QItemSelectionRange cppArg0 = Shiboken::Converter<QItemSelectionRange >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // append(QItemSelectionRange)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->append(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // append(QList<QItemSelectionRange>)
            {
                QList<QItemSelectionRange > cppArg0 = Shiboken::Converter<QList<QItemSelectionRange > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // append(QList<QItemSelectionRange>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->append(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionFunc_append_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionRange", "list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.append", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_at(PyObject* self, PyObject* arg)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: at(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // at(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_at_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // at(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QItemSelectionRange & cppResult = const_cast<const QItemSelection*>(cppSelf)->at(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QItemSelectionRange >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_at_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.at", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_back(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // back()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QItemSelectionRange & cppResult = cppSelf->back();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QItemSelectionRange & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionFunc_clear(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QItemSelectionFunc_contains(PyObject* self, PyObject* arg)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(QModelIndex)const
    if (Shiboken::Converter< ::QModelIndex >::isConvertible(arg)) {
        overloadId = 0; // contains(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_contains_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // contains(QModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QItemSelection*>(cppSelf)->contains(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.contains", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_count(PyObject* self, PyObject* args)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "count", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: count()const
    // 1: count(QItemSelectionRange)const
    if (numArgs == 0) {
        overloadId = 0; // count()const
    } else if (numArgs == 1 && Shiboken::Converter< ::QItemSelectionRange >::isConvertible(pyargs[0])) {
        overloadId = 1; // count(QItemSelectionRange)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_count_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // count()const
            {

                if(!PyErr_Occurred()) {
                    // count()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = const_cast<const QItemSelection*>(cppSelf)->count();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // count(QItemSelectionRange)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QItemSelectionRange cppArg0 = Shiboken::Converter<QItemSelectionRange >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // count(QItemSelectionRange)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = const_cast<const QItemSelection*>(cppSelf)->count(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_count_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QItemSelectionRange", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelection.count", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_detachShared(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // detachShared()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->detachShared();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QItemSelectionFunc_empty(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // empty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QItemSelection*>(cppSelf)->empty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionFunc_endsWith(PyObject* self, PyObject* arg)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: endsWith(QItemSelectionRange)const
    if (Shiboken::Converter< ::QItemSelectionRange >::isConvertible(arg)) {
        overloadId = 0; // endsWith(QItemSelectionRange)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_endsWith_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QItemSelectionRange cppArg0 = Shiboken::Converter<QItemSelectionRange >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // endsWith(QItemSelectionRange)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QItemSelection*>(cppSelf)->endsWith(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_endsWith_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionRange", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.endsWith", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_first(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // first()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QItemSelectionRange & cppResult = cppSelf->first();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QItemSelectionRange & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionFunc_fromSet(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromSet(QSet<QItemSelectionRange>)
    if (Shiboken::Converter< ::QSet<QItemSelectionRange > >::isConvertible(arg)) {
        overloadId = 0; // fromSet(QSet<QItemSelectionRange>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_fromSet_TypeError;

    // Call function/method
    {
        {
            QSet<QItemSelectionRange > cppArg0 = Shiboken::Converter<QSet<QItemSelectionRange > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fromSet(QSet<QItemSelectionRange>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QItemSelectionRange > cppResult = QItemSelection::fromSet(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QItemSelectionRange > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_fromSet_TypeError:
        const char* overloads[] = {"QSet", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.fromSet", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_fromVector(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromVector(QVector<QItemSelectionRange>)
    if (Shiboken::Converter< ::QVector<QItemSelectionRange > >::isConvertible(arg)) {
        overloadId = 0; // fromVector(QVector<QItemSelectionRange>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_fromVector_TypeError;

    // Call function/method
    {
        {
            QVector<QItemSelectionRange > cppArg0 = Shiboken::Converter<QVector<QItemSelectionRange > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fromVector(QVector<QItemSelectionRange>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QItemSelectionRange > cppResult = QItemSelection::fromVector(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QItemSelectionRange > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_fromVector_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.fromVector", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_front(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // front()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QItemSelectionRange & cppResult = cppSelf->front();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QItemSelectionRange & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionFunc_indexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QItemSelection.indexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QItemSelection.indexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:indexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: indexOf(QItemSelectionRange,int)const
    if (Shiboken::Converter< ::QItemSelectionRange >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexOf(QItemSelectionRange,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // indexOf(QItemSelectionRange,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_indexOf_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QItemSelectionFunc_indexOf_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QItemSelection.indexOf(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QItemSelectionRange cppArg0 = Shiboken::Converter<QItemSelectionRange >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // indexOf(QItemSelectionRange,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QItemSelection*>(cppSelf)->indexOf(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_indexOf_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionRange, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelection.indexOf", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_indexes(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // indexes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QModelIndex > cppResult = const_cast<const QItemSelection*>(cppSelf)->indexes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QModelIndex > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionFunc_insert(PyObject* self, PyObject* args)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insert", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insert(int,QItemSelectionRange)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QItemSelectionRange >::isConvertible(pyargs[1])) {
        overloadId = 0; // insert(int,QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_insert_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QItemSelectionRange cppArg1 = Shiboken::Converter<QItemSelectionRange >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insert(int,QItemSelectionRange)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insert(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionFunc_insert_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QItemSelectionRange", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelection.insert", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_isEmpty(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QItemSelection*>(cppSelf)->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionFunc_last(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // last()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QItemSelectionRange & cppResult = cppSelf->last();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QItemSelectionRange & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionFunc_lastIndexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QItemSelection.lastIndexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QItemSelection.lastIndexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:lastIndexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: lastIndexOf(QItemSelectionRange,int)const
    if (Shiboken::Converter< ::QItemSelectionRange >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // lastIndexOf(QItemSelectionRange,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // lastIndexOf(QItemSelectionRange,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_lastIndexOf_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QItemSelectionFunc_lastIndexOf_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QItemSelection.lastIndexOf(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QItemSelectionRange cppArg0 = Shiboken::Converter<QItemSelectionRange >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
                // lastIndexOf(QItemSelectionRange,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QItemSelection*>(cppSelf)->lastIndexOf(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_lastIndexOf_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionRange, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelection.lastIndexOf", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_length(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // length()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QItemSelection*>(cppSelf)->length();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionFunc_merge(PyObject* self, PyObject* args)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "merge", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: merge(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
    if (numArgs == 2 && Shiboken::Converter< ::QItemSelection >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyargs[1])) {
        overloadId = 0; // merge(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_merge_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QItemSelection cppArg0 = Shiboken::Converter<QItemSelection >::toCpp(pyargs[0]);
            QFlags<QItemSelectionModel::SelectionFlag> cppArg1 = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // merge(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->merge(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionFunc_merge_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelection, PySide.QtGui.QItemSelectionModel.SelectionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelection.merge", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_mid(PyObject* self, PyObject* args, PyObject* kwds)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QItemSelection.mid(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QItemSelection.mid(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:mid", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: mid(int,int)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // mid(int,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // mid(int,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_mid_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "length");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "length";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QItemSelectionFunc_mid_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QItemSelection.mid(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
                // mid(int,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QItemSelectionRange > cppResult = const_cast<const QItemSelection*>(cppSelf)->mid(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QItemSelectionRange > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_mid_TypeError:
        const char* overloads[] = {"int, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelection.mid", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_move(PyObject* self, PyObject* args)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "move", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: move(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // move(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_move_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // move(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->move(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionFunc_move_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelection.move", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_pop_back(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pop_back()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->pop_back();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QItemSelectionFunc_pop_front(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pop_front()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->pop_front();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QItemSelectionFunc_prepend(PyObject* self, PyObject* arg)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: prepend(QItemSelectionRange)
    if (Shiboken::Converter< ::QItemSelectionRange >::isConvertible(arg)) {
        overloadId = 0; // prepend(QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_prepend_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QItemSelectionRange cppArg0 = Shiboken::Converter<QItemSelectionRange >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // prepend(QItemSelectionRange)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->prepend(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionFunc_prepend_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionRange", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.prepend", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_push_back(PyObject* self, PyObject* arg)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: push_back(QItemSelectionRange)
    if (Shiboken::Converter< ::QItemSelectionRange >::isConvertible(arg)) {
        overloadId = 0; // push_back(QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_push_back_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QItemSelectionRange cppArg0 = Shiboken::Converter<QItemSelectionRange >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // push_back(QItemSelectionRange)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->push_back(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionFunc_push_back_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionRange", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.push_back", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_push_front(PyObject* self, PyObject* arg)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: push_front(QItemSelectionRange)
    if (Shiboken::Converter< ::QItemSelectionRange >::isConvertible(arg)) {
        overloadId = 0; // push_front(QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_push_front_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QItemSelectionRange cppArg0 = Shiboken::Converter<QItemSelectionRange >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // push_front(QItemSelectionRange)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->push_front(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionFunc_push_front_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionRange", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.push_front", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_removeAll(PyObject* self, PyObject* arg)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAll(QItemSelectionRange)
    if (Shiboken::Converter< ::QItemSelectionRange >::isConvertible(arg)) {
        overloadId = 0; // removeAll(QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_removeAll_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QItemSelectionRange cppArg0 = Shiboken::Converter<QItemSelectionRange >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeAll(QItemSelectionRange)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->removeAll(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_removeAll_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionRange", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.removeAll", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_removeAt(PyObject* self, PyObject* arg)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAt(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // removeAt(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_removeAt_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeAt(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeAt(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionFunc_removeAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.removeAt", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_removeFirst(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // removeFirst()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeFirst();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QItemSelectionFunc_removeLast(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // removeLast()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeLast();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QItemSelectionFunc_removeOne(PyObject* self, PyObject* arg)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeOne(QItemSelectionRange)
    if (Shiboken::Converter< ::QItemSelectionRange >::isConvertible(arg)) {
        overloadId = 0; // removeOne(QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_removeOne_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QItemSelectionRange cppArg0 = Shiboken::Converter<QItemSelectionRange >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeOne(QItemSelectionRange)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->removeOne(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_removeOne_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionRange", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.removeOne", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_replace(PyObject* self, PyObject* args)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replace", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: replace(int,QItemSelectionRange)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QItemSelectionRange >::isConvertible(pyargs[1])) {
        overloadId = 0; // replace(int,QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_replace_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QItemSelectionRange cppArg1 = Shiboken::Converter<QItemSelectionRange >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // replace(int,QItemSelectionRange)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->replace(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionFunc_replace_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QItemSelectionRange", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelection.replace", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_select(PyObject* self, PyObject* args)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "select", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: select(QModelIndex,QModelIndex)
    if (numArgs == 2 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 0; // select(QModelIndex,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_select_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QModelIndex cppArg1 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // select(QModelIndex,QModelIndex)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->select(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionFunc_select_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelection.select", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_setSharable(PyObject* self, PyObject* arg)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSharable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSharable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_setSharable_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSharable(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSharable(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionFunc_setSharable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.setSharable", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_size(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QItemSelection*>(cppSelf)->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionFunc_split(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "split", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: split(QItemSelectionRange,QItemSelectionRange,QItemSelection*)
    if (numArgs == 3 && Shiboken::Converter< ::QItemSelectionRange >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QItemSelectionRange >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QItemSelection * >::isConvertible(pyargs[2])) {
        overloadId = 0; // split(QItemSelectionRange,QItemSelectionRange,QItemSelection*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_split_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QItemSelectionRange cppArg0 = Shiboken::Converter<QItemSelectionRange >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QItemSelectionRange cppArg1 = Shiboken::Converter<QItemSelectionRange >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QItemSelection * cppArg2 = Shiboken::Converter<QItemSelection * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // split(QItemSelectionRange,QItemSelectionRange,QItemSelection*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QItemSelection::split(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionFunc_split_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionRange, PySide.QtGui.QItemSelectionRange, PySide.QtGui.QItemSelection", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelection.split", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_startsWith(PyObject* self, PyObject* arg)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: startsWith(QItemSelectionRange)const
    if (Shiboken::Converter< ::QItemSelectionRange >::isConvertible(arg)) {
        overloadId = 0; // startsWith(QItemSelectionRange)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_startsWith_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QItemSelectionRange cppArg0 = Shiboken::Converter<QItemSelectionRange >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // startsWith(QItemSelectionRange)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QItemSelection*>(cppSelf)->startsWith(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_startsWith_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionRange", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.startsWith", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_swap(PyObject* self, PyObject* args)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "swap", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: swap(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // swap(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_swap_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // swap(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->swap(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionFunc_swap_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelection.swap", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_takeAt(PyObject* self, PyObject* arg)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: takeAt(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // takeAt(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_takeAt_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // takeAt(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QItemSelectionRange cppResult = cppSelf->takeAt(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QItemSelectionRange >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_takeAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelection.takeAt", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionFunc_takeFirst(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // takeFirst()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QItemSelectionRange cppResult = cppSelf->takeFirst();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QItemSelectionRange >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionFunc_takeLast(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // takeLast()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QItemSelectionRange cppResult = cppSelf->takeLast();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QItemSelectionRange >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionFunc_toSet(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toSet()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSet<QItemSelectionRange > cppResult = const_cast<const QItemSelection*>(cppSelf)->toSet();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSet<QItemSelectionRange > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionFunc_toVector(PyObject* self)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toVector()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QItemSelectionRange > cppResult = const_cast<const QItemSelection*>(cppSelf)->toVector();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QItemSelectionRange > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionFunc_value(PyObject* self, PyObject* args)
{
    QItemSelection* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelection* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "value", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: value(int)const
    // 1: value(int,QItemSelectionRange)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // value(int)const
        } else if (numArgs == 2 && Shiboken::Converter< ::QItemSelectionRange >::isConvertible(pyargs[1])) {
            overloadId = 1; // value(int,QItemSelectionRange)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionFunc_value_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // value(int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // value(int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QItemSelectionRange cppResult = const_cast<const QItemSelection*>(cppSelf)->value(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QItemSelectionRange >::toPython(cppResult);
                }
                break;
            }
            case 1: // value(int,QItemSelectionRange)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QItemSelectionRange cppArg1 = Shiboken::Converter<QItemSelectionRange >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // value(int,QItemSelectionRange)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QItemSelectionRange cppResult = const_cast<const QItemSelection*>(cppSelf)->value(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QItemSelectionRange >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionFunc_value_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtGui.QItemSelectionRange", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelection.value", overloads);
        return 0;
}

static PyObject *Sbk_QItemSelection___copy__(PyObject *self)
{
        QItemSelection* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QItemSelection*>::toCpp(self);
        PyObject* pyResult = 0;
        QItemSelection* copy = new QItemSelection(*cppSelf);
        pyResult = Shiboken::Converter<QItemSelection*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QItemSelection_methods[] = {
    {"append", (PyCFunction)Sbk_QItemSelectionFunc_append, METH_O},
    {"at", (PyCFunction)Sbk_QItemSelectionFunc_at, METH_O},
    {"back", (PyCFunction)Sbk_QItemSelectionFunc_back, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QItemSelectionFunc_clear, METH_NOARGS},
    {"contains", (PyCFunction)Sbk_QItemSelectionFunc_contains, METH_O},
    {"count", (PyCFunction)Sbk_QItemSelectionFunc_count, METH_VARARGS},
    {"detachShared", (PyCFunction)Sbk_QItemSelectionFunc_detachShared, METH_NOARGS},
    {"empty", (PyCFunction)Sbk_QItemSelectionFunc_empty, METH_NOARGS},
    {"endsWith", (PyCFunction)Sbk_QItemSelectionFunc_endsWith, METH_O},
    {"first", (PyCFunction)Sbk_QItemSelectionFunc_first, METH_NOARGS},
    {"fromSet", (PyCFunction)Sbk_QItemSelectionFunc_fromSet, METH_O|METH_STATIC},
    {"fromVector", (PyCFunction)Sbk_QItemSelectionFunc_fromVector, METH_O|METH_STATIC},
    {"front", (PyCFunction)Sbk_QItemSelectionFunc_front, METH_NOARGS},
    {"indexOf", (PyCFunction)Sbk_QItemSelectionFunc_indexOf, METH_VARARGS|METH_KEYWORDS},
    {"indexes", (PyCFunction)Sbk_QItemSelectionFunc_indexes, METH_NOARGS},
    {"insert", (PyCFunction)Sbk_QItemSelectionFunc_insert, METH_VARARGS},
    {"isEmpty", (PyCFunction)Sbk_QItemSelectionFunc_isEmpty, METH_NOARGS},
    {"last", (PyCFunction)Sbk_QItemSelectionFunc_last, METH_NOARGS},
    {"lastIndexOf", (PyCFunction)Sbk_QItemSelectionFunc_lastIndexOf, METH_VARARGS|METH_KEYWORDS},
    {"length", (PyCFunction)Sbk_QItemSelectionFunc_length, METH_NOARGS},
    {"merge", (PyCFunction)Sbk_QItemSelectionFunc_merge, METH_VARARGS},
    {"mid", (PyCFunction)Sbk_QItemSelectionFunc_mid, METH_VARARGS|METH_KEYWORDS},
    {"move", (PyCFunction)Sbk_QItemSelectionFunc_move, METH_VARARGS},
    {"pop_back", (PyCFunction)Sbk_QItemSelectionFunc_pop_back, METH_NOARGS},
    {"pop_front", (PyCFunction)Sbk_QItemSelectionFunc_pop_front, METH_NOARGS},
    {"prepend", (PyCFunction)Sbk_QItemSelectionFunc_prepend, METH_O},
    {"push_back", (PyCFunction)Sbk_QItemSelectionFunc_push_back, METH_O},
    {"push_front", (PyCFunction)Sbk_QItemSelectionFunc_push_front, METH_O},
    {"removeAll", (PyCFunction)Sbk_QItemSelectionFunc_removeAll, METH_O},
    {"removeAt", (PyCFunction)Sbk_QItemSelectionFunc_removeAt, METH_O},
    {"removeFirst", (PyCFunction)Sbk_QItemSelectionFunc_removeFirst, METH_NOARGS},
    {"removeLast", (PyCFunction)Sbk_QItemSelectionFunc_removeLast, METH_NOARGS},
    {"removeOne", (PyCFunction)Sbk_QItemSelectionFunc_removeOne, METH_O},
    {"replace", (PyCFunction)Sbk_QItemSelectionFunc_replace, METH_VARARGS},
    {"select", (PyCFunction)Sbk_QItemSelectionFunc_select, METH_VARARGS},
    {"setSharable", (PyCFunction)Sbk_QItemSelectionFunc_setSharable, METH_O},
    {"size", (PyCFunction)Sbk_QItemSelectionFunc_size, METH_NOARGS},
    {"split", (PyCFunction)Sbk_QItemSelectionFunc_split, METH_VARARGS|METH_STATIC},
    {"startsWith", (PyCFunction)Sbk_QItemSelectionFunc_startsWith, METH_O},
    {"swap", (PyCFunction)Sbk_QItemSelectionFunc_swap, METH_VARARGS},
    {"takeAt", (PyCFunction)Sbk_QItemSelectionFunc_takeAt, METH_O},
    {"takeFirst", (PyCFunction)Sbk_QItemSelectionFunc_takeFirst, METH_NOARGS},
    {"takeLast", (PyCFunction)Sbk_QItemSelectionFunc_takeLast, METH_NOARGS},
    {"toSet", (PyCFunction)Sbk_QItemSelectionFunc_toSet, METH_NOARGS},
    {"toVector", (PyCFunction)Sbk_QItemSelectionFunc_toVector, METH_NOARGS},
    {"value", (PyCFunction)Sbk_QItemSelectionFunc_value, METH_VARARGS},

    {"__copy__", (PyCFunction)Sbk_QItemSelection___copy__, METH_NOARGS},
    {0} // Sentinel
};

// type has number operators
static PyNumberMethods Sbk_QItemSelection_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

Py_ssize_t Sbk_QItemSelection__len__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;

    QItemSelection &cppSelf = Shiboken::Converter<QItemSelection& >::toCpp(self);
    return cppSelf.size();
}
PyObject* Sbk_QItemSelection__getitem__(PyObject* self, Py_ssize_t _i)
{
    if (!Shiboken::Object::isValid(self))
        return 0;

    QItemSelection &cppSelf = Shiboken::Converter<QItemSelection& >::toCpp(self);
    if (_i < 0 || _i >= (Py_ssize_t) cppSelf.size()) {
        PyErr_SetString(PyExc_IndexError, "index out of bounds");
        return 0;
    }
    QItemSelection::iterator _item = cppSelf.begin();
    for(Py_ssize_t pos=0; pos < _i; pos++) _item++;
    return Shiboken::Converter<QItemSelection::value_type>::toPython(*_item);
}
int Sbk_QItemSelection__setitem__(PyObject* self, Py_ssize_t _i, PyObject* _value)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    QItemSelection &cppSelf = Shiboken::Converter<QItemSelection& >::toCpp(self);
    if (_i < 0 || _i >= (Py_ssize_t) cppSelf.size()) {
        PyErr_SetString(PyExc_IndexError, "list assignment index out of range");
        return -1;
    }
    QItemSelection::iterator _item = cppSelf.begin();
    for(Py_ssize_t pos=0; pos < _i; pos++) _item++;
    QItemSelection::value_type cppValue = Shiboken::Converter<QItemSelection::value_type>::toCpp(_value);
    *_item = cppValue;
    return 0;
}
static PySequenceMethods PyQItemSelection_as_sequence = {
    /*sq_length*/ Sbk_QItemSelection__len__,
    /*sq_concat*/ 0,
    /*sq_repeat*/ 0,
    /*sq_item*/ Sbk_QItemSelection__getitem__,
    /*sq_slice*/ 0,
    /*sq_ass_item*/ Sbk_QItemSelection__setitem__,
    /*sq_ass_slice*/ 0,
    /*sq_contains*/ 0,
    /*sq_inplace_concat*/ 0,
    /*sq_inplace_repeat*/ 0
};

// Rich comparison
static PyObject* Sbk_QItemSelection_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QItemSelection& cppSelf = *Shiboken::Converter< QItemSelection* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QList<QItemSelectionRange > >::isConvertible(arg)) {
                // operator!=(const QList<QItemSelectionRange > & l) const
                QList<QItemSelectionRange > cppArg0 = Shiboken::Converter< ::QList<QItemSelectionRange > >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QItemSelection_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QList<QItemSelectionRange > >::isConvertible(arg)) {
                // operator==(const QList<QItemSelectionRange > & l) const
                QList<QItemSelectionRange > cppArg0 = Shiboken::Converter< ::QList<QItemSelectionRange > >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QItemSelection_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QItemSelection_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QItemSelection_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QItemSelection_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QItemSelection",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QItemSelection_as_number,
    /*tp_as_sequence*/      &PyQItemSelection_as_sequence,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QItemSelection_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QItemSelection_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QItemSelection_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QItemSelection(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QITEMSELECTION_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QItemSelection_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QItemSelection_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QItemSelection_Type, &Shiboken::callCppDestructor<QItemSelection >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QItemSelection_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QItemSelection_Type, "QItemSelection");
    PyModule_AddObject(module, "QItemSelection",
        ((PyObject*)&Sbk_QItemSelection_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QItemSelection >("QItemSelection");
    Shiboken::TypeResolver::createObjectTypeResolver<QItemSelection >("QItemSelection*");
    Shiboken::TypeResolver::createValueTypeResolver<QItemSelection >(typeid(QItemSelection).name());
    PySide::initQtMetaType< ::QItemSelection >();
}

