/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qkeyevent_wrapper.h"

// Extra includes
#include <qevent.h>


// Native ---------------------------------------------------------

QKeyEventWrapper::QKeyEventWrapper(QEvent::Type type, int key, QFlags<Qt::KeyboardModifier> modifiers, const QString & text, bool autorep, ushort count) : QKeyEvent(type, key, modifiers, text, autorep, count) {
    // ... middle
}

QKeyEventWrapper::~QKeyEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QKeyEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QKeyEvent >()))
        return -1;

    QKeyEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QKeyEvent(): too many arguments");
        return -1;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QKeyEvent(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:QKeyEvent", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return -1;

    // Overloaded function decisor
    // 0: QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
    if (numArgs >= 3 && Shiboken::Converter< ::QEvent::Type >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QFlags<Qt::KeyboardModifier> >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
            } else if (SbkNumber_Check(pyargs[4])) {
                if (numArgs == 5) {
                    overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
                } else if (SbkNumber_Check(pyargs[5])) {
                    overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QKeyEvent_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "text");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "text";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QKeyEvent_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "autorep");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "autorep";
                    else if (SbkNumber_Check(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QKeyEvent_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "count");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "count";
                    else if (SbkNumber_Check(value))
                        pyargs[5] = value;
                    else
                        goto Sbk_QKeyEvent_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QKeyEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            QEvent::Type cppArg0 = Shiboken::Converter<QEvent::Type >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            QFlags<Qt::KeyboardModifier> cppArg2 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(pyargs[2]);
            QString cppArg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
            bool cppArg4 = pyargs[4] ? Shiboken::Converter<bool >::toCpp(pyargs[4]) : false;
            ushort cppArg5 = pyargs[5] ? Shiboken::Converter<ushort >::toCpp(pyargs[5]) : 1;

            if(!PyErr_Occurred()) {
                // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QKeyEventWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QKeyEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QKeyEvent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QKeyEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent.Type, int, PySide.QtCore.Qt.KeyboardModifiers, QString = QString(), bool = false, ushort = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QKeyEvent", overloads);
        return -1;
}

static PyObject* Sbk_QKeyEventFunc_count(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // count()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QKeyEvent*>(cppSelf)->count();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QKeyEventFunc_createExtendedKeyEvent(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 9) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QKeyEvent.createExtendedKeyEvent(): too many arguments");
        return 0;
    } else if (numArgs < 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QKeyEvent.createExtendedKeyEvent(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOOO:createExtendedKeyEvent", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8])))
        return 0;


    // Overloaded function decisor
    // 0: createExtendedKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,ushort)
    if (numArgs >= 6 && Shiboken::Converter< ::QEvent::Type >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QFlags<Qt::KeyboardModifier> >::isConvertible(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        if (numArgs == 6) {
            overloadId = 0; // createExtendedKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,ushort)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[6])) {
            if (numArgs == 7) {
                overloadId = 0; // createExtendedKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,ushort)
            } else if (SbkNumber_Check(pyargs[7])) {
                if (numArgs == 8) {
                    overloadId = 0; // createExtendedKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,ushort)
                } else if (SbkNumber_Check(pyargs[8])) {
                    overloadId = 0; // createExtendedKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,ushort)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QKeyEventFunc_createExtendedKeyEvent_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "text");
                if (value) {
                    if (pyargs[6])
                        errorArgName = "text";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[6] = value;
                    else
                        goto Sbk_QKeyEventFunc_createExtendedKeyEvent_TypeError;
                }
                value = PyDict_GetItemString(kwds, "autorep");
                if (value) {
                    if (pyargs[7])
                        errorArgName = "autorep";
                    else if (SbkNumber_Check(value))
                        pyargs[7] = value;
                    else
                        goto Sbk_QKeyEventFunc_createExtendedKeyEvent_TypeError;
                }
                value = PyDict_GetItemString(kwds, "count");
                if (value) {
                    if (pyargs[8])
                        errorArgName = "count";
                    else if (SbkNumber_Check(value))
                        pyargs[8] = value;
                    else
                        goto Sbk_QKeyEventFunc_createExtendedKeyEvent_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QKeyEvent.createExtendedKeyEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QEvent::Type cppArg0 = Shiboken::Converter<QEvent::Type >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            QFlags<Qt::KeyboardModifier> cppArg2 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(pyargs[2]);
            quint32 cppArg3 = Shiboken::Converter<quint32 >::toCpp(pyargs[3]);
            quint32 cppArg4 = Shiboken::Converter<quint32 >::toCpp(pyargs[4]);
            quint32 cppArg5 = Shiboken::Converter<quint32 >::toCpp(pyargs[5]);
            QString cppArg6 = pyargs[6] ? Shiboken::Converter<QString >::toCpp(pyargs[6]) : QString();
            bool cppArg7 = pyargs[7] ? Shiboken::Converter<bool >::toCpp(pyargs[7]) : false;
            ushort cppArg8 = pyargs[8] ? Shiboken::Converter<ushort >::toCpp(pyargs[8]) : 1;

            if(!PyErr_Occurred()) {
                // createExtendedKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,ushort)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QKeyEvent * cppResult = QKeyEvent::createExtendedKeyEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QKeyEvent * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QKeyEventFunc_createExtendedKeyEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent.Type, int, PySide.QtCore.Qt.KeyboardModifiers, unsigned int, unsigned int, unsigned int, QString = QString(), bool = false, ushort = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QKeyEvent.createExtendedKeyEvent", overloads);
        return 0;
}

static PyObject* Sbk_QKeyEventFunc_hasExtendedInfo(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasExtendedInfo()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QKeyEvent*>(cppSelf)->hasExtendedInfo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QKeyEventFunc_isAutoRepeat(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isAutoRepeat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QKeyEvent*>(cppSelf)->isAutoRepeat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QKeyEventFunc_key(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // key()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QKeyEvent*>(cppSelf)->key();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QKeyEventFunc_matches(PyObject* self, PyObject* arg)
{
    QKeyEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: matches(QKeySequence::StandardKey)const
    if (Shiboken::Converter< ::QKeySequence::StandardKey >::isConvertible(arg)) {
        overloadId = 0; // matches(QKeySequence::StandardKey)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QKeyEventFunc_matches_TypeError;

    // Call function/method
    {
        {
            QKeySequence::StandardKey cppArg0 = Shiboken::Converter<QKeySequence::StandardKey >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // matches(QKeySequence::StandardKey)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QKeyEvent*>(cppSelf)->matches(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QKeyEventFunc_matches_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence.StandardKey", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QKeyEvent.matches", overloads);
        return 0;
}

static PyObject* Sbk_QKeyEventFunc_modifiers(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // modifiers()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::KeyboardModifier> cppResult = const_cast<const QKeyEvent*>(cppSelf)->modifiers();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::KeyboardModifier> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QKeyEventFunc_nativeModifiers(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nativeModifiers()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                quint32 cppResult = const_cast<const QKeyEvent*>(cppSelf)->nativeModifiers();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QKeyEventFunc_nativeScanCode(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nativeScanCode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                quint32 cppResult = const_cast<const QKeyEvent*>(cppSelf)->nativeScanCode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QKeyEventFunc_nativeVirtualKey(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nativeVirtualKey()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                quint32 cppResult = const_cast<const QKeyEvent*>(cppSelf)->nativeVirtualKey();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QKeyEventFunc_text(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // text()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QKeyEvent*>(cppSelf)->text();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QKeyEvent_methods[] = {
    {"count", (PyCFunction)Sbk_QKeyEventFunc_count, METH_NOARGS},
    {"createExtendedKeyEvent", (PyCFunction)Sbk_QKeyEventFunc_createExtendedKeyEvent, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"hasExtendedInfo", (PyCFunction)Sbk_QKeyEventFunc_hasExtendedInfo, METH_NOARGS},
    {"isAutoRepeat", (PyCFunction)Sbk_QKeyEventFunc_isAutoRepeat, METH_NOARGS},
    {"key", (PyCFunction)Sbk_QKeyEventFunc_key, METH_NOARGS},
    {"matches", (PyCFunction)Sbk_QKeyEventFunc_matches, METH_O},
    {"modifiers", (PyCFunction)Sbk_QKeyEventFunc_modifiers, METH_NOARGS},
    {"nativeModifiers", (PyCFunction)Sbk_QKeyEventFunc_nativeModifiers, METH_NOARGS},
    {"nativeScanCode", (PyCFunction)Sbk_QKeyEventFunc_nativeScanCode, METH_NOARGS},
    {"nativeVirtualKey", (PyCFunction)Sbk_QKeyEventFunc_nativeVirtualKey, METH_NOARGS},
    {"text", (PyCFunction)Sbk_QKeyEventFunc_text, METH_NOARGS},

    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QKeyEvent_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QKeyEvent& cppSelf = *Shiboken::Converter< QKeyEvent* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QKeySequence::StandardKey >::isConvertible(arg)) {
                // operator!=(QKeySequence::StandardKey arg__1)
                QKeySequence::StandardKey cppArg0 = Shiboken::Converter< ::QKeySequence::StandardKey >::toCpp(arg);
                // Begin code injection

                pyResult = Shiboken::Converter<bool >::toPython(!(&cppSelf == cppArg0));

                // End of code injection
            } else goto Sbk_QKeyEvent_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QKeySequence::StandardKey >::isConvertible(arg)) {
                // operator==(QKeySequence::StandardKey key)
                QKeySequence::StandardKey cppArg0 = Shiboken::Converter< ::QKeySequence::StandardKey >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(&cppSelf == cppArg0);
            } else if (Shiboken::Converter< ::QKeySequence::StandardKey >::isConvertible(arg)) {
                // operator==(QKeySequence::StandardKey key)
                QKeySequence::StandardKey cppArg0 = Shiboken::Converter< ::QKeySequence::StandardKey >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(&cppSelf == cppArg0);
            } else goto Sbk_QKeyEvent_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QKeyEvent_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QKeyEvent_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

static PyObject* Sbk_QKeyEvent_get_autor(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< unsigned int >::toPython( Shiboken::Converter< QKeyEvent* >::toCpp(self)->autor);
    return val;
}

static int Sbk_QKeyEvent_set_autor(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'autor' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'autor', 'uint' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QKeyEvent* >::toCpp(self)->autor = Shiboken::Converter< unsigned int >::toCpp(value);

    return 0;
}

// Getters and Setters for QKeyEvent
static PyGetSetDef Sbk_QKeyEvent_getsetlist[] = {
    {const_cast<char*>("autor"), Sbk_QKeyEvent_get_autor, Sbk_QKeyEvent_set_autor},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QKeyEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QKeyEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QKeyEvent_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QKeyEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QKeyEvent_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QKeyEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QKeyEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
     if ( reinterpret_cast<QKeyEvent*>(cptr)->type() == QEvent::KeyPress ||  reinterpret_cast<QKeyEvent*>(cptr)->type() == QEvent::KeyRelease)
        return &Sbk_QKeyEvent_Type;
    return 0;
}


void init_QKeyEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QKEYEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QKeyEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QKeyEvent_Type);
    Sbk_QKeyEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QINPUTEVENT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QKeyEvent_Type, &Shiboken::callCppDestructor<QKeyEvent >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QKeyEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QKeyEvent_Type, &Sbk_QKeyEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QINPUTEVENT_IDX]), &Sbk_QKeyEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QKeyEvent_Type, "QKeyEvent*");
    PyModule_AddObject(module, "QKeyEvent",
        ((PyObject*)&Sbk_QKeyEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QKeyEvent >("QKeyEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QKeyEvent >(typeid(QKeyEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QKeyEvent >(typeid(QKeyEventWrapper).name());
    PySide::initQtMetaType< ::QKeyEvent* >();
}

