/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qkeysequence_wrapper.h"

// Extra includes
#include <QList>
#include <qdatastream.h>
#include <qkeysequence.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QKeySequence_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QKeySequence >()))
        return -1;

    QKeySequence* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QKeySequence(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QKeySequence", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QKeySequence()
    // 1: QKeySequence(QKeySequence::StandardKey)
    // 2: QKeySequence(QKeySequence)
    // 3: QKeySequence(QString)
    // 4: QKeySequence(int,int,int,int)
    if (numArgs == 0) {
        overloadId = 0; // QKeySequence()
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 3; // QKeySequence(QString)
    } else if (numArgs == 1 && Shiboken::Converter< ::QKeySequence::StandardKey >::isConvertible(pyargs[0])) {
        overloadId = 1; // QKeySequence(QKeySequence::StandardKey)
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 4; // QKeySequence(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 4; // QKeySequence(int,int,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 4; // QKeySequence(int,int,int,int)
                } else if (SbkNumber_Check(pyargs[3])) {
                    overloadId = 4; // QKeySequence(int,int,int,int)
                }
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QKeySequence >::isConvertible(pyargs[0])) {
        overloadId = 2; // QKeySequence(QKeySequence)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QKeySequence_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QKeySequence()
            {

                if(!PyErr_Occurred()) {
                    // QKeySequence()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QKeySequence();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QKeySequence(QKeySequence::StandardKey)
            {
                QKeySequence::StandardKey cppArg0 = Shiboken::Converter<QKeySequence::StandardKey >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QKeySequence(QKeySequence::StandardKey)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QKeySequence(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QKeySequence(QKeySequence)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QKeySequence cppArg0 = Shiboken::Converter<QKeySequence >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QKeySequence(QKeySequence)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QKeySequence(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QKeySequence(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QKeySequence(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QKeySequence(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QKeySequence(int,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "k2");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "k2";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QKeySequence_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "k3");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "k3";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QKeySequence_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "k4");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "k4";
                        else if (SbkNumber_Check(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QKeySequence_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QKeySequence(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;
                int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                    // QKeySequence(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QKeySequence(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QKeySequence >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QKeySequence_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QKeySequence_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QKeySequence.StandardKey", "PySide.QtGui.QKeySequence", "QString", "int, int = 0, int = 0, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QKeySequence", overloads);
        return -1;
}

static PyObject* Sbk_QKeySequenceFunc___reduce__(PyObject* self)
{
    QKeySequence* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeySequence* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection

                // TEMPLATE - reduce_code - START
                pyResult = Py_BuildValue("(N(iiii))", PyObject_Type(self), (*cppSelf)[0], (*cppSelf)[1], (*cppSelf)[2], (*cppSelf)[3]);
                // TEMPLATE - reduce_code - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QKeySequenceFunc___repr__(PyObject* self)
{
    QKeySequence* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeySequence* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __repr__()
                // Begin code injection

                // TEMPLATE - repr_code - START
                QString format = QString().sprintf("%s(%i, %i, %i, %i)", ((PyObject*)self)->ob_type->tp_name, (*cppSelf)[0], (*cppSelf)[1], (*cppSelf)[2], (*cppSelf)[3]);
                pyResult = PyString_FromString(qPrintable(format));
                // TEMPLATE - repr_code - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QKeySequenceFunc_count(PyObject* self)
{
    QKeySequence* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeySequence* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // count()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                uint cppResult = const_cast<const QKeySequence*>(cppSelf)->count();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QKeySequenceFunc_fromString(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QKeySequence.fromString(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QKeySequence.fromString(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromString", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromString(QString,QKeySequence::SequenceFormat)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromString(QString,QKeySequence::SequenceFormat)
        } else if (Shiboken::Converter< ::QKeySequence::SequenceFormat >::isConvertible(pyargs[1])) {
            overloadId = 0; // fromString(QString,QKeySequence::SequenceFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QKeySequenceFunc_fromString_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else if (Shiboken::Converter< ::QKeySequence::SequenceFormat >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QKeySequenceFunc_fromString_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QKeySequence.fromString(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QKeySequence::SequenceFormat cppArg1 = pyargs[1] ? Shiboken::Converter<QKeySequence::SequenceFormat >::toCpp(pyargs[1]) : QKeySequence::PortableText;

            if(!PyErr_Occurred()) {
                // fromString(QString,QKeySequence::SequenceFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QKeySequence cppResult = QKeySequence::fromString(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QKeySequence >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QKeySequenceFunc_fromString_TypeError:
        const char* overloads[] = {"QString, PySide.QtGui.QKeySequence.SequenceFormat = PortableText", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QKeySequence.fromString", overloads);
        return 0;
}

static PyObject* Sbk_QKeySequenceFunc_isEmpty(PyObject* self)
{
    QKeySequence* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeySequence* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QKeySequence*>(cppSelf)->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QKeySequenceFunc_keyBindings(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyBindings(QKeySequence::StandardKey)
    if (Shiboken::Converter< ::QKeySequence::StandardKey >::isConvertible(arg)) {
        overloadId = 0; // keyBindings(QKeySequence::StandardKey)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QKeySequenceFunc_keyBindings_TypeError;

    // Call function/method
    {
        {
            QKeySequence::StandardKey cppArg0 = Shiboken::Converter<QKeySequence::StandardKey >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // keyBindings(QKeySequence::StandardKey)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QKeySequence > cppResult = QKeySequence::keyBindings(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QKeySequence > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QKeySequenceFunc_keyBindings_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence.StandardKey", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QKeySequence.keyBindings", overloads);
        return 0;
}

static PyObject* Sbk_QKeySequenceFunc_matches(PyObject* self, PyObject* arg)
{
    QKeySequence* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeySequence* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: matches(QKeySequence)const
    if (Shiboken::Converter< ::QKeySequence >::isConvertible(arg)) {
        overloadId = 0; // matches(QKeySequence)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QKeySequenceFunc_matches_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QKeySequence cppArg0 = Shiboken::Converter<QKeySequence >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // matches(QKeySequence)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QKeySequence::SequenceMatch cppResult = const_cast<const QKeySequence*>(cppSelf)->matches(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QKeySequence::SequenceMatch >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QKeySequenceFunc_matches_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QKeySequence.matches", overloads);
        return 0;
}

static PyObject* Sbk_QKeySequenceFunc_mnemonic(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mnemonic(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // mnemonic(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QKeySequenceFunc_mnemonic_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mnemonic(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QKeySequence cppResult = QKeySequence::mnemonic(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QKeySequence >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QKeySequenceFunc_mnemonic_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QKeySequence.mnemonic", overloads);
        return 0;
}

static PyObject* Sbk_QKeySequenceFunc_toString(PyObject* self, PyObject* args, PyObject* kwds)
{
    QKeySequence* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeySequence* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QKeySequence.toString(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toString", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toString(QKeySequence::SequenceFormat)const
    if (numArgs == 0) {
        overloadId = 0; // toString(QKeySequence::SequenceFormat)const
    } else if (Shiboken::Converter< ::QKeySequence::SequenceFormat >::isConvertible(pyargs[0])) {
        overloadId = 0; // toString(QKeySequence::SequenceFormat)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QKeySequenceFunc_toString_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "format";
                    else if (Shiboken::Converter< ::QKeySequence::SequenceFormat >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QKeySequenceFunc_toString_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QKeySequence.toString(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QKeySequence::SequenceFormat cppArg0 = pyargs[0] ? Shiboken::Converter<QKeySequence::SequenceFormat >::toCpp(pyargs[0]) : QKeySequence::PortableText;

            if(!PyErr_Occurred()) {
                // toString(QKeySequence::SequenceFormat)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QKeySequence*>(cppSelf)->toString(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QKeySequenceFunc_toString_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence.SequenceFormat = PortableText", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QKeySequence.toString", overloads);
        return 0;
}

static PyObject *Sbk_QKeySequence___copy__(PyObject *self)
{
        QKeySequence* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QKeySequence*>::toCpp(self);
        PyObject* pyResult = 0;
        QKeySequence* copy = new QKeySequence(*cppSelf);
        pyResult = Shiboken::Converter<QKeySequence*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QKeySequence_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QKeySequenceFunc___reduce__, METH_NOARGS},
    {"count", (PyCFunction)Sbk_QKeySequenceFunc_count, METH_NOARGS},
    {"fromString", (PyCFunction)Sbk_QKeySequenceFunc_fromString, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"isEmpty", (PyCFunction)Sbk_QKeySequenceFunc_isEmpty, METH_NOARGS},
    {"keyBindings", (PyCFunction)Sbk_QKeySequenceFunc_keyBindings, METH_O|METH_STATIC},
    {"matches", (PyCFunction)Sbk_QKeySequenceFunc_matches, METH_O},
    {"mnemonic", (PyCFunction)Sbk_QKeySequenceFunc_mnemonic, METH_O|METH_STATIC},
    {"toString", (PyCFunction)Sbk_QKeySequenceFunc_toString, METH_VARARGS|METH_KEYWORDS},

    {"__copy__", (PyCFunction)Sbk_QKeySequence___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QKeySequenceFunc___lshift__(PyObject* self, PyObject* arg)
{
    QKeySequence* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QKeySequence >::checkType(arg) && !Shiboken::Converter< ::QKeySequence >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeySequence* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QKeySequence)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QKeySequence)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QKeySequenceFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QKeySequence) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QKeySequenceFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QKeySequence.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QKeySequenceFunc___rshift__(PyObject* self, PyObject* arg)
{
    QKeySequence* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QKeySequence >::checkType(arg) && !Shiboken::Converter< ::QKeySequence >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QKeySequence* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QKeySequence&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QKeySequence&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QKeySequenceFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QKeySequence&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QKeySequenceFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QKeySequence.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QKeySequence_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QKeySequenceFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QKeySequenceFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QKeySequence_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QKeySequence& cppSelf = *Shiboken::Converter< QKeySequence* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QKeySequence >::isConvertible(arg)) {
                // operator!=(const QKeySequence & other) const
                QKeySequence cppArg0 = Shiboken::Converter< ::QKeySequence >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QKeySequence_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter< ::QKeySequence >::isConvertible(arg)) {
                // operator<(const QKeySequence & ks) const
                QKeySequence cppArg0 = Shiboken::Converter< ::QKeySequence >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf < cppArg0);
            } else goto Sbk_QKeySequence_RichComparison_TypeError;

            break;
        case Py_LE:
            if (Shiboken::Converter< ::QKeySequence >::isConvertible(arg)) {
                // operator<=(const QKeySequence & other) const
                QKeySequence cppArg0 = Shiboken::Converter< ::QKeySequence >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf <= cppArg0);
            } else goto Sbk_QKeySequence_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QKeySequence >::isConvertible(arg)) {
                // operator==(const QKeySequence & other) const
                QKeySequence cppArg0 = Shiboken::Converter< ::QKeySequence >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QKeySequence_RichComparison_TypeError;

            break;
        case Py_GT:
            if (Shiboken::Converter< ::QKeySequence >::isConvertible(arg)) {
                // operator>(const QKeySequence & other) const
                QKeySequence cppArg0 = Shiboken::Converter< ::QKeySequence >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf > cppArg0);
            } else goto Sbk_QKeySequence_RichComparison_TypeError;

            break;
        case Py_GE:
            if (Shiboken::Converter< ::QKeySequence >::isConvertible(arg)) {
                // operator>=(const QKeySequence & other) const
                QKeySequence cppArg0 = Shiboken::Converter< ::QKeySequence >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf >= cppArg0);
            } else goto Sbk_QKeySequence_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QKeySequence_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QKeySequence_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QKeySequence_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QKeySequence",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QKeySequenceFunc___repr__,
    /*tp_as_number*/        &Sbk_QKeySequence_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QKeySequence_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QKeySequence_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QKeySequence_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QKeySequence(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QKEYSEQUENCE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QKeySequence_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QKeySequence_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QKeySequence_Type, &Shiboken::callCppDestructor<QKeySequence >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QKeySequence_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QKeySequence_Type, "QKeySequence");
    PyModule_AddObject(module, "QKeySequence",
        ((PyObject*)&Sbk_QKeySequence_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: SequenceFormat
    PyTypeObject* SbkPySide_QtGui_QKeySequence_SequenceFormat = Shiboken::Enum::newType("PySide.QtGui.QKeySequence.SequenceFormat");
    SbkPySide_QtGuiTypes[SBK_QKEYSEQUENCE_SEQUENCEFORMAT_IDX] = SbkPySide_QtGui_QKeySequence_SequenceFormat;
    if (PyType_Ready(SbkPySide_QtGui_QKeySequence_SequenceFormat) < 0)
        return;
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,
            "SequenceFormat",((PyObject*)SbkPySide_QtGui_QKeySequence_SequenceFormat));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_SequenceFormat,(long) QKeySequence::NativeText, "NativeText");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"NativeText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_SequenceFormat->tp_dict,"NativeText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_SequenceFormat,(long) QKeySequence::PortableText, "PortableText");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"PortableText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_SequenceFormat->tp_dict,"PortableText", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QKeySequence::SequenceFormat");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::SequenceFormat");
    // end of enum SequenceFormat

    // init enum: StandardKey
    PyTypeObject* SbkPySide_QtGui_QKeySequence_StandardKey = Shiboken::Enum::newType("PySide.QtGui.QKeySequence.StandardKey");
    SbkPySide_QtGuiTypes[SBK_QKEYSEQUENCE_STANDARDKEY_IDX] = SbkPySide_QtGui_QKeySequence_StandardKey;
    if (PyType_Ready(SbkPySide_QtGui_QKeySequence_StandardKey) < 0)
        return;
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,
            "StandardKey",((PyObject*)SbkPySide_QtGui_QKeySequence_StandardKey));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::UnknownKey, "UnknownKey");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"UnknownKey", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"UnknownKey", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::HelpContents, "HelpContents");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"HelpContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"HelpContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::WhatsThis, "WhatsThis");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"WhatsThis", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"WhatsThis", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Open, "Open");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Open", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Open", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Close, "Close");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Close", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Close", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Save, "Save");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Save", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Save", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::New, "New");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"New", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"New", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Delete, "Delete");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Delete", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Delete", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Cut, "Cut");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Cut", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Cut", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Copy, "Copy");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Copy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Copy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Paste, "Paste");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Paste", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Paste", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Undo, "Undo");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Undo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Undo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Redo, "Redo");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Redo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Redo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Back, "Back");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Back", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Back", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Forward, "Forward");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Forward", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Forward", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Refresh, "Refresh");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Refresh", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Refresh", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::ZoomIn, "ZoomIn");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"ZoomIn", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"ZoomIn", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::ZoomOut, "ZoomOut");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"ZoomOut", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"ZoomOut", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Print, "Print");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Print", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Print", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::AddTab, "AddTab");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"AddTab", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"AddTab", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::NextChild, "NextChild");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"NextChild", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"NextChild", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::PreviousChild, "PreviousChild");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"PreviousChild", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"PreviousChild", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Find, "Find");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Find", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Find", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::FindNext, "FindNext");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"FindNext", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"FindNext", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::FindPrevious, "FindPrevious");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"FindPrevious", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"FindPrevious", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Replace, "Replace");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Replace", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Replace", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectAll, "SelectAll");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectAll", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectAll", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Bold, "Bold");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Bold", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Bold", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Italic, "Italic");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Italic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Italic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Underline, "Underline");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Underline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Underline", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToNextChar, "MoveToNextChar");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToNextChar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToNextChar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToPreviousChar, "MoveToPreviousChar");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToPreviousChar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToPreviousChar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToNextWord, "MoveToNextWord");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToNextWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToNextWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToPreviousWord, "MoveToPreviousWord");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToPreviousWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToPreviousWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToNextLine, "MoveToNextLine");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToNextLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToNextLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToPreviousLine, "MoveToPreviousLine");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToPreviousLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToPreviousLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToNextPage, "MoveToNextPage");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToNextPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToNextPage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToPreviousPage, "MoveToPreviousPage");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToPreviousPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToPreviousPage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToStartOfLine, "MoveToStartOfLine");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToStartOfLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToStartOfLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToEndOfLine, "MoveToEndOfLine");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToEndOfLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToEndOfLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToStartOfBlock, "MoveToStartOfBlock");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToStartOfBlock", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToStartOfBlock", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToEndOfBlock, "MoveToEndOfBlock");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToEndOfBlock", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToEndOfBlock", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToStartOfDocument, "MoveToStartOfDocument");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToStartOfDocument", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToStartOfDocument", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::MoveToEndOfDocument, "MoveToEndOfDocument");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"MoveToEndOfDocument", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"MoveToEndOfDocument", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectNextChar, "SelectNextChar");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectNextChar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectNextChar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectPreviousChar, "SelectPreviousChar");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectPreviousChar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectPreviousChar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectNextWord, "SelectNextWord");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectNextWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectNextWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectPreviousWord, "SelectPreviousWord");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectPreviousWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectPreviousWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectNextLine, "SelectNextLine");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectNextLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectNextLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectPreviousLine, "SelectPreviousLine");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectPreviousLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectPreviousLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectNextPage, "SelectNextPage");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectNextPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectNextPage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectPreviousPage, "SelectPreviousPage");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectPreviousPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectPreviousPage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectStartOfLine, "SelectStartOfLine");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectStartOfLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectStartOfLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectEndOfLine, "SelectEndOfLine");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectEndOfLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectEndOfLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectStartOfBlock, "SelectStartOfBlock");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectStartOfBlock", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectStartOfBlock", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectEndOfBlock, "SelectEndOfBlock");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectEndOfBlock", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectEndOfBlock", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectStartOfDocument, "SelectStartOfDocument");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectStartOfDocument", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectStartOfDocument", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SelectEndOfDocument, "SelectEndOfDocument");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SelectEndOfDocument", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SelectEndOfDocument", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::DeleteStartOfWord, "DeleteStartOfWord");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"DeleteStartOfWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"DeleteStartOfWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::DeleteEndOfWord, "DeleteEndOfWord");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"DeleteEndOfWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"DeleteEndOfWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::DeleteEndOfLine, "DeleteEndOfLine");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"DeleteEndOfLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"DeleteEndOfLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::InsertParagraphSeparator, "InsertParagraphSeparator");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"InsertParagraphSeparator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"InsertParagraphSeparator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::InsertLineSeparator, "InsertLineSeparator");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"InsertLineSeparator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"InsertLineSeparator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::SaveAs, "SaveAs");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"SaveAs", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"SaveAs", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Preferences, "Preferences");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Preferences", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Preferences", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_StandardKey,(long) QKeySequence::Quit, "Quit");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"Quit", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_StandardKey->tp_dict,"Quit", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QKeySequence::StandardKey");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StandardKey");
    // end of enum StandardKey

    // init enum: SequenceMatch
    PyTypeObject* SbkPySide_QtGui_QKeySequence_SequenceMatch = Shiboken::Enum::newType("PySide.QtGui.QKeySequence.SequenceMatch");
    SbkPySide_QtGuiTypes[SBK_QKEYSEQUENCE_SEQUENCEMATCH_IDX] = SbkPySide_QtGui_QKeySequence_SequenceMatch;
    if (PyType_Ready(SbkPySide_QtGui_QKeySequence_SequenceMatch) < 0)
        return;
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,
            "SequenceMatch",((PyObject*)SbkPySide_QtGui_QKeySequence_SequenceMatch));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_SequenceMatch,(long) QKeySequence::NoMatch, "NoMatch");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"NoMatch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_SequenceMatch->tp_dict,"NoMatch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_SequenceMatch,(long) QKeySequence::PartialMatch, "PartialMatch");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"PartialMatch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_SequenceMatch->tp_dict,"PartialMatch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QKeySequence_SequenceMatch,(long) QKeySequence::ExactMatch, "ExactMatch");
    PyDict_SetItemString(Sbk_QKeySequence_Type.super.ht_type.tp_dict,"ExactMatch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QKeySequence_SequenceMatch->tp_dict,"ExactMatch", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QKeySequence::SequenceMatch");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::SequenceMatch");
    // end of enum SequenceMatch


    Shiboken::TypeResolver::createValueTypeResolver<QKeySequence >("QKeySequence");
    Shiboken::TypeResolver::createObjectTypeResolver<QKeySequence >("QKeySequence*");
    Shiboken::TypeResolver::createValueTypeResolver<QKeySequence >(typeid(QKeySequence).name());
    PySide::initQtMetaType< ::QKeySequence >();
    qRegisterMetaType< ::QKeySequence::SequenceFormat >("QKeySequence::SequenceFormat");
    qRegisterMetaType< ::QKeySequence::StandardKey >("QKeySequence::StandardKey");
    qRegisterMetaType< ::QKeySequence::SequenceMatch >("QKeySequence::SequenceMatch");
}

