/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionmenuitem_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionMenuItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionMenuItem >()))
        return -1;

    QStyleOptionMenuItem* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionMenuItem", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionMenuItem()
    // 1: QStyleOptionMenuItem(QStyleOptionMenuItem)
    // 2: QStyleOptionMenuItem(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionMenuItem()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 2; // QStyleOptionMenuItem(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionMenuItem >::isConvertible(pyargs[0])) {
        overloadId = 1; // QStyleOptionMenuItem(QStyleOptionMenuItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionMenuItem_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionMenuItem()
            {

                if(!PyErr_Occurred()) {
                    // QStyleOptionMenuItem()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionMenuItem();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOptionMenuItem(QStyleOptionMenuItem)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionMenuItem cppArg0 = Shiboken::Converter<QStyleOptionMenuItem >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionMenuItem(QStyleOptionMenuItem)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionMenuItem(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStyleOptionMenuItem(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionMenuItem(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionMenuItem(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionMenuItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionMenuItem_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionMenuItem_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionMenuItem", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionMenuItem", overloads);
        return -1;
}

static PyObject *Sbk_QStyleOptionMenuItem___copy__(PyObject *self)
{
        QStyleOptionMenuItem* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOptionMenuItem*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOptionMenuItem* copy = new QStyleOptionMenuItem(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOptionMenuItem*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOptionMenuItem_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QStyleOptionMenuItem___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionMenuItem_get_menuHasCheckableItems(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< bool >::toPython( Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->menuHasCheckableItems);
    return val;
}

static int Sbk_QStyleOptionMenuItem_set_menuHasCheckableItems(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'menuHasCheckableItems' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'menuHasCheckableItems', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->menuHasCheckableItems = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_menuRect(PyObject* self, void*)
{
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->menuRect);
    Shiboken::Object::releaseOwnership(val);
    return val;
}

static int Sbk_QStyleOptionMenuItem_set_menuRect(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'menuRect' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QRect >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'menuRect', 'QRect' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->menuRect = Shiboken::Converter< ::QRect >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_checkType(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::QStyleOptionMenuItem::CheckType >::toPython( Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->checkType);
    return val;
}

static int Sbk_QStyleOptionMenuItem_set_checkType(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'checkType' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStyleOptionMenuItem::CheckType >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'checkType', 'CheckType' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->checkType = Shiboken::Converter< ::QStyleOptionMenuItem::CheckType >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_icon(PyObject* self, void*)
{
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->icon);
    Shiboken::Object::releaseOwnership(val);
    return val;
}

static int Sbk_QStyleOptionMenuItem_set_icon(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'icon' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QIcon >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'icon', 'QIcon' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->icon = Shiboken::Converter< ::QIcon >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_checked(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< bool >::toPython( Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->checked);
    return val;
}

static int Sbk_QStyleOptionMenuItem_set_checked(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'checked' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'checked', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->checked = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_maxIconWidth(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->maxIconWidth);
    return val;
}

static int Sbk_QStyleOptionMenuItem_set_maxIconWidth(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'maxIconWidth' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'maxIconWidth', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->maxIconWidth = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_tabWidth(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->tabWidth);
    return val;
}

static int Sbk_QStyleOptionMenuItem_set_tabWidth(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'tabWidth' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'tabWidth', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->tabWidth = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_text(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< QString >::toPython( Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->text);
    return val;
}

static int Sbk_QStyleOptionMenuItem_set_text(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'text' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'text', 'QString' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->text = Shiboken::Converter< QString >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_font(PyObject* self, void*)
{
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->font);
    Shiboken::Object::releaseOwnership(val);
    return val;
}

static int Sbk_QStyleOptionMenuItem_set_font(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'font' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFont >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'font', 'QFont' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->font = Shiboken::Converter< ::QFont >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionMenuItem_get_menuItemType(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::QStyleOptionMenuItem::MenuItemType >::toPython( Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->menuItemType);
    return val;
}

static int Sbk_QStyleOptionMenuItem_set_menuItemType(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'menuItemType' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStyleOptionMenuItem::MenuItemType >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'menuItemType', 'MenuItemType' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionMenuItem* >::toCpp(self)->menuItemType = Shiboken::Converter< ::QStyleOptionMenuItem::MenuItemType >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionMenuItem
static PyGetSetDef Sbk_QStyleOptionMenuItem_getsetlist[] = {
    {const_cast<char*>("menuHasCheckableItems"), Sbk_QStyleOptionMenuItem_get_menuHasCheckableItems, Sbk_QStyleOptionMenuItem_set_menuHasCheckableItems},
    {const_cast<char*>("menuRect"), Sbk_QStyleOptionMenuItem_get_menuRect, Sbk_QStyleOptionMenuItem_set_menuRect},
    {const_cast<char*>("checkType"), Sbk_QStyleOptionMenuItem_get_checkType, Sbk_QStyleOptionMenuItem_set_checkType},
    {const_cast<char*>("icon"), Sbk_QStyleOptionMenuItem_get_icon, Sbk_QStyleOptionMenuItem_set_icon},
    {const_cast<char*>("checked"), Sbk_QStyleOptionMenuItem_get_checked, Sbk_QStyleOptionMenuItem_set_checked},
    {const_cast<char*>("maxIconWidth"), Sbk_QStyleOptionMenuItem_get_maxIconWidth, Sbk_QStyleOptionMenuItem_set_maxIconWidth},
    {const_cast<char*>("tabWidth"), Sbk_QStyleOptionMenuItem_get_tabWidth, Sbk_QStyleOptionMenuItem_set_tabWidth},
    {const_cast<char*>("text"), Sbk_QStyleOptionMenuItem_get_text, Sbk_QStyleOptionMenuItem_set_text},
    {const_cast<char*>("font"), Sbk_QStyleOptionMenuItem_get_font, Sbk_QStyleOptionMenuItem_set_font},
    {const_cast<char*>("menuItemType"), Sbk_QStyleOptionMenuItem_get_menuItemType, Sbk_QStyleOptionMenuItem_set_menuItemType},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionMenuItem_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionMenuItem",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionMenuItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionMenuItem_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionMenuItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionMenuItem(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionMenuItem_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOptionMenuItem_Type);
    Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOptionMenuItem_Type, &Shiboken::callCppDestructor<QStyleOptionMenuItem >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOptionMenuItem_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOptionMenuItem_Type, "QStyleOptionMenuItem");
    PyModule_AddObject(module, "QStyleOptionMenuItem",
        ((PyObject*)&Sbk_QStyleOptionMenuItem_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOptionMenuItem_StyleOptionVersion = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionMenuItem.StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOptionMenuItem_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionMenuItem_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOptionMenuItem_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionMenuItem_StyleOptionVersion,(long) QStyleOptionMenuItem::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionMenuItem_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionMenuItem::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion

    // init enum: StyleOptionType
    PyTypeObject* SbkPySide_QtGui_QStyleOptionMenuItem_StyleOptionType = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionMenuItem.StyleOptionType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_STYLEOPTIONTYPE_IDX] = SbkPySide_QtGui_QStyleOptionMenuItem_StyleOptionType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionMenuItem_StyleOptionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,
            "StyleOptionType",((PyObject*)SbkPySide_QtGui_QStyleOptionMenuItem_StyleOptionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionMenuItem_StyleOptionType,(long) QStyleOptionMenuItem::Type, "Type");
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionMenuItem_StyleOptionType->tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionMenuItem::StyleOptionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionType");
    // end of enum StyleOptionType

    // init enum: CheckType
    PyTypeObject* SbkPySide_QtGui_QStyleOptionMenuItem_CheckType = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionMenuItem.CheckType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_CHECKTYPE_IDX] = SbkPySide_QtGui_QStyleOptionMenuItem_CheckType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionMenuItem_CheckType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,
            "CheckType",((PyObject*)SbkPySide_QtGui_QStyleOptionMenuItem_CheckType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionMenuItem_CheckType,(long) QStyleOptionMenuItem::NotCheckable, "NotCheckable");
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,"NotCheckable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionMenuItem_CheckType->tp_dict,"NotCheckable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionMenuItem_CheckType,(long) QStyleOptionMenuItem::Exclusive, "Exclusive");
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,"Exclusive", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionMenuItem_CheckType->tp_dict,"Exclusive", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionMenuItem_CheckType,(long) QStyleOptionMenuItem::NonExclusive, "NonExclusive");
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,"NonExclusive", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionMenuItem_CheckType->tp_dict,"NonExclusive", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionMenuItem::CheckType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::CheckType");
    // end of enum CheckType

    // init enum: MenuItemType
    PyTypeObject* SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionMenuItem.MenuItemType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONMENUITEM_MENUITEMTYPE_IDX] = SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,
            "MenuItemType",((PyObject*)SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType,(long) QStyleOptionMenuItem::Normal, "Normal");
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,"Normal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType->tp_dict,"Normal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType,(long) QStyleOptionMenuItem::DefaultItem, "DefaultItem");
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,"DefaultItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType->tp_dict,"DefaultItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType,(long) QStyleOptionMenuItem::Separator, "Separator");
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,"Separator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType->tp_dict,"Separator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType,(long) QStyleOptionMenuItem::SubMenu, "SubMenu");
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,"SubMenu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType->tp_dict,"SubMenu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType,(long) QStyleOptionMenuItem::Scroller, "Scroller");
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,"Scroller", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType->tp_dict,"Scroller", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType,(long) QStyleOptionMenuItem::TearOff, "TearOff");
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,"TearOff", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType->tp_dict,"TearOff", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType,(long) QStyleOptionMenuItem::Margin, "Margin");
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,"Margin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType->tp_dict,"Margin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType,(long) QStyleOptionMenuItem::EmptyArea, "EmptyArea");
    PyDict_SetItemString(Sbk_QStyleOptionMenuItem_Type.super.ht_type.tp_dict,"EmptyArea", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionMenuItem_MenuItemType->tp_dict,"EmptyArea", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionMenuItem::MenuItemType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::MenuItemType");
    // end of enum MenuItemType


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionMenuItem >("QStyleOptionMenuItem");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionMenuItem >("QStyleOptionMenuItem*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionMenuItem >(typeid(QStyleOptionMenuItem).name());
    PySide::initQtMetaType< ::QStyleOptionMenuItem >();
    qRegisterMetaType< ::QStyleOptionMenuItem::StyleOptionVersion >("QStyleOptionMenuItem::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionMenuItem::StyleOptionType >("QStyleOptionMenuItem::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionMenuItem::CheckType >("QStyleOptionMenuItem::CheckType");
    qRegisterMetaType< ::QStyleOptionMenuItem::MenuItemType >("QStyleOptionMenuItem::MenuItemType");
}

