/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionprogressbarv2_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionProgressBarV2_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionProgressBarV2 >()))
        return -1;

    QStyleOptionProgressBarV2* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionProgressBarV2", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionProgressBarV2()
    // 1: QStyleOptionProgressBarV2(QStyleOptionProgressBar)
    // 2: QStyleOptionProgressBarV2(QStyleOptionProgressBarV2)
    // 3: QStyleOptionProgressBarV2(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionProgressBarV2()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 3; // QStyleOptionProgressBarV2(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionProgressBarV2 >::isConvertible(pyargs[0])) {
        overloadId = 2; // QStyleOptionProgressBarV2(QStyleOptionProgressBarV2)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionProgressBar >::isConvertible(pyargs[0])) {
        overloadId = 1; // QStyleOptionProgressBarV2(QStyleOptionProgressBar)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionProgressBarV2_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionProgressBarV2()
            {

                if(!PyErr_Occurred()) {
                    // QStyleOptionProgressBarV2()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionProgressBarV2();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOptionProgressBarV2(QStyleOptionProgressBar)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionProgressBar cppArg0 = Shiboken::Converter<QStyleOptionProgressBar >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionProgressBarV2(QStyleOptionProgressBar)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionProgressBarV2(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStyleOptionProgressBarV2(QStyleOptionProgressBarV2)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionProgressBarV2 cppArg0 = Shiboken::Converter<QStyleOptionProgressBarV2 >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionProgressBarV2(QStyleOptionProgressBarV2)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionProgressBarV2(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QStyleOptionProgressBarV2(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionProgressBarV2(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionProgressBarV2(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionProgressBarV2 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionProgressBarV2_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionProgressBarV2_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionProgressBar", "PySide.QtGui.QStyleOptionProgressBarV2", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionProgressBarV2", overloads);
        return -1;
}

static PyObject *Sbk_QStyleOptionProgressBarV2___copy__(PyObject *self)
{
        QStyleOptionProgressBarV2* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOptionProgressBarV2*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOptionProgressBarV2* copy = new QStyleOptionProgressBarV2(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOptionProgressBarV2*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOptionProgressBarV2_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QStyleOptionProgressBarV2___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionProgressBarV2_get_bottomToTop(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< bool >::toPython( Shiboken::Converter< QStyleOptionProgressBarV2* >::toCpp(self)->bottomToTop);
    return val;
}

static int Sbk_QStyleOptionProgressBarV2_set_bottomToTop(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'bottomToTop' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'bottomToTop', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionProgressBarV2* >::toCpp(self)->bottomToTop = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionProgressBarV2_get_invertedAppearance(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< bool >::toPython( Shiboken::Converter< QStyleOptionProgressBarV2* >::toCpp(self)->invertedAppearance);
    return val;
}

static int Sbk_QStyleOptionProgressBarV2_set_invertedAppearance(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'invertedAppearance' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'invertedAppearance', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionProgressBarV2* >::toCpp(self)->invertedAppearance = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionProgressBarV2_get_orientation(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::Qt::Orientation >::toPython( Shiboken::Converter< QStyleOptionProgressBarV2* >::toCpp(self)->orientation);
    return val;
}

static int Sbk_QStyleOptionProgressBarV2_set_orientation(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'orientation' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::Qt::Orientation >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'orientation', 'Orientation' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionProgressBarV2* >::toCpp(self)->orientation = Shiboken::Converter< ::Qt::Orientation >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionProgressBarV2
static PyGetSetDef Sbk_QStyleOptionProgressBarV2_getsetlist[] = {
    {const_cast<char*>("bottomToTop"), Sbk_QStyleOptionProgressBarV2_get_bottomToTop, Sbk_QStyleOptionProgressBarV2_set_bottomToTop},
    {const_cast<char*>("invertedAppearance"), Sbk_QStyleOptionProgressBarV2_get_invertedAppearance, Sbk_QStyleOptionProgressBarV2_set_invertedAppearance},
    {const_cast<char*>("orientation"), Sbk_QStyleOptionProgressBarV2_get_orientation, Sbk_QStyleOptionProgressBarV2_set_orientation},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionProgressBarV2_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionProgressBarV2",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionProgressBarV2_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionProgressBarV2_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionProgressBarV2_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionProgressBarV2(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONPROGRESSBARV2_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionProgressBarV2_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOptionProgressBarV2_Type);
    Sbk_QStyleOptionProgressBarV2_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONPROGRESSBAR_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOptionProgressBarV2_Type, &Shiboken::callCppDestructor<QStyleOptionProgressBarV2 >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOptionProgressBarV2_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOptionProgressBarV2_Type, "QStyleOptionProgressBarV2");
    PyModule_AddObject(module, "QStyleOptionProgressBarV2",
        ((PyObject*)&Sbk_QStyleOptionProgressBarV2_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOptionProgressBarV2_StyleOptionVersion = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionProgressBarV2.StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONPROGRESSBARV2_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOptionProgressBarV2_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionProgressBarV2_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionProgressBarV2_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOptionProgressBarV2_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionProgressBarV2_StyleOptionVersion,(long) QStyleOptionProgressBarV2::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOptionProgressBarV2_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionProgressBarV2_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionProgressBarV2::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion

    // init enum: StyleOptionType
    PyTypeObject* SbkPySide_QtGui_QStyleOptionProgressBarV2_StyleOptionType = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionProgressBarV2.StyleOptionType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONPROGRESSBARV2_STYLEOPTIONTYPE_IDX] = SbkPySide_QtGui_QStyleOptionProgressBarV2_StyleOptionType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionProgressBarV2_StyleOptionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionProgressBarV2_Type.super.ht_type.tp_dict,
            "StyleOptionType",((PyObject*)SbkPySide_QtGui_QStyleOptionProgressBarV2_StyleOptionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionProgressBarV2_StyleOptionType,(long) QStyleOptionProgressBarV2::Type, "Type");
    PyDict_SetItemString(Sbk_QStyleOptionProgressBarV2_Type.super.ht_type.tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionProgressBarV2_StyleOptionType->tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionProgressBarV2::StyleOptionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionType");
    // end of enum StyleOptionType


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionProgressBarV2 >("QStyleOptionProgressBarV2");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionProgressBarV2 >("QStyleOptionProgressBarV2*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionProgressBarV2 >(typeid(QStyleOptionProgressBarV2).name());
    PySide::initQtMetaType< ::QStyleOptionProgressBarV2 >();
    qRegisterMetaType< ::QStyleOptionProgressBarV2::StyleOptionVersion >("QStyleOptionProgressBarV2::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionProgressBarV2::StyleOptionType >("QStyleOptionProgressBarV2::StyleOptionType");
}

