/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextedit_extraselection_wrapper.h"

// Extra includes



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextEdit_ExtraSelection_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextEdit::ExtraSelection >()))
        return -1;

    QTextEdit::ExtraSelection* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "ExtraSelection", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: ExtraSelection()
    // 1: ExtraSelection(QTextEdit::ExtraSelection)
    if (numArgs == 0) {
        overloadId = 0; // ExtraSelection()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextEdit::ExtraSelection >::isConvertible(pyargs[0])) {
        overloadId = 1; // ExtraSelection(QTextEdit::ExtraSelection)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextEdit_ExtraSelection_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // ExtraSelection()
            {

                if(!PyErr_Occurred()) {
                    // ExtraSelection()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextEdit::ExtraSelection();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // ExtraSelection(QTextEdit::ExtraSelection)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextEdit::ExtraSelection cppArg0 = Shiboken::Converter<QTextEdit::ExtraSelection >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // ExtraSelection(QTextEdit::ExtraSelection)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextEdit::ExtraSelection(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextEdit::ExtraSelection >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextEdit_ExtraSelection_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextEdit_ExtraSelection_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextEdit::ExtraSelection", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.ExtraSelection", overloads);
        return -1;
}

static PyObject *Sbk_QTextEdit_ExtraSelection___copy__(PyObject *self)
{
        QTextEdit::ExtraSelection* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextEdit::ExtraSelection*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextEdit::ExtraSelection* copy = new QTextEdit::ExtraSelection(*cppSelf);
        pyResult = Shiboken::Converter<QTextEdit::ExtraSelection*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextEdit_ExtraSelection_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QTextEdit_ExtraSelection___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QTextEdit_ExtraSelection_get_cursor(PyObject* self, void*)
{
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QTextEdit::ExtraSelection* >::toCpp(self)->cursor);
    Shiboken::Object::releaseOwnership(val);
    return val;
}

static int Sbk_QTextEdit_ExtraSelection_set_cursor(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'cursor' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QTextCursor >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'cursor', 'QTextCursor' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QTextEdit::ExtraSelection* >::toCpp(self)->cursor = Shiboken::Converter< ::QTextCursor >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QTextEdit_ExtraSelection_get_format(PyObject* self, void*)
{
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QTextEdit::ExtraSelection* >::toCpp(self)->format);
    Shiboken::Object::releaseOwnership(val);
    return val;
}

static int Sbk_QTextEdit_ExtraSelection_set_format(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'format' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QTextCharFormat >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'format', 'QTextCharFormat' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QTextEdit::ExtraSelection* >::toCpp(self)->format = Shiboken::Converter< ::QTextCharFormat >::toCpp(value);

    return 0;
}

// Getters and Setters for ExtraSelection
static PyGetSetDef Sbk_QTextEdit_ExtraSelection_getsetlist[] = {
    {const_cast<char*>("cursor"), Sbk_QTextEdit_ExtraSelection_get_cursor, Sbk_QTextEdit_ExtraSelection_set_cursor},
    {const_cast<char*>("format"), Sbk_QTextEdit_ExtraSelection_get_format, Sbk_QTextEdit_ExtraSelection_set_format},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextEdit_ExtraSelection_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextEdit.ExtraSelection",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextEdit_ExtraSelection_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QTextEdit_ExtraSelection_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextEdit_ExtraSelection_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextEdit_ExtraSelection(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_EXTRASELECTION_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextEdit_ExtraSelection_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextEdit_ExtraSelection_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextEdit_ExtraSelection_Type, &Shiboken::callCppDestructor<QTextEdit::ExtraSelection >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextEdit_ExtraSelection_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextEdit_ExtraSelection_Type, "QTextEdit::ExtraSelection");
    PyDict_SetItemString(module,"ExtraSelection", (PyObject*)&Sbk_QTextEdit_ExtraSelection_Type);

    Shiboken::TypeResolver::createValueTypeResolver<QTextEdit::ExtraSelection >("QTextEdit::ExtraSelection");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextEdit::ExtraSelection >("QTextEdit::ExtraSelection*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextEdit::ExtraSelection >(typeid(QTextEdit::ExtraSelection).name());
    PySide::initQtMetaType< ::QTextEdit::ExtraSelection >();
}

