/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextfragment_wrapper.h"

// Extra includes
#include <qtextformat.h>
#include <qtextobject.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextFragment_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextFragment >()))
        return -1;

    QTextFragment* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextFragment", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QTextFragment()
    // 1: QTextFragment(QTextFragment)
    if (numArgs == 0) {
        overloadId = 0; // QTextFragment()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextFragment >::isConvertible(pyargs[0])) {
        overloadId = 1; // QTextFragment(QTextFragment)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFragment_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextFragment()
            {

                if(!PyErr_Occurred()) {
                    // QTextFragment()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextFragment();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTextFragment(QTextFragment)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextFragment cppArg0 = Shiboken::Converter<QTextFragment >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextFragment(QTextFragment)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextFragment(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextFragment >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextFragment_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextFragment_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextFragment", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextFragment", overloads);
        return -1;
}

static PyObject* Sbk_QTextFragmentFunc_charFormat(PyObject* self)
{
    QTextFragment* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFragment* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // charFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextCharFormat cppResult = const_cast<const QTextFragment*>(cppSelf)->charFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextCharFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFragmentFunc_charFormatIndex(PyObject* self)
{
    QTextFragment* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFragment* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // charFormatIndex()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextFragment*>(cppSelf)->charFormatIndex();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFragmentFunc_contains(PyObject* self, PyObject* arg)
{
    QTextFragment* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFragment* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // contains(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFragmentFunc_contains_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // contains(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextFragment*>(cppSelf)->contains(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFragmentFunc_contains_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFragment.contains", overloads);
        return 0;
}

static PyObject* Sbk_QTextFragmentFunc_isValid(PyObject* self)
{
    QTextFragment* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFragment* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextFragment*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFragmentFunc_length(PyObject* self)
{
    QTextFragment* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFragment* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // length()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextFragment*>(cppSelf)->length();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFragmentFunc_position(PyObject* self)
{
    QTextFragment* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFragment* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // position()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextFragment*>(cppSelf)->position();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFragmentFunc_text(PyObject* self)
{
    QTextFragment* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFragment* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // text()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextFragment*>(cppSelf)->text();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QTextFragment___copy__(PyObject *self)
{
        QTextFragment* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextFragment*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextFragment* copy = new QTextFragment(*cppSelf);
        pyResult = Shiboken::Converter<QTextFragment*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextFragment_methods[] = {
    {"charFormat", (PyCFunction)Sbk_QTextFragmentFunc_charFormat, METH_NOARGS},
    {"charFormatIndex", (PyCFunction)Sbk_QTextFragmentFunc_charFormatIndex, METH_NOARGS},
    {"contains", (PyCFunction)Sbk_QTextFragmentFunc_contains, METH_O},
    {"isValid", (PyCFunction)Sbk_QTextFragmentFunc_isValid, METH_NOARGS},
    {"length", (PyCFunction)Sbk_QTextFragmentFunc_length, METH_NOARGS},
    {"position", (PyCFunction)Sbk_QTextFragmentFunc_position, METH_NOARGS},
    {"text", (PyCFunction)Sbk_QTextFragmentFunc_text, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTextFragment___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QTextFragment_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QTextFragment& cppSelf = *Shiboken::Converter< QTextFragment* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QTextFragment >::isConvertible(arg)) {
                // operator!=(const QTextFragment & o) const
                QTextFragment cppArg0 = Shiboken::Converter< ::QTextFragment >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QTextFragment_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter< ::QTextFragment >::isConvertible(arg)) {
                // operator<(const QTextFragment & o) const
                QTextFragment cppArg0 = Shiboken::Converter< ::QTextFragment >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf < cppArg0);
            } else goto Sbk_QTextFragment_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QTextFragment >::isConvertible(arg)) {
                // operator==(const QTextFragment & o) const
                QTextFragment cppArg0 = Shiboken::Converter< ::QTextFragment >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QTextFragment_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QTextFragment_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QTextFragment_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextFragment_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextFragment",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QTextFragment_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextFragment_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextFragment_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextFragment(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTFRAGMENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextFragment_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextFragment_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextFragment_Type, &Shiboken::callCppDestructor<QTextFragment >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextFragment_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextFragment_Type, "QTextFragment");
    PyModule_AddObject(module, "QTextFragment",
        ((PyObject*)&Sbk_QTextFragment_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QTextFragment >("QTextFragment");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextFragment >("QTextFragment*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextFragment >(typeid(QTextFragment).name());
    PySide::initQtMetaType< ::QTextFragment >();
}

