/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextitem_wrapper.h"

// Extra includes
#include <qfont.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextItem >()))
        return -1;

    QTextItem* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QTextItem()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QTextItem();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QTextItemFunc_ascent(PyObject* self)
{
    QTextItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // ascent()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextItem*>(cppSelf)->ascent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextItemFunc_descent(PyObject* self)
{
    QTextItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // descent()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextItem*>(cppSelf)->descent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextItemFunc_font(PyObject* self)
{
    QTextItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // font()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont cppResult = const_cast<const QTextItem*>(cppSelf)->font();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextItemFunc_renderFlags(PyObject* self)
{
    QTextItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // renderFlags()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QTextItem::RenderFlag> cppResult = const_cast<const QTextItem*>(cppSelf)->renderFlags();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QTextItem::RenderFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextItemFunc_text(PyObject* self)
{
    QTextItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // text()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextItem*>(cppSelf)->text();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextItemFunc_width(PyObject* self)
{
    QTextItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // width()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextItem*>(cppSelf)->width();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QTextItem_methods[] = {
    {"ascent", (PyCFunction)Sbk_QTextItemFunc_ascent, METH_NOARGS},
    {"descent", (PyCFunction)Sbk_QTextItemFunc_descent, METH_NOARGS},
    {"font", (PyCFunction)Sbk_QTextItemFunc_font, METH_NOARGS},
    {"renderFlags", (PyCFunction)Sbk_QTextItemFunc_renderFlags, METH_NOARGS},
    {"text", (PyCFunction)Sbk_QTextItemFunc_text, METH_NOARGS},
    {"width", (PyCFunction)Sbk_QTextItemFunc_width, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextItem_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextItem",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtGui_QTextItem_RenderFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextItem::RenderFlags >::toPython(
        Shiboken::Converter<QTextItem::RenderFlags>::toCpp(self)
        & Shiboken::Converter< QTextItem::RenderFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextItem_RenderFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextItem::RenderFlags >::toPython(
        Shiboken::Converter<QTextItem::RenderFlags>::toCpp(self)
        | Shiboken::Converter< QTextItem::RenderFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextItem_RenderFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextItem::RenderFlags >::toPython(
        Shiboken::Converter<QTextItem::RenderFlags>::toCpp(self)
        ^ Shiboken::Converter< QTextItem::RenderFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextItem_RenderFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextItem::RenderFlags >::toPython(
        ~Shiboken::Converter<QTextItem::RenderFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QTextItem_RenderFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QTextItem_RenderFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QTextItem_RenderFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QTextItem_RenderFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QTextItem_RenderFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QTextItem_RenderFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RenderFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QTextItem_RenderFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QTextItem(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTITEM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextItem_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextItem_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextItem_Type, &Shiboken::callCppDestructor<QTextItem >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextItem_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextItem_Type, "QTextItem*");
    PyModule_AddObject(module, "QTextItem",
        ((PyObject*)&Sbk_QTextItem_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: RenderFlag
    PyTypeObject* SbkPySide_QtGui_QTextItem_RenderFlag = Shiboken::Enum::newType("PySide.QtGui.QTextItem.RenderFlag");
    SbkPySide_QtGui_QTextItem_RenderFlag->tp_as_number = &SbkPySide_QtGui_QTextItem_RenderFlag_as_number;
    SbkPySide_QtGuiTypes[SBK_QTEXTITEM_RENDERFLAG_IDX] = SbkPySide_QtGui_QTextItem_RenderFlag;
    if (PyType_Ready(SbkPySide_QtGui_QTextItem_RenderFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextItem_Type.super.ht_type.tp_dict,
            "RenderFlag",((PyObject*)SbkPySide_QtGui_QTextItem_RenderFlag));

    // init flags class: QFlags<QTextItem::RenderFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QTEXTITEM_RENDERFLAG__IDX] = &SbkPySide_QtGui_QTextItem_RenderFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextItem_RenderFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextItem_Type.super.ht_type.tp_dict,
            "RenderFlags",((PyObject*)&SbkPySide_QtGui_QTextItem_RenderFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextItem_RenderFlag,(long) QTextItem::RightToLeft, "RightToLeft");
    PyDict_SetItemString(Sbk_QTextItem_Type.super.ht_type.tp_dict,"RightToLeft", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextItem_RenderFlag->tp_dict,"RightToLeft", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextItem_RenderFlag,(long) QTextItem::Overline, "Overline");
    PyDict_SetItemString(Sbk_QTextItem_Type.super.ht_type.tp_dict,"Overline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextItem_RenderFlag->tp_dict,"Overline", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextItem_RenderFlag,(long) QTextItem::Underline, "Underline");
    PyDict_SetItemString(Sbk_QTextItem_Type.super.ht_type.tp_dict,"Underline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextItem_RenderFlag->tp_dict,"Underline", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextItem_RenderFlag,(long) QTextItem::StrikeOut, "StrikeOut");
    PyDict_SetItemString(Sbk_QTextItem_Type.super.ht_type.tp_dict,"StrikeOut", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextItem_RenderFlag->tp_dict,"StrikeOut", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextItem_RenderFlag,(long) QTextItem::Dummy, "Dummy");
    PyDict_SetItemString(Sbk_QTextItem_Type.super.ht_type.tp_dict,"Dummy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextItem_RenderFlag->tp_dict,"Dummy", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextItem::RenderFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::RenderFlag");
    // end of enum RenderFlag


    Shiboken::TypeResolver::createObjectTypeResolver<QTextItem >("QTextItem*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextItem >(typeid(QTextItem).name());
    PySide::initQtMetaType< ::QTextItem* >();
    qRegisterMetaType< ::QTextItem::RenderFlag >("QTextItem::RenderFlag");
    qRegisterMetaType< ::QTextItem::RenderFlags >("QTextItem::RenderFlags");
}

