/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtreewidgetitemiterator_wrapper.h"

// Extra includes
#include <qtreewidget.h>
#include <qtreewidgetitemiterator.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTreeWidgetItemIterator_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTreeWidgetItemIterator >()))
        return -1;

    QTreeWidgetItemIterator* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItemIterator(): too many arguments");
        return -1;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItemIterator(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QTreeWidgetItemIterator", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QTreeWidgetItemIterator(QTreeWidget*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
    // 1: QTreeWidgetItemIterator(QTreeWidgetItem*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
    // 2: QTreeWidgetItemIterator(QTreeWidgetItemIterator)
    if (numArgs == 1 && Shiboken::Converter< ::QTreeWidgetItemIterator >::isConvertible(pyargs[0])) {
        overloadId = 2; // QTreeWidgetItemIterator(QTreeWidgetItemIterator)
    } else if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QTreeWidgetItemIterator(QTreeWidgetItem*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
        } else if (Shiboken::Converter< ::QFlags<QTreeWidgetItemIterator::IteratorFlag> >::isConvertible(pyargs[1])) {
            overloadId = 1; // QTreeWidgetItemIterator(QTreeWidgetItem*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
        }
    } else if (Shiboken::Converter< ::QTreeWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QTreeWidgetItemIterator(QTreeWidget*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
        } else if (Shiboken::Converter< ::QFlags<QTreeWidgetItemIterator::IteratorFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // QTreeWidgetItemIterator(QTreeWidget*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetItemIterator_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTreeWidgetItemIterator(QTreeWidget*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<QTreeWidgetItemIterator::IteratorFlag> >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QTreeWidgetItemIterator_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItemIterator(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTreeWidget * cppArg0 = Shiboken::Converter<QTreeWidget * >::toCpp(pyargs[0]);
                QFlags<QTreeWidgetItemIterator::IteratorFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QTreeWidgetItemIterator::IteratorFlag> >::toCpp(pyargs[1]) : QTreeWidgetItemIterator::All;

                if(!PyErr_Occurred()) {
                    // QTreeWidgetItemIterator(QTreeWidget*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTreeWidgetItemIterator(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QTreeWidgetItemIterator(QTreeWidgetItem*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<QTreeWidgetItemIterator::IteratorFlag> >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QTreeWidgetItemIterator_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidgetItemIterator(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
                QFlags<QTreeWidgetItemIterator::IteratorFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QTreeWidgetItemIterator::IteratorFlag> >::toCpp(pyargs[1]) : QTreeWidgetItemIterator::All;

                if(!PyErr_Occurred()) {
                    // QTreeWidgetItemIterator(QTreeWidgetItem*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTreeWidgetItemIterator(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QTreeWidgetItemIterator(QTreeWidgetItemIterator)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTreeWidgetItemIterator cppArg0 = Shiboken::Converter<QTreeWidgetItemIterator >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTreeWidgetItemIterator(QTreeWidgetItemIterator)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTreeWidgetItemIterator(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTreeWidgetItemIterator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTreeWidgetItemIterator_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTreeWidgetItemIterator_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidget, PySide.QtGui.QTreeWidgetItemIterator.IteratorFlags = QTreeWidgetItemIterator.All", "PySide.QtGui.QTreeWidgetItem, PySide.QtGui.QTreeWidgetItemIterator.IteratorFlags = QTreeWidgetItemIterator.All", "PySide.QtGui.QTreeWidgetItemIterator", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidgetItemIterator", overloads);
        return -1;
}

static PyObject* Sbk_QTreeWidgetItemIteratorFunc_value(PyObject* self)
{
    QTreeWidgetItemIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidgetItemIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // value()
                // Begin code injection

                pyResult = Shiboken::Converter<QTreeWidgetItem* >::toPython(cppSelf->operator*());
                Shiboken::Object::releaseOwnership(pyResult);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QTreeWidgetItemIterator___copy__(PyObject *self)
{
        QTreeWidgetItemIterator* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTreeWidgetItemIterator*>::toCpp(self);
        PyObject* pyResult = 0;
        QTreeWidgetItemIterator* copy = new QTreeWidgetItemIterator(*cppSelf);
        pyResult = Shiboken::Converter<QTreeWidgetItemIterator*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTreeWidgetItemIterator_methods[] = {
    {"value", (PyCFunction)Sbk_QTreeWidgetItemIteratorFunc_value, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTreeWidgetItemIterator___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QTreeWidgetItemIteratorFunc___iadd__(PyObject* self, PyObject* arg)
{
    QTreeWidgetItemIterator* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QTreeWidgetItemIterator >::checkType(arg) && !Shiboken::Converter< ::QTreeWidgetItemIterator >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidgetItemIterator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(int)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator+=(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetItemIteratorFunc___iadd___TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+=(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) += cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QTreeWidgetItemIteratorFunc___iadd___TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItemIterator.__iadd__", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetItemIteratorFunc___isub__(PyObject* self, PyObject* arg)
{
    QTreeWidgetItemIterator* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QTreeWidgetItemIterator >::checkType(arg) && !Shiboken::Converter< ::QTreeWidgetItemIterator >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidgetItemIterator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(int)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator-=(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetItemIteratorFunc___isub___TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator-=(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) -= cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QTreeWidgetItemIteratorFunc___isub___TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidgetItemIterator.__isub__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QTreeWidgetItemIterator_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)Sbk_QTreeWidgetItemIteratorFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)Sbk_QTreeWidgetItemIteratorFunc___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTreeWidgetItemIterator_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTreeWidgetItemIterator",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QTreeWidgetItemIterator_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTreeWidgetItemIterator_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTreeWidgetItemIterator_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTreeWidgetItemIterator::IteratorFlags >::toPython(
        Shiboken::Converter<QTreeWidgetItemIterator::IteratorFlags>::toCpp(self)
        & Shiboken::Converter< QTreeWidgetItemIterator::IteratorFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTreeWidgetItemIterator::IteratorFlags >::toPython(
        Shiboken::Converter<QTreeWidgetItemIterator::IteratorFlags>::toCpp(self)
        | Shiboken::Converter< QTreeWidgetItemIterator::IteratorFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTreeWidgetItemIterator::IteratorFlags >::toPython(
        Shiboken::Converter<QTreeWidgetItemIterator::IteratorFlags>::toCpp(self)
        ^ Shiboken::Converter< QTreeWidgetItemIterator::IteratorFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTreeWidgetItemIterator::IteratorFlags >::toPython(
        ~Shiboken::Converter<QTreeWidgetItemIterator::IteratorFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "IteratorFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QTreeWidgetItemIterator(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTREEWIDGETITEMITERATOR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTreeWidgetItemIterator_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTreeWidgetItemIterator_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTreeWidgetItemIterator_Type, &Shiboken::callCppDestructor<QTreeWidgetItemIterator >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTreeWidgetItemIterator_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTreeWidgetItemIterator_Type, "QTreeWidgetItemIterator");
    PyModule_AddObject(module, "QTreeWidgetItemIterator",
        ((PyObject*)&Sbk_QTreeWidgetItemIterator_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: IteratorFlag
    PyTypeObject* SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag = Shiboken::Enum::newType("PySide.QtGui.QTreeWidgetItemIterator.IteratorFlag");
    SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_as_number = &SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag_as_number;
    SbkPySide_QtGuiTypes[SBK_QTREEWIDGETITEMITERATOR_ITERATORFLAG_IDX] = SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag;
    if (PyType_Ready(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,
            "IteratorFlag",((PyObject*)SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag));

    // init flags class: QFlags<QTreeWidgetItemIterator::IteratorFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QTREEWIDGETITEMITERATOR_ITERATORFLAG__IDX] = &SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,
            "IteratorFlags",((PyObject*)&SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::All, "All");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"All", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"All", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::Hidden, "Hidden");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"Hidden", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"Hidden", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::NotHidden, "NotHidden");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"NotHidden", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"NotHidden", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::Selected, "Selected");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"Selected", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"Selected", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::Unselected, "Unselected");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"Unselected", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"Unselected", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::Selectable, "Selectable");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"Selectable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"Selectable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::NotSelectable, "NotSelectable");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"NotSelectable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"NotSelectable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::DragEnabled, "DragEnabled");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"DragEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"DragEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::DragDisabled, "DragDisabled");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"DragDisabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"DragDisabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::DropEnabled, "DropEnabled");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"DropEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"DropEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::DropDisabled, "DropDisabled");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"DropDisabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"DropDisabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::HasChildren, "HasChildren");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"HasChildren", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"HasChildren", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::NoChildren, "NoChildren");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"NoChildren", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"NoChildren", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::Checked, "Checked");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"Checked", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"Checked", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::NotChecked, "NotChecked");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"NotChecked", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"NotChecked", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::Enabled, "Enabled");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"Enabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"Enabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::Disabled, "Disabled");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"Disabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"Disabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::Editable, "Editable");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"Editable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"Editable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::NotEditable, "NotEditable");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"NotEditable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"NotEditable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag,(long) QTreeWidgetItemIterator::UserFlag, "UserFlag");
    PyDict_SetItemString(Sbk_QTreeWidgetItemIterator_Type.super.ht_type.tp_dict,"UserFlag", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTreeWidgetItemIterator_IteratorFlag->tp_dict,"UserFlag", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTreeWidgetItemIterator::IteratorFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::IteratorFlag");
    // end of enum IteratorFlag


    Shiboken::TypeResolver::createValueTypeResolver<QTreeWidgetItemIterator >("QTreeWidgetItemIterator");
    Shiboken::TypeResolver::createObjectTypeResolver<QTreeWidgetItemIterator >("QTreeWidgetItemIterator*");
    Shiboken::TypeResolver::createValueTypeResolver<QTreeWidgetItemIterator >(typeid(QTreeWidgetItemIterator).name());
    PySide::initQtMetaType< ::QTreeWidgetItemIterator >();
    qRegisterMetaType< ::QTreeWidgetItemIterator::IteratorFlag >("QTreeWidgetItemIterator::IteratorFlag");
    qRegisterMetaType< ::QTreeWidgetItemIterator::IteratorFlags >("QTreeWidgetItemIterator::IteratorFlags");
}

