/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtmultimedia_python.h"

#include "qaudioformat_wrapper.h"

// Extra includes
#include <qaudioformat.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAudioFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QAudioFormat >()))
        return -1;

    QAudioFormat* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QAudioFormat", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QAudioFormat()
    // 1: QAudioFormat(QAudioFormat)
    if (numArgs == 0) {
        overloadId = 0; // QAudioFormat()
    } else if (numArgs == 1 && Shiboken::Converter< ::QAudioFormat >::isConvertible(pyargs[0])) {
        overloadId = 1; // QAudioFormat(QAudioFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QAudioFormat()
            {

                if(!PyErr_Occurred()) {
                    // QAudioFormat()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QAudioFormat();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QAudioFormat(QAudioFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QAudioFormat cppArg0 = Shiboken::Converter<QAudioFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QAudioFormat(QAudioFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QAudioFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QAudioFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QAudioFormat_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QAudioFormat_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtMultimedia.QAudioFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAudioFormat", overloads);
        return -1;
}

static PyObject* Sbk_QAudioFormatFunc_byteOrder(PyObject* self)
{
    QAudioFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // byteOrder()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAudioFormat::Endian cppResult = const_cast<const QAudioFormat*>(cppSelf)->byteOrder();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAudioFormat::Endian >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAudioFormatFunc_channels(PyObject* self)
{
    QAudioFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // channels()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QAudioFormat*>(cppSelf)->channels();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAudioFormatFunc_codec(PyObject* self)
{
    QAudioFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // codec()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QAudioFormat*>(cppSelf)->codec();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAudioFormatFunc_frequency(PyObject* self)
{
    QAudioFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // frequency()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QAudioFormat*>(cppSelf)->frequency();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAudioFormatFunc_isValid(PyObject* self)
{
    QAudioFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QAudioFormat*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAudioFormatFunc_sampleSize(PyObject* self)
{
    QAudioFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sampleSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QAudioFormat*>(cppSelf)->sampleSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAudioFormatFunc_sampleType(PyObject* self)
{
    QAudioFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sampleType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAudioFormat::SampleType cppResult = const_cast<const QAudioFormat*>(cppSelf)->sampleType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAudioFormat::SampleType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAudioFormatFunc_setByteOrder(PyObject* self, PyObject* arg)
{
    QAudioFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setByteOrder(QAudioFormat::Endian)
    if (Shiboken::Converter< ::QAudioFormat::Endian >::isConvertible(arg)) {
        overloadId = 0; // setByteOrder(QAudioFormat::Endian)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioFormatFunc_setByteOrder_TypeError;

    // Call function/method
    {
        {
            QAudioFormat::Endian cppArg0 = Shiboken::Converter<QAudioFormat::Endian >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setByteOrder(QAudioFormat::Endian)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setByteOrder(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QAudioFormatFunc_setByteOrder_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QAudioFormat.Endian", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAudioFormat.setByteOrder", overloads);
        return 0;
}

static PyObject* Sbk_QAudioFormatFunc_setChannels(PyObject* self, PyObject* arg)
{
    QAudioFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setChannels(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setChannels(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioFormatFunc_setChannels_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setChannels(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setChannels(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QAudioFormatFunc_setChannels_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAudioFormat.setChannels", overloads);
        return 0;
}

static PyObject* Sbk_QAudioFormatFunc_setCodec(PyObject* self, PyObject* arg)
{
    QAudioFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCodec(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setCodec(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioFormatFunc_setCodec_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCodec(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCodec(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QAudioFormatFunc_setCodec_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAudioFormat.setCodec", overloads);
        return 0;
}

static PyObject* Sbk_QAudioFormatFunc_setFrequency(PyObject* self, PyObject* arg)
{
    QAudioFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFrequency(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFrequency(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioFormatFunc_setFrequency_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFrequency(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFrequency(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QAudioFormatFunc_setFrequency_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAudioFormat.setFrequency", overloads);
        return 0;
}

static PyObject* Sbk_QAudioFormatFunc_setSampleSize(PyObject* self, PyObject* arg)
{
    QAudioFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSampleSize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSampleSize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioFormatFunc_setSampleSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSampleSize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSampleSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QAudioFormatFunc_setSampleSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAudioFormat.setSampleSize", overloads);
        return 0;
}

static PyObject* Sbk_QAudioFormatFunc_setSampleType(PyObject* self, PyObject* arg)
{
    QAudioFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSampleType(QAudioFormat::SampleType)
    if (Shiboken::Converter< ::QAudioFormat::SampleType >::isConvertible(arg)) {
        overloadId = 0; // setSampleType(QAudioFormat::SampleType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioFormatFunc_setSampleType_TypeError;

    // Call function/method
    {
        {
            QAudioFormat::SampleType cppArg0 = Shiboken::Converter<QAudioFormat::SampleType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSampleType(QAudioFormat::SampleType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSampleType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QAudioFormatFunc_setSampleType_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QAudioFormat.SampleType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAudioFormat.setSampleType", overloads);
        return 0;
}

static PyObject *Sbk_QAudioFormat___copy__(PyObject *self)
{
        QAudioFormat* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QAudioFormat*>::toCpp(self);
        PyObject* pyResult = 0;
        QAudioFormat* copy = new QAudioFormat(*cppSelf);
        pyResult = Shiboken::Converter<QAudioFormat*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QAudioFormat_methods[] = {
    {"byteOrder", (PyCFunction)Sbk_QAudioFormatFunc_byteOrder, METH_NOARGS},
    {"channels", (PyCFunction)Sbk_QAudioFormatFunc_channels, METH_NOARGS},
    {"codec", (PyCFunction)Sbk_QAudioFormatFunc_codec, METH_NOARGS},
    {"frequency", (PyCFunction)Sbk_QAudioFormatFunc_frequency, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QAudioFormatFunc_isValid, METH_NOARGS},
    {"sampleSize", (PyCFunction)Sbk_QAudioFormatFunc_sampleSize, METH_NOARGS},
    {"sampleType", (PyCFunction)Sbk_QAudioFormatFunc_sampleType, METH_NOARGS},
    {"setByteOrder", (PyCFunction)Sbk_QAudioFormatFunc_setByteOrder, METH_O},
    {"setChannels", (PyCFunction)Sbk_QAudioFormatFunc_setChannels, METH_O},
    {"setCodec", (PyCFunction)Sbk_QAudioFormatFunc_setCodec, METH_O},
    {"setFrequency", (PyCFunction)Sbk_QAudioFormatFunc_setFrequency, METH_O},
    {"setSampleSize", (PyCFunction)Sbk_QAudioFormatFunc_setSampleSize, METH_O},
    {"setSampleType", (PyCFunction)Sbk_QAudioFormatFunc_setSampleType, METH_O},

    {"__copy__", (PyCFunction)Sbk_QAudioFormat___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QAudioFormat_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QAudioFormat& cppSelf = *Shiboken::Converter< QAudioFormat* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QAudioFormat >::isConvertible(arg)) {
                // operator!=(const QAudioFormat & other) const
                QAudioFormat cppArg0 = Shiboken::Converter< ::QAudioFormat >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QAudioFormat_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QAudioFormat >::isConvertible(arg)) {
                // operator==(const QAudioFormat & other) const
                QAudioFormat cppArg0 = Shiboken::Converter< ::QAudioFormat >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QAudioFormat_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QAudioFormat_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QAudioFormat_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QAudioFormat_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtMultimedia.QAudioFormat",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QAudioFormat_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QAudioFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QAudioFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QAudioFormat(PyObject* module)
{
    SbkPySide_QtMultimediaTypes[SBK_QAUDIOFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QAudioFormat_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QAudioFormat_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QAudioFormat_Type, &Shiboken::callCppDestructor<QAudioFormat >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QAudioFormat_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QAudioFormat_Type, "QAudioFormat");
    PyModule_AddObject(module, "QAudioFormat",
        ((PyObject*)&Sbk_QAudioFormat_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: SampleType
    PyTypeObject* SbkPySide_QtMultimedia_QAudioFormat_SampleType = Shiboken::Enum::newType("PySide.QtMultimedia.QAudioFormat.SampleType");
    SbkPySide_QtMultimediaTypes[SBK_QAUDIOFORMAT_SAMPLETYPE_IDX] = SbkPySide_QtMultimedia_QAudioFormat_SampleType;
    if (PyType_Ready(SbkPySide_QtMultimedia_QAudioFormat_SampleType) < 0)
        return;
    PyDict_SetItemString(Sbk_QAudioFormat_Type.super.ht_type.tp_dict,
            "SampleType",((PyObject*)SbkPySide_QtMultimedia_QAudioFormat_SampleType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAudioFormat_SampleType,(long) QAudioFormat::Unknown, "Unknown");
    PyDict_SetItemString(Sbk_QAudioFormat_Type.super.ht_type.tp_dict,"Unknown", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAudioFormat_SampleType->tp_dict,"Unknown", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAudioFormat_SampleType,(long) QAudioFormat::SignedInt, "SignedInt");
    PyDict_SetItemString(Sbk_QAudioFormat_Type.super.ht_type.tp_dict,"SignedInt", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAudioFormat_SampleType->tp_dict,"SignedInt", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAudioFormat_SampleType,(long) QAudioFormat::UnSignedInt, "UnSignedInt");
    PyDict_SetItemString(Sbk_QAudioFormat_Type.super.ht_type.tp_dict,"UnSignedInt", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAudioFormat_SampleType->tp_dict,"UnSignedInt", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAudioFormat_SampleType,(long) QAudioFormat::Float, "Float");
    PyDict_SetItemString(Sbk_QAudioFormat_Type.super.ht_type.tp_dict,"Float", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAudioFormat_SampleType->tp_dict,"Float", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAudioFormat::SampleType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::SampleType");
    // end of enum SampleType

    // init enum: Endian
    PyTypeObject* SbkPySide_QtMultimedia_QAudioFormat_Endian = Shiboken::Enum::newType("PySide.QtMultimedia.QAudioFormat.Endian");
    SbkPySide_QtMultimediaTypes[SBK_QAUDIOFORMAT_ENDIAN_IDX] = SbkPySide_QtMultimedia_QAudioFormat_Endian;
    if (PyType_Ready(SbkPySide_QtMultimedia_QAudioFormat_Endian) < 0)
        return;
    PyDict_SetItemString(Sbk_QAudioFormat_Type.super.ht_type.tp_dict,
            "Endian",((PyObject*)SbkPySide_QtMultimedia_QAudioFormat_Endian));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAudioFormat_Endian,(long) QAudioFormat::BigEndian, "BigEndian");
    PyDict_SetItemString(Sbk_QAudioFormat_Type.super.ht_type.tp_dict,"BigEndian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAudioFormat_Endian->tp_dict,"BigEndian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAudioFormat_Endian,(long) QAudioFormat::LittleEndian, "LittleEndian");
    PyDict_SetItemString(Sbk_QAudioFormat_Type.super.ht_type.tp_dict,"LittleEndian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAudioFormat_Endian->tp_dict,"LittleEndian", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAudioFormat::Endian");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Endian");
    // end of enum Endian


    Shiboken::TypeResolver::createValueTypeResolver<QAudioFormat >("QAudioFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QAudioFormat >("QAudioFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QAudioFormat >(typeid(QAudioFormat).name());
    PySide::initQtMetaType< ::QAudioFormat >();
    qRegisterMetaType< ::QAudioFormat::SampleType >("QAudioFormat::SampleType");
    qRegisterMetaType< ::QAudioFormat::Endian >("QAudioFormat::Endian");
}

