/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtmultimedia_python.h"

#include "qvideoframe_wrapper.h"

// Extra includes
#include <qabstractvideobuffer.h>
#include <qimage.h>
#include <qsize.h>
#include <qvideoframe.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QVideoFrame_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QVideoFrame >()))
        return -1;

    QVideoFrame* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto Sbk_QVideoFrame_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QVideoFrame", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QVideoFrame()
    // 1: QVideoFrame(QAbstractVideoBuffer*,QSize,QVideoFrame::PixelFormat)
    // 2: QVideoFrame(QImage)
    // 3: QVideoFrame(QVideoFrame)
    // 4: QVideoFrame(int,QSize,int,QVideoFrame::PixelFormat)
    if (numArgs == 0) {
        overloadId = 0; // QVideoFrame()
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QSize >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2]) && Shiboken::Converter< ::QVideoFrame::PixelFormat >::isConvertible(pyargs[3])) {
        overloadId = 4; // QVideoFrame(int,QSize,int,QVideoFrame::PixelFormat)
    } else if (numArgs == 1 && Shiboken::Converter< ::QVideoFrame >::isConvertible(pyargs[0])) {
        overloadId = 3; // QVideoFrame(QVideoFrame)
    } else if (numArgs == 1 && Shiboken::Converter< ::QImage >::isConvertible(pyargs[0])) {
        overloadId = 2; // QVideoFrame(QImage)
    } else if (numArgs == 3 && Shiboken::Converter< ::QAbstractVideoBuffer * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSize >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QVideoFrame::PixelFormat >::isConvertible(pyargs[2])) {
        overloadId = 1; // QVideoFrame(QAbstractVideoBuffer*,QSize,QVideoFrame::PixelFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoFrame_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QVideoFrame()
            {

                if(!PyErr_Occurred()) {
                    // QVideoFrame()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVideoFrame();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QVideoFrame(QAbstractVideoBuffer*,QSize,QVideoFrame::PixelFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QAbstractVideoBuffer * cppArg0 = Shiboken::Converter<QAbstractVideoBuffer * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QSize cppArg1 = Shiboken::Converter<QSize >::toCpp(pyargs[1]);
                QVideoFrame::PixelFormat cppArg2 = Shiboken::Converter<QVideoFrame::PixelFormat >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // QVideoFrame(QAbstractVideoBuffer*,QSize,QVideoFrame::PixelFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVideoFrame(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QVideoFrame(QImage)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QImage cppArg0 = Shiboken::Converter<QImage >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QVideoFrame(QImage)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVideoFrame(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QVideoFrame(QVideoFrame)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                const QVideoFrame & cppArg0 = Shiboken::Converter<const QVideoFrame & >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QVideoFrame(QVideoFrame)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVideoFrame(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QVideoFrame(int,QSize,int,QVideoFrame::PixelFormat)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QSize cppArg1 = Shiboken::Converter<QSize >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                QVideoFrame::PixelFormat cppArg3 = Shiboken::Converter<QVideoFrame::PixelFormat >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // QVideoFrame(int,QSize,int,QVideoFrame::PixelFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVideoFrame(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QVideoFrame >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QVideoFrame_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QVideoFrame_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtMultimedia.QAbstractVideoBuffer, PySide.QtCore.QSize, PySide.QtMultimedia.QVideoFrame.PixelFormat", "PySide.QtGui.QImage", "PySide.QtMultimedia.QVideoFrame", "int, PySide.QtCore.QSize, int, PySide.QtMultimedia.QVideoFrame.PixelFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QVideoFrame", overloads);
        return -1;
}

static PyObject* Sbk_QVideoFrameFunc_bits(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bits()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                uchar * cppResult = cppSelf->bits();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::uchar * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_bytesPerLine(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bytesPerLine()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QVideoFrame*>(cppSelf)->bytesPerLine();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_endTime(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // endTime()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QVideoFrame*>(cppSelf)->endTime();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_fieldType(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fieldType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVideoFrame::FieldType cppResult = const_cast<const QVideoFrame*>(cppSelf)->fieldType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVideoFrame::FieldType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_handle(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // handle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = const_cast<const QVideoFrame*>(cppSelf)->handle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_handleType(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // handleType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractVideoBuffer::HandleType cppResult = const_cast<const QVideoFrame*>(cppSelf)->handleType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractVideoBuffer::HandleType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_height(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // height()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QVideoFrame*>(cppSelf)->height();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_imageFormatFromPixelFormat(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: imageFormatFromPixelFormat(QVideoFrame::PixelFormat)
    if (Shiboken::Converter< ::QVideoFrame::PixelFormat >::isConvertible(arg)) {
        overloadId = 0; // imageFormatFromPixelFormat(QVideoFrame::PixelFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoFrameFunc_imageFormatFromPixelFormat_TypeError;

    // Call function/method
    {
        {
            QVideoFrame::PixelFormat cppArg0 = Shiboken::Converter<QVideoFrame::PixelFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // imageFormatFromPixelFormat(QVideoFrame::PixelFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage::Format cppResult = QVideoFrame::imageFormatFromPixelFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage::Format >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVideoFrameFunc_imageFormatFromPixelFormat_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QVideoFrame.PixelFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QVideoFrame.imageFormatFromPixelFormat", overloads);
        return 0;
}

static PyObject* Sbk_QVideoFrameFunc_isMapped(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isMapped()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QVideoFrame*>(cppSelf)->isMapped();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_isReadable(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isReadable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QVideoFrame*>(cppSelf)->isReadable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_isValid(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QVideoFrame*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_isWritable(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isWritable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QVideoFrame*>(cppSelf)->isWritable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_map(PyObject* self, PyObject* arg)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: map(QAbstractVideoBuffer::MapMode)
    if (Shiboken::Converter< ::QAbstractVideoBuffer::MapMode >::isConvertible(arg)) {
        overloadId = 0; // map(QAbstractVideoBuffer::MapMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoFrameFunc_map_TypeError;

    // Call function/method
    {
        {
            QAbstractVideoBuffer::MapMode cppArg0 = Shiboken::Converter<QAbstractVideoBuffer::MapMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // map(QAbstractVideoBuffer::MapMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->map(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVideoFrameFunc_map_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QAbstractVideoBuffer.MapMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QVideoFrame.map", overloads);
        return 0;
}

static PyObject* Sbk_QVideoFrameFunc_mapMode(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // mapMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractVideoBuffer::MapMode cppResult = const_cast<const QVideoFrame*>(cppSelf)->mapMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractVideoBuffer::MapMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_mappedBytes(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // mappedBytes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QVideoFrame*>(cppSelf)->mappedBytes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_pixelFormat(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pixelFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVideoFrame::PixelFormat cppResult = const_cast<const QVideoFrame*>(cppSelf)->pixelFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVideoFrame::PixelFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_pixelFormatFromImageFormat(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: pixelFormatFromImageFormat(QImage::Format)
    if (Shiboken::Converter< ::QImage::Format >::isConvertible(arg)) {
        overloadId = 0; // pixelFormatFromImageFormat(QImage::Format)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoFrameFunc_pixelFormatFromImageFormat_TypeError;

    // Call function/method
    {
        {
            QImage::Format cppArg0 = Shiboken::Converter<QImage::Format >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // pixelFormatFromImageFormat(QImage::Format)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVideoFrame::PixelFormat cppResult = QVideoFrame::pixelFormatFromImageFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVideoFrame::PixelFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVideoFrameFunc_pixelFormatFromImageFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage.Format", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QVideoFrame.pixelFormatFromImageFormat", overloads);
        return 0;
}

static PyObject* Sbk_QVideoFrameFunc_setEndTime(PyObject* self, PyObject* arg)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEndTime(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEndTime(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoFrameFunc_setEndTime_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEndTime(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEndTime(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVideoFrameFunc_setEndTime_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QVideoFrame.setEndTime", overloads);
        return 0;
}

static PyObject* Sbk_QVideoFrameFunc_setFieldType(PyObject* self, PyObject* arg)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFieldType(QVideoFrame::FieldType)
    if (Shiboken::Converter< ::QVideoFrame::FieldType >::isConvertible(arg)) {
        overloadId = 0; // setFieldType(QVideoFrame::FieldType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoFrameFunc_setFieldType_TypeError;

    // Call function/method
    {
        {
            QVideoFrame::FieldType cppArg0 = Shiboken::Converter<QVideoFrame::FieldType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFieldType(QVideoFrame::FieldType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFieldType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVideoFrameFunc_setFieldType_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QVideoFrame.FieldType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QVideoFrame.setFieldType", overloads);
        return 0;
}

static PyObject* Sbk_QVideoFrameFunc_setStartTime(PyObject* self, PyObject* arg)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStartTime(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStartTime(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoFrameFunc_setStartTime_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStartTime(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStartTime(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVideoFrameFunc_setStartTime_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QVideoFrame.setStartTime", overloads);
        return 0;
}

static PyObject* Sbk_QVideoFrameFunc_size(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QVideoFrame*>(cppSelf)->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_startTime(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // startTime()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QVideoFrame*>(cppSelf)->startTime();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoFrameFunc_unmap(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // unmap()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->unmap();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QVideoFrameFunc_width(PyObject* self)
{
    QVideoFrame* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // width()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QVideoFrame*>(cppSelf)->width();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QVideoFrame_methods[] = {
    {"bits", (PyCFunction)Sbk_QVideoFrameFunc_bits, METH_NOARGS},
    {"bytesPerLine", (PyCFunction)Sbk_QVideoFrameFunc_bytesPerLine, METH_NOARGS},
    {"endTime", (PyCFunction)Sbk_QVideoFrameFunc_endTime, METH_NOARGS},
    {"fieldType", (PyCFunction)Sbk_QVideoFrameFunc_fieldType, METH_NOARGS},
    {"handle", (PyCFunction)Sbk_QVideoFrameFunc_handle, METH_NOARGS},
    {"handleType", (PyCFunction)Sbk_QVideoFrameFunc_handleType, METH_NOARGS},
    {"height", (PyCFunction)Sbk_QVideoFrameFunc_height, METH_NOARGS},
    {"imageFormatFromPixelFormat", (PyCFunction)Sbk_QVideoFrameFunc_imageFormatFromPixelFormat, METH_O|METH_STATIC},
    {"isMapped", (PyCFunction)Sbk_QVideoFrameFunc_isMapped, METH_NOARGS},
    {"isReadable", (PyCFunction)Sbk_QVideoFrameFunc_isReadable, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QVideoFrameFunc_isValid, METH_NOARGS},
    {"isWritable", (PyCFunction)Sbk_QVideoFrameFunc_isWritable, METH_NOARGS},
    {"map", (PyCFunction)Sbk_QVideoFrameFunc_map, METH_O},
    {"mapMode", (PyCFunction)Sbk_QVideoFrameFunc_mapMode, METH_NOARGS},
    {"mappedBytes", (PyCFunction)Sbk_QVideoFrameFunc_mappedBytes, METH_NOARGS},
    {"pixelFormat", (PyCFunction)Sbk_QVideoFrameFunc_pixelFormat, METH_NOARGS},
    {"pixelFormatFromImageFormat", (PyCFunction)Sbk_QVideoFrameFunc_pixelFormatFromImageFormat, METH_O|METH_STATIC},
    {"setEndTime", (PyCFunction)Sbk_QVideoFrameFunc_setEndTime, METH_O},
    {"setFieldType", (PyCFunction)Sbk_QVideoFrameFunc_setFieldType, METH_O},
    {"setStartTime", (PyCFunction)Sbk_QVideoFrameFunc_setStartTime, METH_O},
    {"size", (PyCFunction)Sbk_QVideoFrameFunc_size, METH_NOARGS},
    {"startTime", (PyCFunction)Sbk_QVideoFrameFunc_startTime, METH_NOARGS},
    {"unmap", (PyCFunction)Sbk_QVideoFrameFunc_unmap, METH_NOARGS},
    {"width", (PyCFunction)Sbk_QVideoFrameFunc_width, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QVideoFrame_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtMultimedia.QVideoFrame",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QVideoFrame_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QVideoFrame_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QVideoFrame(PyObject* module)
{
    SbkPySide_QtMultimediaTypes[SBK_QVIDEOFRAME_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QVideoFrame_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QVideoFrame_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QVideoFrame_Type, &Shiboken::callCppDestructor<QVideoFrame >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QVideoFrame_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QVideoFrame_Type, "QVideoFrame*");
    PyModule_AddObject(module, "QVideoFrame",
        ((PyObject*)&Sbk_QVideoFrame_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: FieldType
    PyTypeObject* SbkPySide_QtMultimedia_QVideoFrame_FieldType = Shiboken::Enum::newType("PySide.QtMultimedia.QVideoFrame.FieldType");
    SbkPySide_QtMultimediaTypes[SBK_QVIDEOFRAME_FIELDTYPE_IDX] = SbkPySide_QtMultimedia_QVideoFrame_FieldType;
    if (PyType_Ready(SbkPySide_QtMultimedia_QVideoFrame_FieldType) < 0)
        return;
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,
            "FieldType",((PyObject*)SbkPySide_QtMultimedia_QVideoFrame_FieldType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_FieldType,(long) QVideoFrame::ProgressiveFrame, "ProgressiveFrame");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"ProgressiveFrame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_FieldType->tp_dict,"ProgressiveFrame", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_FieldType,(long) QVideoFrame::TopField, "TopField");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"TopField", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_FieldType->tp_dict,"TopField", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_FieldType,(long) QVideoFrame::BottomField, "BottomField");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"BottomField", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_FieldType->tp_dict,"BottomField", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_FieldType,(long) QVideoFrame::InterlacedFrame, "InterlacedFrame");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"InterlacedFrame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_FieldType->tp_dict,"InterlacedFrame", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QVideoFrame::FieldType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FieldType");
    // end of enum FieldType

    // init enum: PixelFormat
    PyTypeObject* SbkPySide_QtMultimedia_QVideoFrame_PixelFormat = Shiboken::Enum::newType("PySide.QtMultimedia.QVideoFrame.PixelFormat");
    SbkPySide_QtMultimediaTypes[SBK_QVIDEOFRAME_PIXELFORMAT_IDX] = SbkPySide_QtMultimedia_QVideoFrame_PixelFormat;
    if (PyType_Ready(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat) < 0)
        return;
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,
            "PixelFormat",((PyObject*)SbkPySide_QtMultimedia_QVideoFrame_PixelFormat));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_Invalid, "Format_Invalid");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_Invalid", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_Invalid", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_ARGB32, "Format_ARGB32");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_ARGB32", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_ARGB32", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_ARGB32_Premultiplied, "Format_ARGB32_Premultiplied");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_ARGB32_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_ARGB32_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_RGB32, "Format_RGB32");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_RGB32", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_RGB32", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_RGB24, "Format_RGB24");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_RGB24", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_RGB24", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_RGB565, "Format_RGB565");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_RGB565", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_RGB565", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_RGB555, "Format_RGB555");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_RGB555", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_RGB555", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_ARGB8565_Premultiplied, "Format_ARGB8565_Premultiplied");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_ARGB8565_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_ARGB8565_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_BGRA32, "Format_BGRA32");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_BGRA32", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_BGRA32", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_BGRA32_Premultiplied, "Format_BGRA32_Premultiplied");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_BGRA32_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_BGRA32_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_BGR32, "Format_BGR32");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_BGR32", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_BGR32", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_BGR24, "Format_BGR24");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_BGR24", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_BGR24", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_BGR565, "Format_BGR565");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_BGR565", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_BGR565", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_BGR555, "Format_BGR555");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_BGR555", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_BGR555", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_BGRA5658_Premultiplied, "Format_BGRA5658_Premultiplied");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_BGRA5658_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_BGRA5658_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_AYUV444, "Format_AYUV444");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_AYUV444", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_AYUV444", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_AYUV444_Premultiplied, "Format_AYUV444_Premultiplied");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_AYUV444_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_AYUV444_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_YUV444, "Format_YUV444");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_YUV444", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_YUV444", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_YUV420P, "Format_YUV420P");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_YUV420P", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_YUV420P", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_YV12, "Format_YV12");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_YV12", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_YV12", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_UYVY, "Format_UYVY");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_UYVY", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_UYVY", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_YUYV, "Format_YUYV");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_YUYV", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_YUYV", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_NV12, "Format_NV12");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_NV12", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_NV12", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_NV21, "Format_NV21");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_NV21", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_NV21", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_IMC1, "Format_IMC1");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_IMC1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_IMC1", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_IMC2, "Format_IMC2");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_IMC2", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_IMC2", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_IMC3, "Format_IMC3");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_IMC3", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_IMC3", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_IMC4, "Format_IMC4");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_IMC4", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_IMC4", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_Y8, "Format_Y8");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_Y8", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_Y8", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_Y16, "Format_Y16");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_Y16", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_Y16", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat,(long) QVideoFrame::Format_User, "Format_User");
    PyDict_SetItemString(Sbk_QVideoFrame_Type.super.ht_type.tp_dict,"Format_User", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoFrame_PixelFormat->tp_dict,"Format_User", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QVideoFrame::PixelFormat");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::PixelFormat");
    // end of enum PixelFormat


    Shiboken::TypeResolver::createObjectTypeResolver<QVideoFrame >("QVideoFrame*");
    Shiboken::TypeResolver::createObjectTypeResolver<QVideoFrame >(typeid(QVideoFrame).name());
    PySide::initQtMetaType< ::QVideoFrame* >();
    qRegisterMetaType< ::QVideoFrame::FieldType >("QVideoFrame::FieldType");
    qRegisterMetaType< ::QVideoFrame::PixelFormat >("QVideoFrame::PixelFormat");
}

