/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtnetwork_python.h"

#include "qftp_wrapper.h"

// Extra includes
#include <QList>
#include <autoarraypointer.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qftp.h>
#include <qiodevice.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurlinfo.h>


// Native ---------------------------------------------------------

QFtpWrapper::QFtpWrapper(QObject * parent) : QFtp(parent) {
    // ... middle
}

void QFtpWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFtpWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QFtpWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFtpWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QFtpWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFtp.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QFtpWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFtp.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QFtpWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QFtpWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QFtpWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QFtp::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QFtpWrapper::~QFtpWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFtp_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QFtp >()))
        return -1;

    QFtpWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QFtp", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QFtp(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QFtp(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QFtp(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtp_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QFtp_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QFtp(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QFtpWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QFtp >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QFtp_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QFtp_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp", overloads);
        return -1;
}

static PyObject* Sbk_QFtpFunc_abort(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // abort()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->abort();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QFtpFunc_bytesAvailable(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bytesAvailable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QFtp*>(cppSelf)->bytesAvailable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFtpFunc_cd(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: cd(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // cd(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_cd_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // cd(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->cd(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_cd_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.cd", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_clearPendingCommands(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearPendingCommands()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearPendingCommands();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QFtpFunc_close(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // close()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->close();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFtpFunc_connectToHost(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.connectToHost(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.connectToHost(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:connectToHost", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: connectToHost(QString,quint16)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // connectToHost(QString,quint16)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // connectToHost(QString,quint16)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_connectToHost_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "port");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "port";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QFtpFunc_connectToHost_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.connectToHost(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            quint16 cppArg1 = pyargs[1] ? Shiboken::Converter<quint16 >::toCpp(pyargs[1]) : 21;

            if(!PyErr_Occurred()) {
                // connectToHost(QString,quint16)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->connectToHost(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_connectToHost_TypeError:
        const char* overloads[] = {"QString, unsigned short = 21", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp.connectToHost", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_currentCommand(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentCommand()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFtp::Command cppResult = const_cast<const QFtp*>(cppSelf)->currentCommand();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFtp::Command >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFtpFunc_currentDevice(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentDevice()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIODevice * cppResult = const_cast<const QFtp*>(cppSelf)->currentDevice();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIODevice * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFtpFunc_currentId(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QFtp*>(cppSelf)->currentId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFtpFunc_error(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // error()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFtp::Error cppResult = const_cast<const QFtp*>(cppSelf)->error();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFtp::Error >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFtpFunc_errorString(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QFtp*>(cppSelf)->errorString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFtpFunc_get(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.get(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.get(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:get", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: get(QString,QIODevice*,QFtp::TransferType)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // get(QString,QIODevice*,QFtp::TransferType)
        } else if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // get(QString,QIODevice*,QFtp::TransferType)
            } else if (Shiboken::Converter< ::QFtp::TransferType >::isConvertible(pyargs[2])) {
                overloadId = 0; // get(QString,QIODevice*,QFtp::TransferType)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_get_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "dev");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "dev";
                    else if (Shiboken::Converter< ::QIODevice * >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QFtpFunc_get_TypeError;
                }
                value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "type";
                    else if (Shiboken::Converter< ::QFtp::TransferType >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QFtpFunc_get_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.get(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QIODevice * cppArg1 = pyargs[1] ? Shiboken::Converter<QIODevice * >::toCpp(pyargs[1]) : 0;
            QFtp::TransferType cppArg2 = pyargs[2] ? Shiboken::Converter<QFtp::TransferType >::toCpp(pyargs[2]) : QFtp::Binary;

            if(!PyErr_Occurred()) {
                // get(QString,QIODevice*,QFtp::TransferType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->get(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_get_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice = None, PySide.QtNetwork.QFtp.TransferType = Binary", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp.get", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_hasPendingCommands(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasPendingCommands()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFtp*>(cppSelf)->hasPendingCommands();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFtpFunc_list(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.list(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:list", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: list(QString)
    if (numArgs == 0) {
        overloadId = 0; // list(QString)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 0; // list(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_list_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "dir");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "dir";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QFtpFunc_list_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.list(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();

            if(!PyErr_Occurred()) {
                // list(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->list(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_list_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp.list", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_login(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.login(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:login", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: login(QString,QString)
    if (numArgs == 0) {
        overloadId = 0; // login(QString,QString)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // login(QString,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // login(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_login_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "user");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "user";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QFtpFunc_login_TypeError;
                }
                value = PyDict_GetItemString(kwds, "password");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "password";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QFtpFunc_login_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.login(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // login(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->login(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_login_TypeError:
        const char* overloads[] = {"QString = QString(), QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp.login", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_mkdir(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mkdir(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // mkdir(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_mkdir_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mkdir(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->mkdir(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_mkdir_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.mkdir", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_put(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.put(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.put(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:put", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: put(QIODevice*,QString,QFtp::TransferType)
    // 1: put(QByteArray,QString,QFtp::TransferType)
    if (numArgs >= 2 && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // put(QByteArray,QString,QFtp::TransferType)
        } else if (Shiboken::Converter< ::QFtp::TransferType >::isConvertible(pyargs[2])) {
            overloadId = 1; // put(QByteArray,QString,QFtp::TransferType)
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // put(QIODevice*,QString,QFtp::TransferType)
        } else if (Shiboken::Converter< ::QFtp::TransferType >::isConvertible(pyargs[2])) {
            overloadId = 0; // put(QIODevice*,QString,QFtp::TransferType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_put_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // put(QIODevice*,QString,QFtp::TransferType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "type";
                        else if (Shiboken::Converter< ::QFtp::TransferType >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QFtpFunc_put_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.put(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QFtp::TransferType cppArg2 = pyargs[2] ? Shiboken::Converter<QFtp::TransferType >::toCpp(pyargs[2]) : QFtp::Binary;

                if(!PyErr_Occurred()) {
                    // put(QIODevice*,QString,QFtp::TransferType)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->put(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // put(QByteArray,QString,QFtp::TransferType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "type";
                        else if (Shiboken::Converter< ::QFtp::TransferType >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QFtpFunc_put_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.put(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QFtp::TransferType cppArg2 = pyargs[2] ? Shiboken::Converter<QFtp::TransferType >::toCpp(pyargs[2]) : QFtp::Binary;

                if(!PyErr_Occurred()) {
                    // put(QByteArray,QString,QFtp::TransferType)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->put(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_put_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, QString, PySide.QtNetwork.QFtp.TransferType = Binary", "PySide.QtCore.QByteArray, QString, PySide.QtNetwork.QFtp.TransferType = Binary", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp.put", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_rawCommand(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rawCommand(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // rawCommand(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_rawCommand_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // rawCommand(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->rawCommand(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_rawCommand_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.rawCommand", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_read(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: read(char*,qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // read(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_read_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // read(char*,qint64)
                // Begin code injection

                // TEMPLATE - read_wrapper - START
                PySide::AutoArrayPointer<char> _data(cppArg0);
                qint64 _size = cppSelf->read(_data, cppArg0);
                if (_size > 0)
                pyResult = Shiboken::Converter<QByteArray >::toPython(QByteArray(_data, _size));
                else
                pyResult = Shiboken::Converter<QByteArray >::toPython(QByteArray());
                // TEMPLATE - read_wrapper - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_read_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.read", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_readAll(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readAll()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->readAll();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFtpFunc_remove(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: remove(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // remove(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_remove_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // remove(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->remove(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_remove_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.remove", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_rename(PyObject* self, PyObject* args)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "rename", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: rename(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // rename(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_rename_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // rename(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->rename(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_rename_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp.rename", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_rmdir(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rmdir(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // rmdir(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_rmdir_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // rmdir(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->rmdir(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_rmdir_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.rmdir", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_setProxy(PyObject* self, PyObject* args)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setProxy", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setProxy(QString,quint16)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setProxy(QString,quint16)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_setProxy_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            quint16 cppArg1 = Shiboken::Converter<quint16 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setProxy(QString,quint16)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->setProxy(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_setProxy_TypeError:
        const char* overloads[] = {"QString, unsigned short", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp.setProxy", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_setTransferMode(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTransferMode(QFtp::TransferMode)
    if (Shiboken::Converter< ::QFtp::TransferMode >::isConvertible(arg)) {
        overloadId = 0; // setTransferMode(QFtp::TransferMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFtpFunc_setTransferMode_TypeError;

    // Call function/method
    {
        {
            QFtp::TransferMode cppArg0 = Shiboken::Converter<QFtp::TransferMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTransferMode(QFtp::TransferMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->setTransferMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFtpFunc_setTransferMode_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QFtp.TransferMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.setTransferMode", overloads);
        return 0;
}

static PyObject* Sbk_QFtpFunc_state(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // state()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFtp::State cppResult = const_cast<const QFtp*>(cppSelf)->state();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFtp::State >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QFtp_methods[] = {
    {"abort", (PyCFunction)Sbk_QFtpFunc_abort, METH_NOARGS},
    {"bytesAvailable", (PyCFunction)Sbk_QFtpFunc_bytesAvailable, METH_NOARGS},
    {"cd", (PyCFunction)Sbk_QFtpFunc_cd, METH_O},
    {"clearPendingCommands", (PyCFunction)Sbk_QFtpFunc_clearPendingCommands, METH_NOARGS},
    {"close", (PyCFunction)Sbk_QFtpFunc_close, METH_NOARGS},
    {"connectToHost", (PyCFunction)Sbk_QFtpFunc_connectToHost, METH_VARARGS|METH_KEYWORDS},
    {"currentCommand", (PyCFunction)Sbk_QFtpFunc_currentCommand, METH_NOARGS},
    {"currentDevice", (PyCFunction)Sbk_QFtpFunc_currentDevice, METH_NOARGS},
    {"currentId", (PyCFunction)Sbk_QFtpFunc_currentId, METH_NOARGS},
    {"error", (PyCFunction)Sbk_QFtpFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QFtpFunc_errorString, METH_NOARGS},
    {"get", (PyCFunction)Sbk_QFtpFunc_get, METH_VARARGS|METH_KEYWORDS},
    {"hasPendingCommands", (PyCFunction)Sbk_QFtpFunc_hasPendingCommands, METH_NOARGS},
    {"list", (PyCFunction)Sbk_QFtpFunc_list, METH_VARARGS|METH_KEYWORDS},
    {"login", (PyCFunction)Sbk_QFtpFunc_login, METH_VARARGS|METH_KEYWORDS},
    {"mkdir", (PyCFunction)Sbk_QFtpFunc_mkdir, METH_O},
    {"put", (PyCFunction)Sbk_QFtpFunc_put, METH_VARARGS|METH_KEYWORDS},
    {"rawCommand", (PyCFunction)Sbk_QFtpFunc_rawCommand, METH_O},
    {"read", (PyCFunction)Sbk_QFtpFunc_read, METH_O},
    {"readAll", (PyCFunction)Sbk_QFtpFunc_readAll, METH_NOARGS},
    {"remove", (PyCFunction)Sbk_QFtpFunc_remove, METH_O},
    {"rename", (PyCFunction)Sbk_QFtpFunc_rename, METH_VARARGS},
    {"rmdir", (PyCFunction)Sbk_QFtpFunc_rmdir, METH_O},
    {"setProxy", (PyCFunction)Sbk_QFtpFunc_setProxy, METH_VARARGS},
    {"setTransferMode", (PyCFunction)Sbk_QFtpFunc_setTransferMode, METH_O},
    {"state", (PyCFunction)Sbk_QFtpFunc_state, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QFtp_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QFtp",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QFtp_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QFtp_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QFtp_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QFtp*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QFtp_Type;
    return 0;
}


void init_QFtp(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QFTP_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QFtp_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QFtp_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QFtp_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QFtp_Type, &QFtp::staticMetaObject);    Sbk_QFtp_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QFtp_Type, &Shiboken::callCppDestructor<QFtp >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QFtp_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QFtp_Type, &Sbk_QFtp_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QFtp_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QFtp_Type, "QFtp*");
    PyModule_AddObject(module, "QFtp",
        ((PyObject*)&Sbk_QFtp_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: TransferType
    PyTypeObject* SbkPySide_QtNetwork_QFtp_TransferType = Shiboken::Enum::newType("PySide.QtNetwork.QFtp.TransferType");
    SbkPySide_QtNetworkTypes[SBK_QFTP_TRANSFERTYPE_IDX] = SbkPySide_QtNetwork_QFtp_TransferType;
    if (PyType_Ready(SbkPySide_QtNetwork_QFtp_TransferType) < 0)
        return;
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,
            "TransferType",((PyObject*)SbkPySide_QtNetwork_QFtp_TransferType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_TransferType,(long) QFtp::Binary, "Binary");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Binary", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_TransferType->tp_dict,"Binary", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_TransferType,(long) QFtp::Ascii, "Ascii");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Ascii", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_TransferType->tp_dict,"Ascii", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFtp::TransferType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::TransferType");
    // end of enum TransferType

    // init enum: Error
    PyTypeObject* SbkPySide_QtNetwork_QFtp_Error = Shiboken::Enum::newType("PySide.QtNetwork.QFtp.Error");
    SbkPySide_QtNetworkTypes[SBK_QFTP_ERROR_IDX] = SbkPySide_QtNetwork_QFtp_Error;
    if (PyType_Ready(SbkPySide_QtNetwork_QFtp_Error) < 0)
        return;
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,
            "Error",((PyObject*)SbkPySide_QtNetwork_QFtp_Error));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Error,(long) QFtp::NoError, "NoError");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Error->tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Error,(long) QFtp::UnknownError, "UnknownError");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"UnknownError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Error->tp_dict,"UnknownError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Error,(long) QFtp::HostNotFound, "HostNotFound");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"HostNotFound", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Error->tp_dict,"HostNotFound", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Error,(long) QFtp::ConnectionRefused, "ConnectionRefused");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"ConnectionRefused", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Error->tp_dict,"ConnectionRefused", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Error,(long) QFtp::NotConnected, "NotConnected");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"NotConnected", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Error->tp_dict,"NotConnected", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFtp::Error");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Error");
    // end of enum Error

    // init enum: Command
    PyTypeObject* SbkPySide_QtNetwork_QFtp_Command = Shiboken::Enum::newType("PySide.QtNetwork.QFtp.Command");
    SbkPySide_QtNetworkTypes[SBK_QFTP_COMMAND_IDX] = SbkPySide_QtNetwork_QFtp_Command;
    if (PyType_Ready(SbkPySide_QtNetwork_QFtp_Command) < 0)
        return;
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,
            "Command",((PyObject*)SbkPySide_QtNetwork_QFtp_Command));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::None, "None");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"None", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"None", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::SetTransferMode, "SetTransferMode");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"SetTransferMode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"SetTransferMode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::SetProxy, "SetProxy");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"SetProxy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"SetProxy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::ConnectToHost, "ConnectToHost");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"ConnectToHost", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"ConnectToHost", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::Login, "Login");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Login", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"Login", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::Close, "Close");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Close", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"Close", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::List, "List");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"List", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"List", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::Cd, "Cd");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Cd", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"Cd", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::Get, "Get");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Get", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"Get", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::Put, "Put");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Put", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"Put", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::Remove, "Remove");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Remove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"Remove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::Mkdir, "Mkdir");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Mkdir", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"Mkdir", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::Rmdir, "Rmdir");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Rmdir", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"Rmdir", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::Rename, "Rename");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Rename", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"Rename", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_Command,(long) QFtp::RawCommand, "RawCommand");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"RawCommand", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command->tp_dict,"RawCommand", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFtp::Command");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Command");
    // end of enum Command

    // init enum: TransferMode
    PyTypeObject* SbkPySide_QtNetwork_QFtp_TransferMode = Shiboken::Enum::newType("PySide.QtNetwork.QFtp.TransferMode");
    SbkPySide_QtNetworkTypes[SBK_QFTP_TRANSFERMODE_IDX] = SbkPySide_QtNetwork_QFtp_TransferMode;
    if (PyType_Ready(SbkPySide_QtNetwork_QFtp_TransferMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,
            "TransferMode",((PyObject*)SbkPySide_QtNetwork_QFtp_TransferMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_TransferMode,(long) QFtp::Active, "Active");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Active", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_TransferMode->tp_dict,"Active", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_TransferMode,(long) QFtp::Passive, "Passive");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Passive", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_TransferMode->tp_dict,"Passive", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFtp::TransferMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::TransferMode");
    // end of enum TransferMode

    // init enum: State
    PyTypeObject* SbkPySide_QtNetwork_QFtp_State = Shiboken::Enum::newType("PySide.QtNetwork.QFtp.State");
    SbkPySide_QtNetworkTypes[SBK_QFTP_STATE_IDX] = SbkPySide_QtNetwork_QFtp_State;
    if (PyType_Ready(SbkPySide_QtNetwork_QFtp_State) < 0)
        return;
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,
            "State",((PyObject*)SbkPySide_QtNetwork_QFtp_State));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_State,(long) QFtp::Unconnected, "Unconnected");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Unconnected", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_State->tp_dict,"Unconnected", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_State,(long) QFtp::HostLookup, "HostLookup");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"HostLookup", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_State->tp_dict,"HostLookup", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_State,(long) QFtp::Connecting, "Connecting");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Connecting", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_State->tp_dict,"Connecting", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_State,(long) QFtp::Connected, "Connected");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Connected", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_State->tp_dict,"Connected", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_State,(long) QFtp::LoggedIn, "LoggedIn");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"LoggedIn", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_State->tp_dict,"LoggedIn", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QFtp_State,(long) QFtp::Closing, "Closing");
    PyDict_SetItemString(Sbk_QFtp_Type.super.ht_type.tp_dict,"Closing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_State->tp_dict,"Closing", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFtp::State");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::State");
    // end of enum State

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("done", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QFtp_Type, "done", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("rawCommandReply", "int,QString", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QFtp_Type, "rawCommandReply", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("commandStarted", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QFtp_Type, "commandStarted", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("dataTransferProgress", "qint64,qint64", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QFtp_Type, "dataTransferProgress", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("commandFinished", "int,bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QFtp_Type, "commandFinished", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("listInfo", "QUrlInfo", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QFtp_Type, "listInfo", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("stateChanged", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QFtp_Type, "stateChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("readyRead", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QFtp_Type, "readyRead", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QFtp >("QFtp*");
    Shiboken::TypeResolver::createObjectTypeResolver<QFtp >(typeid(QFtp).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QFtp >(typeid(QFtpWrapper).name());
    PySide::initQtMetaType< ::QFtp* >();
    qRegisterMetaType< ::QFtp::TransferType >("QFtp::TransferType");
    qRegisterMetaType< ::QFtp::Error >("QFtp::Error");
    qRegisterMetaType< ::QFtp::Command >("QFtp::Command");
    qRegisterMetaType< ::QFtp::TransferMode >("QFtp::TransferMode");
    qRegisterMetaType< ::QFtp::State >("QFtp::State");
}

