/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtnetwork_python.h"

#include "qnetworkaccessmanager_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractnetworkcache.h>
#include <qauthenticator.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qnetworkcookiejar.h>
#include <qnetworkproxy.h>
#include <qnetworkreply.h>
#include <qnetworkrequest.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsslerror.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QNetworkAccessManagerWrapper::QNetworkAccessManagerWrapper(QObject * parent) : QNetworkAccessManager(parent) {
    // ... middle
}

void QNetworkAccessManagerWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QNetworkAccessManagerWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QNetworkReply * QNetworkAccessManagerWrapper::createRequest(QNetworkAccessManager::Operation op, const QNetworkRequest & request, QIODevice * outgoingData)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createRequest"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QNetworkAccessManager::createRequest(op, request, outgoingData);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QNetworkAccessManager::Operation >::toPython(op),
        Shiboken::Converter< ::QNetworkRequest >::toPython(request),
        Shiboken::Converter< ::QIODevice * >::toPython(outgoingData)
    ));
    bool invalidadeArg3 = PyTuple_GET_ITEM(pyargs, 2)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QNetworkReply * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkAccessManager.createRequest", Shiboken::SbkType<QNetworkReply >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QNetworkReply * cppResult(Shiboken::Converter< ::QNetworkReply * >::toCpp(pyResult));
    if (invalidadeArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 2));
    return cppResult;
}

void QNetworkAccessManagerWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QNetworkAccessManagerWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QNetworkAccessManagerWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkAccessManager.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QNetworkAccessManagerWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkAccessManager.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QNetworkAccessManagerWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QNetworkAccessManagerWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QNetworkAccessManagerWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QNetworkAccessManager::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QNetworkAccessManagerWrapper::~QNetworkAccessManagerWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkAccessManager_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QNetworkAccessManager >()))
        return -1;

    QNetworkAccessManagerWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QNetworkAccessManager", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QNetworkAccessManager(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkAccessManager(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QNetworkAccessManager(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAccessManager_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QNetworkAccessManager_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkAccessManager(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QNetworkAccessManager(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QNetworkAccessManagerWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QNetworkAccessManager >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QNetworkAccessManager_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QNetworkAccessManager_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkAccessManager", overloads);
        return -1;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_cache(PyObject* self)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cache()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractNetworkCache * cppResult = const_cast<const QNetworkAccessManager*>(cppSelf)->cache();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractNetworkCache * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_cookieJar(PyObject* self)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cookieJar()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkCookieJar * cppResult = const_cast<const QNetworkAccessManager*>(cppSelf)->cookieJar();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkCookieJar * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_createRequest(PyObject* self, PyObject* args, PyObject* kwds)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkAccessManager.createRequest(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkAccessManager.createRequest(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:createRequest", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: createRequest(QNetworkAccessManager::Operation,QNetworkRequest,QIODevice*)
    if (numArgs >= 2 && Shiboken::Converter< ::QNetworkAccessManager::Operation >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QNetworkRequest >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // createRequest(QNetworkAccessManager::Operation,QNetworkRequest,QIODevice*)
        } else if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[2])) {
            overloadId = 0; // createRequest(QNetworkAccessManager::Operation,QNetworkRequest,QIODevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAccessManagerFunc_createRequest_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "outgoingData");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "outgoingData";
                    else if (Shiboken::Converter< ::QIODevice * >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QNetworkAccessManagerFunc_createRequest_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkAccessManager.createRequest(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QNetworkAccessManager::Operation cppArg0 = Shiboken::Converter<QNetworkAccessManager::Operation >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QNetworkRequest cppArg1 = Shiboken::Converter<QNetworkRequest >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QIODevice * cppArg2 = pyargs[2] ? Shiboken::Converter<QIODevice * >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
                // createRequest(QNetworkAccessManager::Operation,QNetworkRequest,QIODevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkReply * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QNetworkAccessManager::createRequest(cppArg0, cppArg1, cppArg2) : cppSelf->createRequest(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkReply * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkAccessManagerFunc_createRequest_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkAccessManager.Operation, PySide.QtNetwork.QNetworkRequest, PySide.QtCore.QIODevice = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkAccessManager.createRequest", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_deleteResource(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: deleteResource(QNetworkRequest)
    if (Shiboken::Converter< ::QNetworkRequest >::isConvertible(arg)) {
        overloadId = 0; // deleteResource(QNetworkRequest)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAccessManagerFunc_deleteResource_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QNetworkRequest cppArg0 = Shiboken::Converter<QNetworkRequest >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // deleteResource(QNetworkRequest)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkReply * cppResult = cppSelf->deleteResource(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkReply * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkAccessManagerFunc_deleteResource_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.deleteResource", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_get(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: get(QNetworkRequest)
    if (Shiboken::Converter< ::QNetworkRequest >::isConvertible(arg)) {
        overloadId = 0; // get(QNetworkRequest)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAccessManagerFunc_get_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QNetworkRequest cppArg0 = Shiboken::Converter<QNetworkRequest >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // get(QNetworkRequest)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkReply * cppResult = cppSelf->get(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkReply * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkAccessManagerFunc_get_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.get", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_head(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: head(QNetworkRequest)
    if (Shiboken::Converter< ::QNetworkRequest >::isConvertible(arg)) {
        overloadId = 0; // head(QNetworkRequest)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAccessManagerFunc_head_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QNetworkRequest cppArg0 = Shiboken::Converter<QNetworkRequest >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // head(QNetworkRequest)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkReply * cppResult = cppSelf->head(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkReply * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkAccessManagerFunc_head_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.head", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_post(PyObject* self, PyObject* args)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "post", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: post(QNetworkRequest,QIODevice*)
    // 1: post(QNetworkRequest,QByteArray)
    if (Shiboken::Converter< ::QNetworkRequest >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[1])) {
            overloadId = 1; // post(QNetworkRequest,QByteArray)
        } else if (numArgs == 2 && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[1])) {
            overloadId = 0; // post(QNetworkRequest,QIODevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAccessManagerFunc_post_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // post(QNetworkRequest,QIODevice*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QNetworkRequest cppArg0 = Shiboken::Converter<QNetworkRequest >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QIODevice * cppArg1 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // post(QNetworkRequest,QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QNetworkReply * cppResult = cppSelf->post(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QNetworkReply * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // post(QNetworkRequest,QByteArray)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QNetworkRequest cppArg0 = Shiboken::Converter<QNetworkRequest >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QByteArray cppArg1 = Shiboken::Converter<QByteArray >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // post(QNetworkRequest,QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QNetworkReply * cppResult = cppSelf->post(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QNetworkReply * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkAccessManagerFunc_post_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest, PySide.QtCore.QIODevice", "PySide.QtNetwork.QNetworkRequest, PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkAccessManager.post", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_proxy(PyObject* self)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // proxy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkProxy cppResult = const_cast<const QNetworkAccessManager*>(cppSelf)->proxy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkProxy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_proxyFactory(PyObject* self)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // proxyFactory()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkProxyFactory * cppResult = const_cast<const QNetworkAccessManager*>(cppSelf)->proxyFactory();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkProxyFactory * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_put(PyObject* self, PyObject* args)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "put", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: put(QNetworkRequest,QIODevice*)
    // 1: put(QNetworkRequest,QByteArray)
    if (Shiboken::Converter< ::QNetworkRequest >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[1])) {
            overloadId = 1; // put(QNetworkRequest,QByteArray)
        } else if (numArgs == 2 && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[1])) {
            overloadId = 0; // put(QNetworkRequest,QIODevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAccessManagerFunc_put_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // put(QNetworkRequest,QIODevice*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QNetworkRequest cppArg0 = Shiboken::Converter<QNetworkRequest >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QIODevice * cppArg1 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // put(QNetworkRequest,QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QNetworkReply * cppResult = cppSelf->put(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QNetworkReply * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // put(QNetworkRequest,QByteArray)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QNetworkRequest cppArg0 = Shiboken::Converter<QNetworkRequest >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QByteArray cppArg1 = Shiboken::Converter<QByteArray >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // put(QNetworkRequest,QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QNetworkReply * cppResult = cppSelf->put(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QNetworkReply * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkAccessManagerFunc_put_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest, PySide.QtCore.QIODevice", "PySide.QtNetwork.QNetworkRequest, PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkAccessManager.put", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_setCache(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCache(QAbstractNetworkCache*)
    if (Shiboken::Converter< ::QAbstractNetworkCache * >::isConvertible(arg)) {
        overloadId = 0; // setCache(QAbstractNetworkCache*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAccessManagerFunc_setCache_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractNetworkCache * cppArg0 = Shiboken::Converter<QAbstractNetworkCache * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCache(QAbstractNetworkCache*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCache(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkAccessManagerFunc_setCache_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QAbstractNetworkCache", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.setCache", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_setCookieJar(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCookieJar(QNetworkCookieJar*)
    if (Shiboken::Converter< ::QNetworkCookieJar * >::isConvertible(arg)) {
        overloadId = 0; // setCookieJar(QNetworkCookieJar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAccessManagerFunc_setCookieJar_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QNetworkCookieJar * cppArg0 = Shiboken::Converter<QNetworkCookieJar * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCookieJar(QNetworkCookieJar*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCookieJar(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

                // Ownership transferences.
                Shiboken::Object::releaseOwnership(arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkAccessManagerFunc_setCookieJar_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkCookieJar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.setCookieJar", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_setProxy(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProxy(QNetworkProxy)
    if (Shiboken::Converter< ::QNetworkProxy >::isConvertible(arg)) {
        overloadId = 0; // setProxy(QNetworkProxy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAccessManagerFunc_setProxy_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QNetworkProxy cppArg0 = Shiboken::Converter<QNetworkProxy >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setProxy(QNetworkProxy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProxy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkAccessManagerFunc_setProxy_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.setProxy", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkAccessManagerFunc_setProxyFactory(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAccessManager* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProxyFactory(QNetworkProxyFactory*)
    if (Shiboken::Converter< ::QNetworkProxyFactory * >::isConvertible(arg)) {
        overloadId = 0; // setProxyFactory(QNetworkProxyFactory*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAccessManagerFunc_setProxyFactory_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QNetworkProxyFactory * cppArg0 = Shiboken::Converter<QNetworkProxyFactory * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setProxyFactory(QNetworkProxyFactory*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProxyFactory(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkAccessManagerFunc_setProxyFactory_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxyFactory", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.setProxyFactory", overloads);
        return 0;
}

static PyMethodDef Sbk_QNetworkAccessManager_methods[] = {
    {"cache", (PyCFunction)Sbk_QNetworkAccessManagerFunc_cache, METH_NOARGS},
    {"cookieJar", (PyCFunction)Sbk_QNetworkAccessManagerFunc_cookieJar, METH_NOARGS},
    {"createRequest", (PyCFunction)Sbk_QNetworkAccessManagerFunc_createRequest, METH_VARARGS|METH_KEYWORDS},
    {"deleteResource", (PyCFunction)Sbk_QNetworkAccessManagerFunc_deleteResource, METH_O},
    {"get", (PyCFunction)Sbk_QNetworkAccessManagerFunc_get, METH_O},
    {"head", (PyCFunction)Sbk_QNetworkAccessManagerFunc_head, METH_O},
    {"post", (PyCFunction)Sbk_QNetworkAccessManagerFunc_post, METH_VARARGS},
    {"proxy", (PyCFunction)Sbk_QNetworkAccessManagerFunc_proxy, METH_NOARGS},
    {"proxyFactory", (PyCFunction)Sbk_QNetworkAccessManagerFunc_proxyFactory, METH_NOARGS},
    {"put", (PyCFunction)Sbk_QNetworkAccessManagerFunc_put, METH_VARARGS},
    {"setCache", (PyCFunction)Sbk_QNetworkAccessManagerFunc_setCache, METH_O},
    {"setCookieJar", (PyCFunction)Sbk_QNetworkAccessManagerFunc_setCookieJar, METH_O},
    {"setProxy", (PyCFunction)Sbk_QNetworkAccessManagerFunc_setProxy, METH_O},
    {"setProxyFactory", (PyCFunction)Sbk_QNetworkAccessManagerFunc_setProxyFactory, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QNetworkAccessManager_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QNetworkAccessManager",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QNetworkAccessManager_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QNetworkAccessManager_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QNetworkAccessManager_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QNetworkAccessManager*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QNetworkAccessManager_Type;
    return 0;
}


void init_QNetworkAccessManager(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QNetworkAccessManager_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QNetworkAccessManager_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QNetworkAccessManager_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QNetworkAccessManager_Type, &QNetworkAccessManager::staticMetaObject);    Sbk_QNetworkAccessManager_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QNetworkAccessManager_Type, &Shiboken::callCppDestructor<QNetworkAccessManager >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QNetworkAccessManager_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QNetworkAccessManager_Type, &Sbk_QNetworkAccessManager_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QNetworkAccessManager_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QNetworkAccessManager_Type, "QNetworkAccessManager*");
    PyModule_AddObject(module, "QNetworkAccessManager",
        ((PyObject*)&Sbk_QNetworkAccessManager_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Operation
    PyTypeObject* SbkPySide_QtNetwork_QNetworkAccessManager_Operation = Shiboken::Enum::newType("PySide.QtNetwork.QNetworkAccessManager.Operation");
    SbkPySide_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_OPERATION_IDX] = SbkPySide_QtNetwork_QNetworkAccessManager_Operation;
    if (PyType_Ready(SbkPySide_QtNetwork_QNetworkAccessManager_Operation) < 0)
        return;
    PyDict_SetItemString(Sbk_QNetworkAccessManager_Type.super.ht_type.tp_dict,
            "Operation",((PyObject*)SbkPySide_QtNetwork_QNetworkAccessManager_Operation));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkAccessManager_Operation,(long) QNetworkAccessManager::HeadOperation, "HeadOperation");
    PyDict_SetItemString(Sbk_QNetworkAccessManager_Type.super.ht_type.tp_dict,"HeadOperation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_Operation->tp_dict,"HeadOperation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkAccessManager_Operation,(long) QNetworkAccessManager::GetOperation, "GetOperation");
    PyDict_SetItemString(Sbk_QNetworkAccessManager_Type.super.ht_type.tp_dict,"GetOperation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_Operation->tp_dict,"GetOperation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkAccessManager_Operation,(long) QNetworkAccessManager::PutOperation, "PutOperation");
    PyDict_SetItemString(Sbk_QNetworkAccessManager_Type.super.ht_type.tp_dict,"PutOperation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_Operation->tp_dict,"PutOperation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkAccessManager_Operation,(long) QNetworkAccessManager::PostOperation, "PostOperation");
    PyDict_SetItemString(Sbk_QNetworkAccessManager_Type.super.ht_type.tp_dict,"PostOperation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_Operation->tp_dict,"PostOperation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkAccessManager_Operation,(long) QNetworkAccessManager::DeleteOperation, "DeleteOperation");
    PyDict_SetItemString(Sbk_QNetworkAccessManager_Type.super.ht_type.tp_dict,"DeleteOperation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_Operation->tp_dict,"DeleteOperation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkAccessManager_Operation,(long) QNetworkAccessManager::UnknownOperation, "UnknownOperation");
    PyDict_SetItemString(Sbk_QNetworkAccessManager_Type.super.ht_type.tp_dict,"UnknownOperation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_Operation->tp_dict,"UnknownOperation", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkAccessManager::Operation");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Operation");
    // end of enum Operation

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("sslErrors", "QNetworkReply*,QList<QSslError>", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QNetworkAccessManager_Type, "sslErrors", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("authenticationRequired", "QNetworkReply*,QAuthenticator*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QNetworkAccessManager_Type, "authenticationRequired", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("finished", "QNetworkReply*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QNetworkAccessManager_Type, "finished", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("proxyAuthenticationRequired", "QNetworkProxy,QAuthenticator*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QNetworkAccessManager_Type, "proxyAuthenticationRequired", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkAccessManager >("QNetworkAccessManager*");
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkAccessManager >(typeid(QNetworkAccessManager).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkAccessManager >(typeid(QNetworkAccessManagerWrapper).name());
    PySide::initQtMetaType< ::QNetworkAccessManager* >();
    qRegisterMetaType< ::QNetworkAccessManager::Operation >("QNetworkAccessManager::Operation");
}

