/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qnetworkaddressentry_wrapper.h"

// Extra includes
#include <qhostaddress.h>
#include <qnetworkinterface.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkAddressEntry_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QNetworkAddressEntry >()))
        return -1;

    QNetworkAddressEntry* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QNetworkAddressEntry", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QNetworkAddressEntry()
    // 1: QNetworkAddressEntry(QNetworkAddressEntry)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkAddressEntry()
    } else if (numArgs == 1 && Shiboken::Converter< ::QNetworkAddressEntry >::isConvertible(pyargs[0])) {
        overloadId = 1; // QNetworkAddressEntry(QNetworkAddressEntry)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAddressEntry_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QNetworkAddressEntry()
            {

                if(!PyErr_Occurred()) {
                    // QNetworkAddressEntry()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkAddressEntry();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QNetworkAddressEntry(QNetworkAddressEntry)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QNetworkAddressEntry cppArg0 = Shiboken::Converter<QNetworkAddressEntry >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QNetworkAddressEntry(QNetworkAddressEntry)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkAddressEntry(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QNetworkAddressEntry >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QNetworkAddressEntry_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QNetworkAddressEntry_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QNetworkAddressEntry", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkAddressEntry", overloads);
        return -1;
}

static PyObject* Sbk_QNetworkAddressEntryFunc_broadcast(PyObject* self)
{
    QNetworkAddressEntry* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAddressEntry* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // broadcast()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QHostAddress cppResult = const_cast<const QNetworkAddressEntry*>(cppSelf)->broadcast();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QHostAddress >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkAddressEntryFunc_ip(PyObject* self)
{
    QNetworkAddressEntry* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAddressEntry* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // ip()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QHostAddress cppResult = const_cast<const QNetworkAddressEntry*>(cppSelf)->ip();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QHostAddress >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkAddressEntryFunc_netmask(PyObject* self)
{
    QNetworkAddressEntry* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAddressEntry* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // netmask()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QHostAddress cppResult = const_cast<const QNetworkAddressEntry*>(cppSelf)->netmask();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QHostAddress >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkAddressEntryFunc_prefixLength(PyObject* self)
{
    QNetworkAddressEntry* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAddressEntry* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // prefixLength()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QNetworkAddressEntry*>(cppSelf)->prefixLength();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkAddressEntryFunc_setBroadcast(PyObject* self, PyObject* arg)
{
    QNetworkAddressEntry* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAddressEntry* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBroadcast(QHostAddress)
    if (Shiboken::Converter< ::QHostAddress >::isConvertible(arg)) {
        overloadId = 0; // setBroadcast(QHostAddress)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAddressEntryFunc_setBroadcast_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QHostAddress cppArg0 = Shiboken::Converter<QHostAddress >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBroadcast(QHostAddress)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBroadcast(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkAddressEntryFunc_setBroadcast_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QHostAddress", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAddressEntry.setBroadcast", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkAddressEntryFunc_setIp(PyObject* self, PyObject* arg)
{
    QNetworkAddressEntry* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAddressEntry* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIp(QHostAddress)
    if (Shiboken::Converter< ::QHostAddress >::isConvertible(arg)) {
        overloadId = 0; // setIp(QHostAddress)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAddressEntryFunc_setIp_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QHostAddress cppArg0 = Shiboken::Converter<QHostAddress >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIp(QHostAddress)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIp(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkAddressEntryFunc_setIp_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QHostAddress", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAddressEntry.setIp", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkAddressEntryFunc_setNetmask(PyObject* self, PyObject* arg)
{
    QNetworkAddressEntry* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAddressEntry* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNetmask(QHostAddress)
    if (Shiboken::Converter< ::QHostAddress >::isConvertible(arg)) {
        overloadId = 0; // setNetmask(QHostAddress)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAddressEntryFunc_setNetmask_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QHostAddress cppArg0 = Shiboken::Converter<QHostAddress >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNetmask(QHostAddress)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNetmask(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkAddressEntryFunc_setNetmask_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QHostAddress", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAddressEntry.setNetmask", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkAddressEntryFunc_setPrefixLength(PyObject* self, PyObject* arg)
{
    QNetworkAddressEntry* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkAddressEntry* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPrefixLength(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPrefixLength(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkAddressEntryFunc_setPrefixLength_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPrefixLength(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPrefixLength(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkAddressEntryFunc_setPrefixLength_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAddressEntry.setPrefixLength", overloads);
        return 0;
}

static PyObject *Sbk_QNetworkAddressEntry___copy__(PyObject *self)
{
        QNetworkAddressEntry* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QNetworkAddressEntry*>::toCpp(self);
        PyObject* pyResult = 0;
        QNetworkAddressEntry* copy = new QNetworkAddressEntry(*cppSelf);
        pyResult = Shiboken::Converter<QNetworkAddressEntry*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QNetworkAddressEntry_methods[] = {
    {"broadcast", (PyCFunction)Sbk_QNetworkAddressEntryFunc_broadcast, METH_NOARGS},
    {"ip", (PyCFunction)Sbk_QNetworkAddressEntryFunc_ip, METH_NOARGS},
    {"netmask", (PyCFunction)Sbk_QNetworkAddressEntryFunc_netmask, METH_NOARGS},
    {"prefixLength", (PyCFunction)Sbk_QNetworkAddressEntryFunc_prefixLength, METH_NOARGS},
    {"setBroadcast", (PyCFunction)Sbk_QNetworkAddressEntryFunc_setBroadcast, METH_O},
    {"setIp", (PyCFunction)Sbk_QNetworkAddressEntryFunc_setIp, METH_O},
    {"setNetmask", (PyCFunction)Sbk_QNetworkAddressEntryFunc_setNetmask, METH_O},
    {"setPrefixLength", (PyCFunction)Sbk_QNetworkAddressEntryFunc_setPrefixLength, METH_O},

    {"__copy__", (PyCFunction)Sbk_QNetworkAddressEntry___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QNetworkAddressEntry_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QNetworkAddressEntry& cppSelf = *Shiboken::Converter< QNetworkAddressEntry* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QNetworkAddressEntry >::isConvertible(arg)) {
                // operator!=(const QNetworkAddressEntry & other) const
                QNetworkAddressEntry cppArg0 = Shiboken::Converter< ::QNetworkAddressEntry >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QNetworkAddressEntry_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QNetworkAddressEntry >::isConvertible(arg)) {
                // operator==(const QNetworkAddressEntry & other) const
                QNetworkAddressEntry cppArg0 = Shiboken::Converter< ::QNetworkAddressEntry >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QNetworkAddressEntry_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QNetworkAddressEntry_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QNetworkAddressEntry_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QNetworkAddressEntry_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QNetworkAddressEntry",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QNetworkAddressEntry_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QNetworkAddressEntry_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QNetworkAddressEntry_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QNetworkAddressEntry(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QNETWORKADDRESSENTRY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QNetworkAddressEntry_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QNetworkAddressEntry_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QNetworkAddressEntry_Type, &Shiboken::callCppDestructor<QNetworkAddressEntry >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QNetworkAddressEntry_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QNetworkAddressEntry_Type, "QNetworkAddressEntry");
    PyModule_AddObject(module, "QNetworkAddressEntry",
        ((PyObject*)&Sbk_QNetworkAddressEntry_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QNetworkAddressEntry >("QNetworkAddressEntry");
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkAddressEntry >("QNetworkAddressEntry*");
    Shiboken::TypeResolver::createValueTypeResolver<QNetworkAddressEntry >(typeid(QNetworkAddressEntry).name());
    PySide::initQtMetaType< ::QNetworkAddressEntry >();
}

