/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qurlinfo_wrapper.h"

// Extra includes
#include <qdatetime.h>
#include <qurl.h>
#include <qurlinfo.h>


// Native ---------------------------------------------------------

QUrlInfoWrapper::QUrlInfoWrapper() : QUrlInfo() {
    // ... middle
}

QUrlInfoWrapper::QUrlInfoWrapper(const QString & name, int permissions, const QString & owner, const QString & group, qint64 size, const QDateTime & lastModified, const QDateTime & lastRead, bool isDir, bool isFile, bool isSymLink, bool isWritable, bool isReadable, bool isExecutable) : QUrlInfo(name, permissions, owner, group, size, lastModified, lastRead, isDir, isFile, isSymLink, isWritable, isReadable, isExecutable) {
    // ... middle
}

QUrlInfoWrapper::QUrlInfoWrapper(const QUrl & url, int permissions, const QString & owner, const QString & group, qint64 size, const QDateTime & lastModified, const QDateTime & lastRead, bool isDir, bool isFile, bool isSymLink, bool isWritable, bool isReadable, bool isExecutable) : QUrlInfo(url, permissions, owner, group, size, lastModified, lastRead, isDir, isFile, isSymLink, isWritable, isReadable, isExecutable) {
    // ... middle
}

void QUrlInfoWrapper::setDir(bool b)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setDir"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUrlInfo::setDir(b);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(b)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QUrlInfoWrapper::setFile(bool b)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setFile"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUrlInfo::setFile(b);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(b)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QUrlInfoWrapper::setGroup(const QString & s)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setGroup"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUrlInfo::setGroup(s);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(s)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QUrlInfoWrapper::setLastModified(const QDateTime & dt)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setLastModified"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUrlInfo::setLastModified(dt);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDateTime >::toPython(dt)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QUrlInfoWrapper::setName(const QString & name)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setName"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUrlInfo::setName(name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QUrlInfoWrapper::setOwner(const QString & s)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setOwner"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUrlInfo::setOwner(s);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(s)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QUrlInfoWrapper::setPermissions(int p)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setPermissions"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUrlInfo::setPermissions(p);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        p
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QUrlInfoWrapper::setReadable(bool b)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setReadable"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUrlInfo::setReadable(b);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(b)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QUrlInfoWrapper::setSize(qint64 size)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setSize"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUrlInfo::setSize(size);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        size
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QUrlInfoWrapper::setSymLink(bool b)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setSymLink"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUrlInfo::setSymLink(b);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(b)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QUrlInfoWrapper::setWritable(bool b)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setWritable"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUrlInfo::setWritable(b);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(b)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QUrlInfoWrapper::~QUrlInfoWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QUrlInfo_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QUrlInfo >()))
        return -1;

    QUrlInfoWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 6 || numArgs == 7 || numArgs == 8 || numArgs == 9 || numArgs == 10 || numArgs == 11 || numArgs == 12)
        goto Sbk_QUrlInfo_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QUrlInfo", 0, 13, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8]), &(pyargs[9]), &(pyargs[10]), &(pyargs[11]), &(pyargs[12])))
        return -1;

    // Overloaded function decisor
    // 0: QUrlInfo()
    // 1: QUrlInfo(QString,int,QString,QString,qint64,QDateTime,QDateTime,bool,bool,bool,bool,bool,bool)
    // 2: QUrlInfo(QUrl,int,QString,QString,qint64,QDateTime,QDateTime,bool,bool,bool,bool,bool,bool)
    // 3: QUrlInfo(QUrlInfo)
    if (numArgs == 0) {
        overloadId = 0; // QUrlInfo()
    } else if (numArgs == 1 && Shiboken::Converter< ::QUrlInfo >::isConvertible(pyargs[0])) {
        overloadId = 3; // QUrlInfo(QUrlInfo)
    } else if (numArgs == 13 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2]) && Shiboken::Converter< QString >::isConvertible(pyargs[3]) && SbkNumber_Check(pyargs[4]) && Shiboken::Converter< ::QDateTime >::isConvertible(pyargs[5]) && Shiboken::Converter< ::QDateTime >::isConvertible(pyargs[6]) && SbkNumber_Check(pyargs[7]) && SbkNumber_Check(pyargs[8]) && SbkNumber_Check(pyargs[9]) && SbkNumber_Check(pyargs[10]) && SbkNumber_Check(pyargs[11]) && SbkNumber_Check(pyargs[12])) {
        overloadId = 1; // QUrlInfo(QString,int,QString,QString,qint64,QDateTime,QDateTime,bool,bool,bool,bool,bool,bool)
    } else if (numArgs == 13 && Shiboken::Converter< ::QUrl >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2]) && Shiboken::Converter< QString >::isConvertible(pyargs[3]) && SbkNumber_Check(pyargs[4]) && Shiboken::Converter< ::QDateTime >::isConvertible(pyargs[5]) && Shiboken::Converter< ::QDateTime >::isConvertible(pyargs[6]) && SbkNumber_Check(pyargs[7]) && SbkNumber_Check(pyargs[8]) && SbkNumber_Check(pyargs[9]) && SbkNumber_Check(pyargs[10]) && SbkNumber_Check(pyargs[11]) && SbkNumber_Check(pyargs[12])) {
        overloadId = 2; // QUrlInfo(QUrl,int,QString,QString,qint64,QDateTime,QDateTime,bool,bool,bool,bool,bool,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfo_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QUrlInfo()
            {

                if(!PyErr_Occurred()) {
                    // QUrlInfo()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QUrlInfoWrapper();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QUrlInfo(QString,int,QString,QString,qint64,QDateTime,QDateTime,bool,bool,bool,bool,bool,bool)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                QString cppArg3 = Shiboken::Converter<QString >::toCpp(pyargs[3]);
                qint64 cppArg4 = Shiboken::Converter<qint64 >::toCpp(pyargs[4]);
                if (!Shiboken::Object::isValid(pyargs[5]))
                    return -1;
                QDateTime cppArg5 = Shiboken::Converter<QDateTime >::toCpp(pyargs[5]);
                if (!Shiboken::Object::isValid(pyargs[6]))
                    return -1;
                QDateTime cppArg6 = Shiboken::Converter<QDateTime >::toCpp(pyargs[6]);
                bool cppArg7 = Shiboken::Converter<bool >::toCpp(pyargs[7]);
                bool cppArg8 = Shiboken::Converter<bool >::toCpp(pyargs[8]);
                bool cppArg9 = Shiboken::Converter<bool >::toCpp(pyargs[9]);
                bool cppArg10 = Shiboken::Converter<bool >::toCpp(pyargs[10]);
                bool cppArg11 = Shiboken::Converter<bool >::toCpp(pyargs[11]);
                bool cppArg12 = Shiboken::Converter<bool >::toCpp(pyargs[12]);

                if(!PyErr_Occurred()) {
                    // QUrlInfo(QString,int,QString,QString,qint64,QDateTime,QDateTime,bool,bool,bool,bool,bool,bool)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QUrlInfoWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QUrlInfo(QUrl,int,QString,QString,qint64,QDateTime,QDateTime,bool,bool,bool,bool,bool,bool)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                QString cppArg3 = Shiboken::Converter<QString >::toCpp(pyargs[3]);
                qint64 cppArg4 = Shiboken::Converter<qint64 >::toCpp(pyargs[4]);
                if (!Shiboken::Object::isValid(pyargs[5]))
                    return -1;
                QDateTime cppArg5 = Shiboken::Converter<QDateTime >::toCpp(pyargs[5]);
                if (!Shiboken::Object::isValid(pyargs[6]))
                    return -1;
                QDateTime cppArg6 = Shiboken::Converter<QDateTime >::toCpp(pyargs[6]);
                bool cppArg7 = Shiboken::Converter<bool >::toCpp(pyargs[7]);
                bool cppArg8 = Shiboken::Converter<bool >::toCpp(pyargs[8]);
                bool cppArg9 = Shiboken::Converter<bool >::toCpp(pyargs[9]);
                bool cppArg10 = Shiboken::Converter<bool >::toCpp(pyargs[10]);
                bool cppArg11 = Shiboken::Converter<bool >::toCpp(pyargs[11]);
                bool cppArg12 = Shiboken::Converter<bool >::toCpp(pyargs[12]);

                if(!PyErr_Occurred()) {
                    // QUrlInfo(QUrl,int,QString,QString,qint64,QDateTime,QDateTime,bool,bool,bool,bool,bool,bool)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QUrlInfoWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QUrlInfo(QUrlInfo)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QUrlInfo cppArg0 = Shiboken::Converter<QUrlInfo >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QUrlInfo(QUrlInfo)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QUrlInfoWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QUrlInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QUrlInfo_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QUrlInfo_Init_TypeError:
        const char* overloads[] = {"", "QString, int, QString, QString, long long, PySide.QtCore.QDateTime, PySide.QtCore.QDateTime, bool, bool, bool, bool, bool, bool", "PySide.QtCore.QUrl, int, QString, QString, long long, PySide.QtCore.QDateTime, PySide.QtCore.QDateTime, bool, bool, bool, bool, bool, bool", "PySide.QtNetwork.QUrlInfo", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QUrlInfo", overloads);
        return -1;
}

static PyObject* Sbk_QUrlInfoFunc_equal(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "equal", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: equal(QUrlInfo,QUrlInfo,int)
    if (numArgs == 3 && Shiboken::Converter< ::QUrlInfo >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QUrlInfo >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // equal(QUrlInfo,QUrlInfo,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_equal_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QUrlInfo cppArg0 = Shiboken::Converter<QUrlInfo >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QUrlInfo cppArg1 = Shiboken::Converter<QUrlInfo >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // equal(QUrlInfo,QUrlInfo,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QUrlInfo::equal(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlInfoFunc_equal_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QUrlInfo, PySide.QtNetwork.QUrlInfo, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QUrlInfo.equal", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_greaterThan(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "greaterThan", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: greaterThan(QUrlInfo,QUrlInfo,int)
    if (numArgs == 3 && Shiboken::Converter< ::QUrlInfo >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QUrlInfo >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // greaterThan(QUrlInfo,QUrlInfo,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_greaterThan_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QUrlInfo cppArg0 = Shiboken::Converter<QUrlInfo >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QUrlInfo cppArg1 = Shiboken::Converter<QUrlInfo >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // greaterThan(QUrlInfo,QUrlInfo,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QUrlInfo::greaterThan(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlInfoFunc_greaterThan_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QUrlInfo, PySide.QtNetwork.QUrlInfo, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QUrlInfo.greaterThan", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_group(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // group()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QUrlInfo*>(cppSelf)->group();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlInfoFunc_isDir(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isDir()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUrlInfo*>(cppSelf)->isDir();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlInfoFunc_isExecutable(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isExecutable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUrlInfo*>(cppSelf)->isExecutable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlInfoFunc_isFile(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isFile()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUrlInfo*>(cppSelf)->isFile();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlInfoFunc_isReadable(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isReadable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUrlInfo*>(cppSelf)->isReadable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlInfoFunc_isSymLink(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSymLink()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUrlInfo*>(cppSelf)->isSymLink();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlInfoFunc_isValid(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUrlInfo*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlInfoFunc_isWritable(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isWritable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUrlInfo*>(cppSelf)->isWritable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlInfoFunc_lastModified(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastModified()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDateTime cppResult = const_cast<const QUrlInfo*>(cppSelf)->lastModified();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDateTime >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlInfoFunc_lastRead(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastRead()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDateTime cppResult = const_cast<const QUrlInfo*>(cppSelf)->lastRead();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDateTime >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlInfoFunc_lessThan(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "lessThan", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: lessThan(QUrlInfo,QUrlInfo,int)
    if (numArgs == 3 && Shiboken::Converter< ::QUrlInfo >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QUrlInfo >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // lessThan(QUrlInfo,QUrlInfo,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_lessThan_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QUrlInfo cppArg0 = Shiboken::Converter<QUrlInfo >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QUrlInfo cppArg1 = Shiboken::Converter<QUrlInfo >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // lessThan(QUrlInfo,QUrlInfo,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QUrlInfo::lessThan(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlInfoFunc_lessThan_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QUrlInfo, PySide.QtNetwork.QUrlInfo, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QUrlInfo.lessThan", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_name(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // name()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QUrlInfo*>(cppSelf)->name();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlInfoFunc_owner(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // owner()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QUrlInfo*>(cppSelf)->owner();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlInfoFunc_permissions(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // permissions()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QUrlInfo*>(cppSelf)->permissions();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlInfoFunc_setDir(PyObject* self, PyObject* arg)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDir(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDir(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_setDir_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDir(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QUrlInfo::setDir(cppArg0) : cppSelf->setDir(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlInfoFunc_setDir_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QUrlInfo.setDir", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_setFile(PyObject* self, PyObject* arg)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFile(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFile(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_setFile_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFile(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QUrlInfo::setFile(cppArg0) : cppSelf->setFile(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlInfoFunc_setFile_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QUrlInfo.setFile", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_setGroup(PyObject* self, PyObject* arg)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGroup(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setGroup(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_setGroup_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGroup(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QUrlInfo::setGroup(cppArg0) : cppSelf->setGroup(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlInfoFunc_setGroup_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QUrlInfo.setGroup", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_setLastModified(PyObject* self, PyObject* arg)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastModified(QDateTime)
    if (Shiboken::Converter< ::QDateTime >::isConvertible(arg)) {
        overloadId = 0; // setLastModified(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_setLastModified_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDateTime cppArg0 = Shiboken::Converter<QDateTime >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLastModified(QDateTime)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QUrlInfo::setLastModified(cppArg0) : cppSelf->setLastModified(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlInfoFunc_setLastModified_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDateTime", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QUrlInfo.setLastModified", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_setLastRead(PyObject* self, PyObject* arg)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastRead(QDateTime)
    if (Shiboken::Converter< ::QDateTime >::isConvertible(arg)) {
        overloadId = 0; // setLastRead(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_setLastRead_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDateTime cppArg0 = Shiboken::Converter<QDateTime >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLastRead(QDateTime)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLastRead(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlInfoFunc_setLastRead_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDateTime", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QUrlInfo.setLastRead", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_setName(PyObject* self, PyObject* arg)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_setName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QUrlInfo::setName(cppArg0) : cppSelf->setName(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlInfoFunc_setName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QUrlInfo.setName", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_setOwner(PyObject* self, PyObject* arg)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOwner(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setOwner(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_setOwner_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOwner(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QUrlInfo::setOwner(cppArg0) : cppSelf->setOwner(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlInfoFunc_setOwner_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QUrlInfo.setOwner", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_setPermissions(PyObject* self, PyObject* arg)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPermissions(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPermissions(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_setPermissions_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPermissions(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QUrlInfo::setPermissions(cppArg0) : cppSelf->setPermissions(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlInfoFunc_setPermissions_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QUrlInfo.setPermissions", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_setReadable(PyObject* self, PyObject* arg)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setReadable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setReadable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_setReadable_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setReadable(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QUrlInfo::setReadable(cppArg0) : cppSelf->setReadable(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlInfoFunc_setReadable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QUrlInfo.setReadable", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_setSize(PyObject* self, PyObject* arg)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSize(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSize(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_setSize_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSize(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QUrlInfo::setSize(cppArg0) : cppSelf->setSize(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlInfoFunc_setSize_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QUrlInfo.setSize", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_setSymLink(PyObject* self, PyObject* arg)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSymLink(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSymLink(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_setSymLink_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSymLink(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QUrlInfo::setSymLink(cppArg0) : cppSelf->setSymLink(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlInfoFunc_setSymLink_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QUrlInfo.setSymLink", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_setWritable(PyObject* self, PyObject* arg)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWritable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWritable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlInfoFunc_setWritable_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWritable(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QUrlInfo::setWritable(cppArg0) : cppSelf->setWritable(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlInfoFunc_setWritable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QUrlInfo.setWritable", overloads);
        return 0;
}

static PyObject* Sbk_QUrlInfoFunc_size(PyObject* self)
{
    QUrlInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrlInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QUrlInfo*>(cppSelf)->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QUrlInfo___copy__(PyObject *self)
{
        QUrlInfo* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QUrlInfo*>::toCpp(self);
        PyObject* pyResult = 0;
        QUrlInfo* copy = new QUrlInfo(*cppSelf);
        pyResult = Shiboken::Converter<QUrlInfo*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QUrlInfo_methods[] = {
    {"equal", (PyCFunction)Sbk_QUrlInfoFunc_equal, METH_VARARGS|METH_STATIC},
    {"greaterThan", (PyCFunction)Sbk_QUrlInfoFunc_greaterThan, METH_VARARGS|METH_STATIC},
    {"group", (PyCFunction)Sbk_QUrlInfoFunc_group, METH_NOARGS},
    {"isDir", (PyCFunction)Sbk_QUrlInfoFunc_isDir, METH_NOARGS},
    {"isExecutable", (PyCFunction)Sbk_QUrlInfoFunc_isExecutable, METH_NOARGS},
    {"isFile", (PyCFunction)Sbk_QUrlInfoFunc_isFile, METH_NOARGS},
    {"isReadable", (PyCFunction)Sbk_QUrlInfoFunc_isReadable, METH_NOARGS},
    {"isSymLink", (PyCFunction)Sbk_QUrlInfoFunc_isSymLink, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QUrlInfoFunc_isValid, METH_NOARGS},
    {"isWritable", (PyCFunction)Sbk_QUrlInfoFunc_isWritable, METH_NOARGS},
    {"lastModified", (PyCFunction)Sbk_QUrlInfoFunc_lastModified, METH_NOARGS},
    {"lastRead", (PyCFunction)Sbk_QUrlInfoFunc_lastRead, METH_NOARGS},
    {"lessThan", (PyCFunction)Sbk_QUrlInfoFunc_lessThan, METH_VARARGS|METH_STATIC},
    {"name", (PyCFunction)Sbk_QUrlInfoFunc_name, METH_NOARGS},
    {"owner", (PyCFunction)Sbk_QUrlInfoFunc_owner, METH_NOARGS},
    {"permissions", (PyCFunction)Sbk_QUrlInfoFunc_permissions, METH_NOARGS},
    {"setDir", (PyCFunction)Sbk_QUrlInfoFunc_setDir, METH_O},
    {"setFile", (PyCFunction)Sbk_QUrlInfoFunc_setFile, METH_O},
    {"setGroup", (PyCFunction)Sbk_QUrlInfoFunc_setGroup, METH_O},
    {"setLastModified", (PyCFunction)Sbk_QUrlInfoFunc_setLastModified, METH_O},
    {"setLastRead", (PyCFunction)Sbk_QUrlInfoFunc_setLastRead, METH_O},
    {"setName", (PyCFunction)Sbk_QUrlInfoFunc_setName, METH_O},
    {"setOwner", (PyCFunction)Sbk_QUrlInfoFunc_setOwner, METH_O},
    {"setPermissions", (PyCFunction)Sbk_QUrlInfoFunc_setPermissions, METH_O},
    {"setReadable", (PyCFunction)Sbk_QUrlInfoFunc_setReadable, METH_O},
    {"setSize", (PyCFunction)Sbk_QUrlInfoFunc_setSize, METH_O},
    {"setSymLink", (PyCFunction)Sbk_QUrlInfoFunc_setSymLink, METH_O},
    {"setWritable", (PyCFunction)Sbk_QUrlInfoFunc_setWritable, METH_O},
    {"size", (PyCFunction)Sbk_QUrlInfoFunc_size, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QUrlInfo___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QUrlInfo_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QUrlInfo& cppSelf = *Shiboken::Converter< QUrlInfo* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QUrlInfo >::isConvertible(arg)) {
                // operator!=(const QUrlInfo & i) const
                QUrlInfo cppArg0 = Shiboken::Converter< ::QUrlInfo >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QUrlInfo_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QUrlInfo >::isConvertible(arg)) {
                // operator==(const QUrlInfo & i) const
                QUrlInfo cppArg0 = Shiboken::Converter< ::QUrlInfo >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QUrlInfo_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QUrlInfo_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QUrlInfo_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QUrlInfo_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QUrlInfo",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QUrlInfo_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QUrlInfo_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QUrlInfo_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QUrlInfo(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QURLINFO_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QUrlInfo_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QUrlInfo_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QUrlInfo_Type, &Shiboken::callCppDestructor<QUrlInfoWrapper >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QUrlInfo_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QUrlInfo_Type, "QUrlInfo");
    PyModule_AddObject(module, "QUrlInfo",
        ((PyObject*)&Sbk_QUrlInfo_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: PermissionSpec
    PyTypeObject* SbkPySide_QtNetwork_QUrlInfo_PermissionSpec = Shiboken::Enum::newType("PySide.QtNetwork.QUrlInfo.PermissionSpec");
    SbkPySide_QtNetworkTypes[SBK_QURLINFO_PERMISSIONSPEC_IDX] = SbkPySide_QtNetwork_QUrlInfo_PermissionSpec;
    if (PyType_Ready(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec) < 0)
        return;
    PyDict_SetItemString(Sbk_QUrlInfo_Type.super.ht_type.tp_dict,
            "PermissionSpec",((PyObject*)SbkPySide_QtNetwork_QUrlInfo_PermissionSpec));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec,(long) QUrlInfo::ReadOwner, "ReadOwner");
    PyDict_SetItemString(Sbk_QUrlInfo_Type.super.ht_type.tp_dict,"ReadOwner", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec->tp_dict,"ReadOwner", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec,(long) QUrlInfo::WriteOwner, "WriteOwner");
    PyDict_SetItemString(Sbk_QUrlInfo_Type.super.ht_type.tp_dict,"WriteOwner", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec->tp_dict,"WriteOwner", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec,(long) QUrlInfo::ExeOwner, "ExeOwner");
    PyDict_SetItemString(Sbk_QUrlInfo_Type.super.ht_type.tp_dict,"ExeOwner", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec->tp_dict,"ExeOwner", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec,(long) QUrlInfo::ReadGroup, "ReadGroup");
    PyDict_SetItemString(Sbk_QUrlInfo_Type.super.ht_type.tp_dict,"ReadGroup", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec->tp_dict,"ReadGroup", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec,(long) QUrlInfo::WriteGroup, "WriteGroup");
    PyDict_SetItemString(Sbk_QUrlInfo_Type.super.ht_type.tp_dict,"WriteGroup", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec->tp_dict,"WriteGroup", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec,(long) QUrlInfo::ExeGroup, "ExeGroup");
    PyDict_SetItemString(Sbk_QUrlInfo_Type.super.ht_type.tp_dict,"ExeGroup", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec->tp_dict,"ExeGroup", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec,(long) QUrlInfo::ReadOther, "ReadOther");
    PyDict_SetItemString(Sbk_QUrlInfo_Type.super.ht_type.tp_dict,"ReadOther", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec->tp_dict,"ReadOther", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec,(long) QUrlInfo::WriteOther, "WriteOther");
    PyDict_SetItemString(Sbk_QUrlInfo_Type.super.ht_type.tp_dict,"WriteOther", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec->tp_dict,"WriteOther", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec,(long) QUrlInfo::ExeOther, "ExeOther");
    PyDict_SetItemString(Sbk_QUrlInfo_Type.super.ht_type.tp_dict,"ExeOther", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QUrlInfo_PermissionSpec->tp_dict,"ExeOther", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QUrlInfo::PermissionSpec");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::PermissionSpec");
    // end of enum PermissionSpec


    Shiboken::TypeResolver::createValueTypeResolver<QUrlInfo >("QUrlInfo");
    Shiboken::TypeResolver::createObjectTypeResolver<QUrlInfo >("QUrlInfo*");
    Shiboken::TypeResolver::createValueTypeResolver<QUrlInfo >(typeid(QUrlInfo).name());
    Shiboken::TypeResolver::createValueTypeResolver<QUrlInfo >(typeid(QUrlInfoWrapper).name());
    PySide::initQtMetaType< ::QUrlInfo >();
    qRegisterMetaType< ::QUrlInfo::PermissionSpec >("QUrlInfo::PermissionSpec");
}

