/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtopengl_python.h"

#include "qgl_wrapper.h"

// Extra includes
#include <qgl.h>



// Target ---------------------------------------------------------

extern "C" {
static PyObject* Sbk_QGLFunc_setPreferredPaintEngine(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPreferredPaintEngine(QPaintEngine::Type)
    if (Shiboken::Converter< ::QPaintEngine::Type >::isConvertible(arg)) {
        overloadId = 0; // setPreferredPaintEngine(QPaintEngine::Type)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFunc_setPreferredPaintEngine_TypeError;

    // Call function/method
    {
        {
            QPaintEngine::Type cppArg0 = Shiboken::Converter<QPaintEngine::Type >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPreferredPaintEngine(QPaintEngine::Type)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGL::setPreferredPaintEngine(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFunc_setPreferredPaintEngine_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintEngine.Type", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGL.setPreferredPaintEngine", overloads);
        return 0;
}

static PyMethodDef Sbk_QGL_methods[] = {
    {"setPreferredPaintEngine", (PyCFunction)Sbk_QGLFunc_setPreferredPaintEngine, METH_O|METH_STATIC},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGL_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGL",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGL_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtOpenGL_QGL_FormatOption___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGL::FormatOptions >::toPython(
        Shiboken::Converter<QGL::FormatOptions>::toCpp(self)
        & Shiboken::Converter< QGL::FormatOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGL_FormatOption___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGL::FormatOptions >::toPython(
        Shiboken::Converter<QGL::FormatOptions>::toCpp(self)
        | Shiboken::Converter< QGL::FormatOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGL_FormatOption___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGL::FormatOptions >::toPython(
        Shiboken::Converter<QGL::FormatOptions>::toCpp(self)
        ^ Shiboken::Converter< QGL::FormatOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGL_FormatOption___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGL::FormatOptions >::toPython(
        ~Shiboken::Converter<QGL::FormatOptions >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtOpenGL_QGL_FormatOption_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtOpenGL_QGL_FormatOption___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtOpenGL_QGL_FormatOption___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtOpenGL_QGL_FormatOption___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtOpenGL_QGL_FormatOption___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtOpenGL_QGL_FormatOptions_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FormatOptions",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtOpenGL_QGL_FormatOption_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QGL(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGL_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGL_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGL_Type);
    if (PyType_Ready((PyTypeObject*)&Sbk_QGL_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QGL_Type, "QGL");
    PyModule_AddObject(module, "QGL",
        ((PyObject*)&Sbk_QGL_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: FormatOption
    PyTypeObject* SbkPySide_QtOpenGL_QGL_FormatOption = Shiboken::Enum::newType("PySide.QtOpenGL.QGL.FormatOption");
    SbkPySide_QtOpenGL_QGL_FormatOption->tp_as_number = &SbkPySide_QtOpenGL_QGL_FormatOption_as_number;
    SbkPySide_QtOpenGLTypes[SBK_QGL_FORMATOPTION_IDX] = SbkPySide_QtOpenGL_QGL_FormatOption;
    if (PyType_Ready(SbkPySide_QtOpenGL_QGL_FormatOption) < 0)
        return;
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,
            "FormatOption",((PyObject*)SbkPySide_QtOpenGL_QGL_FormatOption));

    // init flags class: QFlags<QGL::FormatOption>
    SbkPySide_QtOpenGLTypes[SBK_QFLAGS_QGL_FORMATOPTION__IDX] = &SbkPySide_QtOpenGL_QGL_FormatOptions_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtOpenGL_QGL_FormatOptions_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,
            "FormatOptions",((PyObject*)&SbkPySide_QtOpenGL_QGL_FormatOptions_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::DoubleBuffer, "DoubleBuffer");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"DoubleBuffer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"DoubleBuffer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::DepthBuffer, "DepthBuffer");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"DepthBuffer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"DepthBuffer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::Rgba, "Rgba");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"Rgba", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"Rgba", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::AlphaChannel, "AlphaChannel");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"AlphaChannel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"AlphaChannel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::AccumBuffer, "AccumBuffer");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"AccumBuffer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"AccumBuffer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::StencilBuffer, "StencilBuffer");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"StencilBuffer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"StencilBuffer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::StereoBuffers, "StereoBuffers");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"StereoBuffers", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"StereoBuffers", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::DirectRendering, "DirectRendering");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"DirectRendering", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"DirectRendering", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::HasOverlay, "HasOverlay");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"HasOverlay", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"HasOverlay", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::SampleBuffers, "SampleBuffers");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"SampleBuffers", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"SampleBuffers", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::SingleBuffer, "SingleBuffer");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"SingleBuffer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"SingleBuffer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::NoDepthBuffer, "NoDepthBuffer");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"NoDepthBuffer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"NoDepthBuffer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::ColorIndex, "ColorIndex");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"ColorIndex", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"ColorIndex", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::NoAlphaChannel, "NoAlphaChannel");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"NoAlphaChannel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"NoAlphaChannel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::NoAccumBuffer, "NoAccumBuffer");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"NoAccumBuffer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"NoAccumBuffer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::NoStencilBuffer, "NoStencilBuffer");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"NoStencilBuffer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"NoStencilBuffer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::NoStereoBuffers, "NoStereoBuffers");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"NoStereoBuffers", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"NoStereoBuffers", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::IndirectRendering, "IndirectRendering");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"IndirectRendering", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"IndirectRendering", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::NoOverlay, "NoOverlay");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"NoOverlay", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"NoOverlay", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGL_FormatOption,(long) QGL::NoSampleBuffers, "NoSampleBuffers");
    PyDict_SetItemString(Sbk_QGL_Type.super.ht_type.tp_dict,"NoSampleBuffers", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGL_FormatOption->tp_dict,"NoSampleBuffers", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGL::FormatOption");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FormatOption");
    // end of enum FormatOption


    qRegisterMetaType< ::QGL::FormatOption >("QGL::FormatOption");
    qRegisterMetaType< ::QGL::FormatOptions >("QGL::FormatOptions");
}

