/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtopengl_python.h"

#include "qglformat_wrapper.h"

// Extra includes
#include <qgl.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGLFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLFormat >()))
        return -1;

    QGLFormat* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLFormat(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QGLFormat", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QGLFormat()
    // 1: QGLFormat(QFlags<QGL::FormatOption>,int)
    // 2: QGLFormat(QGLFormat)
    if (numArgs == 0) {
        overloadId = 0; // QGLFormat()
    } else if (Shiboken::Converter< ::QFlags<QGL::FormatOption> >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QGLFormat(QFlags<QGL::FormatOption>,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // QGLFormat(QFlags<QGL::FormatOption>,int)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QGLFormat >::isConvertible(pyargs[0])) {
        overloadId = 2; // QGLFormat(QGLFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGLFormat()
            {

                if(!PyErr_Occurred()) {
                    // QGLFormat()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLFormat();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QGLFormat(QFlags<QGL::FormatOption>,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "plane");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "plane";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGLFormat_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFormat(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QFlags<QGL::FormatOption> cppArg0 = Shiboken::Converter<QFlags<QGL::FormatOption> >::toCpp(pyargs[0]);
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // QGLFormat(QFlags<QGL::FormatOption>,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLFormat(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QGLFormat(QGLFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QGLFormat cppArg0 = Shiboken::Converter<QGLFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QGLFormat(QGLFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGLFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGLFormat_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QGLFormat_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtOpenGL.QGL.FormatOptions, int = 0", "PySide.QtOpenGL.QGLFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLFormat", overloads);
        return -1;
}

static PyObject* Sbk_QGLFormatFunc_accum(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // accum()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLFormat*>(cppSelf)->accum();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_accumBufferSize(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // accumBufferSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGLFormat*>(cppSelf)->accumBufferSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_alpha(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // alpha()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLFormat*>(cppSelf)->alpha();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_alphaBufferSize(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // alphaBufferSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGLFormat*>(cppSelf)->alphaBufferSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_blueBufferSize(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // blueBufferSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGLFormat*>(cppSelf)->blueBufferSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_defaultFormat(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultFormat()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLFormat cppResult = QGLFormat::defaultFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGLFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_defaultOverlayFormat(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultOverlayFormat()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLFormat cppResult = QGLFormat::defaultOverlayFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGLFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_depth(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // depth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLFormat*>(cppSelf)->depth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_depthBufferSize(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // depthBufferSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGLFormat*>(cppSelf)->depthBufferSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_directRendering(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // directRendering()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLFormat*>(cppSelf)->directRendering();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_doubleBuffer(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // doubleBuffer()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLFormat*>(cppSelf)->doubleBuffer();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_greenBufferSize(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // greenBufferSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGLFormat*>(cppSelf)->greenBufferSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_hasOpenGL(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasOpenGL()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QGLFormat::hasOpenGL();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_hasOpenGLOverlays(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasOpenGLOverlays()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QGLFormat::hasOpenGLOverlays();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_hasOverlay(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasOverlay()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLFormat*>(cppSelf)->hasOverlay();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_openGLVersionFlags(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // openGLVersionFlags()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QGLFormat::OpenGLVersionFlag> cppResult = QGLFormat::openGLVersionFlags();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QGLFormat::OpenGLVersionFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_plane(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // plane()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGLFormat*>(cppSelf)->plane();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_redBufferSize(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // redBufferSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGLFormat*>(cppSelf)->redBufferSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_rgba(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rgba()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLFormat*>(cppSelf)->rgba();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_sampleBuffers(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sampleBuffers()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLFormat*>(cppSelf)->sampleBuffers();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_samples(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // samples()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGLFormat*>(cppSelf)->samples();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_setAccum(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAccum(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAccum(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setAccum_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAccum(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAccum(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setAccum_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setAccum", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setAccumBufferSize(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAccumBufferSize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAccumBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setAccumBufferSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAccumBufferSize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAccumBufferSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setAccumBufferSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setAccumBufferSize", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setAlpha(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlpha(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAlpha(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setAlpha_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAlpha(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAlpha(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setAlpha_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setAlpha", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setAlphaBufferSize(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlphaBufferSize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAlphaBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setAlphaBufferSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAlphaBufferSize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAlphaBufferSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setAlphaBufferSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setAlphaBufferSize", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setBlueBufferSize(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBlueBufferSize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBlueBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setBlueBufferSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBlueBufferSize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBlueBufferSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setBlueBufferSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setBlueBufferSize", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setDefaultFormat(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultFormat(QGLFormat)
    if (Shiboken::Converter< ::QGLFormat >::isConvertible(arg)) {
        overloadId = 0; // setDefaultFormat(QGLFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setDefaultFormat_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGLFormat cppArg0 = Shiboken::Converter<QGLFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDefaultFormat(QGLFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLFormat::setDefaultFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setDefaultFormat_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setDefaultFormat", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setDefaultOverlayFormat(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultOverlayFormat(QGLFormat)
    if (Shiboken::Converter< ::QGLFormat >::isConvertible(arg)) {
        overloadId = 0; // setDefaultOverlayFormat(QGLFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setDefaultOverlayFormat_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGLFormat cppArg0 = Shiboken::Converter<QGLFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDefaultOverlayFormat(QGLFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLFormat::setDefaultOverlayFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setDefaultOverlayFormat_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setDefaultOverlayFormat", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setDepth(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDepth(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDepth(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setDepth_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDepth(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDepth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setDepth_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setDepth", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setDepthBufferSize(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDepthBufferSize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDepthBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setDepthBufferSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDepthBufferSize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDepthBufferSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setDepthBufferSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setDepthBufferSize", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setDirectRendering(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDirectRendering(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDirectRendering(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setDirectRendering_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDirectRendering(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDirectRendering(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setDirectRendering_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setDirectRendering", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setDoubleBuffer(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDoubleBuffer(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDoubleBuffer(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setDoubleBuffer_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDoubleBuffer(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDoubleBuffer(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setDoubleBuffer_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setDoubleBuffer", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setGreenBufferSize(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGreenBufferSize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGreenBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setGreenBufferSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGreenBufferSize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setGreenBufferSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setGreenBufferSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setGreenBufferSize", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setOption(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOption(QFlags<QGL::FormatOption>)
    if (Shiboken::Converter< ::QFlags<QGL::FormatOption> >::isConvertible(arg)) {
        overloadId = 0; // setOption(QFlags<QGL::FormatOption>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setOption_TypeError;

    // Call function/method
    {
        {
            QFlags<QGL::FormatOption> cppArg0 = Shiboken::Converter<QFlags<QGL::FormatOption> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOption(QFlags<QGL::FormatOption>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOption(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setOption_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGL.FormatOptions", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setOption", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setOverlay(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOverlay(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOverlay(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setOverlay_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOverlay(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOverlay(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setOverlay_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setOverlay", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setPlane(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPlane(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPlane(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setPlane_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPlane(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPlane(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setPlane_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setPlane", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setRedBufferSize(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRedBufferSize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRedBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setRedBufferSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRedBufferSize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRedBufferSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setRedBufferSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setRedBufferSize", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setRgba(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRgba(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRgba(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setRgba_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRgba(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRgba(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setRgba_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setRgba", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setSampleBuffers(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSampleBuffers(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSampleBuffers(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setSampleBuffers_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSampleBuffers(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSampleBuffers(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setSampleBuffers_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setSampleBuffers", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setSamples(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSamples(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSamples(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setSamples_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSamples(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSamples(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setSamples_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setSamples", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setStencil(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStencil(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStencil(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setStencil_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStencil(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStencil(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setStencil_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setStencil", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setStencilBufferSize(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStencilBufferSize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStencilBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setStencilBufferSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStencilBufferSize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStencilBufferSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setStencilBufferSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setStencilBufferSize", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setStereo(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStereo(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStereo(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setStereo_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStereo(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStereo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setStereo_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setStereo", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_setSwapInterval(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSwapInterval(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSwapInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_setSwapInterval_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSwapInterval(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSwapInterval(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFormatFunc_setSwapInterval_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.setSwapInterval", overloads);
        return 0;
}

static PyObject* Sbk_QGLFormatFunc_stencil(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // stencil()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLFormat*>(cppSelf)->stencil();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_stencilBufferSize(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // stencilBufferSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGLFormat*>(cppSelf)->stencilBufferSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_stereo(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // stereo()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLFormat*>(cppSelf)->stereo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_swapInterval(PyObject* self)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // swapInterval()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGLFormat*>(cppSelf)->swapInterval();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFormatFunc_testOption(PyObject* self, PyObject* arg)
{
    QGLFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testOption(QFlags<QGL::FormatOption>)const
    if (Shiboken::Converter< ::QFlags<QGL::FormatOption> >::isConvertible(arg)) {
        overloadId = 0; // testOption(QFlags<QGL::FormatOption>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFormatFunc_testOption_TypeError;

    // Call function/method
    {
        {
            QFlags<QGL::FormatOption> cppArg0 = Shiboken::Converter<QFlags<QGL::FormatOption> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // testOption(QFlags<QGL::FormatOption>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLFormat*>(cppSelf)->testOption(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLFormatFunc_testOption_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGL.FormatOptions", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFormat.testOption", overloads);
        return 0;
}

static PyObject *Sbk_QGLFormat___copy__(PyObject *self)
{
        QGLFormat* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QGLFormat*>::toCpp(self);
        PyObject* pyResult = 0;
        QGLFormat* copy = new QGLFormat(*cppSelf);
        pyResult = Shiboken::Converter<QGLFormat*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QGLFormat_methods[] = {
    {"accum", (PyCFunction)Sbk_QGLFormatFunc_accum, METH_NOARGS},
    {"accumBufferSize", (PyCFunction)Sbk_QGLFormatFunc_accumBufferSize, METH_NOARGS},
    {"alpha", (PyCFunction)Sbk_QGLFormatFunc_alpha, METH_NOARGS},
    {"alphaBufferSize", (PyCFunction)Sbk_QGLFormatFunc_alphaBufferSize, METH_NOARGS},
    {"blueBufferSize", (PyCFunction)Sbk_QGLFormatFunc_blueBufferSize, METH_NOARGS},
    {"defaultFormat", (PyCFunction)Sbk_QGLFormatFunc_defaultFormat, METH_NOARGS|METH_STATIC},
    {"defaultOverlayFormat", (PyCFunction)Sbk_QGLFormatFunc_defaultOverlayFormat, METH_NOARGS|METH_STATIC},
    {"depth", (PyCFunction)Sbk_QGLFormatFunc_depth, METH_NOARGS},
    {"depthBufferSize", (PyCFunction)Sbk_QGLFormatFunc_depthBufferSize, METH_NOARGS},
    {"directRendering", (PyCFunction)Sbk_QGLFormatFunc_directRendering, METH_NOARGS},
    {"doubleBuffer", (PyCFunction)Sbk_QGLFormatFunc_doubleBuffer, METH_NOARGS},
    {"greenBufferSize", (PyCFunction)Sbk_QGLFormatFunc_greenBufferSize, METH_NOARGS},
    {"hasOpenGL", (PyCFunction)Sbk_QGLFormatFunc_hasOpenGL, METH_NOARGS|METH_STATIC},
    {"hasOpenGLOverlays", (PyCFunction)Sbk_QGLFormatFunc_hasOpenGLOverlays, METH_NOARGS|METH_STATIC},
    {"hasOverlay", (PyCFunction)Sbk_QGLFormatFunc_hasOverlay, METH_NOARGS},
    {"openGLVersionFlags", (PyCFunction)Sbk_QGLFormatFunc_openGLVersionFlags, METH_NOARGS|METH_STATIC},
    {"plane", (PyCFunction)Sbk_QGLFormatFunc_plane, METH_NOARGS},
    {"redBufferSize", (PyCFunction)Sbk_QGLFormatFunc_redBufferSize, METH_NOARGS},
    {"rgba", (PyCFunction)Sbk_QGLFormatFunc_rgba, METH_NOARGS},
    {"sampleBuffers", (PyCFunction)Sbk_QGLFormatFunc_sampleBuffers, METH_NOARGS},
    {"samples", (PyCFunction)Sbk_QGLFormatFunc_samples, METH_NOARGS},
    {"setAccum", (PyCFunction)Sbk_QGLFormatFunc_setAccum, METH_O},
    {"setAccumBufferSize", (PyCFunction)Sbk_QGLFormatFunc_setAccumBufferSize, METH_O},
    {"setAlpha", (PyCFunction)Sbk_QGLFormatFunc_setAlpha, METH_O},
    {"setAlphaBufferSize", (PyCFunction)Sbk_QGLFormatFunc_setAlphaBufferSize, METH_O},
    {"setBlueBufferSize", (PyCFunction)Sbk_QGLFormatFunc_setBlueBufferSize, METH_O},
    {"setDefaultFormat", (PyCFunction)Sbk_QGLFormatFunc_setDefaultFormat, METH_O|METH_STATIC},
    {"setDefaultOverlayFormat", (PyCFunction)Sbk_QGLFormatFunc_setDefaultOverlayFormat, METH_O|METH_STATIC},
    {"setDepth", (PyCFunction)Sbk_QGLFormatFunc_setDepth, METH_O},
    {"setDepthBufferSize", (PyCFunction)Sbk_QGLFormatFunc_setDepthBufferSize, METH_O},
    {"setDirectRendering", (PyCFunction)Sbk_QGLFormatFunc_setDirectRendering, METH_O},
    {"setDoubleBuffer", (PyCFunction)Sbk_QGLFormatFunc_setDoubleBuffer, METH_O},
    {"setGreenBufferSize", (PyCFunction)Sbk_QGLFormatFunc_setGreenBufferSize, METH_O},
    {"setOption", (PyCFunction)Sbk_QGLFormatFunc_setOption, METH_O},
    {"setOverlay", (PyCFunction)Sbk_QGLFormatFunc_setOverlay, METH_O},
    {"setPlane", (PyCFunction)Sbk_QGLFormatFunc_setPlane, METH_O},
    {"setRedBufferSize", (PyCFunction)Sbk_QGLFormatFunc_setRedBufferSize, METH_O},
    {"setRgba", (PyCFunction)Sbk_QGLFormatFunc_setRgba, METH_O},
    {"setSampleBuffers", (PyCFunction)Sbk_QGLFormatFunc_setSampleBuffers, METH_O},
    {"setSamples", (PyCFunction)Sbk_QGLFormatFunc_setSamples, METH_O},
    {"setStencil", (PyCFunction)Sbk_QGLFormatFunc_setStencil, METH_O},
    {"setStencilBufferSize", (PyCFunction)Sbk_QGLFormatFunc_setStencilBufferSize, METH_O},
    {"setStereo", (PyCFunction)Sbk_QGLFormatFunc_setStereo, METH_O},
    {"setSwapInterval", (PyCFunction)Sbk_QGLFormatFunc_setSwapInterval, METH_O},
    {"stencil", (PyCFunction)Sbk_QGLFormatFunc_stencil, METH_NOARGS},
    {"stencilBufferSize", (PyCFunction)Sbk_QGLFormatFunc_stencilBufferSize, METH_NOARGS},
    {"stereo", (PyCFunction)Sbk_QGLFormatFunc_stereo, METH_NOARGS},
    {"swapInterval", (PyCFunction)Sbk_QGLFormatFunc_swapInterval, METH_NOARGS},
    {"testOption", (PyCFunction)Sbk_QGLFormatFunc_testOption, METH_O},

    {"__copy__", (PyCFunction)Sbk_QGLFormat___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QGLFormat_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QGLFormat& cppSelf = *Shiboken::Converter< QGLFormat* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QGLFormat >::isConvertible(arg)) {
                // operator!=(const QGLFormat & arg__2)
                QGLFormat cppArg0 = Shiboken::Converter< ::QGLFormat >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QGLFormat_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QGLFormat >::isConvertible(arg)) {
                // operator==(const QGLFormat & arg__2)
                QGLFormat cppArg0 = Shiboken::Converter< ::QGLFormat >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QGLFormat_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QGLFormat_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QGLFormat_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGLFormat_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLFormat",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QGLFormat_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGLFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGLFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLFormat::OpenGLVersionFlags >::toPython(
        Shiboken::Converter<QGLFormat::OpenGLVersionFlags>::toCpp(self)
        & Shiboken::Converter< QGLFormat::OpenGLVersionFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLFormat::OpenGLVersionFlags >::toPython(
        Shiboken::Converter<QGLFormat::OpenGLVersionFlags>::toCpp(self)
        | Shiboken::Converter< QGLFormat::OpenGLVersionFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLFormat::OpenGLVersionFlags >::toPython(
        Shiboken::Converter<QGLFormat::OpenGLVersionFlags>::toCpp(self)
        ^ Shiboken::Converter< QGLFormat::OpenGLVersionFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLFormat::OpenGLVersionFlags >::toPython(
        ~Shiboken::Converter<QGLFormat::OpenGLVersionFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "OpenGLVersionFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QGLFormat(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGLFormat_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGLFormat_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGLFormat_Type, &Shiboken::callCppDestructor<QGLFormat >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QGLFormat_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QGLFormat_Type, "QGLFormat");
    PyModule_AddObject(module, "QGLFormat",
        ((PyObject*)&Sbk_QGLFormat_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: OpenGLVersionFlag
    PyTypeObject* SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag = Shiboken::Enum::newType("PySide.QtOpenGL.QGLFormat.OpenGLVersionFlag");
    SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_as_number = &SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag_as_number;
    SbkPySide_QtOpenGLTypes[SBK_QGLFORMAT_OPENGLVERSIONFLAG_IDX] = SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag;
    if (PyType_Ready(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,
            "OpenGLVersionFlag",((PyObject*)SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag));

    // init flags class: QFlags<QGLFormat::OpenGLVersionFlag>
    SbkPySide_QtOpenGLTypes[SBK_QFLAGS_QGLFORMAT_OPENGLVERSIONFLAG__IDX] = &SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,
            "OpenGLVersionFlags",((PyObject*)&SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_Version_None, "OpenGL_Version_None");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_Version_None", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_Version_None", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_Version_1_1, "OpenGL_Version_1_1");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_Version_1_1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_Version_1_1", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_Version_1_2, "OpenGL_Version_1_2");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_Version_1_2", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_Version_1_2", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_Version_1_3, "OpenGL_Version_1_3");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_Version_1_3", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_Version_1_3", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_Version_1_4, "OpenGL_Version_1_4");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_Version_1_4", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_Version_1_4", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_Version_1_5, "OpenGL_Version_1_5");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_Version_1_5", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_Version_1_5", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_Version_2_0, "OpenGL_Version_2_0");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_Version_2_0", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_Version_2_0", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_Version_2_1, "OpenGL_Version_2_1");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_Version_2_1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_Version_2_1", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_ES_Common_Version_1_0, "OpenGL_ES_Common_Version_1_0");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_ES_Common_Version_1_0", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_ES_Common_Version_1_0", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_ES_CommonLite_Version_1_0, "OpenGL_ES_CommonLite_Version_1_0");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_ES_CommonLite_Version_1_0", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_ES_CommonLite_Version_1_0", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_ES_Common_Version_1_1, "OpenGL_ES_Common_Version_1_1");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_ES_Common_Version_1_1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_ES_Common_Version_1_1", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_ES_CommonLite_Version_1_1, "OpenGL_ES_CommonLite_Version_1_1");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_ES_CommonLite_Version_1_1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_ES_CommonLite_Version_1_1", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_ES_Version_2_0, "OpenGL_ES_Version_2_0");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_ES_Version_2_0", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_ES_Version_2_0", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag,(long) QGLFormat::OpenGL_Version_3_0, "OpenGL_Version_3_0");
    PyDict_SetItemString(Sbk_QGLFormat_Type.super.ht_type.tp_dict,"OpenGL_Version_3_0", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFormat_OpenGLVersionFlag->tp_dict,"OpenGL_Version_3_0", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGLFormat::OpenGLVersionFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::OpenGLVersionFlag");
    // end of enum OpenGLVersionFlag


    Shiboken::TypeResolver::createValueTypeResolver<QGLFormat >("QGLFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLFormat >("QGLFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QGLFormat >(typeid(QGLFormat).name());
    PySide::initQtMetaType< ::QGLFormat >();
    qRegisterMetaType< ::QGLFormat::OpenGLVersionFlag >("QGLFormat::OpenGLVersionFlag");
    qRegisterMetaType< ::QGLFormat::OpenGLVersionFlags >("QGLFormat::OpenGLVersionFlags");
}

