/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtopengl_python.h"

#include "qglpixelbuffer_wrapper.h"

// Extra includes
#include <QImage>
#include <qgl.h>
#include <qglpixelbuffer.h>
#include <qimage.h>
#include <qpaintengine.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>


// Native ---------------------------------------------------------

QGLPixelBufferWrapper::QGLPixelBufferWrapper(const QSize & size, const QGLFormat & format, QGLWidget * shareWidget) : QGLPixelBuffer(size, format, shareWidget) {
    // ... middle
}

QGLPixelBufferWrapper::QGLPixelBufferWrapper(int width, int height, const QGLFormat & format, QGLWidget * shareWidget) : QGLPixelBuffer(width, height, format, shareWidget) {
    // ... middle
}

int QGLPixelBufferWrapper::devType() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLPixelBuffer::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLPixelBuffer.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

int QGLPixelBufferWrapper::metric(QPaintDevice::PaintDeviceMetric metric) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLPixelBuffer::metric(metric);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(metric)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLPixelBuffer.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QPaintEngine * QGLPixelBufferWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLPixelBuffer::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLPixelBuffer.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

QGLPixelBufferWrapper::~QGLPixelBufferWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGLPixelBuffer_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLPixelBuffer >()))
        return -1;

    QGLPixelBufferWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLPixelBuffer(): too many arguments");
        return -1;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLPixelBuffer(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QGLPixelBuffer", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QGLPixelBuffer(QSize,QGLFormat,QGLWidget*)
    // 1: QGLPixelBuffer(int,int,QGLFormat,QGLWidget*)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // QGLPixelBuffer(int,int,QGLFormat,QGLWidget*)
        } else if (Shiboken::Converter< ::QGLFormat >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // QGLPixelBuffer(int,int,QGLFormat,QGLWidget*)
            } else if (Shiboken::Converter< ::QGLWidget * >::isConvertible(pyargs[3])) {
                overloadId = 1; // QGLPixelBuffer(int,int,QGLFormat,QGLWidget*)
            }
        }
    } else if (Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QGLPixelBuffer(QSize,QGLFormat,QGLWidget*)
        } else if (Shiboken::Converter< ::QGLFormat >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // QGLPixelBuffer(QSize,QGLFormat,QGLWidget*)
            } else if (Shiboken::Converter< ::QGLWidget * >::isConvertible(pyargs[2])) {
                overloadId = 0; // QGLPixelBuffer(QSize,QGLFormat,QGLWidget*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLPixelBuffer_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGLPixelBuffer(QSize,QGLFormat,QGLWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< ::QGLFormat >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGLPixelBuffer_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "shareWidget");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "shareWidget";
                        else if (Shiboken::Converter< ::QGLWidget * >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLPixelBuffer_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLPixelBuffer(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QGLFormat cppArg1_tmp = QGLFormat::defaultFormat();
                QGLFormat cppArg1 = pyargs[1] ? Shiboken::Converter<QGLFormat >::toCpp(pyargs[1]) : cppArg1_tmp;
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QGLWidget * cppArg2 = pyargs[2] ? Shiboken::Converter<QGLWidget * >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // QGLPixelBuffer(QSize,QGLFormat,QGLWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLPixelBufferWrapper(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QGLPixelBuffer(int,int,QGLFormat,QGLWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "format";
                        else if (Shiboken::Converter< ::QGLFormat >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLPixelBuffer_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "shareWidget");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "shareWidget";
                        else if (Shiboken::Converter< ::QGLWidget * >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QGLPixelBuffer_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLPixelBuffer(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QGLFormat cppArg2_tmp = QGLFormat::defaultFormat();
                QGLFormat cppArg2 = pyargs[2] ? Shiboken::Converter<QGLFormat >::toCpp(pyargs[2]) : cppArg2_tmp;
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return -1;
                QGLWidget * cppArg3 = pyargs[3] ? Shiboken::Converter<QGLWidget * >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                    // QGLPixelBuffer(int,int,QGLFormat,QGLWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLPixelBufferWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGLPixelBuffer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGLPixelBuffer_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QGLPixelBuffer_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtOpenGL.QGLFormat = QGLFormat.defaultFormat(), PySide.QtOpenGL.QGLWidget = None", "int, int, PySide.QtOpenGL.QGLFormat = QGLFormat.defaultFormat(), PySide.QtOpenGL.QGLWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLPixelBuffer", overloads);
        return -1;
}

static PyObject* Sbk_QGLPixelBufferFunc_bindTexture(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLPixelBuffer.bindTexture(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLPixelBuffer.bindTexture(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:bindTexture", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: bindTexture(QImage,uint)
    // 1: bindTexture(QPixmap,uint)
    // 2: bindTexture(QString)
    if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 2; // bindTexture(QString)
    } else if (Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // bindTexture(QPixmap,uint)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // bindTexture(QPixmap,uint)
        }
    } else if (Shiboken::Converter< ::QImage >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // bindTexture(QImage,uint)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // bindTexture(QImage,uint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLPixelBufferFunc_bindTexture_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // bindTexture(QImage,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "target";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGLPixelBufferFunc_bindTexture_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLPixelBuffer.bindTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QImage cppArg0 = Shiboken::Converter<QImage >::toCpp(pyargs[0]);
                unsigned int cppArg1 = pyargs[1] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[1]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                    // bindTexture(QImage,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    unsigned int cppResult = cppSelf->bindTexture(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 1: // bindTexture(QPixmap,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "target";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGLPixelBufferFunc_bindTexture_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLPixelBuffer.bindTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPixmap cppArg0 = Shiboken::Converter<QPixmap >::toCpp(pyargs[0]);
                unsigned int cppArg1 = pyargs[1] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[1]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                    // bindTexture(QPixmap,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    unsigned int cppResult = cppSelf->bindTexture(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 2: // bindTexture(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // bindTexture(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    unsigned int cppResult = cppSelf->bindTexture(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLPixelBufferFunc_bindTexture_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage, unsigned int = 0x0DE1", "PySide.QtGui.QPixmap, unsigned int = 0x0DE1", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLPixelBuffer.bindTexture", overloads);
        return 0;
}

static PyObject* Sbk_QGLPixelBufferFunc_bindToDynamicTexture(PyObject* self, PyObject* arg)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: bindToDynamicTexture(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // bindToDynamicTexture(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLPixelBufferFunc_bindToDynamicTexture_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // bindToDynamicTexture(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->bindToDynamicTexture(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLPixelBufferFunc_bindToDynamicTexture_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLPixelBuffer.bindToDynamicTexture", overloads);
        return 0;
}

static PyObject* Sbk_QGLPixelBufferFunc_deleteTexture(PyObject* self, PyObject* arg)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: deleteTexture(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // deleteTexture(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLPixelBufferFunc_deleteTexture_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // deleteTexture(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->deleteTexture(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLPixelBufferFunc_deleteTexture_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLPixelBuffer.deleteTexture", overloads);
        return 0;
}

static PyObject* Sbk_QGLPixelBufferFunc_devType(PyObject* self)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // devType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QGLPixelBuffer*>(cppSelf)->::QGLPixelBuffer::devType() : const_cast<const QGLPixelBuffer*>(cppSelf)->devType());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLPixelBufferFunc_doneCurrent(PyObject* self)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // doneCurrent()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->doneCurrent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLPixelBufferFunc_drawTexture(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLPixelBuffer.drawTexture(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLPixelBuffer.drawTexture(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:drawTexture", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: drawTexture(QPointF,uint,uint)
    // 1: drawTexture(QRectF,uint,uint)
    if (numArgs >= 2 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // drawTexture(QRectF,uint,uint)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 1; // drawTexture(QRectF,uint,uint)
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // drawTexture(QPointF,uint,uint)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // drawTexture(QPointF,uint,uint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLPixelBufferFunc_drawTexture_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawTexture(QPointF,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "textureTarget");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "textureTarget";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLPixelBufferFunc_drawTexture_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLPixelBuffer.drawTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                unsigned int cppArg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                unsigned int cppArg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                    // drawTexture(QPointF,uint,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawTexture(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawTexture(QRectF,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "textureTarget");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "textureTarget";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLPixelBufferFunc_drawTexture_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLPixelBuffer.drawTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                unsigned int cppArg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                unsigned int cppArg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                    // drawTexture(QRectF,uint,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawTexture(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLPixelBufferFunc_drawTexture_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, unsigned int, unsigned int = 0x0DE1", "PySide.QtCore.QRectF, unsigned int, unsigned int = 0x0DE1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLPixelBuffer.drawTexture", overloads);
        return 0;
}

static PyObject* Sbk_QGLPixelBufferFunc_format(PyObject* self)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // format()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLFormat cppResult = const_cast<const QGLPixelBuffer*>(cppSelf)->format();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGLFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLPixelBufferFunc_generateDynamicTexture(PyObject* self)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // generateDynamicTexture()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = const_cast<const QGLPixelBuffer*>(cppSelf)->generateDynamicTexture();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLPixelBufferFunc_handle(PyObject* self)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // handle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::HANDLE cppResult = const_cast<const QGLPixelBuffer*>(cppSelf)->handle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< Qt::HANDLE >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLPixelBufferFunc_hasOpenGLPbuffers(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasOpenGLPbuffers()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QGLPixelBuffer::hasOpenGLPbuffers();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLPixelBufferFunc_isValid(PyObject* self)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLPixelBuffer*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLPixelBufferFunc_makeCurrent(PyObject* self)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // makeCurrent()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->makeCurrent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLPixelBufferFunc_metric(PyObject* self, PyObject* arg)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: metric(QPaintDevice::PaintDeviceMetric)const
    if (Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::isConvertible(arg)) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLPixelBufferFunc_metric_TypeError;

    // Call function/method
    {
        {
            QPaintDevice::PaintDeviceMetric cppArg0 = Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // metric(QPaintDevice::PaintDeviceMetric)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QGLPixelBuffer*>(cppSelf)->::QGLPixelBuffer::metric(cppArg0) : const_cast<const QGLPixelBuffer*>(cppSelf)->metric(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLPixelBufferFunc_metric_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice.PaintDeviceMetric", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLPixelBuffer.metric", overloads);
        return 0;
}

static PyObject* Sbk_QGLPixelBufferFunc_paintEngine(PyObject* self)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // paintEngine()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPaintEngine * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QGLPixelBuffer*>(cppSelf)->::QGLPixelBuffer::paintEngine() : const_cast<const QGLPixelBuffer*>(cppSelf)->paintEngine());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPaintEngine * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLPixelBufferFunc_releaseFromDynamicTexture(PyObject* self)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // releaseFromDynamicTexture()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->releaseFromDynamicTexture();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGLPixelBufferFunc_size(PyObject* self)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QGLPixelBuffer*>(cppSelf)->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLPixelBufferFunc_toImage(PyObject* self)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toImage()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = const_cast<const QGLPixelBuffer*>(cppSelf)->toImage();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLPixelBufferFunc_updateDynamicTexture(PyObject* self, PyObject* arg)
{
    QGLPixelBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLPixelBuffer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: updateDynamicTexture(uint)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // updateDynamicTexture(uint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLPixelBufferFunc_updateDynamicTexture_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // updateDynamicTexture(uint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const_cast<const QGLPixelBuffer*>(cppSelf)->updateDynamicTexture(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLPixelBufferFunc_updateDynamicTexture_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLPixelBuffer.updateDynamicTexture", overloads);
        return 0;
}

static PyMethodDef Sbk_QGLPixelBuffer_methods[] = {
    {"bindTexture", (PyCFunction)Sbk_QGLPixelBufferFunc_bindTexture, METH_VARARGS|METH_KEYWORDS},
    {"bindToDynamicTexture", (PyCFunction)Sbk_QGLPixelBufferFunc_bindToDynamicTexture, METH_O},
    {"deleteTexture", (PyCFunction)Sbk_QGLPixelBufferFunc_deleteTexture, METH_O},
    {"devType", (PyCFunction)Sbk_QGLPixelBufferFunc_devType, METH_NOARGS},
    {"doneCurrent", (PyCFunction)Sbk_QGLPixelBufferFunc_doneCurrent, METH_NOARGS},
    {"drawTexture", (PyCFunction)Sbk_QGLPixelBufferFunc_drawTexture, METH_VARARGS|METH_KEYWORDS},
    {"format", (PyCFunction)Sbk_QGLPixelBufferFunc_format, METH_NOARGS},
    {"generateDynamicTexture", (PyCFunction)Sbk_QGLPixelBufferFunc_generateDynamicTexture, METH_NOARGS},
    {"handle", (PyCFunction)Sbk_QGLPixelBufferFunc_handle, METH_NOARGS},
    {"hasOpenGLPbuffers", (PyCFunction)Sbk_QGLPixelBufferFunc_hasOpenGLPbuffers, METH_NOARGS|METH_STATIC},
    {"isValid", (PyCFunction)Sbk_QGLPixelBufferFunc_isValid, METH_NOARGS},
    {"makeCurrent", (PyCFunction)Sbk_QGLPixelBufferFunc_makeCurrent, METH_NOARGS},
    {"metric", (PyCFunction)Sbk_QGLPixelBufferFunc_metric, METH_O},
    {"paintEngine", (PyCFunction)Sbk_QGLPixelBufferFunc_paintEngine, METH_NOARGS},
    {"releaseFromDynamicTexture", (PyCFunction)Sbk_QGLPixelBufferFunc_releaseFromDynamicTexture, METH_NOARGS},
    {"size", (PyCFunction)Sbk_QGLPixelBufferFunc_size, METH_NOARGS},
    {"toImage", (PyCFunction)Sbk_QGLPixelBufferFunc_toImage, METH_NOARGS},
    {"updateDynamicTexture", (PyCFunction)Sbk_QGLPixelBufferFunc_updateDynamicTexture, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGLPixelBuffer_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLPixelBuffer",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGLPixelBuffer_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGLPixelBuffer_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QGLPixelBuffer_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QGLPixelBuffer*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QGLPixelBuffer_Type;
    return 0;
}


void init_QGLPixelBuffer(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLPIXELBUFFER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGLPixelBuffer_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGLPixelBuffer_Type);
    Sbk_QGLPixelBuffer_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGLPixelBuffer_Type, &Shiboken::callCppDestructor<QGLPixelBuffer >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QGLPixelBuffer_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QGLPixelBuffer_Type, &Sbk_QGLPixelBuffer_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]), &Sbk_QGLPixelBuffer_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QGLPixelBuffer_Type, "QGLPixelBuffer*");
    PyModule_AddObject(module, "QGLPixelBuffer",
        ((PyObject*)&Sbk_QGLPixelBuffer_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QGLPixelBuffer >("QGLPixelBuffer*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLPixelBuffer >(typeid(QGLPixelBuffer).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGLPixelBuffer >(typeid(QGLPixelBufferWrapper).name());
    PySide::initQtMetaType< ::QGLPixelBuffer* >();
}

