/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtopengl_python.h"

#include "qglshader_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qgl.h>
#include <qglshaderprogram.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QGLShaderWrapper::QGLShaderWrapper(QFlags<QGLShader::ShaderTypeBit> type, QObject * parent) : QGLShader(type, parent) {
    // ... middle
}

QGLShaderWrapper::QGLShaderWrapper(QFlags<QGLShader::ShaderTypeBit> type, const QGLContext * context, QObject * parent) : QGLShader(type, context, parent) {
    // ... middle
}

void QGLShaderWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGLShaderWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGLShaderWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGLShaderWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QGLShaderWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLShader.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QGLShaderWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLShader.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QGLShaderWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QGLShaderWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QGLShaderWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGLShader::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QGLShaderWrapper::~QGLShaderWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGLShader_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLShader >()))
        return -1;

    QGLShaderWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShader(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QGLShader", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QGLShader(QFlags<QGLShader::ShaderTypeBit>,QObject*)
    // 1: QGLShader(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*,QObject*)
    if (Shiboken::Converter< ::QFlags<QGLShader::ShaderTypeBit> >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QGLShader(QFlags<QGLShader::ShaderTypeBit>,QObject*)
        } else if (Shiboken::Converter< ::QGLContext * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // QGLShader(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*,QObject*)
            } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[2])) {
                overloadId = 1; // QGLShader(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*,QObject*)
            }
        } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[1])) {
            overloadId = 0; // QGLShader(QFlags<QGLShader::ShaderTypeBit>,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShader_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGLShader(QFlags<QGLShader::ShaderTypeBit>,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGLShader_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShader(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QFlags<QGLShader::ShaderTypeBit> cppArg0 = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QObject * cppArg1 = pyargs[1] ? Shiboken::Converter<QObject * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // QGLShader(QFlags<QGLShader::ShaderTypeBit>,QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLShaderWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[1], self);
                }
                break;
            }
            case 1: // QGLShader(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLShader_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShader(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QFlags<QGLShader::ShaderTypeBit> cppArg0 = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QGLContext * cppArg1 = Shiboken::Converter<QGLContext * >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QObject * cppArg2 = pyargs[2] ? Shiboken::Converter<QObject * >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // QGLShader(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*,QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLShaderWrapper(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[2], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGLShader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGLShader_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QGLShader_Init_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader.ShaderType, PySide.QtCore.QObject = None", "PySide.QtOpenGL.QGLShader.ShaderType, PySide.QtOpenGL.QGLContext, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShader", overloads);
        return -1;
}

static PyObject* Sbk_QGLShaderFunc_compileSourceCode(PyObject* self, PyObject* arg)
{
    QGLShader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: compileSourceCode(QByteArray)
    // 1: compileSourceCode(QString)
    // 2: compileSourceCode(const char*)
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 2; // compileSourceCode(const char*)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 1; // compileSourceCode(QString)
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // compileSourceCode(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderFunc_compileSourceCode_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // compileSourceCode(QByteArray)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // compileSourceCode(QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->compileSourceCode(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // compileSourceCode(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // compileSourceCode(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->compileSourceCode(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // compileSourceCode(const char*)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // compileSourceCode(const char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->compileSourceCode(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderFunc_compileSourceCode_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "QString", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShader.compileSourceCode", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderFunc_compileSourceFile(PyObject* self, PyObject* arg)
{
    QGLShader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: compileSourceFile(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // compileSourceFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderFunc_compileSourceFile_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // compileSourceFile(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->compileSourceFile(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderFunc_compileSourceFile_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShader.compileSourceFile", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderFunc_isCompiled(PyObject* self)
{
    QGLShader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isCompiled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLShader*>(cppSelf)->isCompiled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderFunc_log(PyObject* self)
{
    QGLShader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // log()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QGLShader*>(cppSelf)->log();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderFunc_shaderId(PyObject* self)
{
    QGLShader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // shaderId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = const_cast<const QGLShader*>(cppSelf)->shaderId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderFunc_shaderType(PyObject* self)
{
    QGLShader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // shaderType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QGLShader::ShaderTypeBit> cppResult = const_cast<const QGLShader*>(cppSelf)->shaderType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QGLShader::ShaderTypeBit> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderFunc_sourceCode(PyObject* self)
{
    QGLShader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sourceCode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = const_cast<const QGLShader*>(cppSelf)->sourceCode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QGLShader_methods[] = {
    {"compileSourceCode", (PyCFunction)Sbk_QGLShaderFunc_compileSourceCode, METH_O},
    {"compileSourceFile", (PyCFunction)Sbk_QGLShaderFunc_compileSourceFile, METH_O},
    {"isCompiled", (PyCFunction)Sbk_QGLShaderFunc_isCompiled, METH_NOARGS},
    {"log", (PyCFunction)Sbk_QGLShaderFunc_log, METH_NOARGS},
    {"shaderId", (PyCFunction)Sbk_QGLShaderFunc_shaderId, METH_NOARGS},
    {"shaderType", (PyCFunction)Sbk_QGLShaderFunc_shaderType, METH_NOARGS},
    {"sourceCode", (PyCFunction)Sbk_QGLShaderFunc_sourceCode, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGLShader_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLShader",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGLShader_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGLShader_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QGLShader_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QGLShader*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QGLShader_Type;
    return 0;
}

PyObject* SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLShader::ShaderType >::toPython(
        Shiboken::Converter<QGLShader::ShaderType>::toCpp(self)
        & Shiboken::Converter< QGLShader::ShaderType >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLShader::ShaderType >::toPython(
        Shiboken::Converter<QGLShader::ShaderType>::toCpp(self)
        | Shiboken::Converter< QGLShader::ShaderType >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLShader::ShaderType >::toPython(
        Shiboken::Converter<QGLShader::ShaderType>::toCpp(self)
        ^ Shiboken::Converter< QGLShader::ShaderType >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLShader::ShaderType >::toPython(
        ~Shiboken::Converter<QGLShader::ShaderType >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtOpenGL_QGLShader_ShaderType_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ShaderType",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QGLShader(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLSHADER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGLShader_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGLShader_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QGLShader_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QGLShader_Type, &QGLShader::staticMetaObject);    Sbk_QGLShader_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGLShader_Type, &Shiboken::callCppDestructor<QGLShader >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QGLShader_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QGLShader_Type, &Sbk_QGLShader_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QGLShader_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QGLShader_Type, "QGLShader*");
    PyModule_AddObject(module, "QGLShader",
        ((PyObject*)&Sbk_QGLShader_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ShaderTypeBit
    PyTypeObject* SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit = Shiboken::Enum::newType("PySide.QtOpenGL.QGLShader.ShaderTypeBit");
    SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit->tp_as_number = &SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_as_number;
    SbkPySide_QtOpenGLTypes[SBK_QGLSHADER_SHADERTYPEBIT_IDX] = SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit;
    if (PyType_Ready(SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit) < 0)
        return;
    PyDict_SetItemString(Sbk_QGLShader_Type.super.ht_type.tp_dict,
            "ShaderTypeBit",((PyObject*)SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit));

    // init flags class: QFlags<QGLShader::ShaderTypeBit>
    SbkPySide_QtOpenGLTypes[SBK_QFLAGS_QGLSHADER_SHADERTYPEBIT__IDX] = &SbkPySide_QtOpenGL_QGLShader_ShaderType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtOpenGL_QGLShader_ShaderType_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QGLShader_Type.super.ht_type.tp_dict,
            "ShaderType",((PyObject*)&SbkPySide_QtOpenGL_QGLShader_ShaderType_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit,(long) QGLShader::Vertex, "Vertex");
    PyDict_SetItemString(Sbk_QGLShader_Type.super.ht_type.tp_dict,"Vertex", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit->tp_dict,"Vertex", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit,(long) QGLShader::Fragment, "Fragment");
    PyDict_SetItemString(Sbk_QGLShader_Type.super.ht_type.tp_dict,"Fragment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit->tp_dict,"Fragment", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGLShader::ShaderTypeBit");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ShaderTypeBit");
    // end of enum ShaderTypeBit


    Shiboken::TypeResolver::createObjectTypeResolver<QGLShader >("QGLShader*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLShader >(typeid(QGLShader).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGLShader >(typeid(QGLShaderWrapper).name());
    PySide::initQtMetaType< ::QGLShader* >();
    qRegisterMetaType< ::QGLShader::ShaderTypeBit >("QGLShader::ShaderTypeBit");
    qRegisterMetaType< ::QGLShader::ShaderType >("QGLShader::ShaderType");
}

