/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtscript_python.h"

#include "qscriptengine_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdatetime.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qregexp.h>
#include <qscriptclass.h>
#include <qscriptcontext.h>
#include <qscriptengine.h>
#include <qscriptengineagent.h>
#include <qscriptprogram.h>
#include <qscriptstring.h>
#include <qscriptvalue.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QScriptEngineWrapper::QScriptEngineWrapper() : QScriptEngine() {
    // ... middle
}

QScriptEngineWrapper::QScriptEngineWrapper(QObject * parent) : QScriptEngine(parent) {
    // ... middle
}

void QScriptEngineWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QScriptEngineWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QScriptEngineWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QScriptEngineWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QScriptEngineWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptEngine.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QScriptEngineWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptEngine.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QScriptEngineWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QScriptEngineWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QScriptEngineWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QScriptEngine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QScriptEngineWrapper::~QScriptEngineWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScriptEngine_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QScriptEngine >()))
        return -1;

    QScriptEngineWrapper* cptr = 0;
    int overloadId = -1;
    const char** argNames = 0;
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QScriptEngine", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QScriptEngine()
    // 1: QScriptEngine(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QScriptEngine()
    } else if (numArgs == 1 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QScriptEngine(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngine_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QScriptEngine()
            {

                if(!PyErr_Occurred()) {
                    // QScriptEngine()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QScriptEngineWrapper();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QScriptEngine(QObject*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QScriptEngine(QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QScriptEngineWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QScriptEngine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QScriptEngine_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 0))
        return -1;


    return 1;

    Sbk_QScriptEngine_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine", overloads);
        return -1;
}

static PyObject* Sbk_QScriptEngineFunc_abortEvaluation(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.abortEvaluation(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:abortEvaluation", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: abortEvaluation(QScriptValue)
    if (numArgs == 0) {
        overloadId = 0; // abortEvaluation(QScriptValue)
    } else if (Shiboken::Converter< ::QScriptValue >::isConvertible(pyargs[0])) {
        overloadId = 0; // abortEvaluation(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_abortEvaluation_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "result");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "result";
                    else if (Shiboken::Converter< ::QScriptValue >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QScriptEngineFunc_abortEvaluation_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.abortEvaluation(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QScriptValue cppArg0_tmp = QScriptValue();
            QScriptValue cppArg0 = pyargs[0] ? Shiboken::Converter<QScriptValue >::toCpp(pyargs[0]) : cppArg0_tmp;

            if(!PyErr_Occurred()) {
                // abortEvaluation(QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->abortEvaluation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineFunc_abortEvaluation_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue = QScriptValue()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.abortEvaluation", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_agent(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // agent()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptEngineAgent * cppResult = const_cast<const QScriptEngine*>(cppSelf)->agent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptEngineAgent * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_availableExtensions(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // availableExtensions()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QScriptEngine*>(cppSelf)->availableExtensions();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_canEvaluate(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: canEvaluate(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // canEvaluate(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_canEvaluate_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // canEvaluate(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QScriptEngine*>(cppSelf)->canEvaluate(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_canEvaluate_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.canEvaluate", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_clearExceptions(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearExceptions()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearExceptions();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QScriptEngineFunc_collectGarbage(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // collectGarbage()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->collectGarbage();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QScriptEngineFunc_currentContext(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentContext()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptContext * cppResult = const_cast<const QScriptEngine*>(cppSelf)->currentContext();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptContext * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_defaultPrototype(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: defaultPrototype(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // defaultPrototype(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_defaultPrototype_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // defaultPrototype(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = const_cast<const QScriptEngine*>(cppSelf)->defaultPrototype(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_defaultPrototype_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.defaultPrototype", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_evaluate(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.evaluate(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.evaluate(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:evaluate", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: evaluate(QScriptProgram)
    // 1: evaluate(QString,QString,int)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // evaluate(QString,QString,int)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // evaluate(QString,QString,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 1; // evaluate(QString,QString,int)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QScriptProgram >::isConvertible(pyargs[0])) {
        overloadId = 0; // evaluate(QScriptProgram)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_evaluate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // evaluate(QScriptProgram)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QScriptProgram cppArg0 = Shiboken::Converter<QScriptProgram >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // evaluate(QScriptProgram)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QScriptValue cppResult = cppSelf->evaluate(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // evaluate(QString,QString,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "fileName");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "fileName";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QScriptEngineFunc_evaluate_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "lineNumber");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "lineNumber";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QScriptEngineFunc_evaluate_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.evaluate(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 1;

                if(!PyErr_Occurred()) {
                    // evaluate(QString,QString,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QScriptValue cppResult = cppSelf->evaluate(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_evaluate_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptProgram", "QString, QString = QString(), int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.evaluate", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_globalObject(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // globalObject()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = const_cast<const QScriptEngine*>(cppSelf)->globalObject();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_hasUncaughtException(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasUncaughtException()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QScriptEngine*>(cppSelf)->hasUncaughtException();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_importExtension(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: importExtension(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // importExtension(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_importExtension_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // importExtension(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = cppSelf->importExtension(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_importExtension_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.importExtension", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_importedExtensions(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // importedExtensions()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QScriptEngine*>(cppSelf)->importedExtensions();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_installTranslatorFunctions(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.installTranslatorFunctions(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:installTranslatorFunctions", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: installTranslatorFunctions(QScriptValue)
    if (numArgs == 0) {
        overloadId = 0; // installTranslatorFunctions(QScriptValue)
    } else if (Shiboken::Converter< ::QScriptValue >::isConvertible(pyargs[0])) {
        overloadId = 0; // installTranslatorFunctions(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_installTranslatorFunctions_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "object");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "object";
                    else if (Shiboken::Converter< ::QScriptValue >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QScriptEngineFunc_installTranslatorFunctions_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.installTranslatorFunctions(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QScriptValue cppArg0_tmp = QScriptValue();
            QScriptValue cppArg0 = pyargs[0] ? Shiboken::Converter<QScriptValue >::toCpp(pyargs[0]) : cppArg0_tmp;

            if(!PyErr_Occurred()) {
                // installTranslatorFunctions(QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->installTranslatorFunctions(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineFunc_installTranslatorFunctions_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue = QScriptValue()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.installTranslatorFunctions", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_isEvaluating(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEvaluating()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QScriptEngine*>(cppSelf)->isEvaluating();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_newActivationObject(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // newActivationObject()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = cppSelf->newActivationObject();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_newArray(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newArray(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:newArray", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: newArray(uint)
    if (numArgs == 0) {
        overloadId = 0; // newArray(uint)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // newArray(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_newArray_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "length");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "length";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QScriptEngineFunc_newArray_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newArray(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            uint cppArg0 = pyargs[0] ? Shiboken::Converter<uint >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // newArray(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = cppSelf->newArray(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_newArray_TypeError:
        const char* overloads[] = {"unsigned int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.newArray", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_newDate(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: newDate(QDateTime)
    // 1: newDate(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // newDate(double)
    } else if (Shiboken::Converter< ::QDateTime >::isConvertible(arg)) {
        overloadId = 0; // newDate(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_newDate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // newDate(QDateTime)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QDateTime cppArg0 = Shiboken::Converter<QDateTime >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // newDate(QDateTime)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QScriptValue cppResult = cppSelf->newDate(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // newDate(double)
            {
                double cppArg0 = Shiboken::Converter<double >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // newDate(double)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QScriptValue cppResult = cppSelf->newDate(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_newDate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDateTime", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.newDate", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_newObject(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newObject(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:newObject", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: newObject()
    // 1: newObject(QScriptClass*,QScriptValue)
    if (numArgs == 0) {
        overloadId = 0; // newObject()
    } else if (Shiboken::Converter< ::QScriptClass * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // newObject(QScriptClass*,QScriptValue)
        } else if (Shiboken::Converter< ::QScriptValue >::isConvertible(pyargs[1])) {
            overloadId = 1; // newObject(QScriptClass*,QScriptValue)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_newObject_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // newObject()
            {

                if(!PyErr_Occurred()) {
                    // newObject()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QScriptValue cppResult = cppSelf->newObject();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // newObject(QScriptClass*,QScriptValue)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "data");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "data";
                        else if (Shiboken::Converter< ::QScriptValue >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QScriptEngineFunc_newObject_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QScriptClass * cppArg0 = Shiboken::Converter<QScriptClass * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QScriptValue cppArg1_tmp = QScriptValue();
                QScriptValue cppArg1 = pyargs[1] ? Shiboken::Converter<QScriptValue >::toCpp(pyargs[1]) : cppArg1_tmp;

                if(!PyErr_Occurred()) {
                    // newObject(QScriptClass*,QScriptValue)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QScriptValue cppResult = cppSelf->newObject(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_newObject_TypeError:
        const char* overloads[] = {"", "PySide.QtScript.QScriptClass, PySide.QtScript.QScriptValue = QScriptValue()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.newObject", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_newQMetaObject(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQMetaObject(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQMetaObject(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:newQMetaObject", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: newQMetaObject(const QMetaObject*,QScriptValue)
    if (Shiboken::Converter< ::QMetaObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // newQMetaObject(const QMetaObject*,QScriptValue)
        } else if (Shiboken::Converter< ::QScriptValue >::isConvertible(pyargs[1])) {
            overloadId = 0; // newQMetaObject(const QMetaObject*,QScriptValue)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_newQMetaObject_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "ctor");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "ctor";
                    else if (Shiboken::Converter< ::QScriptValue >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QScriptEngineFunc_newQMetaObject_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQMetaObject(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QMetaObject * cppArg0 = Shiboken::Converter<QMetaObject * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QScriptValue cppArg1_tmp = QScriptValue();
            QScriptValue cppArg1 = pyargs[1] ? Shiboken::Converter<QScriptValue >::toCpp(pyargs[1]) : cppArg1_tmp;

            if(!PyErr_Occurred()) {
                // newQMetaObject(const QMetaObject*,QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = cppSelf->newQMetaObject(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_newQMetaObject_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMetaObject, PySide.QtScript.QScriptValue = QScriptValue()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.newQMetaObject", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_newQObject(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQObject(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQObject(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:newQObject", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: newQObject(QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
    // 1: newQObject(QScriptValue,QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
    if (numArgs >= 2 && Shiboken::Converter< ::QScriptValue >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // newQObject(QScriptValue,QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
        } else if (Shiboken::Converter< ::QScriptEngine::ValueOwnership >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // newQObject(QScriptValue,QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
            } else if (Shiboken::Converter< ::QFlags<QScriptEngine::QObjectWrapOption> >::isConvertible(pyargs[3])) {
                overloadId = 1; // newQObject(QScriptValue,QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
            }
        }
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // newQObject(QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
        } else if (Shiboken::Converter< ::QScriptEngine::ValueOwnership >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // newQObject(QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
            } else if (Shiboken::Converter< ::QFlags<QScriptEngine::QObjectWrapOption> >::isConvertible(pyargs[2])) {
                overloadId = 0; // newQObject(QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_newQObject_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // newQObject(QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "ownership");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "ownership";
                        else if (Shiboken::Converter< ::QScriptEngine::ValueOwnership >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QScriptEngineFunc_newQObject_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "options");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "options";
                        else if (Shiboken::Converter< ::QFlags<QScriptEngine::QObjectWrapOption> >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QScriptEngineFunc_newQObject_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                QScriptEngine::ValueOwnership cppArg1 = pyargs[1] ? Shiboken::Converter<QScriptEngine::ValueOwnership >::toCpp(pyargs[1]) : QScriptEngine::QtOwnership;
                const QFlags<QScriptEngine::QObjectWrapOption> & cppArg2 = pyargs[2] ? Shiboken::Converter<const QFlags<QScriptEngine::QObjectWrapOption> & >::toCpp(pyargs[2]) : QFlags<QScriptEngine::QObjectWrapOption> (0);

                if(!PyErr_Occurred()) {
                    // newQObject(QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QScriptValue cppResult = cppSelf->newQObject(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // newQObject(QScriptValue,QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "ownership");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "ownership";
                        else if (Shiboken::Converter< ::QScriptEngine::ValueOwnership >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QScriptEngineFunc_newQObject_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "options");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "options";
                        else if (Shiboken::Converter< ::QFlags<QScriptEngine::QObjectWrapOption> >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QScriptEngineFunc_newQObject_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QScriptValue cppArg0 = Shiboken::Converter<QScriptValue >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QObject * cppArg1 = Shiboken::Converter<QObject * >::toCpp(pyargs[1]);
                QScriptEngine::ValueOwnership cppArg2 = pyargs[2] ? Shiboken::Converter<QScriptEngine::ValueOwnership >::toCpp(pyargs[2]) : QScriptEngine::QtOwnership;
                const QFlags<QScriptEngine::QObjectWrapOption> & cppArg3 = pyargs[3] ? Shiboken::Converter<const QFlags<QScriptEngine::QObjectWrapOption> & >::toCpp(pyargs[3]) : QFlags<QScriptEngine::QObjectWrapOption> (0);

                if(!PyErr_Occurred()) {
                    // newQObject(QScriptValue,QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QScriptValue cppResult = cppSelf->newQObject(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_newQObject_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtScript.QScriptEngine.ValueOwnership = QtOwnership, PySide.QtScript.QScriptEngine.QObjectWrapOptions = 0", "PySide.QtScript.QScriptValue, PySide.QtCore.QObject, PySide.QtScript.QScriptEngine.ValueOwnership = QtOwnership, PySide.QtScript.QScriptEngine.QObjectWrapOptions = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.newQObject", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_newRegExp(PyObject* self, PyObject* args)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "newRegExp", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: newRegExp(QRegExp)
    // 1: newRegExp(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 1; // newRegExp(QString,QString)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRegExp >::isConvertible(pyargs[0])) {
        overloadId = 0; // newRegExp(QRegExp)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_newRegExp_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // newRegExp(QRegExp)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRegExp cppArg0 = Shiboken::Converter<QRegExp >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // newRegExp(QRegExp)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QScriptValue cppResult = cppSelf->newRegExp(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // newRegExp(QString,QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // newRegExp(QString,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QScriptValue cppResult = cppSelf->newRegExp(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_newRegExp_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRegExp", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.newRegExp", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_newVariant(PyObject* self, PyObject* args)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "newVariant", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: newVariant(QScriptValue,QVariant)
    // 1: newVariant(QVariant)
    if (numArgs == 2 && Shiboken::Converter< ::QScriptValue >::isConvertible(pyargs[0]) && Shiboken::Converter< QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // newVariant(QScriptValue,QVariant)
    } else if (numArgs == 1 && Shiboken::Converter< QVariant >::isConvertible(pyargs[0])) {
        overloadId = 1; // newVariant(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_newVariant_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // newVariant(QScriptValue,QVariant)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QScriptValue cppArg0 = Shiboken::Converter<QScriptValue >::toCpp(pyargs[0]);
                QVariant cppArg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // newVariant(QScriptValue,QVariant)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QScriptValue cppResult = cppSelf->newVariant(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // newVariant(QVariant)
            {
                QVariant cppArg0 = Shiboken::Converter<QVariant >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // newVariant(QVariant)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QScriptValue cppResult = cppSelf->newVariant(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_newVariant_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue, QVariant", "QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.newVariant", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_nullValue(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nullValue()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = cppSelf->nullValue();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_objectById(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: objectById(qint64)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // objectById(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_objectById_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // objectById(qint64)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = const_cast<const QScriptEngine*>(cppSelf)->objectById(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_objectById_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.objectById", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_popContext(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // popContext()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->popContext();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QScriptEngineFunc_processEventsInterval(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // processEventsInterval()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QScriptEngine*>(cppSelf)->processEventsInterval();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_pushContext(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pushContext()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptContext * cppResult = cppSelf->pushContext();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptContext * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_setAgent(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAgent(QScriptEngineAgent*)
    if (Shiboken::Converter< ::QScriptEngineAgent * >::isConvertible(arg)) {
        overloadId = 0; // setAgent(QScriptEngineAgent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_setAgent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QScriptEngineAgent * cppArg0 = Shiboken::Converter<QScriptEngineAgent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAgent(QScriptEngineAgent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAgent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineFunc_setAgent_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptEngineAgent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.setAgent", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_setDefaultPrototype(PyObject* self, PyObject* args)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setDefaultPrototype", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setDefaultPrototype(int,QScriptValue)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QScriptValue >::isConvertible(pyargs[1])) {
        overloadId = 0; // setDefaultPrototype(int,QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_setDefaultPrototype_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QScriptValue cppArg1 = Shiboken::Converter<QScriptValue >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setDefaultPrototype(int,QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDefaultPrototype(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineFunc_setDefaultPrototype_TypeError:
        const char* overloads[] = {"int, PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.setDefaultPrototype", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_setGlobalObject(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGlobalObject(QScriptValue)
    if (Shiboken::Converter< ::QScriptValue >::isConvertible(arg)) {
        overloadId = 0; // setGlobalObject(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_setGlobalObject_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QScriptValue cppArg0 = Shiboken::Converter<QScriptValue >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGlobalObject(QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setGlobalObject(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineFunc_setGlobalObject_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.setGlobalObject", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_setProcessEventsInterval(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProcessEventsInterval(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setProcessEventsInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_setProcessEventsInterval_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setProcessEventsInterval(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProcessEventsInterval(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineFunc_setProcessEventsInterval_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.setProcessEventsInterval", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_toObject(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toObject(QScriptValue)
    if (Shiboken::Converter< ::QScriptValue >::isConvertible(arg)) {
        overloadId = 0; // toObject(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_toObject_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QScriptValue cppArg0 = Shiboken::Converter<QScriptValue >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // toObject(QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = cppSelf->toObject(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_toObject_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.toObject", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_toStringHandle(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toStringHandle(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // toStringHandle(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineFunc_toStringHandle_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // toStringHandle(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptString cppResult = cppSelf->toStringHandle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineFunc_toStringHandle_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.toStringHandle", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineFunc_uncaughtException(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // uncaughtException()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = const_cast<const QScriptEngine*>(cppSelf)->uncaughtException();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_uncaughtExceptionBacktrace(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // uncaughtExceptionBacktrace()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QScriptEngine*>(cppSelf)->uncaughtExceptionBacktrace();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_uncaughtExceptionLineNumber(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // uncaughtExceptionLineNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QScriptEngine*>(cppSelf)->uncaughtExceptionLineNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineFunc_undefinedValue(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // undefinedValue()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = cppSelf->undefinedValue();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QScriptEngine_methods[] = {
    {"abortEvaluation", (PyCFunction)Sbk_QScriptEngineFunc_abortEvaluation, METH_VARARGS|METH_KEYWORDS},
    {"agent", (PyCFunction)Sbk_QScriptEngineFunc_agent, METH_NOARGS},
    {"availableExtensions", (PyCFunction)Sbk_QScriptEngineFunc_availableExtensions, METH_NOARGS},
    {"canEvaluate", (PyCFunction)Sbk_QScriptEngineFunc_canEvaluate, METH_O},
    {"clearExceptions", (PyCFunction)Sbk_QScriptEngineFunc_clearExceptions, METH_NOARGS},
    {"collectGarbage", (PyCFunction)Sbk_QScriptEngineFunc_collectGarbage, METH_NOARGS},
    {"currentContext", (PyCFunction)Sbk_QScriptEngineFunc_currentContext, METH_NOARGS},
    {"defaultPrototype", (PyCFunction)Sbk_QScriptEngineFunc_defaultPrototype, METH_O},
    {"evaluate", (PyCFunction)Sbk_QScriptEngineFunc_evaluate, METH_VARARGS|METH_KEYWORDS},
    {"globalObject", (PyCFunction)Sbk_QScriptEngineFunc_globalObject, METH_NOARGS},
    {"hasUncaughtException", (PyCFunction)Sbk_QScriptEngineFunc_hasUncaughtException, METH_NOARGS},
    {"importExtension", (PyCFunction)Sbk_QScriptEngineFunc_importExtension, METH_O},
    {"importedExtensions", (PyCFunction)Sbk_QScriptEngineFunc_importedExtensions, METH_NOARGS},
    {"installTranslatorFunctions", (PyCFunction)Sbk_QScriptEngineFunc_installTranslatorFunctions, METH_VARARGS|METH_KEYWORDS},
    {"isEvaluating", (PyCFunction)Sbk_QScriptEngineFunc_isEvaluating, METH_NOARGS},
    {"newActivationObject", (PyCFunction)Sbk_QScriptEngineFunc_newActivationObject, METH_NOARGS},
    {"newArray", (PyCFunction)Sbk_QScriptEngineFunc_newArray, METH_VARARGS|METH_KEYWORDS},
    {"newDate", (PyCFunction)Sbk_QScriptEngineFunc_newDate, METH_O},
    {"newObject", (PyCFunction)Sbk_QScriptEngineFunc_newObject, METH_VARARGS|METH_KEYWORDS},
    {"newQMetaObject", (PyCFunction)Sbk_QScriptEngineFunc_newQMetaObject, METH_VARARGS|METH_KEYWORDS},
    {"newQObject", (PyCFunction)Sbk_QScriptEngineFunc_newQObject, METH_VARARGS|METH_KEYWORDS},
    {"newRegExp", (PyCFunction)Sbk_QScriptEngineFunc_newRegExp, METH_VARARGS},
    {"newVariant", (PyCFunction)Sbk_QScriptEngineFunc_newVariant, METH_VARARGS},
    {"nullValue", (PyCFunction)Sbk_QScriptEngineFunc_nullValue, METH_NOARGS},
    {"objectById", (PyCFunction)Sbk_QScriptEngineFunc_objectById, METH_O},
    {"popContext", (PyCFunction)Sbk_QScriptEngineFunc_popContext, METH_NOARGS},
    {"processEventsInterval", (PyCFunction)Sbk_QScriptEngineFunc_processEventsInterval, METH_NOARGS},
    {"pushContext", (PyCFunction)Sbk_QScriptEngineFunc_pushContext, METH_NOARGS},
    {"setAgent", (PyCFunction)Sbk_QScriptEngineFunc_setAgent, METH_O},
    {"setDefaultPrototype", (PyCFunction)Sbk_QScriptEngineFunc_setDefaultPrototype, METH_VARARGS},
    {"setGlobalObject", (PyCFunction)Sbk_QScriptEngineFunc_setGlobalObject, METH_O},
    {"setProcessEventsInterval", (PyCFunction)Sbk_QScriptEngineFunc_setProcessEventsInterval, METH_O},
    {"toObject", (PyCFunction)Sbk_QScriptEngineFunc_toObject, METH_O},
    {"toStringHandle", (PyCFunction)Sbk_QScriptEngineFunc_toStringHandle, METH_O},
    {"uncaughtException", (PyCFunction)Sbk_QScriptEngineFunc_uncaughtException, METH_NOARGS},
    {"uncaughtExceptionBacktrace", (PyCFunction)Sbk_QScriptEngineFunc_uncaughtExceptionBacktrace, METH_NOARGS},
    {"uncaughtExceptionLineNumber", (PyCFunction)Sbk_QScriptEngineFunc_uncaughtExceptionLineNumber, METH_NOARGS},
    {"undefinedValue", (PyCFunction)Sbk_QScriptEngineFunc_undefinedValue, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QScriptEngine_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtScript.QScriptEngine",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QScriptEngine_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QScriptEngine_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QScriptEngine_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QScriptEngine*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QScriptEngine_Type;
    return 0;
}

PyObject* SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toPython(
        Shiboken::Converter<QScriptEngine::QObjectWrapOptions>::toCpp(self)
        & Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toPython(
        Shiboken::Converter<QScriptEngine::QObjectWrapOptions>::toCpp(self)
        | Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toPython(
        Shiboken::Converter<QScriptEngine::QObjectWrapOptions>::toCpp(self)
        ^ Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toPython(
        ~Shiboken::Converter<QScriptEngine::QObjectWrapOptions >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtScript_QScriptEngine_QObjectWrapOptions_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "QObjectWrapOptions",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QScriptEngine(PyObject* module)
{
    SbkPySide_QtScriptTypes[SBK_QSCRIPTENGINE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QScriptEngine_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QScriptEngine_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QScriptEngine_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QScriptEngine_Type, &QScriptEngine::staticMetaObject);    Sbk_QScriptEngine_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QScriptEngine_Type, &Shiboken::callCppDestructor<QScriptEngine >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QScriptEngine_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QScriptEngine_Type, &Sbk_QScriptEngine_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QScriptEngine_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QScriptEngine_Type, "QScriptEngine*");
    PyModule_AddObject(module, "QScriptEngine",
        ((PyObject*)&Sbk_QScriptEngine_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ValueOwnership
    PyTypeObject* SbkPySide_QtScript_QScriptEngine_ValueOwnership = Shiboken::Enum::newType("PySide.QtScript.QScriptEngine.ValueOwnership");
    SbkPySide_QtScriptTypes[SBK_QSCRIPTENGINE_VALUEOWNERSHIP_IDX] = SbkPySide_QtScript_QScriptEngine_ValueOwnership;
    if (PyType_Ready(SbkPySide_QtScript_QScriptEngine_ValueOwnership) < 0)
        return;
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,
            "ValueOwnership",((PyObject*)SbkPySide_QtScript_QScriptEngine_ValueOwnership));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptEngine_ValueOwnership,(long) QScriptEngine::QtOwnership, "QtOwnership");
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,"QtOwnership", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_ValueOwnership->tp_dict,"QtOwnership", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptEngine_ValueOwnership,(long) QScriptEngine::ScriptOwnership, "ScriptOwnership");
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,"ScriptOwnership", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_ValueOwnership->tp_dict,"ScriptOwnership", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptEngine_ValueOwnership,(long) QScriptEngine::AutoOwnership, "AutoOwnership");
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,"AutoOwnership", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_ValueOwnership->tp_dict,"AutoOwnership", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptEngine::ValueOwnership");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ValueOwnership");
    // end of enum ValueOwnership

    // init enum: QObjectWrapOption
    PyTypeObject* SbkPySide_QtScript_QScriptEngine_QObjectWrapOption = Shiboken::Enum::newType("PySide.QtScript.QScriptEngine.QObjectWrapOption");
    SbkPySide_QtScript_QScriptEngine_QObjectWrapOption->tp_as_number = &SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_as_number;
    SbkPySide_QtScriptTypes[SBK_QSCRIPTENGINE_QOBJECTWRAPOPTION_IDX] = SbkPySide_QtScript_QScriptEngine_QObjectWrapOption;
    if (PyType_Ready(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption) < 0)
        return;
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,
            "QObjectWrapOption",((PyObject*)SbkPySide_QtScript_QScriptEngine_QObjectWrapOption));

    // init flags class: QFlags<QScriptEngine::QObjectWrapOption>
    SbkPySide_QtScriptTypes[SBK_QFLAGS_QSCRIPTENGINE_QOBJECTWRAPOPTION__IDX] = &SbkPySide_QtScript_QScriptEngine_QObjectWrapOptions_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtScript_QScriptEngine_QObjectWrapOptions_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,
            "QObjectWrapOptions",((PyObject*)&SbkPySide_QtScript_QScriptEngine_QObjectWrapOptions_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption,(long) QScriptEngine::ExcludeChildObjects, "ExcludeChildObjects");
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,"ExcludeChildObjects", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption->tp_dict,"ExcludeChildObjects", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption,(long) QScriptEngine::ExcludeSuperClassMethods, "ExcludeSuperClassMethods");
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,"ExcludeSuperClassMethods", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption->tp_dict,"ExcludeSuperClassMethods", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption,(long) QScriptEngine::ExcludeSuperClassProperties, "ExcludeSuperClassProperties");
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,"ExcludeSuperClassProperties", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption->tp_dict,"ExcludeSuperClassProperties", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption,(long) QScriptEngine::ExcludeSuperClassContents, "ExcludeSuperClassContents");
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,"ExcludeSuperClassContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption->tp_dict,"ExcludeSuperClassContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption,(long) QScriptEngine::SkipMethodsInEnumeration, "SkipMethodsInEnumeration");
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,"SkipMethodsInEnumeration", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption->tp_dict,"SkipMethodsInEnumeration", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption,(long) QScriptEngine::ExcludeDeleteLater, "ExcludeDeleteLater");
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,"ExcludeDeleteLater", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption->tp_dict,"ExcludeDeleteLater", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption,(long) QScriptEngine::AutoCreateDynamicProperties, "AutoCreateDynamicProperties");
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,"AutoCreateDynamicProperties", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption->tp_dict,"AutoCreateDynamicProperties", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption,(long) QScriptEngine::PreferExistingWrapperObject, "PreferExistingWrapperObject");
    PyDict_SetItemString(Sbk_QScriptEngine_Type.super.ht_type.tp_dict,"PreferExistingWrapperObject", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption->tp_dict,"PreferExistingWrapperObject", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptEngine::QObjectWrapOption");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::QObjectWrapOption");
    // end of enum QObjectWrapOption

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("signalHandlerException", "QScriptValue", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QScriptEngine_Type, "signalHandlerException", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngine >("QScriptEngine*");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngine >(typeid(QScriptEngine).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngine >(typeid(QScriptEngineWrapper).name());
    PySide::initQtMetaType< ::QScriptEngine* >();
    qRegisterMetaType< ::QScriptEngine::ValueOwnership >("QScriptEngine::ValueOwnership");
    qRegisterMetaType< ::QScriptEngine::QObjectWrapOption >("QScriptEngine::QObjectWrapOption");
    qRegisterMetaType< ::QScriptEngine::QObjectWrapOptions >("QScriptEngine::QObjectWrapOptions");
}

