/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtsql_python.h"

#include "qsqldriver_wrapper.h"

// Extra includes
#include <QList>
#include <QSize>
#include <QSqlError>
#include <QSqlIndex>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QStringList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsqldriver.h>
#include <qsqlerror.h>
#include <qsqlfield.h>
#include <qsqlindex.h>
#include <qsqlrecord.h>
#include <qsqlresult.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QSqlDriverWrapper::QSqlDriverWrapper(QObject * parent) : QSqlDriver(parent) {
    // ... middle
}

bool QSqlDriverWrapper::beginTransaction()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "beginTransaction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSqlDriver::beginTransaction();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.beginTransaction", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QSqlDriverWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QSqlDriverWrapper::close()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "close"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.close()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QSqlDriverWrapper::commitTransaction()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "commitTransaction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSqlDriver::commitTransaction();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.commitTransaction", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QSqlDriverWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QSqlResult * QSqlDriverWrapper::createResult() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createResult"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.createResult()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSqlResult * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.createResult", Shiboken::SbkType<QSqlResult >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QSqlResult * cppResult(Shiboken::Converter< ::QSqlResult * >::toCpp(pyResult));
    return cppResult;
}

void QSqlDriverWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QSqlDriverWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QString QSqlDriverWrapper::escapeIdentifier(const QString & identifier, QSqlDriver::IdentifierType type) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QString();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "escapeIdentifier"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSqlDriver::escapeIdentifier(identifier, type);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< QString >::toPython(identifier),
        Shiboken::Converter< ::QSqlDriver::IdentifierType >::toPython(type)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.escapeIdentifier", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

bool QSqlDriverWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QSqlDriverWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

QString QSqlDriverWrapper::formatValue(const QSqlField & field, bool trimStrings) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QString();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "formatValue"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSqlDriver::formatValue(field, trimStrings);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QSqlField >::toPython(field),
        Shiboken::Converter< bool >::toPython(trimStrings)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.formatValue", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

bool QSqlDriverWrapper::hasFeature(QSqlDriver::DriverFeature f) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hasFeature"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.hasFeature()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QSqlDriver::DriverFeature >::toPython(f)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.hasFeature", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QSqlDriverWrapper::isOpen() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isOpen"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSqlDriver::isOpen();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.isOpen", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QSqlDriverWrapper::open(const QString & db, const QString & user, const QString & password, const QString & host, int port, const QString & connOpts)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "open"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.open()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNNiN)",
        Shiboken::Converter< QString >::toPython(db),
        Shiboken::Converter< QString >::toPython(user),
        Shiboken::Converter< QString >::toPython(password),
        Shiboken::Converter< QString >::toPython(host),
        port,
        Shiboken::Converter< QString >::toPython(connOpts)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.open", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QSqlIndex QSqlDriverWrapper::primaryIndex(const QString & tableName) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSqlIndex();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "primaryIndex"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSqlDriver::primaryIndex(tableName);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(tableName)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSqlIndex();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSqlIndex >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.primaryIndex", Shiboken::SbkType<QSqlIndex >()->tp_name, pyResult->ob_type->tp_name);
        return QSqlIndex();
    }
    QSqlIndex cppResult(Shiboken::Converter< ::QSqlIndex >::toCpp(pyResult));
    return cppResult;
}

QSqlRecord QSqlDriverWrapper::record(const QString & tableName) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSqlRecord();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "record"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSqlDriver::record(tableName);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(tableName)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSqlRecord();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSqlRecord >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.record", Shiboken::SbkType<QSqlRecord >()->tp_name, pyResult->ob_type->tp_name);
        return QSqlRecord();
    }
    QSqlRecord cppResult(Shiboken::Converter< ::QSqlRecord >::toCpp(pyResult));
    return cppResult;
}

bool QSqlDriverWrapper::rollbackTransaction()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "rollbackTransaction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSqlDriver::rollbackTransaction();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.rollbackTransaction", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QSqlDriverWrapper::setLastError(const QSqlError & e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setLastError"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSqlDriver::setLastError(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QSqlError >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QSqlDriverWrapper::setOpen(bool o)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setOpen"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSqlDriver::setOpen(o);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(o)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QSqlDriverWrapper::setOpenError(bool e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setOpenError"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSqlDriver::setOpenError(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QString QSqlDriverWrapper::sqlStatement(QSqlDriver::StatementType type, const QString & tableName, const QSqlRecord & rec, bool preparedStatement) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QString();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sqlStatement"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSqlDriver::sqlStatement(type, tableName, rec, preparedStatement);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QSqlDriver::StatementType >::toPython(type),
        Shiboken::Converter< QString >::toPython(tableName),
        Shiboken::Converter< ::QSqlRecord >::toPython(rec),
        Shiboken::Converter< bool >::toPython(preparedStatement)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.sqlStatement", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

QStringList QSqlDriverWrapper::tables(QSql::TableType tableType) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QStringList();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "tables"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSqlDriver::tables(tableType);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QSql::TableType >::toPython(tableType)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStringList();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStringList >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.tables", "list", pyResult->ob_type->tp_name);
        return QStringList();
    }
    QStringList cppResult(Shiboken::Converter< ::QStringList >::toCpp(pyResult));
    return cppResult;
}

void QSqlDriverWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QSqlDriverWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QSqlDriverWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QSqlDriver::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QSqlDriverWrapper::~QSqlDriverWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSqlDriver_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QSqlDriver >()))
        return -1;

    QSqlDriverWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtSqlTypes[SBK_QSQLDRIVER_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QSqlDriver' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }



    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QSqlDriver", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QSqlDriver(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QSqlDriver(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QSqlDriver(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriver_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QSqlDriver_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDriver(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QSqlDriver(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QSqlDriverWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QSqlDriver >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSqlDriver_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QSqlDriver_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver", overloads);
        return -1;
}

static PyObject* Sbk_QSqlDriverFunc_beginTransaction(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // beginTransaction()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QSqlDriver::beginTransaction() : cppSelf->beginTransaction());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlDriverFunc_close(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // close()
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.close()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->close();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QSqlDriverFunc_commitTransaction(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // commitTransaction()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QSqlDriver::commitTransaction() : cppSelf->commitTransaction());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlDriverFunc_createResult(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // createResult()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.createResult()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSqlResult * cppResult = const_cast<const QSqlDriver*>(cppSelf)->createResult();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSqlResult * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlDriverFunc_escapeIdentifier(PyObject* self, PyObject* args)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "escapeIdentifier", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: escapeIdentifier(QString,QSqlDriver::IdentifierType)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSqlDriver::IdentifierType >::isConvertible(pyargs[1])) {
        overloadId = 0; // escapeIdentifier(QString,QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_escapeIdentifier_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QSqlDriver::IdentifierType cppArg1 = Shiboken::Converter<QSqlDriver::IdentifierType >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // escapeIdentifier(QString,QSqlDriver::IdentifierType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QSqlDriver*>(cppSelf)->::QSqlDriver::escapeIdentifier(cppArg0, cppArg1) : const_cast<const QSqlDriver*>(cppSelf)->escapeIdentifier(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_escapeIdentifier_TypeError:
        const char* overloads[] = {"QString, PySide.QtSql.QSqlDriver.IdentifierType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.escapeIdentifier", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_formatValue(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDriver.formatValue(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDriver.formatValue(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:formatValue", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: formatValue(QSqlField,bool)const
    if (Shiboken::Converter< ::QSqlField >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // formatValue(QSqlField,bool)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // formatValue(QSqlField,bool)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_formatValue_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "trimStrings");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "trimStrings";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QSqlDriverFunc_formatValue_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDriver.formatValue(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QSqlField cppArg0 = Shiboken::Converter<QSqlField >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
                // formatValue(QSqlField,bool)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QSqlDriver*>(cppSelf)->::QSqlDriver::formatValue(cppArg0, cppArg1) : const_cast<const QSqlDriver*>(cppSelf)->formatValue(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_formatValue_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlField, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.formatValue", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_hasFeature(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasFeature(QSqlDriver::DriverFeature)const
    if (Shiboken::Converter< ::QSqlDriver::DriverFeature >::isConvertible(arg)) {
        overloadId = 0; // hasFeature(QSqlDriver::DriverFeature)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_hasFeature_TypeError;

    // Call function/method
    {
        {
            QSqlDriver::DriverFeature cppArg0 = Shiboken::Converter<QSqlDriver::DriverFeature >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hasFeature(QSqlDriver::DriverFeature)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.hasFeature()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QSqlDriver*>(cppSelf)->hasFeature(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_hasFeature_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlDriver.DriverFeature", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.hasFeature", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_isIdentifierEscaped(PyObject* self, PyObject* args)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isIdentifierEscaped", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isIdentifierEscaped(QString,QSqlDriver::IdentifierType)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSqlDriver::IdentifierType >::isConvertible(pyargs[1])) {
        overloadId = 0; // isIdentifierEscaped(QString,QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_isIdentifierEscaped_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QSqlDriver::IdentifierType cppArg1 = Shiboken::Converter<QSqlDriver::IdentifierType >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // isIdentifierEscaped(QString,QSqlDriver::IdentifierType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QSqlDriver*>(cppSelf)->isIdentifierEscaped(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_isIdentifierEscaped_TypeError:
        const char* overloads[] = {"QString, PySide.QtSql.QSqlDriver.IdentifierType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.isIdentifierEscaped", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_isIdentifierEscapedImplementation(PyObject* self, PyObject* args)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isIdentifierEscapedImplementation", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isIdentifierEscapedImplementation(QString,QSqlDriver::IdentifierType)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSqlDriver::IdentifierType >::isConvertible(pyargs[1])) {
        overloadId = 0; // isIdentifierEscapedImplementation(QString,QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_isIdentifierEscapedImplementation_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QSqlDriver::IdentifierType cppArg1 = Shiboken::Converter<QSqlDriver::IdentifierType >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // isIdentifierEscapedImplementation(QString,QSqlDriver::IdentifierType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QSqlDriver*>(cppSelf)->isIdentifierEscapedImplementation(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_isIdentifierEscapedImplementation_TypeError:
        const char* overloads[] = {"QString, PySide.QtSql.QSqlDriver.IdentifierType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.isIdentifierEscapedImplementation", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_isOpen(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isOpen()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QSqlDriver*>(cppSelf)->::QSqlDriver::isOpen() : const_cast<const QSqlDriver*>(cppSelf)->isOpen());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlDriverFunc_isOpenError(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isOpenError()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QSqlDriver*>(cppSelf)->isOpenError();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlDriverFunc_lastError(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastError()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSqlError cppResult = const_cast<const QSqlDriver*>(cppSelf)->lastError();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSqlError >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlDriverFunc_numericalPrecisionPolicy(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // numericalPrecisionPolicy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSql::NumericalPrecisionPolicy cppResult = const_cast<const QSqlDriver*>(cppSelf)->numericalPrecisionPolicy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSql::NumericalPrecisionPolicy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlDriverFunc_open(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDriver.open(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDriver.open(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:open", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: open(QString,QString,QString,QString,int,QString)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // open(QString,QString,QString,QString,int,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // open(QString,QString,QString,QString,int,QString)
            } else if (Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // open(QString,QString,QString,QString,int,QString)
                } else if (Shiboken::Converter< QString >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // open(QString,QString,QString,QString,int,QString)
                    } else if (SbkNumber_Check(pyargs[4])) {
                        if (numArgs == 5) {
                            overloadId = 0; // open(QString,QString,QString,QString,int,QString)
                        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[5])) {
                            overloadId = 0; // open(QString,QString,QString,QString,int,QString)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_open_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "user");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "user";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QSqlDriverFunc_open_TypeError;
                }
                value = PyDict_GetItemString(kwds, "password");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "password";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QSqlDriverFunc_open_TypeError;
                }
                value = PyDict_GetItemString(kwds, "host");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "host";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QSqlDriverFunc_open_TypeError;
                }
                value = PyDict_GetItemString(kwds, "port");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "port";
                    else if (SbkNumber_Check(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QSqlDriverFunc_open_TypeError;
                }
                value = PyDict_GetItemString(kwds, "connOpts");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "connOpts";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[5] = value;
                    else
                        goto Sbk_QSqlDriverFunc_open_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDriver.open(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
            QString cppArg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
            QString cppArg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
            int cppArg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : -1;
            QString cppArg5 = pyargs[5] ? Shiboken::Converter<QString >::toCpp(pyargs[5]) : QString();

            if(!PyErr_Occurred()) {
                // open(QString,QString,QString,QString,int,QString)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.open()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->open(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_open_TypeError:
        const char* overloads[] = {"QString, QString = QString(), QString = QString(), QString = QString(), int = -1, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.open", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_primaryIndex(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: primaryIndex(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // primaryIndex(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_primaryIndex_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // primaryIndex(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSqlIndex cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QSqlDriver*>(cppSelf)->::QSqlDriver::primaryIndex(cppArg0) : const_cast<const QSqlDriver*>(cppSelf)->primaryIndex(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSqlIndex >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_primaryIndex_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.primaryIndex", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_record(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: record(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // record(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_record_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // record(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSqlRecord cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QSqlDriver*>(cppSelf)->::QSqlDriver::record(cppArg0) : const_cast<const QSqlDriver*>(cppSelf)->record(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSqlRecord >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_record_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.record", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_rollbackTransaction(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rollbackTransaction()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QSqlDriver::rollbackTransaction() : cppSelf->rollbackTransaction());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlDriverFunc_setLastError(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastError(QSqlError)
    if (Shiboken::Converter< ::QSqlError >::isConvertible(arg)) {
        overloadId = 0; // setLastError(QSqlError)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_setLastError_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSqlError cppArg0 = Shiboken::Converter<QSqlError >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLastError(QSqlError)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QSqlDriver::setLastError(cppArg0) : cppSelf->setLastError(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlDriverFunc_setLastError_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlError", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.setLastError", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_setNumericalPrecisionPolicy(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    if (Shiboken::Converter< ::QSql::NumericalPrecisionPolicy >::isConvertible(arg)) {
        overloadId = 0; // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_setNumericalPrecisionPolicy_TypeError;

    // Call function/method
    {
        {
            QSql::NumericalPrecisionPolicy cppArg0 = Shiboken::Converter<QSql::NumericalPrecisionPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNumericalPrecisionPolicy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlDriverFunc_setNumericalPrecisionPolicy_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSql.NumericalPrecisionPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.setNumericalPrecisionPolicy", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_setOpen(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOpen(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOpen(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_setOpen_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOpen(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QSqlDriver::setOpen(cppArg0) : cppSelf->setOpen(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlDriverFunc_setOpen_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.setOpen", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_setOpenError(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOpenError(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOpenError(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_setOpenError_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOpenError(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QSqlDriver::setOpenError(cppArg0) : cppSelf->setOpenError(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlDriverFunc_setOpenError_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.setOpenError", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_sqlStatement(PyObject* self, PyObject* args)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sqlStatement", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: sqlStatement(QSqlDriver::StatementType,QString,QSqlRecord,bool)const
    if (numArgs == 4 && Shiboken::Converter< ::QSqlDriver::StatementType >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QSqlRecord >::isConvertible(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // sqlStatement(QSqlDriver::StatementType,QString,QSqlRecord,bool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_sqlStatement_TypeError;

    // Call function/method
    {
        {
            QSqlDriver::StatementType cppArg0 = Shiboken::Converter<QSqlDriver::StatementType >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QSqlRecord cppArg2 = Shiboken::Converter<QSqlRecord >::toCpp(pyargs[2]);
            bool cppArg3 = Shiboken::Converter<bool >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // sqlStatement(QSqlDriver::StatementType,QString,QSqlRecord,bool)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QSqlDriver*>(cppSelf)->::QSqlDriver::sqlStatement(cppArg0, cppArg1, cppArg2, cppArg3) : const_cast<const QSqlDriver*>(cppSelf)->sqlStatement(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_sqlStatement_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlDriver.StatementType, QString, PySide.QtSql.QSqlRecord, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.sqlStatement", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_stripDelimiters(PyObject* self, PyObject* args)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "stripDelimiters", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: stripDelimiters(QString,QSqlDriver::IdentifierType)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSqlDriver::IdentifierType >::isConvertible(pyargs[1])) {
        overloadId = 0; // stripDelimiters(QString,QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_stripDelimiters_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QSqlDriver::IdentifierType cppArg1 = Shiboken::Converter<QSqlDriver::IdentifierType >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // stripDelimiters(QString,QSqlDriver::IdentifierType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QSqlDriver*>(cppSelf)->stripDelimiters(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_stripDelimiters_TypeError:
        const char* overloads[] = {"QString, PySide.QtSql.QSqlDriver.IdentifierType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.stripDelimiters", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_stripDelimitersImplementation(PyObject* self, PyObject* args)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "stripDelimitersImplementation", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: stripDelimitersImplementation(QString,QSqlDriver::IdentifierType)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSqlDriver::IdentifierType >::isConvertible(pyargs[1])) {
        overloadId = 0; // stripDelimitersImplementation(QString,QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_stripDelimitersImplementation_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QSqlDriver::IdentifierType cppArg1 = Shiboken::Converter<QSqlDriver::IdentifierType >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // stripDelimitersImplementation(QString,QSqlDriver::IdentifierType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QSqlDriver*>(cppSelf)->stripDelimitersImplementation(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_stripDelimitersImplementation_TypeError:
        const char* overloads[] = {"QString, PySide.QtSql.QSqlDriver.IdentifierType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.stripDelimitersImplementation", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_subscribeToNotification(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: subscribeToNotification(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // subscribeToNotification(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_subscribeToNotification_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // subscribeToNotification(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->subscribeToNotification(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_subscribeToNotification_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.subscribeToNotification", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_subscribeToNotificationImplementation(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: subscribeToNotificationImplementation(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // subscribeToNotificationImplementation(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_subscribeToNotificationImplementation_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // subscribeToNotificationImplementation(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->subscribeToNotificationImplementation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_subscribeToNotificationImplementation_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.subscribeToNotificationImplementation", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_subscribedToNotifications(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // subscribedToNotifications()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QSqlDriver*>(cppSelf)->subscribedToNotifications();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlDriverFunc_subscribedToNotificationsImplementation(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // subscribedToNotificationsImplementation()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QSqlDriver*>(cppSelf)->subscribedToNotificationsImplementation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlDriverFunc_tables(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: tables(QSql::TableType)const
    if (Shiboken::Converter< ::QSql::TableType >::isConvertible(arg)) {
        overloadId = 0; // tables(QSql::TableType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_tables_TypeError;

    // Call function/method
    {
        {
            QSql::TableType cppArg0 = Shiboken::Converter<QSql::TableType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // tables(QSql::TableType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QSqlDriver*>(cppSelf)->::QSqlDriver::tables(cppArg0) : const_cast<const QSqlDriver*>(cppSelf)->tables(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_tables_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSql.TableType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.tables", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_unsubscribeFromNotification(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: unsubscribeFromNotification(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // unsubscribeFromNotification(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_unsubscribeFromNotification_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // unsubscribeFromNotification(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->unsubscribeFromNotification(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_unsubscribeFromNotification_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.unsubscribeFromNotification", overloads);
        return 0;
}

static PyObject* Sbk_QSqlDriverFunc_unsubscribeFromNotificationImplementation(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: unsubscribeFromNotificationImplementation(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // unsubscribeFromNotificationImplementation(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlDriverFunc_unsubscribeFromNotificationImplementation_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // unsubscribeFromNotificationImplementation(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->unsubscribeFromNotificationImplementation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlDriverFunc_unsubscribeFromNotificationImplementation_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.unsubscribeFromNotificationImplementation", overloads);
        return 0;
}

static PyMethodDef Sbk_QSqlDriver_methods[] = {
    {"beginTransaction", (PyCFunction)Sbk_QSqlDriverFunc_beginTransaction, METH_NOARGS},
    {"close", (PyCFunction)Sbk_QSqlDriverFunc_close, METH_NOARGS},
    {"commitTransaction", (PyCFunction)Sbk_QSqlDriverFunc_commitTransaction, METH_NOARGS},
    {"createResult", (PyCFunction)Sbk_QSqlDriverFunc_createResult, METH_NOARGS},
    {"escapeIdentifier", (PyCFunction)Sbk_QSqlDriverFunc_escapeIdentifier, METH_VARARGS},
    {"formatValue", (PyCFunction)Sbk_QSqlDriverFunc_formatValue, METH_VARARGS|METH_KEYWORDS},
    {"hasFeature", (PyCFunction)Sbk_QSqlDriverFunc_hasFeature, METH_O},
    {"isIdentifierEscaped", (PyCFunction)Sbk_QSqlDriverFunc_isIdentifierEscaped, METH_VARARGS},
    {"isIdentifierEscapedImplementation", (PyCFunction)Sbk_QSqlDriverFunc_isIdentifierEscapedImplementation, METH_VARARGS},
    {"isOpen", (PyCFunction)Sbk_QSqlDriverFunc_isOpen, METH_NOARGS},
    {"isOpenError", (PyCFunction)Sbk_QSqlDriverFunc_isOpenError, METH_NOARGS},
    {"lastError", (PyCFunction)Sbk_QSqlDriverFunc_lastError, METH_NOARGS},
    {"numericalPrecisionPolicy", (PyCFunction)Sbk_QSqlDriverFunc_numericalPrecisionPolicy, METH_NOARGS},
    {"open", (PyCFunction)Sbk_QSqlDriverFunc_open, METH_VARARGS|METH_KEYWORDS},
    {"primaryIndex", (PyCFunction)Sbk_QSqlDriverFunc_primaryIndex, METH_O},
    {"record", (PyCFunction)Sbk_QSqlDriverFunc_record, METH_O},
    {"rollbackTransaction", (PyCFunction)Sbk_QSqlDriverFunc_rollbackTransaction, METH_NOARGS},
    {"setLastError", (PyCFunction)Sbk_QSqlDriverFunc_setLastError, METH_O},
    {"setNumericalPrecisionPolicy", (PyCFunction)Sbk_QSqlDriverFunc_setNumericalPrecisionPolicy, METH_O},
    {"setOpen", (PyCFunction)Sbk_QSqlDriverFunc_setOpen, METH_O},
    {"setOpenError", (PyCFunction)Sbk_QSqlDriverFunc_setOpenError, METH_O},
    {"sqlStatement", (PyCFunction)Sbk_QSqlDriverFunc_sqlStatement, METH_VARARGS},
    {"stripDelimiters", (PyCFunction)Sbk_QSqlDriverFunc_stripDelimiters, METH_VARARGS},
    {"stripDelimitersImplementation", (PyCFunction)Sbk_QSqlDriverFunc_stripDelimitersImplementation, METH_VARARGS},
    {"subscribeToNotification", (PyCFunction)Sbk_QSqlDriverFunc_subscribeToNotification, METH_O},
    {"subscribeToNotificationImplementation", (PyCFunction)Sbk_QSqlDriverFunc_subscribeToNotificationImplementation, METH_O},
    {"subscribedToNotifications", (PyCFunction)Sbk_QSqlDriverFunc_subscribedToNotifications, METH_NOARGS},
    {"subscribedToNotificationsImplementation", (PyCFunction)Sbk_QSqlDriverFunc_subscribedToNotificationsImplementation, METH_NOARGS},
    {"tables", (PyCFunction)Sbk_QSqlDriverFunc_tables, METH_O},
    {"unsubscribeFromNotification", (PyCFunction)Sbk_QSqlDriverFunc_unsubscribeFromNotification, METH_O},
    {"unsubscribeFromNotificationImplementation", (PyCFunction)Sbk_QSqlDriverFunc_unsubscribeFromNotificationImplementation, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSqlDriver_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtSql.QSqlDriver",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSqlDriver_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSqlDriver_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QSqlDriver_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QSqlDriver*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QSqlDriver_Type;
    return 0;
}


void init_QSqlDriver(PyObject* module)
{
    SbkPySide_QtSqlTypes[SBK_QSQLDRIVER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSqlDriver_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSqlDriver_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QSqlDriver_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QSqlDriver_Type, &QSqlDriver::staticMetaObject);    Sbk_QSqlDriver_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QSqlDriver_Type, &Shiboken::callCppDestructor<QSqlDriver >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QSqlDriver_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QSqlDriver_Type, &Sbk_QSqlDriver_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QSqlDriver_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QSqlDriver_Type, "QSqlDriver*");
    PyModule_AddObject(module, "QSqlDriver",
        ((PyObject*)&Sbk_QSqlDriver_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StatementType
    PyTypeObject* SbkPySide_QtSql_QSqlDriver_StatementType = Shiboken::Enum::newType("PySide.QtSql.QSqlDriver.StatementType");
    SbkPySide_QtSqlTypes[SBK_QSQLDRIVER_STATEMENTTYPE_IDX] = SbkPySide_QtSql_QSqlDriver_StatementType;
    if (PyType_Ready(SbkPySide_QtSql_QSqlDriver_StatementType) < 0)
        return;
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,
            "StatementType",((PyObject*)SbkPySide_QtSql_QSqlDriver_StatementType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_StatementType,(long) QSqlDriver::WhereStatement, "WhereStatement");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"WhereStatement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_StatementType->tp_dict,"WhereStatement", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_StatementType,(long) QSqlDriver::SelectStatement, "SelectStatement");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"SelectStatement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_StatementType->tp_dict,"SelectStatement", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_StatementType,(long) QSqlDriver::UpdateStatement, "UpdateStatement");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"UpdateStatement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_StatementType->tp_dict,"UpdateStatement", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_StatementType,(long) QSqlDriver::InsertStatement, "InsertStatement");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"InsertStatement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_StatementType->tp_dict,"InsertStatement", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_StatementType,(long) QSqlDriver::DeleteStatement, "DeleteStatement");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"DeleteStatement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_StatementType->tp_dict,"DeleteStatement", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSqlDriver::StatementType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSqlDriver$ConcreteWrapper::StatementType");
    // end of enum StatementType

    // init enum: IdentifierType
    PyTypeObject* SbkPySide_QtSql_QSqlDriver_IdentifierType = Shiboken::Enum::newType("PySide.QtSql.QSqlDriver.IdentifierType");
    SbkPySide_QtSqlTypes[SBK_QSQLDRIVER_IDENTIFIERTYPE_IDX] = SbkPySide_QtSql_QSqlDriver_IdentifierType;
    if (PyType_Ready(SbkPySide_QtSql_QSqlDriver_IdentifierType) < 0)
        return;
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,
            "IdentifierType",((PyObject*)SbkPySide_QtSql_QSqlDriver_IdentifierType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_IdentifierType,(long) QSqlDriver::FieldName, "FieldName");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"FieldName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_IdentifierType->tp_dict,"FieldName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_IdentifierType,(long) QSqlDriver::TableName, "TableName");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"TableName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_IdentifierType->tp_dict,"TableName", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSqlDriver::IdentifierType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSqlDriver$ConcreteWrapper::IdentifierType");
    // end of enum IdentifierType

    // init enum: DriverFeature
    PyTypeObject* SbkPySide_QtSql_QSqlDriver_DriverFeature = Shiboken::Enum::newType("PySide.QtSql.QSqlDriver.DriverFeature");
    SbkPySide_QtSqlTypes[SBK_QSQLDRIVER_DRIVERFEATURE_IDX] = SbkPySide_QtSql_QSqlDriver_DriverFeature;
    if (PyType_Ready(SbkPySide_QtSql_QSqlDriver_DriverFeature) < 0)
        return;
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,
            "DriverFeature",((PyObject*)SbkPySide_QtSql_QSqlDriver_DriverFeature));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::Transactions, "Transactions");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"Transactions", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"Transactions", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::QuerySize, "QuerySize");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"QuerySize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"QuerySize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::BLOB, "BLOB");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"BLOB", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"BLOB", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::Unicode, "Unicode");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"Unicode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"Unicode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::PreparedQueries, "PreparedQueries");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"PreparedQueries", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"PreparedQueries", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::NamedPlaceholders, "NamedPlaceholders");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"NamedPlaceholders", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"NamedPlaceholders", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::PositionalPlaceholders, "PositionalPlaceholders");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"PositionalPlaceholders", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"PositionalPlaceholders", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::LastInsertId, "LastInsertId");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"LastInsertId", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"LastInsertId", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::BatchOperations, "BatchOperations");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"BatchOperations", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"BatchOperations", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::SimpleLocking, "SimpleLocking");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"SimpleLocking", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"SimpleLocking", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::LowPrecisionNumbers, "LowPrecisionNumbers");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"LowPrecisionNumbers", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"LowPrecisionNumbers", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::EventNotifications, "EventNotifications");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"EventNotifications", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"EventNotifications", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::FinishQuery, "FinishQuery");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"FinishQuery", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"FinishQuery", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlDriver_DriverFeature,(long) QSqlDriver::MultipleResultSets, "MultipleResultSets");
    PyDict_SetItemString(Sbk_QSqlDriver_Type.super.ht_type.tp_dict,"MultipleResultSets", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature->tp_dict,"MultipleResultSets", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSqlDriver::DriverFeature");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSqlDriver$ConcreteWrapper::DriverFeature");
    // end of enum DriverFeature

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("notification", "QString", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QSqlDriver_Type, "notification", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QSqlDriver >("QSqlDriver*");
    Shiboken::TypeResolver::createObjectTypeResolver<QSqlDriver >("QSqlDriver$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QSqlDriver >(typeid(QSqlDriver).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QSqlDriver >(typeid(QSqlDriverWrapper).name());
    PySide::initQtMetaType< ::QSqlDriver* >();
    qRegisterMetaType< ::QSqlDriver::StatementType >("QSqlDriver::StatementType");
    qRegisterMetaType< ::QSqlDriver::IdentifierType >("QSqlDriver::IdentifierType");
    qRegisterMetaType< ::QSqlDriver::DriverFeature >("QSqlDriver::DriverFeature");
}

