/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtsql_python.h"

#include "qsqlrecord_wrapper.h"

// Extra includes
#include <QSqlField>
#include <qsqlfield.h>
#include <qsqlrecord.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSqlRecord_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QSqlRecord >()))
        return -1;

    QSqlRecord* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QSqlRecord", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QSqlRecord()
    // 1: QSqlRecord(QSqlRecord)
    if (numArgs == 0) {
        overloadId = 0; // QSqlRecord()
    } else if (numArgs == 1 && Shiboken::Converter< ::QSqlRecord >::isConvertible(pyargs[0])) {
        overloadId = 1; // QSqlRecord(QSqlRecord)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecord_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSqlRecord()
            {

                if(!PyErr_Occurred()) {
                    // QSqlRecord()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSqlRecord();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QSqlRecord(QSqlRecord)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSqlRecord cppArg0 = Shiboken::Converter<QSqlRecord >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QSqlRecord(QSqlRecord)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSqlRecord(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QSqlRecord >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSqlRecord_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSqlRecord_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtSql.QSqlRecord", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlRecord", overloads);
        return -1;
}

static PyObject* Sbk_QSqlRecordFunc_append(PyObject* self, PyObject* arg)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: append(QSqlField)
    if (Shiboken::Converter< ::QSqlField >::isConvertible(arg)) {
        overloadId = 0; // append(QSqlField)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_append_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSqlField cppArg0 = Shiboken::Converter<QSqlField >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // append(QSqlField)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->append(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlRecordFunc_append_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlField", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlRecord.append", overloads);
        return 0;
}

static PyObject* Sbk_QSqlRecordFunc_clear(PyObject* self)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QSqlRecordFunc_clearValues(PyObject* self)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearValues()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearValues();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QSqlRecordFunc_contains(PyObject* self, PyObject* arg)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // contains(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_contains_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // contains(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QSqlRecord*>(cppSelf)->contains(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlRecordFunc_contains_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlRecord.contains", overloads);
        return 0;
}

static PyObject* Sbk_QSqlRecordFunc_count(PyObject* self)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // count()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QSqlRecord*>(cppSelf)->count();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlRecordFunc_field(PyObject* self, PyObject* arg)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: field(QString)const
    // 1: field(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // field(int)const
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // field(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_field_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // field(QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // field(QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QSqlField cppResult = const_cast<const QSqlRecord*>(cppSelf)->field(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QSqlField >::toPython(cppResult);
                }
                break;
            }
            case 1: // field(int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // field(int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QSqlField cppResult = const_cast<const QSqlRecord*>(cppSelf)->field(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QSqlField >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlRecordFunc_field_TypeError:
        const char* overloads[] = {"QString", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlRecord.field", overloads);
        return 0;
}

static PyObject* Sbk_QSqlRecordFunc_fieldName(PyObject* self, PyObject* arg)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fieldName(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // fieldName(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_fieldName_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fieldName(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QSqlRecord*>(cppSelf)->fieldName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlRecordFunc_fieldName_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlRecord.fieldName", overloads);
        return 0;
}

static PyObject* Sbk_QSqlRecordFunc_indexOf(PyObject* self, PyObject* arg)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOf(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // indexOf(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_indexOf_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // indexOf(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QSqlRecord*>(cppSelf)->indexOf(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlRecordFunc_indexOf_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlRecord.indexOf", overloads);
        return 0;
}

static PyObject* Sbk_QSqlRecordFunc_insert(PyObject* self, PyObject* args)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insert", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insert(int,QSqlField)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QSqlField >::isConvertible(pyargs[1])) {
        overloadId = 0; // insert(int,QSqlField)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_insert_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QSqlField cppArg1 = Shiboken::Converter<QSqlField >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insert(int,QSqlField)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insert(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlRecordFunc_insert_TypeError:
        const char* overloads[] = {"int, PySide.QtSql.QSqlField", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlRecord.insert", overloads);
        return 0;
}

static PyObject* Sbk_QSqlRecordFunc_isEmpty(PyObject* self)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QSqlRecord*>(cppSelf)->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlRecordFunc_isGenerated(PyObject* self, PyObject* arg)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isGenerated(QString)const
    // 1: isGenerated(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // isGenerated(int)const
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // isGenerated(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_isGenerated_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // isGenerated(QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // isGenerated(QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QSqlRecord*>(cppSelf)->isGenerated(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // isGenerated(int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // isGenerated(int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QSqlRecord*>(cppSelf)->isGenerated(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlRecordFunc_isGenerated_TypeError:
        const char* overloads[] = {"QString", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlRecord.isGenerated", overloads);
        return 0;
}

static PyObject* Sbk_QSqlRecordFunc_isNull(PyObject* self, PyObject* arg)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isNull(QString)const
    // 1: isNull(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // isNull(int)const
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // isNull(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_isNull_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // isNull(QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // isNull(QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QSqlRecord*>(cppSelf)->isNull(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // isNull(int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // isNull(int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QSqlRecord*>(cppSelf)->isNull(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlRecordFunc_isNull_TypeError:
        const char* overloads[] = {"QString", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlRecord.isNull", overloads);
        return 0;
}

static PyObject* Sbk_QSqlRecordFunc_remove(PyObject* self, PyObject* arg)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: remove(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // remove(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_remove_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // remove(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->remove(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlRecordFunc_remove_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlRecord.remove", overloads);
        return 0;
}

static PyObject* Sbk_QSqlRecordFunc_replace(PyObject* self, PyObject* args)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replace", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: replace(int,QSqlField)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QSqlField >::isConvertible(pyargs[1])) {
        overloadId = 0; // replace(int,QSqlField)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_replace_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QSqlField cppArg1 = Shiboken::Converter<QSqlField >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // replace(int,QSqlField)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->replace(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlRecordFunc_replace_TypeError:
        const char* overloads[] = {"int, PySide.QtSql.QSqlField", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlRecord.replace", overloads);
        return 0;
}

static PyObject* Sbk_QSqlRecordFunc_setGenerated(PyObject* self, PyObject* args)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setGenerated", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setGenerated(QString,bool)
    // 1: setGenerated(int,bool)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setGenerated(int,bool)
    } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setGenerated(QString,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_setGenerated_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setGenerated(QString,bool)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setGenerated(QString,bool)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setGenerated(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setGenerated(int,bool)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setGenerated(int,bool)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setGenerated(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlRecordFunc_setGenerated_TypeError:
        const char* overloads[] = {"QString, bool", "int, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlRecord.setGenerated", overloads);
        return 0;
}

static PyObject* Sbk_QSqlRecordFunc_setNull(PyObject* self, PyObject* arg)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNull(QString)
    // 1: setNull(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // setNull(int)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setNull(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_setNull_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setNull(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setNull(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setNull(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setNull(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setNull(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setNull(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlRecordFunc_setNull_TypeError:
        const char* overloads[] = {"QString", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlRecord.setNull", overloads);
        return 0;
}

static PyObject* Sbk_QSqlRecordFunc_setValue(PyObject* self, PyObject* args)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setValue", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setValue(QString,QVariant)
    // 1: setValue(int,QVariant)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< QVariant >::isConvertible(pyargs[1])) {
        overloadId = 1; // setValue(int,QVariant)
    } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setValue(QString,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_setValue_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setValue(QString,QVariant)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QVariant cppArg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setValue(QString,QVariant)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setValue(int,QVariant)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QVariant cppArg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setValue(int,QVariant)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlRecordFunc_setValue_TypeError:
        const char* overloads[] = {"QString, QVariant", "int, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlRecord.setValue", overloads);
        return 0;
}

static PyObject* Sbk_QSqlRecordFunc_value(PyObject* self, PyObject* arg)
{
    QSqlRecord* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlRecord* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: value(QString)const
    // 1: value(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // value(int)const
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // value(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlRecordFunc_value_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // value(QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // value(QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVariant cppResult = const_cast<const QSqlRecord*>(cppSelf)->value(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
                }
                break;
            }
            case 1: // value(int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // value(int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVariant cppResult = const_cast<const QSqlRecord*>(cppSelf)->value(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSqlRecordFunc_value_TypeError:
        const char* overloads[] = {"QString", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlRecord.value", overloads);
        return 0;
}

static PyObject *Sbk_QSqlRecord___copy__(PyObject *self)
{
        QSqlRecord* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QSqlRecord*>::toCpp(self);
        PyObject* pyResult = 0;
        QSqlRecord* copy = new QSqlRecord(*cppSelf);
        pyResult = Shiboken::Converter<QSqlRecord*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QSqlRecord_methods[] = {
    {"append", (PyCFunction)Sbk_QSqlRecordFunc_append, METH_O},
    {"clear", (PyCFunction)Sbk_QSqlRecordFunc_clear, METH_NOARGS},
    {"clearValues", (PyCFunction)Sbk_QSqlRecordFunc_clearValues, METH_NOARGS},
    {"contains", (PyCFunction)Sbk_QSqlRecordFunc_contains, METH_O},
    {"count", (PyCFunction)Sbk_QSqlRecordFunc_count, METH_NOARGS},
    {"field", (PyCFunction)Sbk_QSqlRecordFunc_field, METH_O},
    {"fieldName", (PyCFunction)Sbk_QSqlRecordFunc_fieldName, METH_O},
    {"indexOf", (PyCFunction)Sbk_QSqlRecordFunc_indexOf, METH_O},
    {"insert", (PyCFunction)Sbk_QSqlRecordFunc_insert, METH_VARARGS},
    {"isEmpty", (PyCFunction)Sbk_QSqlRecordFunc_isEmpty, METH_NOARGS},
    {"isGenerated", (PyCFunction)Sbk_QSqlRecordFunc_isGenerated, METH_O},
    {"isNull", (PyCFunction)Sbk_QSqlRecordFunc_isNull, METH_O},
    {"remove", (PyCFunction)Sbk_QSqlRecordFunc_remove, METH_O},
    {"replace", (PyCFunction)Sbk_QSqlRecordFunc_replace, METH_VARARGS},
    {"setGenerated", (PyCFunction)Sbk_QSqlRecordFunc_setGenerated, METH_VARARGS},
    {"setNull", (PyCFunction)Sbk_QSqlRecordFunc_setNull, METH_O},
    {"setValue", (PyCFunction)Sbk_QSqlRecordFunc_setValue, METH_VARARGS},
    {"value", (PyCFunction)Sbk_QSqlRecordFunc_value, METH_O},

    {"__copy__", (PyCFunction)Sbk_QSqlRecord___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QSqlRecord_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QSqlRecord& cppSelf = *Shiboken::Converter< QSqlRecord* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QSqlRecord >::isConvertible(arg)) {
                // operator!=(const QSqlRecord & other) const
                QSqlRecord cppArg0 = Shiboken::Converter< ::QSqlRecord >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QSqlRecord_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QSqlRecord >::isConvertible(arg)) {
                // operator==(const QSqlRecord & other) const
                QSqlRecord cppArg0 = Shiboken::Converter< ::QSqlRecord >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QSqlRecord_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QSqlRecord_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QSqlRecord_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QSqlRecord__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QSqlRecord >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtSql.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSqlRecord_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtSql.QSqlRecord",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QSqlRecord__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QSqlRecord_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSqlRecord_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSqlRecord_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSqlRecord(PyObject* module)
{
    SbkPySide_QtSqlTypes[SBK_QSQLRECORD_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSqlRecord_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSqlRecord_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QSqlRecord_Type, &Shiboken::callCppDestructor<QSqlRecord >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QSqlRecord_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QSqlRecord_Type, "QSqlRecord");
    PyModule_AddObject(module, "QSqlRecord",
        ((PyObject*)&Sbk_QSqlRecord_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QSqlRecord >("QSqlRecord");
    Shiboken::TypeResolver::createObjectTypeResolver<QSqlRecord >("QSqlRecord*");
    Shiboken::TypeResolver::createValueTypeResolver<QSqlRecord >(typeid(QSqlRecord).name());
    PySide::initQtMetaType< ::QSqlRecord >();
}

