/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <Python.h>
#include <shiboken.h>
#include <algorithm>
#include "pyside_qtwebkit_python.h"



// Extra includes

// Global functions ------------------------------------------------------------

static PyMethodDef QtWebKit_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_WebCore(PyObject* module);
void init_QWebSecurityOrigin(PyObject* module);
void init_QWebHistory(PyObject* module);
void init_QWebHistoryItem(PyObject* module);
void init_QWebHitTestResult(PyObject* module);
void init_QWebElementCollection(PyObject* module);
void init_QWebElement(PyObject* module);
void init_QWebDatabase(PyObject* module);
void init_QWebSettings(PyObject* module);
void init_QWebInspector(PyObject* module);
void init_QWebPluginFactory(PyObject* module);
void init_QWebPluginFactory_MimeType(PyObject* module);
void init_QWebPluginFactory_Plugin(PyObject* module);
void init_QWebHistoryInterface(PyObject* module);
void init_QWebPage(PyObject* module);
void init_QWebPage_ExtensionOption(PyObject* module);
void init_QWebPage_ErrorPageExtensionOption(PyObject* module);
void init_QWebPage_ChooseMultipleFilesExtensionOption(PyObject* module);
void init_QWebPage_ExtensionReturn(PyObject* module);
void init_QWebPage_ChooseMultipleFilesExtensionReturn(PyObject* module);
void init_QWebPage_ErrorPageExtensionReturn(PyObject* module);
void init_QWebView(PyObject* module);
void init_QWebFrame(PyObject* module);
void init_QGraphicsWebView(PyObject* module);

PyTypeObject** SbkPySide_QtWebKitTypes;

PyTypeObject** SbkPySide_QtCoreTypes;

PyTypeObject** SbkPySide_QtGuiTypes;

PyTypeObject** SbkPySide_QtNetworkTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

extern "C" SBK_EXPORT_MODULE void initQtWebKit()
{
    if (!Shiboken::importModule("PySide.QtCore", &SbkPySide_QtCoreTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtCore");
        return;
    }

    if (!Shiboken::importModule("PySide.QtGui", &SbkPySide_QtGuiTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtGui");
        return;
    }

    if (!Shiboken::importModule("PySide.QtNetwork", &SbkPySide_QtNetworkTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtNetwork");
        return;
    }

    Shiboken::init();
    PyObject* module = Py_InitModule("QtWebKit", QtWebKit_methods);

    // Create a CObject containing the API pointer array's address
    static PyTypeObject* cppApi[SBK_QtWebKit_IDX_COUNT];
    SbkPySide_QtWebKitTypes = cppApi;
    PyObject* cppApiObject = PyCObject_FromVoidPtr(reinterpret_cast<void*>(cppApi), 0);
    PyModule_AddObject(module, "_Cpp_Api", cppApiObject);

    // Initialize classes in the type system
    init_WebCore(module);
    init_QWebSecurityOrigin(module);
    init_QWebHistory(module);
    init_QWebHistoryItem(module);
    init_QWebHitTestResult(module);
    init_QWebElementCollection(module);
    init_QWebElement(module);
    init_QWebDatabase(module);
    init_QWebSettings(module);
    init_QWebInspector(module);
    init_QWebPluginFactory(module);
    init_QWebPluginFactory_MimeType(SbkPySide_QtWebKitTypes[SBK_QWEBPLUGINFACTORY_IDX]->tp_dict);
    init_QWebPluginFactory_Plugin(SbkPySide_QtWebKitTypes[SBK_QWEBPLUGINFACTORY_IDX]->tp_dict);
    init_QWebHistoryInterface(module);
    init_QWebPage(module);
    init_QWebPage_ExtensionOption(SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_IDX]->tp_dict);
    init_QWebPage_ErrorPageExtensionOption(SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_IDX]->tp_dict);
    init_QWebPage_ChooseMultipleFilesExtensionOption(SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_IDX]->tp_dict);
    init_QWebPage_ExtensionReturn(SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_IDX]->tp_dict);
    init_QWebPage_ChooseMultipleFilesExtensionReturn(SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_IDX]->tp_dict);
    init_QWebPage_ErrorPageExtensionReturn(SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_IDX]->tp_dict);
    init_QWebView(module);
    init_QWebFrame(module);
    init_QGraphicsWebView(module);

    // Register primitive types on TypeResolver

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtWebKit");
    }
}

