/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtwebkit_python.h"

#include "qwebpluginfactory_plugin_wrapper.h"

// Extra includes



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebPluginFactory_Plugin_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QWebPluginFactory::Plugin >()))
        return -1;

    QWebPluginFactory::Plugin* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "Plugin", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: Plugin()
    // 1: Plugin(QWebPluginFactory::Plugin)
    if (numArgs == 0) {
        overloadId = 0; // Plugin()
    } else if (numArgs == 1 && Shiboken::Converter< ::QWebPluginFactory::Plugin >::isConvertible(pyargs[0])) {
        overloadId = 1; // Plugin(QWebPluginFactory::Plugin)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPluginFactory_Plugin_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // Plugin()
            {

                if(!PyErr_Occurred()) {
                    // Plugin()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QWebPluginFactory::Plugin();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // Plugin(QWebPluginFactory::Plugin)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QWebPluginFactory::Plugin cppArg0 = Shiboken::Converter<QWebPluginFactory::Plugin >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // Plugin(QWebPluginFactory::Plugin)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QWebPluginFactory::Plugin(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QWebPluginFactory::Plugin >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QWebPluginFactory_Plugin_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QWebPluginFactory_Plugin_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtWebKit.QWebPluginFactory::Plugin", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.Plugin", overloads);
        return -1;
}

static PyObject *Sbk_QWebPluginFactory_Plugin___copy__(PyObject *self)
{
        QWebPluginFactory::Plugin* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QWebPluginFactory::Plugin*>::toCpp(self);
        PyObject* pyResult = 0;
        QWebPluginFactory::Plugin* copy = new QWebPluginFactory::Plugin(*cppSelf);
        pyResult = Shiboken::Converter<QWebPluginFactory::Plugin*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QWebPluginFactory_Plugin_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QWebPluginFactory_Plugin___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QWebPluginFactory_Plugin_get_description(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< QString >::toPython( Shiboken::Converter< QWebPluginFactory::Plugin* >::toCpp(self)->description);
    return val;
}

static int Sbk_QWebPluginFactory_Plugin_set_description(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'description' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'description', 'QString' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QWebPluginFactory::Plugin* >::toCpp(self)->description = Shiboken::Converter< QString >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QWebPluginFactory_Plugin_get_name(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< QString >::toPython( Shiboken::Converter< QWebPluginFactory::Plugin* >::toCpp(self)->name);
    return val;
}

static int Sbk_QWebPluginFactory_Plugin_set_name(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'name' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'name', 'QString' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QWebPluginFactory::Plugin* >::toCpp(self)->name = Shiboken::Converter< QString >::toCpp(value);

    return 0;
}

// Getters and Setters for Plugin
static PyGetSetDef Sbk_QWebPluginFactory_Plugin_getsetlist[] = {
    {const_cast<char*>("description"), Sbk_QWebPluginFactory_Plugin_get_description, Sbk_QWebPluginFactory_Plugin_set_description},
    {const_cast<char*>("name"), Sbk_QWebPluginFactory_Plugin_get_name, Sbk_QWebPluginFactory_Plugin_set_name},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QWebPluginFactory_Plugin_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.QWebPluginFactory.Plugin",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QWebPluginFactory_Plugin_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QWebPluginFactory_Plugin_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QWebPluginFactory_Plugin_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QWebPluginFactory_Plugin(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBPLUGINFACTORY_PLUGIN_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QWebPluginFactory_Plugin_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QWebPluginFactory_Plugin_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QWebPluginFactory_Plugin_Type, &Shiboken::callCppDestructor<QWebPluginFactory::Plugin >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QWebPluginFactory_Plugin_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QWebPluginFactory_Plugin_Type, "QWebPluginFactory::Plugin");
    PyDict_SetItemString(module,"Plugin", (PyObject*)&Sbk_QWebPluginFactory_Plugin_Type);

    Shiboken::TypeResolver::createValueTypeResolver<QWebPluginFactory::Plugin >("QWebPluginFactory::Plugin");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebPluginFactory::Plugin >("QWebPluginFactory::Plugin*");
    Shiboken::TypeResolver::createValueTypeResolver<QWebPluginFactory::Plugin >(typeid(QWebPluginFactory::Plugin).name());
    PySide::initQtMetaType< ::QWebPluginFactory::Plugin >();
}

