/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtwebkit_python.h"

#include "qwebsecurityorigin_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qwebdatabase.h>
#include <qwebsecurityorigin.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebSecurityOrigin_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QWebSecurityOrigin >()))
        return -1;

    QWebSecurityOrigin* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QWebSecurityOrigin", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QWebSecurityOrigin(QWebSecurityOrigin)
    if (numArgs == 1 && Shiboken::Converter< ::QWebSecurityOrigin >::isConvertible(pyargs[0])) {
        overloadId = 0; // QWebSecurityOrigin(QWebSecurityOrigin)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSecurityOrigin_Init_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QWebSecurityOrigin cppArg0 = Shiboken::Converter<QWebSecurityOrigin >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
                // QWebSecurityOrigin(QWebSecurityOrigin)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QWebSecurityOrigin(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QWebSecurityOrigin >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QWebSecurityOrigin_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QWebSecurityOrigin_Init_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSecurityOrigin", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebSecurityOrigin", overloads);
        return -1;
}

static PyObject* Sbk_QWebSecurityOriginFunc_addLocalScheme(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addLocalScheme(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // addLocalScheme(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSecurityOriginFunc_addLocalScheme_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addLocalScheme(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSecurityOrigin::addLocalScheme(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSecurityOriginFunc_addLocalScheme_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSecurityOrigin.addLocalScheme", overloads);
        return 0;
}

static PyObject* Sbk_QWebSecurityOriginFunc_allOrigins(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // allOrigins()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QWebSecurityOrigin > cppResult = QWebSecurityOrigin::allOrigins();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QWebSecurityOrigin > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSecurityOriginFunc_databaseQuota(PyObject* self)
{
    QWebSecurityOrigin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSecurityOrigin* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // databaseQuota()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QWebSecurityOrigin*>(cppSelf)->databaseQuota();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSecurityOriginFunc_databaseUsage(PyObject* self)
{
    QWebSecurityOrigin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSecurityOrigin* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // databaseUsage()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QWebSecurityOrigin*>(cppSelf)->databaseUsage();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSecurityOriginFunc_databases(PyObject* self)
{
    QWebSecurityOrigin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSecurityOrigin* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // databases()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QWebDatabase > cppResult = const_cast<const QWebSecurityOrigin*>(cppSelf)->databases();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QWebDatabase > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSecurityOriginFunc_host(PyObject* self)
{
    QWebSecurityOrigin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSecurityOrigin* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // host()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWebSecurityOrigin*>(cppSelf)->host();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSecurityOriginFunc_localSchemes(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // localSchemes()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = QWebSecurityOrigin::localSchemes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSecurityOriginFunc_port(PyObject* self)
{
    QWebSecurityOrigin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSecurityOrigin* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // port()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QWebSecurityOrigin*>(cppSelf)->port();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSecurityOriginFunc_removeLocalScheme(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeLocalScheme(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // removeLocalScheme(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSecurityOriginFunc_removeLocalScheme_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeLocalScheme(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSecurityOrigin::removeLocalScheme(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSecurityOriginFunc_removeLocalScheme_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSecurityOrigin.removeLocalScheme", overloads);
        return 0;
}

static PyObject* Sbk_QWebSecurityOriginFunc_scheme(PyObject* self)
{
    QWebSecurityOrigin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSecurityOrigin* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // scheme()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWebSecurityOrigin*>(cppSelf)->scheme();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSecurityOriginFunc_setDatabaseQuota(PyObject* self, PyObject* arg)
{
    QWebSecurityOrigin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSecurityOrigin* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDatabaseQuota(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDatabaseQuota(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSecurityOriginFunc_setDatabaseQuota_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDatabaseQuota(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDatabaseQuota(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSecurityOriginFunc_setDatabaseQuota_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSecurityOrigin.setDatabaseQuota", overloads);
        return 0;
}

static PyObject *Sbk_QWebSecurityOrigin___copy__(PyObject *self)
{
        QWebSecurityOrigin* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QWebSecurityOrigin*>::toCpp(self);
        PyObject* pyResult = 0;
        QWebSecurityOrigin* copy = new QWebSecurityOrigin(*cppSelf);
        pyResult = Shiboken::Converter<QWebSecurityOrigin*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QWebSecurityOrigin_methods[] = {
    {"addLocalScheme", (PyCFunction)Sbk_QWebSecurityOriginFunc_addLocalScheme, METH_O|METH_STATIC},
    {"allOrigins", (PyCFunction)Sbk_QWebSecurityOriginFunc_allOrigins, METH_NOARGS|METH_STATIC},
    {"databaseQuota", (PyCFunction)Sbk_QWebSecurityOriginFunc_databaseQuota, METH_NOARGS},
    {"databaseUsage", (PyCFunction)Sbk_QWebSecurityOriginFunc_databaseUsage, METH_NOARGS},
    {"databases", (PyCFunction)Sbk_QWebSecurityOriginFunc_databases, METH_NOARGS},
    {"host", (PyCFunction)Sbk_QWebSecurityOriginFunc_host, METH_NOARGS},
    {"localSchemes", (PyCFunction)Sbk_QWebSecurityOriginFunc_localSchemes, METH_NOARGS|METH_STATIC},
    {"port", (PyCFunction)Sbk_QWebSecurityOriginFunc_port, METH_NOARGS},
    {"removeLocalScheme", (PyCFunction)Sbk_QWebSecurityOriginFunc_removeLocalScheme, METH_O|METH_STATIC},
    {"scheme", (PyCFunction)Sbk_QWebSecurityOriginFunc_scheme, METH_NOARGS},
    {"setDatabaseQuota", (PyCFunction)Sbk_QWebSecurityOriginFunc_setDatabaseQuota, METH_O},

    {"__copy__", (PyCFunction)Sbk_QWebSecurityOrigin___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QWebSecurityOrigin_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.QWebSecurityOrigin",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QWebSecurityOrigin_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QWebSecurityOrigin_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QWebSecurityOrigin(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBSECURITYORIGIN_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QWebSecurityOrigin_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QWebSecurityOrigin_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QWebSecurityOrigin_Type, &Shiboken::callCppDestructor<QWebSecurityOrigin >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QWebSecurityOrigin_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QWebSecurityOrigin_Type, "QWebSecurityOrigin");
    PyModule_AddObject(module, "QWebSecurityOrigin",
        ((PyObject*)&Sbk_QWebSecurityOrigin_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QWebSecurityOrigin >("QWebSecurityOrigin");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebSecurityOrigin >("QWebSecurityOrigin*");
    Shiboken::TypeResolver::createValueTypeResolver<QWebSecurityOrigin >(typeid(QWebSecurityOrigin).name());
    PySide::initQtMetaType< ::QWebSecurityOrigin >();
}

