/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomdocumentfragment_wrapper.h"

// Extra includes
#include <qdom.h>
#include <qtextstream.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomDocumentFragment_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDomDocumentFragment >()))
        return -1;

    QDomDocumentFragment* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDomDocumentFragment", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QDomDocumentFragment()
    // 1: QDomDocumentFragment(QDomDocumentFragment)
    if (numArgs == 0) {
        overloadId = 0; // QDomDocumentFragment()
    } else if (numArgs == 1 && Shiboken::Converter< ::QDomDocumentFragment >::isConvertible(pyargs[0])) {
        overloadId = 1; // QDomDocumentFragment(QDomDocumentFragment)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomDocumentFragment_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDomDocumentFragment()
            {

                if(!PyErr_Occurred()) {
                    // QDomDocumentFragment()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDomDocumentFragment();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QDomDocumentFragment(QDomDocumentFragment)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDomDocumentFragment cppArg0 = Shiboken::Converter<QDomDocumentFragment >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDomDocumentFragment(QDomDocumentFragment)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDomDocumentFragment(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDomDocumentFragment >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDomDocumentFragment_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDomDocumentFragment_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomDocumentFragment", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomDocumentFragment", overloads);
        return -1;
}

static PyObject *Sbk_QDomDocumentFragment___copy__(PyObject *self)
{
        QDomDocumentFragment* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QDomDocumentFragment*>::toCpp(self);
        PyObject* pyResult = 0;
        QDomDocumentFragment* copy = new QDomDocumentFragment(*cppSelf);
        pyResult = Shiboken::Converter<QDomDocumentFragment*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QDomDocumentFragment_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QDomDocumentFragment___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QDomDocumentFragment___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QDomDocumentFragment* cppSelf = Shiboken::Converter< ::QDomDocumentFragment*>::toCpp(pyObj);
    int result;
    Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    Py_END_ALLOW_THREADS
    return result;
}

// type has number operators
static PyNumberMethods Sbk_QDomDocumentFragment_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QDomDocumentFragment___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDomDocumentFragment_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomDocumentFragment",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QDomDocumentFragment_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDomDocumentFragment_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDomDocumentFragment_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QDomDocumentFragment(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMDOCUMENTFRAGMENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDomDocumentFragment_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDomDocumentFragment_Type);
    Sbk_QDomDocumentFragment_Type.super.ht_type.tp_base = SbkPySide_QtXmlTypes[SBK_QDOMNODE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDomDocumentFragment_Type, &Shiboken::callCppDestructor<QDomDocumentFragment >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDomDocumentFragment_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QDomDocumentFragment_Type, "QDomDocumentFragment");
    PyModule_AddObject(module, "QDomDocumentFragment",
        ((PyObject*)&Sbk_QDomDocumentFragment_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDomDocumentFragment >("QDomDocumentFragment");
    Shiboken::TypeResolver::createObjectTypeResolver<QDomDocumentFragment >("QDomDocumentFragment*");
    Shiboken::TypeResolver::createValueTypeResolver<QDomDocumentFragment >(typeid(QDomDocumentFragment).name());
    PySide::initQtMetaType< ::QDomDocumentFragment >();
}

