/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qxmlsimplereader_wrapper.h"

// Extra includes
#include <qxml.h>


// Native ---------------------------------------------------------

QXmlDTDHandler * QXmlSimpleReaderWrapper::DTDHandler() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "DTDHandler"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::DTDHandler();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QXmlDTDHandler * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.DTDHandler", Shiboken::SbkType<QXmlDTDHandler >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QXmlDTDHandler * cppResult(Shiboken::Converter< ::QXmlDTDHandler * >::toCpp(pyResult));
    return cppResult;
}

QXmlSimpleReaderWrapper::QXmlSimpleReaderWrapper() : QXmlSimpleReader() {
    // ... middle
}

QXmlContentHandler * QXmlSimpleReaderWrapper::contentHandler() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contentHandler"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::contentHandler();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QXmlContentHandler * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.contentHandler", Shiboken::SbkType<QXmlContentHandler >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QXmlContentHandler * cppResult(Shiboken::Converter< ::QXmlContentHandler * >::toCpp(pyResult));
    return cppResult;
}

QXmlDeclHandler * QXmlSimpleReaderWrapper::declHandler() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "declHandler"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::declHandler();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QXmlDeclHandler * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.declHandler", Shiboken::SbkType<QXmlDeclHandler >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QXmlDeclHandler * cppResult(Shiboken::Converter< ::QXmlDeclHandler * >::toCpp(pyResult));
    return cppResult;
}

QXmlEntityResolver * QXmlSimpleReaderWrapper::entityResolver() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "entityResolver"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::entityResolver();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QXmlEntityResolver * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.entityResolver", Shiboken::SbkType<QXmlEntityResolver >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QXmlEntityResolver * cppResult(Shiboken::Converter< ::QXmlEntityResolver * >::toCpp(pyResult));
    return cppResult;
}

QXmlErrorHandler * QXmlSimpleReaderWrapper::errorHandler() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "errorHandler"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::errorHandler();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QXmlErrorHandler * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.errorHandler", Shiboken::SbkType<QXmlErrorHandler >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QXmlErrorHandler * cppResult(Shiboken::Converter< ::QXmlErrorHandler * >::toCpp(pyResult));
    return cppResult;
}

bool QXmlSimpleReaderWrapper::feature(const QString & name, bool * ok) const
{

    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "feature"));
    if (py_override.isNull()) {

        gil.release();
        return this->::QXmlSimpleReader::feature(name, ok);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(name)
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PySequence_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.feature", "PySequence", pyResult->ob_type->tp_name);
        return bool(0);
    }
    // Begin code injection

    // TEMPLATE - fix_virtual_method_return_value_and_bool* - START
    Shiboken::AutoDecRef _py_ret_(PySequence_GetItem(pyResult, 0));
    Shiboken::AutoDecRef _py_ok_(PySequence_GetItem(pyResult, 1));
    bool cppResult = Shiboken::Converter<bool >::toCpp(_py_ret_);
    *ok = Shiboken::Converter<bool >::toCpp(_py_ok_);
    // TEMPLATE - fix_virtual_method_return_value_and_bool* - END

    // End of code injection

    return cppResult;
}

bool QXmlSimpleReaderWrapper::hasFeature(const QString & name) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hasFeature"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::hasFeature(name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.hasFeature", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QXmlSimpleReaderWrapper::hasProperty(const QString & name) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hasProperty"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::hasProperty(name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.hasProperty", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QXmlLexicalHandler * QXmlSimpleReaderWrapper::lexicalHandler() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "lexicalHandler"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::lexicalHandler();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QXmlLexicalHandler * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.lexicalHandler", Shiboken::SbkType<QXmlLexicalHandler >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QXmlLexicalHandler * cppResult(Shiboken::Converter< ::QXmlLexicalHandler * >::toCpp(pyResult));
    return cppResult;
}

bool QXmlSimpleReaderWrapper::parse(const QXmlInputSource & input)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "parse"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::parse(input);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlInputSource >::toPython(input)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.parse", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QXmlSimpleReaderWrapper::parse(const QXmlInputSource * input)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "parse"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::parse(input);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlInputSource * >::toPython(input)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.parse", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QXmlSimpleReaderWrapper::parse(const QXmlInputSource * input, bool incremental)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "parse"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::parse(input, incremental);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QXmlInputSource * >::toPython(input),
        Shiboken::Converter< bool >::toPython(incremental)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.parse", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QXmlSimpleReaderWrapper::parseContinue()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "parseContinue"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::parseContinue();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.parseContinue", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void * QXmlSimpleReaderWrapper::property(const QString & name, bool * ok) const
{

    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "property"));
    if (py_override.isNull()) {

        gil.release();
        return this->::QXmlSimpleReader::property(name, ok);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(name)
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = PySequence_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.property", "PySequence", pyResult->ob_type->tp_name);
        return 0;
    }
    // Begin code injection

    // TEMPLATE - fix_virtual_method_return_value_and_bool* - START
    Shiboken::AutoDecRef _py_ret_(PySequence_GetItem(pyResult, 0));
    Shiboken::AutoDecRef _py_ok_(PySequence_GetItem(pyResult, 1));
    void * cppResult = Shiboken::Converter<void * >::toCpp(_py_ret_);
    *ok = Shiboken::Converter<bool >::toCpp(_py_ok_);
    // TEMPLATE - fix_virtual_method_return_value_and_bool* - END

    // End of code injection

    return cppResult;
}

void QXmlSimpleReaderWrapper::setContentHandler(QXmlContentHandler * handler)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setContentHandler"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::setContentHandler(handler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlContentHandler * >::toPython(handler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSimpleReaderWrapper::setDTDHandler(QXmlDTDHandler * handler)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setDTDHandler"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::setDTDHandler(handler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlDTDHandler * >::toPython(handler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSimpleReaderWrapper::setDeclHandler(QXmlDeclHandler * handler)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setDeclHandler"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::setDeclHandler(handler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlDeclHandler * >::toPython(handler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSimpleReaderWrapper::setEntityResolver(QXmlEntityResolver * handler)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setEntityResolver"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::setEntityResolver(handler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlEntityResolver * >::toPython(handler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSimpleReaderWrapper::setErrorHandler(QXmlErrorHandler * handler)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setErrorHandler"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::setErrorHandler(handler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlErrorHandler * >::toPython(handler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSimpleReaderWrapper::setFeature(const QString & name, bool value)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setFeature"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::setFeature(name, value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< QString >::toPython(name),
        Shiboken::Converter< bool >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSimpleReaderWrapper::setLexicalHandler(QXmlLexicalHandler * handler)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setLexicalHandler"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::setLexicalHandler(handler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlLexicalHandler * >::toPython(handler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSimpleReaderWrapper::setProperty(const QString & name, void * value)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setProperty"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSimpleReader::setProperty(name, value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< QString >::toPython(name),
        Shiboken::Converter< void * >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QXmlSimpleReaderWrapper::~QXmlSimpleReaderWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject* Sbk_QXmlSimpleReaderFunc_DTDHandler(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // DTDHandler()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlDTDHandler * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QXmlSimpleReader*>(cppSelf)->::QXmlSimpleReader::DTDHandler() : const_cast<const QXmlSimpleReader*>(cppSelf)->DTDHandler());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlDTDHandler * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static int
Sbk_QXmlSimpleReader_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlSimpleReader >()))
        return -1;

    QXmlSimpleReaderWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QXmlSimpleReader()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QXmlSimpleReaderWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlSimpleReader >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_contentHandler(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // contentHandler()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlContentHandler * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QXmlSimpleReader*>(cppSelf)->::QXmlSimpleReader::contentHandler() : const_cast<const QXmlSimpleReader*>(cppSelf)->contentHandler());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlContentHandler * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_declHandler(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // declHandler()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlDeclHandler * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QXmlSimpleReader*>(cppSelf)->::QXmlSimpleReader::declHandler() : const_cast<const QXmlSimpleReader*>(cppSelf)->declHandler());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlDeclHandler * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_entityResolver(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // entityResolver()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlEntityResolver * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QXmlSimpleReader*>(cppSelf)->::QXmlSimpleReader::entityResolver() : const_cast<const QXmlSimpleReader*>(cppSelf)->entityResolver());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlEntityResolver * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_errorHandler(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorHandler()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlErrorHandler * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QXmlSimpleReader*>(cppSelf)->::QXmlSimpleReader::errorHandler() : const_cast<const QXmlSimpleReader*>(cppSelf)->errorHandler());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlErrorHandler * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_feature(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: feature(QString,bool*)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // feature(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSimpleReaderFunc_feature_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // feature(QString,bool*)const
                // Begin code injection

                // TEMPLATE - fix_args,bool* - START
                bool ok_;
                bool retval_ = cppSelf->feature(cppArg0, &ok_);
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_args,bool* - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlSimpleReaderFunc_feature_TypeError:
        const char* overloads[] = {"QString, bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.feature", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_hasFeature(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasFeature(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // hasFeature(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSimpleReaderFunc_hasFeature_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hasFeature(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QXmlSimpleReader*>(cppSelf)->::QXmlSimpleReader::hasFeature(cppArg0) : const_cast<const QXmlSimpleReader*>(cppSelf)->hasFeature(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlSimpleReaderFunc_hasFeature_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.hasFeature", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_hasProperty(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasProperty(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // hasProperty(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSimpleReaderFunc_hasProperty_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hasProperty(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QXmlSimpleReader*>(cppSelf)->::QXmlSimpleReader::hasProperty(cppArg0) : const_cast<const QXmlSimpleReader*>(cppSelf)->hasProperty(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlSimpleReaderFunc_hasProperty_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.hasProperty", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_lexicalHandler(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lexicalHandler()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlLexicalHandler * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QXmlSimpleReader*>(cppSelf)->::QXmlSimpleReader::lexicalHandler() : const_cast<const QXmlSimpleReader*>(cppSelf)->lexicalHandler());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlLexicalHandler * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_parse(PyObject* self, PyObject* args)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "parse", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: parse(QXmlInputSource)
    // 1: parse(const QXmlInputSource*)
    // 2: parse(const QXmlInputSource*,bool)
    if (Shiboken::Converter< ::QXmlInputSource >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // parse(QXmlInputSource)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 2; // parse(const QXmlInputSource*,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSimpleReaderFunc_parse_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // parse(QXmlInputSource)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                const QXmlInputSource & cppArg0 = Shiboken::Converter<const QXmlInputSource & >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // parse(QXmlInputSource)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSimpleReader::parse(cppArg0) : cppSelf->parse(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // parse(const QXmlInputSource*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QXmlInputSource * cppArg0 = Shiboken::Converter<QXmlInputSource * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // parse(const QXmlInputSource*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSimpleReader::parse(cppArg0) : cppSelf->parse(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // parse(const QXmlInputSource*,bool)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QXmlInputSource * cppArg0 = Shiboken::Converter<QXmlInputSource * >::toCpp(pyargs[0]);
                bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // parse(const QXmlInputSource*,bool)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSimpleReader::parse(cppArg0, cppArg1) : cppSelf->parse(cppArg0, cppArg1));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlSimpleReaderFunc_parse_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlInputSource", "PySide.QtXml.QXmlInputSource", "PySide.QtXml.QXmlInputSource, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlSimpleReader.parse", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_parseContinue(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // parseContinue()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSimpleReader::parseContinue() : cppSelf->parseContinue());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_property(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: property(QString,bool*)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // property(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSimpleReaderFunc_property_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // property(QString,bool*)const
                // Begin code injection

                // TEMPLATE - fix_args,bool* - START
                bool ok_;
                void * retval_ = cppSelf->property(cppArg0, &ok_);
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_args,bool* - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlSimpleReaderFunc_property_TypeError:
        const char* overloads[] = {"QString, bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.property", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_setContentHandler(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setContentHandler(QXmlContentHandler*)
    if (Shiboken::Converter< ::QXmlContentHandler * >::isConvertible(arg)) {
        overloadId = 0; // setContentHandler(QXmlContentHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSimpleReaderFunc_setContentHandler_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlContentHandler * cppArg0 = Shiboken::Converter<QXmlContentHandler * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setContentHandler(QXmlContentHandler*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSimpleReader::setContentHandler(cppArg0) : cppSelf->setContentHandler(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSimpleReaderFunc_setContentHandler_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlContentHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.setContentHandler", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_setDTDHandler(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDTDHandler(QXmlDTDHandler*)
    if (Shiboken::Converter< ::QXmlDTDHandler * >::isConvertible(arg)) {
        overloadId = 0; // setDTDHandler(QXmlDTDHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSimpleReaderFunc_setDTDHandler_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlDTDHandler * cppArg0 = Shiboken::Converter<QXmlDTDHandler * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDTDHandler(QXmlDTDHandler*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSimpleReader::setDTDHandler(cppArg0) : cppSelf->setDTDHandler(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSimpleReaderFunc_setDTDHandler_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlDTDHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.setDTDHandler", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_setDeclHandler(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDeclHandler(QXmlDeclHandler*)
    if (Shiboken::Converter< ::QXmlDeclHandler * >::isConvertible(arg)) {
        overloadId = 0; // setDeclHandler(QXmlDeclHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSimpleReaderFunc_setDeclHandler_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlDeclHandler * cppArg0 = Shiboken::Converter<QXmlDeclHandler * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDeclHandler(QXmlDeclHandler*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSimpleReader::setDeclHandler(cppArg0) : cppSelf->setDeclHandler(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSimpleReaderFunc_setDeclHandler_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlDeclHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.setDeclHandler", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_setEntityResolver(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEntityResolver(QXmlEntityResolver*)
    if (Shiboken::Converter< ::QXmlEntityResolver * >::isConvertible(arg)) {
        overloadId = 0; // setEntityResolver(QXmlEntityResolver*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSimpleReaderFunc_setEntityResolver_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlEntityResolver * cppArg0 = Shiboken::Converter<QXmlEntityResolver * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEntityResolver(QXmlEntityResolver*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSimpleReader::setEntityResolver(cppArg0) : cppSelf->setEntityResolver(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSimpleReaderFunc_setEntityResolver_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlEntityResolver", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.setEntityResolver", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_setErrorHandler(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setErrorHandler(QXmlErrorHandler*)
    if (Shiboken::Converter< ::QXmlErrorHandler * >::isConvertible(arg)) {
        overloadId = 0; // setErrorHandler(QXmlErrorHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSimpleReaderFunc_setErrorHandler_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlErrorHandler * cppArg0 = Shiboken::Converter<QXmlErrorHandler * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setErrorHandler(QXmlErrorHandler*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSimpleReader::setErrorHandler(cppArg0) : cppSelf->setErrorHandler(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSimpleReaderFunc_setErrorHandler_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlErrorHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.setErrorHandler", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_setFeature(PyObject* self, PyObject* args)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFeature", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFeature(QString,bool)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setFeature(QString,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSimpleReaderFunc_setFeature_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setFeature(QString,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSimpleReader::setFeature(cppArg0, cppArg1) : cppSelf->setFeature(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSimpleReaderFunc_setFeature_TypeError:
        const char* overloads[] = {"QString, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlSimpleReader.setFeature", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_setLexicalHandler(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLexicalHandler(QXmlLexicalHandler*)
    if (Shiboken::Converter< ::QXmlLexicalHandler * >::isConvertible(arg)) {
        overloadId = 0; // setLexicalHandler(QXmlLexicalHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSimpleReaderFunc_setLexicalHandler_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlLexicalHandler * cppArg0 = Shiboken::Converter<QXmlLexicalHandler * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLexicalHandler(QXmlLexicalHandler*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSimpleReader::setLexicalHandler(cppArg0) : cppSelf->setLexicalHandler(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSimpleReaderFunc_setLexicalHandler_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlLexicalHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.setLexicalHandler", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSimpleReaderFunc_setProperty(PyObject* self, PyObject* args)
{
    QXmlSimpleReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setProperty", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setProperty(QString,void*)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< void * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setProperty(QString,void*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSimpleReaderFunc_setProperty_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            void * cppArg1 = Shiboken::Converter<void * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setProperty(QString,void*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSimpleReader::setProperty(cppArg0, cppArg1) : cppSelf->setProperty(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSimpleReaderFunc_setProperty_TypeError:
        const char* overloads[] = {"QString, void", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlSimpleReader.setProperty", overloads);
        return 0;
}

static PyMethodDef Sbk_QXmlSimpleReader_methods[] = {
    {"DTDHandler", (PyCFunction)Sbk_QXmlSimpleReaderFunc_DTDHandler, METH_NOARGS},
    {"contentHandler", (PyCFunction)Sbk_QXmlSimpleReaderFunc_contentHandler, METH_NOARGS},
    {"declHandler", (PyCFunction)Sbk_QXmlSimpleReaderFunc_declHandler, METH_NOARGS},
    {"entityResolver", (PyCFunction)Sbk_QXmlSimpleReaderFunc_entityResolver, METH_NOARGS},
    {"errorHandler", (PyCFunction)Sbk_QXmlSimpleReaderFunc_errorHandler, METH_NOARGS},
    {"feature", (PyCFunction)Sbk_QXmlSimpleReaderFunc_feature, METH_O},
    {"hasFeature", (PyCFunction)Sbk_QXmlSimpleReaderFunc_hasFeature, METH_O},
    {"hasProperty", (PyCFunction)Sbk_QXmlSimpleReaderFunc_hasProperty, METH_O},
    {"lexicalHandler", (PyCFunction)Sbk_QXmlSimpleReaderFunc_lexicalHandler, METH_NOARGS},
    {"parse", (PyCFunction)Sbk_QXmlSimpleReaderFunc_parse, METH_VARARGS},
    {"parseContinue", (PyCFunction)Sbk_QXmlSimpleReaderFunc_parseContinue, METH_NOARGS},
    {"property", (PyCFunction)Sbk_QXmlSimpleReaderFunc_property, METH_O},
    {"setContentHandler", (PyCFunction)Sbk_QXmlSimpleReaderFunc_setContentHandler, METH_O},
    {"setDTDHandler", (PyCFunction)Sbk_QXmlSimpleReaderFunc_setDTDHandler, METH_O},
    {"setDeclHandler", (PyCFunction)Sbk_QXmlSimpleReaderFunc_setDeclHandler, METH_O},
    {"setEntityResolver", (PyCFunction)Sbk_QXmlSimpleReaderFunc_setEntityResolver, METH_O},
    {"setErrorHandler", (PyCFunction)Sbk_QXmlSimpleReaderFunc_setErrorHandler, METH_O},
    {"setFeature", (PyCFunction)Sbk_QXmlSimpleReaderFunc_setFeature, METH_VARARGS},
    {"setLexicalHandler", (PyCFunction)Sbk_QXmlSimpleReaderFunc_setLexicalHandler, METH_O},
    {"setProperty", (PyCFunction)Sbk_QXmlSimpleReaderFunc_setProperty, METH_VARARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlSimpleReader_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QXmlSimpleReader",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlSimpleReader_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlSimpleReader_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QXmlSimpleReader_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QXmlReader >()) && dynamic_cast<QXmlSimpleReader*>(reinterpret_cast<QXmlReader*>(cptr)))
        return &Sbk_QXmlSimpleReader_Type;
    return 0;
}


void init_QXmlSimpleReader(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QXMLSIMPLEREADER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlSimpleReader_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QXmlSimpleReader_Type);
    Sbk_QXmlSimpleReader_Type.super.ht_type.tp_base = SbkPySide_QtXmlTypes[SBK_QXMLREADER_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QXmlSimpleReader_Type, &Shiboken::callCppDestructor<QXmlSimpleReader >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QXmlSimpleReader_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QXmlSimpleReader_Type, &Sbk_QXmlSimpleReader_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtXmlTypes[SBK_QXMLREADER_IDX]), &Sbk_QXmlSimpleReader_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QXmlSimpleReader_Type, "QXmlSimpleReader*");
    PyModule_AddObject(module, "QXmlSimpleReader",
        ((PyObject*)&Sbk_QXmlSimpleReader_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSimpleReader >("QXmlSimpleReader*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSimpleReader >(typeid(QXmlSimpleReader).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSimpleReader >(typeid(QXmlSimpleReaderWrapper).name());
    PySide::initQtMetaType< ::QXmlSimpleReader* >();
}

