/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qxmlname_wrapper.h"

// Extra includes
#include <qxmlname.h>
#include <qxmlnamepool.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlName_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlName >()))
        return -1;

    QXmlName* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlName(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QXmlName", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlName()
    // 1: QXmlName(QXmlNamePool&,QString,QString,QString)
    // 2: QXmlName(QXmlName)
    if (numArgs == 0) {
        overloadId = 0; // QXmlName()
    } else if (numArgs == 1 && Shiboken::Converter< ::QXmlName >::isConvertible(pyargs[0])) {
        overloadId = 2; // QXmlName(QXmlName)
    } else if (numArgs >= 2 && Shiboken::Converter< ::QXmlNamePool & >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // QXmlName(QXmlNamePool&,QString,QString,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // QXmlName(QXmlNamePool&,QString,QString,QString)
            } else if (Shiboken::Converter< QString >::isConvertible(pyargs[3])) {
                overloadId = 1; // QXmlName(QXmlNamePool&,QString,QString,QString)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlName_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlName()
            {

                if(!PyErr_Occurred()) {
                    // QXmlName()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlName();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QXmlName(QXmlNamePool&,QString,QString,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "namespaceURI");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "namespaceURI";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QXmlName_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "prefix");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "prefix";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QXmlName_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlName(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QXmlNamePool & cppArg0 = Shiboken::Converter<QXmlNamePool & >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cppArg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
                QString cppArg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();

                if(!PyErr_Occurred()) {
                    // QXmlName(QXmlNamePool&,QString,QString,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlName(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QXmlName(QXmlName)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QXmlName(QXmlName)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlName(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlName >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QXmlName_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QXmlName_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXmlPatterns.QXmlNamePool, QString, QString = QString(), QString = QString()", "PySide.QtXmlPatterns.QXmlName", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlName", overloads);
        return -1;
}

static PyObject* Sbk_QXmlNameFunc_fromClarkName(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fromClarkName", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromClarkName(QString,QXmlNamePool)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QXmlNamePool >::isConvertible(pyargs[1])) {
        overloadId = 0; // fromClarkName(QString,QXmlNamePool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlNameFunc_fromClarkName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QXmlNamePool cppArg1 = Shiboken::Converter<QXmlNamePool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // fromClarkName(QString,QXmlNamePool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlName cppResult = QXmlName::fromClarkName(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlName >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlNameFunc_fromClarkName_TypeError:
        const char* overloads[] = {"QString, PySide.QtXmlPatterns.QXmlNamePool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlName.fromClarkName", overloads);
        return 0;
}

static PyObject* Sbk_QXmlNameFunc_isNCName(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isNCName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // isNCName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlNameFunc_isNCName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isNCName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QXmlName::isNCName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlNameFunc_isNCName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlName.isNCName", overloads);
        return 0;
}

static PyObject* Sbk_QXmlNameFunc_isNull(PyObject* self)
{
    QXmlName* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlName* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlName*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlNameFunc_localName(PyObject* self, PyObject* arg)
{
    QXmlName* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlName* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: localName(QXmlNamePool)const
    if (Shiboken::Converter< ::QXmlNamePool >::isConvertible(arg)) {
        overloadId = 0; // localName(QXmlNamePool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlNameFunc_localName_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNamePool cppArg0 = Shiboken::Converter<QXmlNamePool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // localName(QXmlNamePool)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QXmlName*>(cppSelf)->localName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlNameFunc_localName_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNamePool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlName.localName", overloads);
        return 0;
}

static PyObject* Sbk_QXmlNameFunc_namespaceUri(PyObject* self, PyObject* arg)
{
    QXmlName* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlName* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: namespaceUri(QXmlNamePool)const
    if (Shiboken::Converter< ::QXmlNamePool >::isConvertible(arg)) {
        overloadId = 0; // namespaceUri(QXmlNamePool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlNameFunc_namespaceUri_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNamePool cppArg0 = Shiboken::Converter<QXmlNamePool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // namespaceUri(QXmlNamePool)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QXmlName*>(cppSelf)->namespaceUri(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlNameFunc_namespaceUri_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNamePool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlName.namespaceUri", overloads);
        return 0;
}

static PyObject* Sbk_QXmlNameFunc_prefix(PyObject* self, PyObject* arg)
{
    QXmlName* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlName* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: prefix(QXmlNamePool)const
    if (Shiboken::Converter< ::QXmlNamePool >::isConvertible(arg)) {
        overloadId = 0; // prefix(QXmlNamePool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlNameFunc_prefix_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNamePool cppArg0 = Shiboken::Converter<QXmlNamePool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // prefix(QXmlNamePool)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QXmlName*>(cppSelf)->prefix(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlNameFunc_prefix_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNamePool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlName.prefix", overloads);
        return 0;
}

static PyObject* Sbk_QXmlNameFunc_toClarkName(PyObject* self, PyObject* arg)
{
    QXmlName* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlName* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toClarkName(QXmlNamePool)const
    if (Shiboken::Converter< ::QXmlNamePool >::isConvertible(arg)) {
        overloadId = 0; // toClarkName(QXmlNamePool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlNameFunc_toClarkName_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNamePool cppArg0 = Shiboken::Converter<QXmlNamePool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // toClarkName(QXmlNamePool)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QXmlName*>(cppSelf)->toClarkName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlNameFunc_toClarkName_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNamePool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlName.toClarkName", overloads);
        return 0;
}

static PyObject *Sbk_QXmlName___copy__(PyObject *self)
{
        QXmlName* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QXmlName*>::toCpp(self);
        PyObject* pyResult = 0;
        QXmlName* copy = new QXmlName(*cppSelf);
        pyResult = Shiboken::Converter<QXmlName*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QXmlName_methods[] = {
    {"fromClarkName", (PyCFunction)Sbk_QXmlNameFunc_fromClarkName, METH_VARARGS|METH_STATIC},
    {"isNCName", (PyCFunction)Sbk_QXmlNameFunc_isNCName, METH_O|METH_STATIC},
    {"isNull", (PyCFunction)Sbk_QXmlNameFunc_isNull, METH_NOARGS},
    {"localName", (PyCFunction)Sbk_QXmlNameFunc_localName, METH_O},
    {"namespaceUri", (PyCFunction)Sbk_QXmlNameFunc_namespaceUri, METH_O},
    {"prefix", (PyCFunction)Sbk_QXmlNameFunc_prefix, METH_O},
    {"toClarkName", (PyCFunction)Sbk_QXmlNameFunc_toClarkName, METH_O},

    {"__copy__", (PyCFunction)Sbk_QXmlName___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QXmlName___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QXmlName* cppSelf = Shiboken::Converter< ::QXmlName*>::toCpp(pyObj);
    int result;
    Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    Py_END_ALLOW_THREADS
    return result;
}

// type has number operators
static PyNumberMethods Sbk_QXmlName_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QXmlName___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QXmlName_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QXmlName& cppSelf = *Shiboken::Converter< QXmlName* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QXmlName >::isConvertible(arg)) {
                // operator!=(const QXmlName & other) const
                QXmlName cppArg0 = Shiboken::Converter< ::QXmlName >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QXmlName_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QXmlName >::isConvertible(arg)) {
                // operator==(const QXmlName & other) const
                QXmlName cppArg0 = Shiboken::Converter< ::QXmlName >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QXmlName_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QXmlName_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QXmlName_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlName_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QXmlName",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QXmlName_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QXmlName_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlName_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlName_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QXmlName(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLNAME_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlName_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QXmlName_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QXmlName_Type, &Shiboken::callCppDestructor<QXmlName >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QXmlName_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QXmlName_Type, "QXmlName");
    PyModule_AddObject(module, "QXmlName",
        ((PyObject*)&Sbk_QXmlName_Type));

    // Initialize enums
    PyObject* enumItem;


    Shiboken::TypeResolver::createValueTypeResolver<QXmlName >("QXmlName");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlName >("QXmlName*");
    Shiboken::TypeResolver::createValueTypeResolver<QXmlName >(typeid(QXmlName).name());
    PySide::initQtMetaType< ::QXmlName >();
}

