/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qxmlserializer_wrapper.h"

// Extra includes
#include <qabstractxmlnodemodel.h>
#include <qabstractxmlreceiver.h>
#include <qiodevice.h>
#include <qtextcodec.h>
#include <qxmlname.h>
#include <qxmlquery.h>


// Native ---------------------------------------------------------

QXmlSerializerWrapper::QXmlSerializerWrapper(const QXmlQuery & query, QIODevice * outputDevice) : QXmlSerializer(query, outputDevice) {
    // ... middle
}

void QXmlSerializerWrapper::atomicValue(const QVariant & value)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "atomicValue"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSerializer::atomicValue(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QVariant >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSerializerWrapper::attribute(const QXmlName & name, const QStringRef & value)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "attribute"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSerializer::attribute(name, value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QXmlName >::toPython(name),
        Shiboken::Converter< QStringRef >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSerializerWrapper::characters(const QStringRef & value)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "characters"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSerializer::characters(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QStringRef >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSerializerWrapper::comment(const QString & value)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "comment"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSerializer::comment(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSerializerWrapper::endDocument()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "endDocument"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSerializer::endDocument();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSerializerWrapper::endElement()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "endElement"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSerializer::endElement();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSerializerWrapper::endOfSequence()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "endOfSequence"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSerializer::endOfSequence();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSerializerWrapper::namespaceBinding(const QXmlName & nb)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "namespaceBinding"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSerializer::namespaceBinding(nb);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlName >::toPython(nb)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSerializerWrapper::processingInstruction(const QXmlName & name, const QString & value)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "processingInstruction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSerializer::processingInstruction(name, value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QXmlName >::toPython(name),
        Shiboken::Converter< QString >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSerializerWrapper::startDocument()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "startDocument"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSerializer::startDocument();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSerializerWrapper::startElement(const QXmlName & name)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "startElement"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSerializer::startElement(name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlName >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSerializerWrapper::startOfSequence()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "startOfSequence"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSerializer::startOfSequence();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlSerializerWrapper::whitespaceOnly(const QStringRef & value)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "whitespaceOnly"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractXmlReceiver::whitespaceOnly(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QStringRef >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QXmlSerializerWrapper::~QXmlSerializerWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlSerializer_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlSerializer >()))
        return -1;

    QXmlSerializerWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlSerializer", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlSerializer(QXmlQuery,QIODevice*)
    if (numArgs == 2 && Shiboken::Converter< ::QXmlQuery >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[1])) {
        overloadId = 0; // QXmlSerializer(QXmlQuery,QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSerializer_Init_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QXmlQuery cppArg0 = Shiboken::Converter<QXmlQuery >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return -1;
            QIODevice * cppArg1 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // QXmlSerializer(QXmlQuery,QIODevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QXmlSerializerWrapper(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlSerializer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QXmlSerializer_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QXmlSerializer_Init_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlQuery, PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlSerializer", overloads);
        return -1;
}

static PyObject* Sbk_QXmlSerializerFunc_atomicValue(PyObject* self, PyObject* arg)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: atomicValue(QVariant)
    if (Shiboken::Converter< QVariant >::isConvertible(arg)) {
        overloadId = 0; // atomicValue(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSerializerFunc_atomicValue_TypeError;

    // Call function/method
    {
        {
            QVariant cppArg0 = Shiboken::Converter<QVariant >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // atomicValue(QVariant)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSerializer::atomicValue(cppArg0) : cppSelf->atomicValue(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSerializerFunc_atomicValue_TypeError:
        const char* overloads[] = {"QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSerializer.atomicValue", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSerializerFunc_attribute(PyObject* self, PyObject* args)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "attribute", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: attribute(QXmlName,QStringRef)
    if (numArgs == 2 && Shiboken::Converter< ::QXmlName >::isConvertible(pyargs[0]) && Shiboken::Converter< QStringRef >::isConvertible(pyargs[1])) {
        overloadId = 0; // attribute(QXmlName,QStringRef)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSerializerFunc_attribute_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(pyargs[0]);
            QStringRef cppArg1 = Shiboken::Converter<QStringRef >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // attribute(QXmlName,QStringRef)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSerializer::attribute(cppArg0, cppArg1) : cppSelf->attribute(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSerializerFunc_attribute_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName, QStringRef", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlSerializer.attribute", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSerializerFunc_characters(PyObject* self, PyObject* arg)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: characters(QStringRef)
    if (Shiboken::Converter< QStringRef >::isConvertible(arg)) {
        overloadId = 0; // characters(QStringRef)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSerializerFunc_characters_TypeError;

    // Call function/method
    {
        {
            QStringRef cppArg0 = Shiboken::Converter<QStringRef >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // characters(QStringRef)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSerializer::characters(cppArg0) : cppSelf->characters(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSerializerFunc_characters_TypeError:
        const char* overloads[] = {"QStringRef", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSerializer.characters", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSerializerFunc_codec(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // codec()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QTextCodec * cppResult = const_cast<const QXmlSerializer*>(cppSelf)->codec();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextCodec * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlSerializerFunc_comment(PyObject* self, PyObject* arg)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: comment(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // comment(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSerializerFunc_comment_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // comment(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSerializer::comment(cppArg0) : cppSelf->comment(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSerializerFunc_comment_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSerializer.comment", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSerializerFunc_endDocument(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // endDocument()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSerializer::endDocument() : cppSelf->endDocument());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlSerializerFunc_endElement(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // endElement()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSerializer::endElement() : cppSelf->endElement());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlSerializerFunc_endOfSequence(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // endOfSequence()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSerializer::endOfSequence() : cppSelf->endOfSequence());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlSerializerFunc_namespaceBinding(PyObject* self, PyObject* arg)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: namespaceBinding(QXmlName)
    if (Shiboken::Converter< ::QXmlName >::isConvertible(arg)) {
        overloadId = 0; // namespaceBinding(QXmlName)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSerializerFunc_namespaceBinding_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // namespaceBinding(QXmlName)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSerializer::namespaceBinding(cppArg0) : cppSelf->namespaceBinding(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSerializerFunc_namespaceBinding_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSerializer.namespaceBinding", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSerializerFunc_outputDevice(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // outputDevice()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIODevice * cppResult = const_cast<const QXmlSerializer*>(cppSelf)->outputDevice();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIODevice * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlSerializerFunc_processingInstruction(PyObject* self, PyObject* args)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "processingInstruction", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: processingInstruction(QXmlName,QString)
    if (numArgs == 2 && Shiboken::Converter< ::QXmlName >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // processingInstruction(QXmlName,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSerializerFunc_processingInstruction_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // processingInstruction(QXmlName,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSerializer::processingInstruction(cppArg0, cppArg1) : cppSelf->processingInstruction(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSerializerFunc_processingInstruction_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlSerializer.processingInstruction", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSerializerFunc_setCodec(PyObject* self, PyObject* arg)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCodec(const QTextCodec*)
    if (Shiboken::Converter< ::QTextCodec * >::isConvertible(arg)) {
        overloadId = 0; // setCodec(const QTextCodec*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSerializerFunc_setCodec_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextCodec * cppArg0 = Shiboken::Converter<QTextCodec * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCodec(const QTextCodec*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCodec(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSerializerFunc_setCodec_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextCodec", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSerializer.setCodec", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSerializerFunc_startDocument(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // startDocument()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSerializer::startDocument() : cppSelf->startDocument());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlSerializerFunc_startElement(PyObject* self, PyObject* arg)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: startElement(QXmlName)
    if (Shiboken::Converter< ::QXmlName >::isConvertible(arg)) {
        overloadId = 0; // startElement(QXmlName)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSerializerFunc_startElement_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // startElement(QXmlName)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSerializer::startElement(cppArg0) : cppSelf->startElement(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSerializerFunc_startElement_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSerializer.startElement", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSerializerFunc_startOfSequence(PyObject* self)
{
    QXmlSerializer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSerializer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // startOfSequence()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlSerializer::startOfSequence() : cppSelf->startOfSequence());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_QXmlSerializer_methods[] = {
    {"atomicValue", (PyCFunction)Sbk_QXmlSerializerFunc_atomicValue, METH_O},
    {"attribute", (PyCFunction)Sbk_QXmlSerializerFunc_attribute, METH_VARARGS},
    {"characters", (PyCFunction)Sbk_QXmlSerializerFunc_characters, METH_O},
    {"codec", (PyCFunction)Sbk_QXmlSerializerFunc_codec, METH_NOARGS},
    {"comment", (PyCFunction)Sbk_QXmlSerializerFunc_comment, METH_O},
    {"endDocument", (PyCFunction)Sbk_QXmlSerializerFunc_endDocument, METH_NOARGS},
    {"endElement", (PyCFunction)Sbk_QXmlSerializerFunc_endElement, METH_NOARGS},
    {"endOfSequence", (PyCFunction)Sbk_QXmlSerializerFunc_endOfSequence, METH_NOARGS},
    {"namespaceBinding", (PyCFunction)Sbk_QXmlSerializerFunc_namespaceBinding, METH_O},
    {"outputDevice", (PyCFunction)Sbk_QXmlSerializerFunc_outputDevice, METH_NOARGS},
    {"processingInstruction", (PyCFunction)Sbk_QXmlSerializerFunc_processingInstruction, METH_VARARGS},
    {"setCodec", (PyCFunction)Sbk_QXmlSerializerFunc_setCodec, METH_O},
    {"startDocument", (PyCFunction)Sbk_QXmlSerializerFunc_startDocument, METH_NOARGS},
    {"startElement", (PyCFunction)Sbk_QXmlSerializerFunc_startElement, METH_O},
    {"startOfSequence", (PyCFunction)Sbk_QXmlSerializerFunc_startOfSequence, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlSerializer_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QXmlSerializer",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlSerializer_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlSerializer_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QXmlSerializer_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QAbstractXmlReceiver >()) && dynamic_cast<QXmlSerializer*>(reinterpret_cast<QAbstractXmlReceiver*>(cptr)))
        return &Sbk_QXmlSerializer_Type;
    return 0;
}


void init_QXmlSerializer(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLSERIALIZER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlSerializer_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QXmlSerializer_Type);
    Sbk_QXmlSerializer_Type.super.ht_type.tp_base = SbkPySide_QtXmlPatternsTypes[SBK_QABSTRACTXMLRECEIVER_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QXmlSerializer_Type, &Shiboken::callCppDestructor<QXmlSerializer >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QXmlSerializer_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QXmlSerializer_Type, &Sbk_QXmlSerializer_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtXmlPatternsTypes[SBK_QABSTRACTXMLRECEIVER_IDX]), &Sbk_QXmlSerializer_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QXmlSerializer_Type, "QXmlSerializer*");
    PyModule_AddObject(module, "QXmlSerializer",
        ((PyObject*)&Sbk_QXmlSerializer_Type));

    // Initialize enums
    PyObject* enumItem;


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSerializer >("QXmlSerializer*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSerializer >(typeid(QXmlSerializer).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSerializer >(typeid(QXmlSerializerWrapper).name());
    PySide::initQtMetaType< ::QXmlSerializer* >();
}

