/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_abstractvideooutput_wrapper.h"

// Extra includes
#include <QList>
#include <path.h>

using namespace Phonon;

// Native ---------------------------------------------------------

AbstractVideoOutputWrapper::~AbstractVideoOutputWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyMethodDef Sbk_Phonon_AbstractVideoOutput_methods[] = {

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_Phonon_AbstractVideoOutput_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.Phonon.AbstractVideoOutput",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_Phonon_AbstractVideoOutput_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_Phonon_AbstractVideoOutput_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<Phonon::MediaNode >()) && dynamic_cast<Phonon::AbstractVideoOutput*>(reinterpret_cast<Phonon::MediaNode*>(cptr)))
        return &Sbk_Phonon_AbstractVideoOutput_Type;
    return 0;
}


void init_Phonon_AbstractVideoOutput(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_ABSTRACTVIDEOOUTPUT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_Phonon_AbstractVideoOutput_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_Phonon_AbstractVideoOutput_Type);
    Sbk_Phonon_AbstractVideoOutput_Type.super.ht_type.tp_base = SbkPySide_phononTypes[SBK_PHONON_MEDIANODE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_Phonon_AbstractVideoOutput_Type, &Shiboken::callCppDestructor<Phonon::AbstractVideoOutput >);
    if (PyType_Ready((PyTypeObject*)&Sbk_Phonon_AbstractVideoOutput_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_Phonon_AbstractVideoOutput_Type, &Sbk_Phonon_AbstractVideoOutput_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_phononTypes[SBK_PHONON_MEDIANODE_IDX]), &Sbk_Phonon_AbstractVideoOutput_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_Phonon_AbstractVideoOutput_Type, "Phonon::AbstractVideoOutput*");
    PyDict_SetItemString(module,"AbstractVideoOutput", (PyObject*)&Sbk_Phonon_AbstractVideoOutput_Type);

    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::AbstractVideoOutput >("Phonon::AbstractVideoOutput*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::AbstractVideoOutput >(typeid(Phonon::AbstractVideoOutput).name());
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::AbstractVideoOutput >(typeid(AbstractVideoOutputWrapper).name());
    PySide::initQtMetaType< ::Phonon::AbstractVideoOutput* >();
}

