/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_wrapper.h"
#include "phonon_backendcapabilities_wrapper.h"
#include "phonon_audiochanneldescription_wrapper.h"
#include "phonon_audiooutputdevice_wrapper.h"
#include "phonon_audiocapturedevice_wrapper.h"
#include "phonon_subtitledescription_wrapper.h"
#include "phonon_effectdescriptionmodel_wrapper.h"
#include "phonon_videocapturedevice_wrapper.h"
#include "phonon_effectdescription_wrapper.h"
#include "phonon_audiooutputdevicemodel_wrapper.h"
#include "phonon_volumeslider_wrapper.h"
#include "phonon_volumefaderinterface_wrapper.h"
#include "phonon_videowidgetinterface_wrapper.h"
#include "phonon_videoplayer_wrapper.h"
#include "phonon_streaminterface_wrapper.h"
#include "phonon_seekslider_wrapper.h"
#include "phonon_platformplugin_wrapper.h"
#include "phonon_mediaobjectinterface_wrapper.h"
#include "phonon_mediasource_wrapper.h"
#include "phonon_mediacontroller_wrapper.h"
#include "phonon_effectwidget_wrapper.h"
#include "phonon_effectparameter_wrapper.h"
#include "phonon_effectinterface_wrapper.h"
#include "phonon_backendinterface_wrapper.h"
#include "phonon_addoninterface_wrapper.h"
#include "phonon_abstractmediastream_wrapper.h"
#include "phonon_medianode_wrapper.h"
#include "phonon_mediaobject_wrapper.h"
#include "phonon_effect_wrapper.h"
#include "phonon_volumefadereffect_wrapper.h"
#include "phonon_abstractvideooutput_wrapper.h"
#include "phonon_videowidget_wrapper.h"
#include "phonon_abstractaudiooutput_wrapper.h"
#include "phonon_audiooutput_wrapper.h"
#include "phonon_path_wrapper.h"

// Extra includes
#include <effectparameter.h>
#include <medianode.h>
#include <mediaobject.h>
#include <mediasource.h>
#include <path.h>
#include <phononnamespace.h>



// Target ---------------------------------------------------------

extern "C" {
static PyObject* Sbk_PhononFunc_categoryToString(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: categoryToString(Phonon::Category)
    if (Shiboken::Converter< ::Phonon::Category >::isConvertible(arg)) {
        overloadId = 0; // categoryToString(Phonon::Category)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_PhononFunc_categoryToString_TypeError;

    // Call function/method
    {
        {
            Phonon::Category cppArg0 = Shiboken::Converter<Phonon::Category >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // categoryToString(Phonon::Category)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = Phonon::categoryToString(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_PhononFunc_categoryToString_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon.Category", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.Phonon.categoryToString", overloads);
        return 0;
}

static PyObject* Sbk_PhononFunc_createPath(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "createPath", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createPath(Phonon::MediaNode*,Phonon::MediaNode*)
    if (numArgs == 2 && Shiboken::Converter< ::Phonon::MediaNode * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::Phonon::MediaNode * >::isConvertible(pyargs[1])) {
        overloadId = 0; // createPath(Phonon::MediaNode*,Phonon::MediaNode*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_PhononFunc_createPath_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            Phonon::MediaNode * cppArg0 = Shiboken::Converter<Phonon::MediaNode * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            Phonon::MediaNode * cppArg1 = Shiboken::Converter<Phonon::MediaNode * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // createPath(Phonon::MediaNode*,Phonon::MediaNode*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Phonon::Path cppResult = Phonon::createPath(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Phonon::Path >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_PhononFunc_createPath_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::MediaNode, PySide.phonon.Phonon::MediaNode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.Phonon.createPath", overloads);
        return 0;
}

static PyObject* Sbk_PhononFunc_createPlayer(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.Phonon.createPlayer(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.Phonon.createPlayer(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createPlayer", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createPlayer(Phonon::Category,Phonon::MediaSource)
    if (Shiboken::Converter< ::Phonon::Category >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createPlayer(Phonon::Category,Phonon::MediaSource)
        } else if (Shiboken::Converter< ::Phonon::MediaSource >::isConvertible(pyargs[1])) {
            overloadId = 0; // createPlayer(Phonon::Category,Phonon::MediaSource)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_PhononFunc_createPlayer_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "source");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "source";
                    else if (Shiboken::Converter< ::Phonon::MediaSource >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_PhononFunc_createPlayer_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.phonon.Phonon.createPlayer(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Phonon::Category cppArg0 = Shiboken::Converter<Phonon::Category >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            Phonon::MediaSource cppArg1_tmp = Phonon::MediaSource();
            Phonon::MediaSource cppArg1 = pyargs[1] ? Shiboken::Converter<Phonon::MediaSource >::toCpp(pyargs[1]) : cppArg1_tmp;

            if(!PyErr_Occurred()) {
                // createPlayer(Phonon::Category,Phonon::MediaSource)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Phonon::MediaObject * cppResult = Phonon::createPlayer(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Phonon::MediaObject * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_PhononFunc_createPlayer_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon.Category, PySide.phonon.Phonon::MediaSource = Phonon.MediaSource()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.Phonon.createPlayer", overloads);
        return 0;
}

static PyObject* Sbk_PhononFunc_phononVersion(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // phononVersion()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const char * cppResult = Phonon::phononVersion();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< const char * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_PhononFunc_qHash(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qHash(Phonon::EffectParameter)
    if (Shiboken::Converter< ::Phonon::EffectParameter >::isConvertible(arg)) {
        overloadId = 0; // qHash(Phonon::EffectParameter)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_PhononFunc_qHash_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            Phonon::EffectParameter cppArg0 = Shiboken::Converter<Phonon::EffectParameter >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // qHash(Phonon::EffectParameter)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                uint cppResult = Phonon::qHash(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_PhononFunc_qHash_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::EffectParameter", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.Phonon.qHash", overloads);
        return 0;
}

static PyObject* Sbk_PhononFunc_registerMetaTypes(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // registerMetaTypes()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Phonon::registerMetaTypes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_Phonon_methods[] = {
    {"categoryToString", (PyCFunction)Sbk_PhononFunc_categoryToString, METH_O|METH_STATIC},
    {"createPath", (PyCFunction)Sbk_PhononFunc_createPath, METH_VARARGS|METH_STATIC},
    {"createPlayer", (PyCFunction)Sbk_PhononFunc_createPlayer, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"phononVersion", (PyCFunction)Sbk_PhononFunc_phononVersion, METH_NOARGS|METH_STATIC},
    {"qHash", (PyCFunction)Sbk_PhononFunc_qHash, METH_O|METH_STATIC},
    {"registerMetaTypes", (PyCFunction)Sbk_PhononFunc_registerMetaTypes, METH_NOARGS|METH_STATIC},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_Phonon_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.Phonon",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_Phonon_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_Phonon(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_Phonon_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_Phonon_Type);
    if (PyType_Ready((PyTypeObject*)&Sbk_Phonon_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_Phonon_Type, "Phonon");
    PyModule_AddObject(module, "Phonon",
        ((PyObject*)&Sbk_Phonon_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: DiscType
    PyTypeObject* SbkPySide_phonon_Phonon_DiscType = Shiboken::Enum::newType("PySide.phonon.Phonon.DiscType");
    SbkPySide_phononTypes[SBK_PHONON_DISCTYPE_IDX] = SbkPySide_phonon_Phonon_DiscType;
    if (PyType_Ready(SbkPySide_phonon_Phonon_DiscType) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,
            "DiscType",((PyObject*)SbkPySide_phonon_Phonon_DiscType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_DiscType,(long) Phonon::NoDisc, "NoDisc");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"NoDisc", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_DiscType->tp_dict,"NoDisc", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_DiscType,(long) Phonon::Cd, "Cd");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"Cd", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_DiscType->tp_dict,"Cd", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_DiscType,(long) Phonon::Dvd, "Dvd");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"Dvd", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_DiscType->tp_dict,"Dvd", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_DiscType,(long) Phonon::Vcd, "Vcd");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"Vcd", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_DiscType->tp_dict,"Vcd", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::DiscType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::DiscType");
    // end of enum DiscType

    // init enum: MetaData
    PyTypeObject* SbkPySide_phonon_Phonon_MetaData = Shiboken::Enum::newType("PySide.phonon.Phonon.MetaData");
    SbkPySide_phononTypes[SBK_PHONON_METADATA_IDX] = SbkPySide_phonon_Phonon_MetaData;
    if (PyType_Ready(SbkPySide_phonon_Phonon_MetaData) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,
            "MetaData",((PyObject*)SbkPySide_phonon_Phonon_MetaData));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_MetaData,(long) Phonon::ArtistMetaData, "ArtistMetaData");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"ArtistMetaData", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MetaData->tp_dict,"ArtistMetaData", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_MetaData,(long) Phonon::AlbumMetaData, "AlbumMetaData");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"AlbumMetaData", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MetaData->tp_dict,"AlbumMetaData", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_MetaData,(long) Phonon::TitleMetaData, "TitleMetaData");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"TitleMetaData", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MetaData->tp_dict,"TitleMetaData", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_MetaData,(long) Phonon::DateMetaData, "DateMetaData");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"DateMetaData", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MetaData->tp_dict,"DateMetaData", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_MetaData,(long) Phonon::GenreMetaData, "GenreMetaData");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"GenreMetaData", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MetaData->tp_dict,"GenreMetaData", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_MetaData,(long) Phonon::TracknumberMetaData, "TracknumberMetaData");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"TracknumberMetaData", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MetaData->tp_dict,"TracknumberMetaData", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_MetaData,(long) Phonon::DescriptionMetaData, "DescriptionMetaData");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"DescriptionMetaData", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MetaData->tp_dict,"DescriptionMetaData", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_MetaData,(long) Phonon::MusicBrainzDiscIdMetaData, "MusicBrainzDiscIdMetaData");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"MusicBrainzDiscIdMetaData", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MetaData->tp_dict,"MusicBrainzDiscIdMetaData", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::MetaData");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::MetaData");
    // end of enum MetaData

    // init enum: Category
    PyTypeObject* SbkPySide_phonon_Phonon_Category = Shiboken::Enum::newType("PySide.phonon.Phonon.Category");
    SbkPySide_phononTypes[SBK_PHONON_CATEGORY_IDX] = SbkPySide_phonon_Phonon_Category;
    if (PyType_Ready(SbkPySide_phonon_Phonon_Category) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,
            "Category",((PyObject*)SbkPySide_phonon_Phonon_Category));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_Category,(long) Phonon::NoCategory, "NoCategory");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"NoCategory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_Category->tp_dict,"NoCategory", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_Category,(long) Phonon::NotificationCategory, "NotificationCategory");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"NotificationCategory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_Category->tp_dict,"NotificationCategory", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_Category,(long) Phonon::MusicCategory, "MusicCategory");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"MusicCategory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_Category->tp_dict,"MusicCategory", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_Category,(long) Phonon::VideoCategory, "VideoCategory");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"VideoCategory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_Category->tp_dict,"VideoCategory", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_Category,(long) Phonon::CommunicationCategory, "CommunicationCategory");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"CommunicationCategory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_Category->tp_dict,"CommunicationCategory", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_Category,(long) Phonon::GameCategory, "GameCategory");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"GameCategory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_Category->tp_dict,"GameCategory", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_Category,(long) Phonon::AccessibilityCategory, "AccessibilityCategory");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"AccessibilityCategory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_Category->tp_dict,"AccessibilityCategory", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_Category,(long) Phonon::LastCategory, "LastCategory");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"LastCategory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_Category->tp_dict,"LastCategory", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::Category");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Category");
    // end of enum Category

    // init enum: ObjectDescriptionType
    PyTypeObject* SbkPySide_phonon_Phonon_ObjectDescriptionType = Shiboken::Enum::newType("PySide.phonon.Phonon.ObjectDescriptionType");
    SbkPySide_phononTypes[SBK_PHONON_OBJECTDESCRIPTIONTYPE_IDX] = SbkPySide_phonon_Phonon_ObjectDescriptionType;
    if (PyType_Ready(SbkPySide_phonon_Phonon_ObjectDescriptionType) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,
            "ObjectDescriptionType",((PyObject*)SbkPySide_phonon_Phonon_ObjectDescriptionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_ObjectDescriptionType,(long) Phonon::AudioOutputDeviceType, "AudioOutputDeviceType");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"AudioOutputDeviceType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_ObjectDescriptionType->tp_dict,"AudioOutputDeviceType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_ObjectDescriptionType,(long) Phonon::EffectType, "EffectType");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"EffectType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_ObjectDescriptionType->tp_dict,"EffectType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_ObjectDescriptionType,(long) Phonon::AudioChannelType, "AudioChannelType");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"AudioChannelType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_ObjectDescriptionType->tp_dict,"AudioChannelType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_ObjectDescriptionType,(long) Phonon::SubtitleType, "SubtitleType");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"SubtitleType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_ObjectDescriptionType->tp_dict,"SubtitleType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_ObjectDescriptionType,(long) Phonon::AudioCaptureDeviceType, "AudioCaptureDeviceType");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"AudioCaptureDeviceType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_ObjectDescriptionType->tp_dict,"AudioCaptureDeviceType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_ObjectDescriptionType,(long) Phonon::VideoCaptureDeviceType, "VideoCaptureDeviceType");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"VideoCaptureDeviceType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_ObjectDescriptionType->tp_dict,"VideoCaptureDeviceType", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::ObjectDescriptionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ObjectDescriptionType");
    // end of enum ObjectDescriptionType

    // init enum: State
    PyTypeObject* SbkPySide_phonon_Phonon_State = Shiboken::Enum::newType("PySide.phonon.Phonon.State");
    SbkPySide_phononTypes[SBK_PHONON_STATE_IDX] = SbkPySide_phonon_Phonon_State;
    if (PyType_Ready(SbkPySide_phonon_Phonon_State) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,
            "State",((PyObject*)SbkPySide_phonon_Phonon_State));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_State,(long) Phonon::LoadingState, "LoadingState");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"LoadingState", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_State->tp_dict,"LoadingState", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_State,(long) Phonon::StoppedState, "StoppedState");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"StoppedState", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_State->tp_dict,"StoppedState", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_State,(long) Phonon::PlayingState, "PlayingState");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"PlayingState", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_State->tp_dict,"PlayingState", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_State,(long) Phonon::BufferingState, "BufferingState");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"BufferingState", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_State->tp_dict,"BufferingState", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_State,(long) Phonon::PausedState, "PausedState");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"PausedState", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_State->tp_dict,"PausedState", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_State,(long) Phonon::ErrorState, "ErrorState");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"ErrorState", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_State->tp_dict,"ErrorState", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::State");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::State");
    // end of enum State

    // init enum: ErrorType
    PyTypeObject* SbkPySide_phonon_Phonon_ErrorType = Shiboken::Enum::newType("PySide.phonon.Phonon.ErrorType");
    SbkPySide_phononTypes[SBK_PHONON_ERRORTYPE_IDX] = SbkPySide_phonon_Phonon_ErrorType;
    if (PyType_Ready(SbkPySide_phonon_Phonon_ErrorType) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,
            "ErrorType",((PyObject*)SbkPySide_phonon_Phonon_ErrorType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_ErrorType,(long) Phonon::NoError, "NoError");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_ErrorType->tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_ErrorType,(long) Phonon::NormalError, "NormalError");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"NormalError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_ErrorType->tp_dict,"NormalError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_ErrorType,(long) Phonon::FatalError, "FatalError");
    PyDict_SetItemString(Sbk_Phonon_Type.super.ht_type.tp_dict,"FatalError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_ErrorType->tp_dict,"FatalError", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::ErrorType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ErrorType");
    // end of enum ErrorType


    qRegisterMetaType< ::Phonon::DiscType >("Phonon::DiscType");
    qRegisterMetaType< ::Phonon::MetaData >("Phonon::MetaData");
    qRegisterMetaType< ::Phonon::Category >("Phonon::Category");
    qRegisterMetaType< ::Phonon::ObjectDescriptionType >("Phonon::ObjectDescriptionType");
    qRegisterMetaType< ::Phonon::State >("Phonon::State");
    qRegisterMetaType< ::Phonon::ErrorType >("Phonon::ErrorType");
}

