/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qwidget_wrapper.h"

// Extra includes
#include <QIcon>
#include <QList>
#include <QMessageBox>
#include "glue/qwidget_glue.h"
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qthread.h>
#include <qwidget.h>
#include <qx11info_x11.h>


// Native ---------------------------------------------------------

QWidgetWrapper::QWidgetWrapper(QWidget * parent, QFlags<Qt::WindowType> f) : QWidget(parent, f) {
    // ... middle
}

void QWidgetWrapper::actionEvent(QActionEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QActionEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::changeEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::changeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWidgetWrapper::closeEvent(QCloseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::closeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QCloseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWidgetWrapper::contextMenuEvent(QContextMenuEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::contextMenuEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QContextMenuEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QWidgetWrapper::devType() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWidgetWrapper::dragEnterEvent(QDragEnterEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragEnterEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::dragLeaveEvent(QDragLeaveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragLeaveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::dragMoveEvent(QDragMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::dropEvent(QDropEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDropEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::enterEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QWidgetWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QWidgetWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QWidgetWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QWidgetWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::hideEvent(QHideEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QHideEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QInputMethodEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QWidgetWrapper::inputMethodQuery(Qt::InputMethodQuery arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::inputMethodQuery(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Qt::InputMethodQuery >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::languageChange()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWidgetWrapper::leaveEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QWidgetWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QSize QWidgetWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.minimumSizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::mouseDoubleClickEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::mouseMoveEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::mousePressEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::mouseReleaseEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::moveEvent(QMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QWidgetWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::paintEvent(QPaintEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::resizeEvent(QResizeEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::resizeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QResizeEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWidgetWrapper::showEvent(QShowEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::showEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QShowEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QWidgetWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.sizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::tabletEvent(QTabletEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTabletEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWidgetWrapper::wheelEvent(QWheelEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::wheelEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWheelEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QWidgetWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QWidgetWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QWidget::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QWidgetWrapper::~QWidgetWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWidget_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QWidget >()))
        return -1;

    QWidgetWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"f", "parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]);
    if (type != myType) {
        Shiboken::ObjectType::copyMultimpleheritance(type, myType);
    }



    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QWidget", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QWidget(QWidget*,QFlags<Qt::WindowType>)
    if (numArgs == 0) {
        overloadId = 0; // QWidget(QWidget*,QFlags<Qt::WindowType>)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QWidget(QWidget*,QFlags<Qt::WindowType>)
        } else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(pyargs[1])) {
            overloadId = 0; // QWidget(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidget_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QWidget_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "f");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "f";
                    else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QWidget_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;
            QFlags<Qt::WindowType> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[1]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
                // QWidget(QWidget*,QFlags<Qt::WindowType>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QWidgetWrapper(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QWidget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QWidget_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 2))
        return -1;


    return 1;

    Sbk_QWidget_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget", overloads);
        return -1;
}

static PyObject* Sbk_QWidgetFunc_acceptDrops(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // acceptDrops()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->acceptDrops();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_accessibleDescription(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // accessibleDescription()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWidget*>(cppSelf)->accessibleDescription();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_accessibleName(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // accessibleName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWidget*>(cppSelf)->accessibleName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_actionEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: actionEvent(QActionEvent*)
    if (Shiboken::Converter< ::QActionEvent * >::isConvertible(arg)) {
        overloadId = 0; // actionEvent(QActionEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_actionEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QActionEvent * cppArg0 = Shiboken::Converter<QActionEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // actionEvent(QActionEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::actionEvent(cppArg0) : cppSelf->actionEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_actionEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QActionEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.actionEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_actions(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // actions()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QAction * > cppResult = const_cast<const QWidget*>(cppSelf)->actions();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QAction * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_activateWindow(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // activateWindow()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->activateWindow();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_addAction(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addAction(QAction*)
    if (Shiboken::Converter< ::QAction * >::isConvertible(arg)) {
        overloadId = 0; // addAction(QAction*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_addAction_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAction * cppArg0 = Shiboken::Converter<QAction * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addAction(QAction*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addAction(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_addAction_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.addAction", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_addActions(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addActions(QList<QAction*>)
    if (Shiboken::Converter< ::QList<QAction * > >::isConvertible(arg)) {
        overloadId = 0; // addActions(QList<QAction*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_addActions_TypeError;

    // Call function/method
    {
        {
            QList<QAction * > cppArg0 = Shiboken::Converter<QList<QAction * > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addActions(QList<QAction*>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addActions(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_addActions_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.addActions", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_adjustSize(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // adjustSize()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->adjustSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_autoFillBackground(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // autoFillBackground()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->autoFillBackground();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_backgroundRole(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // backgroundRole()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPalette::ColorRole cppResult = const_cast<const QWidget*>(cppSelf)->backgroundRole();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPalette::ColorRole >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_baseSize(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // baseSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QWidget*>(cppSelf)->baseSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_changeEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: changeEvent(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_changeEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // changeEvent(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::changeEvent(cppArg0) : cppSelf->changeEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_changeEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.changeEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_childAt(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "childAt", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: childAt(QPoint)const
    // 1: childAt(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // childAt(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // childAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_childAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // childAt(QPoint)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // childAt(QPoint)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QWidget * cppResult = const_cast<const QWidget*>(cppSelf)->childAt(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // childAt(int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // childAt(int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QWidget * cppResult = const_cast<const QWidget*>(cppSelf)->childAt(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_childAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.childAt", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_childrenRect(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // childrenRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QWidget*>(cppSelf)->childrenRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_childrenRegion(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // childrenRegion()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRegion cppResult = const_cast<const QWidget*>(cppSelf)->childrenRegion();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRegion >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_clearFocus(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearFocus()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearFocus();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_clearMask(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearMask()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearMask();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_close(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // close()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->close();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_closeEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: closeEvent(QCloseEvent*)
    if (Shiboken::Converter< ::QCloseEvent * >::isConvertible(arg)) {
        overloadId = 0; // closeEvent(QCloseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_closeEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QCloseEvent * cppArg0 = Shiboken::Converter<QCloseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // closeEvent(QCloseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::closeEvent(cppArg0) : cppSelf->closeEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_closeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QCloseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.closeEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_contentsMargins(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // contentsMargins()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMargins cppResult = const_cast<const QWidget*>(cppSelf)->contentsMargins();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMargins >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_contentsRect(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // contentsRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QWidget*>(cppSelf)->contentsRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_contextMenuEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: contextMenuEvent(QContextMenuEvent*)
    if (Shiboken::Converter< ::QContextMenuEvent * >::isConvertible(arg)) {
        overloadId = 0; // contextMenuEvent(QContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_contextMenuEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QContextMenuEvent * cppArg0 = Shiboken::Converter<QContextMenuEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // contextMenuEvent(QContextMenuEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::contextMenuEvent(cppArg0) : cppSelf->contextMenuEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_contextMenuEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QContextMenuEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.contextMenuEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_contextMenuPolicy(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // contextMenuPolicy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::ContextMenuPolicy cppResult = const_cast<const QWidget*>(cppSelf)->contextMenuPolicy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::ContextMenuPolicy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_createWinId(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // createWinId()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->createWinId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_cursor(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cursor()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCursor cppResult = const_cast<const QWidget*>(cppSelf)->cursor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QCursor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_destroy(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.destroy(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:destroy", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: destroy(bool,bool)
    if (numArgs == 0) {
        overloadId = 0; // destroy(bool,bool)
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // destroy(bool,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // destroy(bool,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_destroy_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "destroyWindow");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "destroyWindow";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QWidgetFunc_destroy_TypeError;
                }
                value = PyDict_GetItemString(kwds, "destroySubWindows");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "destroySubWindows";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QWidgetFunc_destroy_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.destroy(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cppArg0 = pyargs[0] ? Shiboken::Converter<bool >::toCpp(pyargs[0]) : true;
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // destroy(bool,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->destroy(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_destroy_TypeError:
        const char* overloads[] = {"bool = true, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.destroy", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_devType(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // devType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QWidget*>(cppSelf)->::QWidget::devType() : const_cast<const QWidget*>(cppSelf)->devType());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_dragEnterEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragEnterEvent(QDragEnterEvent*)
    if (Shiboken::Converter< ::QDragEnterEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragEnterEvent(QDragEnterEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_dragEnterEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDragEnterEvent * cppArg0 = Shiboken::Converter<QDragEnterEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dragEnterEvent(QDragEnterEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::dragEnterEvent(cppArg0) : cppSelf->dragEnterEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_dragEnterEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragEnterEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.dragEnterEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_dragLeaveEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragLeaveEvent(QDragLeaveEvent*)
    if (Shiboken::Converter< ::QDragLeaveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragLeaveEvent(QDragLeaveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_dragLeaveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDragLeaveEvent * cppArg0 = Shiboken::Converter<QDragLeaveEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dragLeaveEvent(QDragLeaveEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::dragLeaveEvent(cppArg0) : cppSelf->dragLeaveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_dragLeaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragLeaveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.dragLeaveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_dragMoveEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragMoveEvent(QDragMoveEvent*)
    if (Shiboken::Converter< ::QDragMoveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragMoveEvent(QDragMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_dragMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDragMoveEvent * cppArg0 = Shiboken::Converter<QDragMoveEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dragMoveEvent(QDragMoveEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::dragMoveEvent(cppArg0) : cppSelf->dragMoveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_dragMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragMoveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.dragMoveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_dropEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dropEvent(QDropEvent*)
    if (Shiboken::Converter< ::QDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_dropEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDropEvent * cppArg0 = Shiboken::Converter<QDropEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dropEvent(QDropEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::dropEvent(cppArg0) : cppSelf->dropEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_dropEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.dropEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_effectiveWinId(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // effectiveWinId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned long cppResult = const_cast<const QWidget*>(cppSelf)->effectiveWinId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_ensurePolished(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // ensurePolished()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const_cast<const QWidget*>(cppSelf)->ensurePolished();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_enterEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: enterEvent(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // enterEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_enterEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // enterEvent(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::enterEvent(cppArg0) : cppSelf->enterEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_enterEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.enterEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_event(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::event(cppArg0) : cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.event", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_focusInEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusInEvent(QFocusEvent*)
    if (Shiboken::Converter< ::QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_focusInEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFocusEvent * cppArg0 = Shiboken::Converter<QFocusEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // focusInEvent(QFocusEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::focusInEvent(cppArg0) : cppSelf->focusInEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_focusInEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.focusInEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_focusNextChild(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // focusNextChild()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->focusNextChild();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_focusNextPrevChild(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusNextPrevChild(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_focusNextPrevChild_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // focusNextPrevChild(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::focusNextPrevChild(cppArg0) : cppSelf->focusNextPrevChild(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_focusNextPrevChild_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.focusNextPrevChild", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_focusOutEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusOutEvent(QFocusEvent*)
    if (Shiboken::Converter< ::QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_focusOutEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFocusEvent * cppArg0 = Shiboken::Converter<QFocusEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // focusOutEvent(QFocusEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::focusOutEvent(cppArg0) : cppSelf->focusOutEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_focusOutEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.focusOutEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_focusPolicy(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // focusPolicy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::FocusPolicy cppResult = const_cast<const QWidget*>(cppSelf)->focusPolicy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::FocusPolicy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_focusPreviousChild(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // focusPreviousChild()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->focusPreviousChild();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_focusProxy(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // focusProxy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QWidget*>(cppSelf)->focusProxy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_focusWidget(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // focusWidget()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QWidget*>(cppSelf)->focusWidget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_font(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // font()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QFont & cppResult = const_cast<const QWidget*>(cppSelf)->font();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_fontInfo(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontInfo()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFontInfo cppResult = const_cast<const QWidget*>(cppSelf)->fontInfo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFontInfo >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_fontMetrics(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontMetrics()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFontMetrics cppResult = const_cast<const QWidget*>(cppSelf)->fontMetrics();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFontMetrics >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_foregroundRole(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // foregroundRole()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPalette::ColorRole cppResult = const_cast<const QWidget*>(cppSelf)->foregroundRole();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPalette::ColorRole >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_frameGeometry(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // frameGeometry()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QWidget*>(cppSelf)->frameGeometry();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_frameSize(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // frameSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QWidget*>(cppSelf)->frameSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_geometry(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // geometry()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QRect & cppResult = const_cast<const QWidget*>(cppSelf)->geometry();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_grabGesture(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.grabGesture(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.grabGesture(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:grabGesture", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: grabGesture(Qt::GestureType,QFlags<Qt::GestureFlag>)
    if (Shiboken::Converter< ::Qt::GestureType >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // grabGesture(Qt::GestureType,QFlags<Qt::GestureFlag>)
        } else if (Shiboken::Converter< ::QFlags<Qt::GestureFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // grabGesture(Qt::GestureType,QFlags<Qt::GestureFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_grabGesture_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "flags";
                    else if (Shiboken::Converter< ::QFlags<Qt::GestureFlag> >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QWidgetFunc_grabGesture_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.grabGesture(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::GestureType cppArg0 = Shiboken::Converter<Qt::GestureType >::toCpp(pyargs[0]);
            QFlags<Qt::GestureFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::GestureFlag> >::toCpp(pyargs[1]) : Qt::GestureFlags();

            if(!PyErr_Occurred()) {
                // grabGesture(Qt::GestureType,QFlags<Qt::GestureFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->grabGesture(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_grabGesture_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.GestureType, PySide.QtCore.Qt.GestureFlags = Qt.GestureFlags()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.grabGesture", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_grabKeyboard(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // grabKeyboard()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->grabKeyboard();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_grabMouse(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "grabMouse", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: grabMouse()
    // 1: grabMouse(QCursor)
    if (numArgs == 0) {
        overloadId = 0; // grabMouse()
    } else if (numArgs == 1 && Shiboken::Converter< ::QCursor >::isConvertible(pyargs[0])) {
        overloadId = 1; // grabMouse(QCursor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_grabMouse_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // grabMouse()
            {

                if(!PyErr_Occurred()) {
                    // grabMouse()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->grabMouse();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // grabMouse(QCursor)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QCursor cppArg0 = Shiboken::Converter<QCursor >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // grabMouse(QCursor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->grabMouse(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_grabMouse_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QCursor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.grabMouse", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_grabShortcut(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.grabShortcut(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.grabShortcut(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:grabShortcut", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: grabShortcut(QKeySequence,Qt::ShortcutContext)
    if (Shiboken::Converter< ::QKeySequence >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // grabShortcut(QKeySequence,Qt::ShortcutContext)
        } else if (Shiboken::Converter< ::Qt::ShortcutContext >::isConvertible(pyargs[1])) {
            overloadId = 0; // grabShortcut(QKeySequence,Qt::ShortcutContext)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_grabShortcut_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "context");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "context";
                    else if (Shiboken::Converter< ::Qt::ShortcutContext >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QWidgetFunc_grabShortcut_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.grabShortcut(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QKeySequence cppArg0 = Shiboken::Converter<QKeySequence >::toCpp(pyargs[0]);
            Qt::ShortcutContext cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::ShortcutContext >::toCpp(pyargs[1]) : Qt::WindowShortcut;

            if(!PyErr_Occurred()) {
                // grabShortcut(QKeySequence,Qt::ShortcutContext)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->grabShortcut(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_grabShortcut_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence, PySide.QtCore.Qt.ShortcutContext = Qt.WindowShortcut", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.grabShortcut", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_graphicsEffect(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // graphicsEffect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsEffect * cppResult = const_cast<const QWidget*>(cppSelf)->graphicsEffect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsEffect * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_graphicsProxyWidget(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // graphicsProxyWidget()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsProxyWidget * cppResult = const_cast<const QWidget*>(cppSelf)->graphicsProxyWidget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsProxyWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_hasFocus(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasFocus()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->hasFocus();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_hasMouseTracking(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasMouseTracking()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->hasMouseTracking();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_height(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // height()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QWidget*>(cppSelf)->height();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_heightForWidth(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: heightForWidth(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // heightForWidth(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_heightForWidth_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // heightForWidth(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QWidget*>(cppSelf)->::QWidget::heightForWidth(cppArg0) : const_cast<const QWidget*>(cppSelf)->heightForWidth(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_heightForWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.heightForWidth", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_hide(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hide()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->hide();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_hideEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: hideEvent(QHideEvent*)
    if (Shiboken::Converter< ::QHideEvent * >::isConvertible(arg)) {
        overloadId = 0; // hideEvent(QHideEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_hideEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QHideEvent * cppArg0 = Shiboken::Converter<QHideEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hideEvent(QHideEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::hideEvent(cppArg0) : cppSelf->hideEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_hideEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QHideEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.hideEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_inputContext(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // inputContext()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QInputContext * cppResult = cppSelf->inputContext();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QInputContext * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_inputMethodEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodEvent(QInputMethodEvent*)
    if (Shiboken::Converter< ::QInputMethodEvent * >::isConvertible(arg)) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_inputMethodEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QInputMethodEvent * cppArg0 = Shiboken::Converter<QInputMethodEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // inputMethodEvent(QInputMethodEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::inputMethodEvent(cppArg0) : cppSelf->inputMethodEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_inputMethodEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputMethodEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.inputMethodEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_inputMethodHints(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // inputMethodHints()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::InputMethodHint> cppResult = const_cast<const QWidget*>(cppSelf)->inputMethodHints();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::InputMethodHint> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_inputMethodQuery(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodQuery(Qt::InputMethodQuery)const
    if (Shiboken::Converter< ::Qt::InputMethodQuery >::isConvertible(arg)) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_inputMethodQuery_TypeError;

    // Call function/method
    {
        {
            Qt::InputMethodQuery cppArg0 = Shiboken::Converter<Qt::InputMethodQuery >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // inputMethodQuery(Qt::InputMethodQuery)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QWidget*>(cppSelf)->::QWidget::inputMethodQuery(cppArg0) : const_cast<const QWidget*>(cppSelf)->inputMethodQuery(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_inputMethodQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodQuery", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.inputMethodQuery", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_insertAction(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertAction", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertAction(QAction*,QAction*)
    if (numArgs == 2 && Shiboken::Converter< ::QAction * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QAction * >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertAction(QAction*,QAction*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_insertAction_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QAction * cppArg0 = Shiboken::Converter<QAction * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QAction * cppArg1 = Shiboken::Converter<QAction * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insertAction(QAction*,QAction*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insertAction(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[1]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_insertAction_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction, PySide.QtGui.QAction", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.insertAction", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_insertActions(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertActions", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertActions(QAction*,QList<QAction*>)
    if (numArgs == 2 && Shiboken::Converter< ::QAction * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QList<QAction * > >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertActions(QAction*,QList<QAction*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_insertActions_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QAction * cppArg0 = Shiboken::Converter<QAction * >::toCpp(pyargs[0]);
            QList<QAction * > cppArg1 = Shiboken::Converter<QList<QAction * > >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insertActions(QAction*,QList<QAction*>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insertActions(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_insertActions_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.insertActions", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_isActiveWindow(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isActiveWindow()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isActiveWindow();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_isAncestorOf(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isAncestorOf(const QWidget*)const
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // isAncestorOf(const QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_isAncestorOf_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isAncestorOf(const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isAncestorOf(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_isAncestorOf_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.isAncestorOf", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_isEnabled(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_isEnabledTo(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isEnabledTo(QWidget*)const
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // isEnabledTo(QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_isEnabledTo_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isEnabledTo(QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isEnabledTo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_isEnabledTo_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.isEnabledTo", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_isFullScreen(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isFullScreen()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isFullScreen();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_isHidden(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isHidden()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isHidden();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_isLeftToRight(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isLeftToRight()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isLeftToRight();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_isMaximized(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isMaximized()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isMaximized();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_isMinimized(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isMinimized()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isMinimized();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_isModal(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isModal()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isModal();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_isRightToLeft(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isRightToLeft()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isRightToLeft();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_isVisible(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isVisible()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isVisible();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_isVisibleTo(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isVisibleTo(QWidget*)const
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // isVisibleTo(QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_isVisibleTo_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isVisibleTo(QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isVisibleTo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_isVisibleTo_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.isVisibleTo", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_isWindow(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isWindow()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isWindow();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_isWindowModified(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isWindowModified()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->isWindowModified();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_keyPressEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyPressEvent(QKeyEvent*)
    if (Shiboken::Converter< ::QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_keyPressEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QKeyEvent * cppArg0 = Shiboken::Converter<QKeyEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // keyPressEvent(QKeyEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::keyPressEvent(cppArg0) : cppSelf->keyPressEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_keyPressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.keyPressEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_keyReleaseEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyReleaseEvent(QKeyEvent*)
    if (Shiboken::Converter< ::QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_keyReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QKeyEvent * cppArg0 = Shiboken::Converter<QKeyEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // keyReleaseEvent(QKeyEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::keyReleaseEvent(cppArg0) : cppSelf->keyReleaseEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_keyReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.keyReleaseEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_keyboardGrabber(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // keyboardGrabber()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = QWidget::keyboardGrabber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_languageChange(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // languageChange()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::languageChange() : cppSelf->languageChange());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_layout(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // layout()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLayout * cppResult = const_cast<const QWidget*>(cppSelf)->layout();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLayout * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_layoutDirection(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // layoutDirection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::LayoutDirection cppResult = const_cast<const QWidget*>(cppSelf)->layoutDirection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::LayoutDirection >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_leaveEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: leaveEvent(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // leaveEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_leaveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // leaveEvent(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::leaveEvent(cppArg0) : cppSelf->leaveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_leaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.leaveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_locale(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // locale()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLocale cppResult = const_cast<const QWidget*>(cppSelf)->locale();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLocale >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_lower(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lower()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->lower();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_mapFrom(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "mapFrom", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: mapFrom(QWidget*,QPoint)const
    if (numArgs == 2 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[1])) {
        overloadId = 0; // mapFrom(QWidget*,QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_mapFrom_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPoint cppArg1 = Shiboken::Converter<QPoint >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // mapFrom(QWidget*,QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QWidget*>(cppSelf)->mapFrom(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_mapFrom_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.mapFrom", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_mapFromGlobal(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapFromGlobal(QPoint)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // mapFromGlobal(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_mapFromGlobal_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mapFromGlobal(QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QWidget*>(cppSelf)->mapFromGlobal(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_mapFromGlobal_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mapFromGlobal", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_mapFromParent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapFromParent(QPoint)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // mapFromParent(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_mapFromParent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mapFromParent(QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QWidget*>(cppSelf)->mapFromParent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_mapFromParent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mapFromParent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_mapTo(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "mapTo", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: mapTo(QWidget*,QPoint)const
    if (numArgs == 2 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[1])) {
        overloadId = 0; // mapTo(QWidget*,QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_mapTo_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPoint cppArg1 = Shiboken::Converter<QPoint >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // mapTo(QWidget*,QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QWidget*>(cppSelf)->mapTo(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_mapTo_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.mapTo", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_mapToGlobal(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapToGlobal(QPoint)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // mapToGlobal(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_mapToGlobal_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mapToGlobal(QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QWidget*>(cppSelf)->mapToGlobal(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_mapToGlobal_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mapToGlobal", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_mapToParent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapToParent(QPoint)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // mapToParent(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_mapToParent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mapToParent(QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QWidget*>(cppSelf)->mapToParent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_mapToParent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mapToParent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_mask(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // mask()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRegion cppResult = const_cast<const QWidget*>(cppSelf)->mask();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRegion >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_maximumHeight(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // maximumHeight()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QWidget*>(cppSelf)->maximumHeight();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_maximumSize(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // maximumSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QWidget*>(cppSelf)->maximumSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_maximumWidth(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // maximumWidth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QWidget*>(cppSelf)->maximumWidth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_metric(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: metric(QPaintDevice::PaintDeviceMetric)const
    if (Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::isConvertible(arg)) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_metric_TypeError;

    // Call function/method
    {
        {
            QPaintDevice::PaintDeviceMetric cppArg0 = Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // metric(QPaintDevice::PaintDeviceMetric)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QWidget*>(cppSelf)->::QWidget::metric(cppArg0) : const_cast<const QWidget*>(cppSelf)->metric(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_metric_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice.PaintDeviceMetric", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.metric", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_minimumHeight(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // minimumHeight()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QWidget*>(cppSelf)->minimumHeight();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_minimumSize(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // minimumSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QWidget*>(cppSelf)->minimumSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_minimumSizeHint(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // minimumSizeHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QWidget*>(cppSelf)->::QWidget::minimumSizeHint() : const_cast<const QWidget*>(cppSelf)->minimumSizeHint());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_minimumWidth(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // minimumWidth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QWidget*>(cppSelf)->minimumWidth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_mouseDoubleClickEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseDoubleClickEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseDoubleClickEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_mouseDoubleClickEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseDoubleClickEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::mouseDoubleClickEvent(cppArg0) : cppSelf->mouseDoubleClickEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_mouseDoubleClickEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mouseDoubleClickEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_mouseGrabber(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // mouseGrabber()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = QWidget::mouseGrabber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_mouseMoveEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseMoveEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_mouseMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseMoveEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::mouseMoveEvent(cppArg0) : cppSelf->mouseMoveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_mouseMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mouseMoveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_mousePressEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mousePressEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_mousePressEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mousePressEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::mousePressEvent(cppArg0) : cppSelf->mousePressEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_mousePressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mousePressEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_mouseReleaseEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseReleaseEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_mouseReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseReleaseEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::mouseReleaseEvent(cppArg0) : cppSelf->mouseReleaseEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_mouseReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mouseReleaseEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_move(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "move", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: move(QPoint)
    // 1: move(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // move(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // move(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_move_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // move(QPoint)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // move(QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->move(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // move(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // move(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->move(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_move_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.move", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_moveEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveEvent(QMoveEvent*)
    if (Shiboken::Converter< ::QMoveEvent * >::isConvertible(arg)) {
        overloadId = 0; // moveEvent(QMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_moveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMoveEvent * cppArg0 = Shiboken::Converter<QMoveEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // moveEvent(QMoveEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::moveEvent(cppArg0) : cppSelf->moveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_moveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMoveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.moveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_nativeParentWidget(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nativeParentWidget()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QWidget*>(cppSelf)->nativeParentWidget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_nextInFocusChain(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nextInFocusChain()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QWidget*>(cppSelf)->nextInFocusChain();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_normalGeometry(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // normalGeometry()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QWidget*>(cppSelf)->normalGeometry();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_overrideWindowFlags(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: overrideWindowFlags(QFlags<Qt::WindowType>)
    if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(arg)) {
        overloadId = 0; // overrideWindowFlags(QFlags<Qt::WindowType>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_overrideWindowFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::WindowType> cppArg0 = Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // overrideWindowFlags(QFlags<Qt::WindowType>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->overrideWindowFlags(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_overrideWindowFlags_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WindowFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.overrideWindowFlags", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_overrideWindowState(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: overrideWindowState(QFlags<Qt::WindowState>)
    if (Shiboken::Converter< ::QFlags<Qt::WindowState> >::isConvertible(arg)) {
        overloadId = 0; // overrideWindowState(QFlags<Qt::WindowState>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_overrideWindowState_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::WindowState> cppArg0 = Shiboken::Converter<QFlags<Qt::WindowState> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // overrideWindowState(QFlags<Qt::WindowState>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->overrideWindowState(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_overrideWindowState_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WindowStates", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.overrideWindowState", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_paintEngine(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // paintEngine()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPaintEngine * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QWidget*>(cppSelf)->::QWidget::paintEngine() : const_cast<const QWidget*>(cppSelf)->paintEngine());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPaintEngine * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_paintEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: paintEvent(QPaintEvent*)
    if (Shiboken::Converter< ::QPaintEvent * >::isConvertible(arg)) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_paintEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPaintEvent * cppArg0 = Shiboken::Converter<QPaintEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // paintEvent(QPaintEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::paintEvent(cppArg0) : cppSelf->paintEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_paintEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.paintEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_palette(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // palette()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QPalette & cppResult = const_cast<const QWidget*>(cppSelf)->palette();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPalette >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_parentWidget(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // parentWidget()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QWidget*>(cppSelf)->parentWidget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);

                // Ownership transferences.
                Shiboken::Object::getOwnership(pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_pos(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QWidget*>(cppSelf)->pos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_previousInFocusChain(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // previousInFocusChain()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QWidget*>(cppSelf)->previousInFocusChain();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_raise_(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // raise()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->raise();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_rect(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QWidget*>(cppSelf)->rect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_releaseKeyboard(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // releaseKeyboard()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->releaseKeyboard();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_releaseMouse(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // releaseMouse()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->releaseMouse();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_releaseShortcut(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: releaseShortcut(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // releaseShortcut(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_releaseShortcut_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // releaseShortcut(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->releaseShortcut(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_releaseShortcut_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.releaseShortcut", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_removeAction(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAction(QAction*)
    if (Shiboken::Converter< ::QAction * >::isConvertible(arg)) {
        overloadId = 0; // removeAction(QAction*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_removeAction_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAction * cppArg0 = Shiboken::Converter<QAction * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeAction(QAction*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeAction(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_removeAction_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.removeAction", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_render(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.render(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.render(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:render", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
    // 1: render(QPainter*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
    if (numArgs >= 2 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // render(QPainter*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
        } else if (Shiboken::Converter< ::QRegion >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // render(QPainter*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
            } else if (Shiboken::Converter< ::QFlags<QWidget::RenderFlag> >::isConvertible(pyargs[3])) {
                overloadId = 1; // render(QPainter*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
            }
        }
    } else if (Shiboken::Converter< ::QPaintDevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
        } else if (Shiboken::Converter< ::QPoint >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
            } else if (Shiboken::Converter< ::QRegion >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
                } else if (Shiboken::Converter< ::QFlags<QWidget::RenderFlag> >::isConvertible(pyargs[3])) {
                    overloadId = 0; // render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_render_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "targetOffset");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "targetOffset";
                        else if (Shiboken::Converter< ::QPoint >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QWidgetFunc_render_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "sourceRegion");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "sourceRegion";
                        else if (Shiboken::Converter< ::QRegion >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QWidgetFunc_render_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "renderFlags");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "renderFlags";
                        else if (Shiboken::Converter< ::QFlags<QWidget::RenderFlag> >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QWidgetFunc_render_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.render(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPaintDevice * cppArg0 = Shiboken::Converter<QPaintDevice * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPoint cppArg1_tmp = QPoint();
                QPoint cppArg1 = pyargs[1] ? Shiboken::Converter<QPoint >::toCpp(pyargs[1]) : cppArg1_tmp;
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QRegion cppArg2_tmp = QRegion();
                QRegion cppArg2 = pyargs[2] ? Shiboken::Converter<QRegion >::toCpp(pyargs[2]) : cppArg2_tmp;
                QFlags<QWidget::RenderFlag> cppArg3 = pyargs[3] ? Shiboken::Converter<QFlags<QWidget::RenderFlag> >::toCpp(pyargs[3]) : QWidget::RenderFlags(QWidget::DrawWindowBackground |QWidget:: DrawChildren);

                if(!PyErr_Occurred()) {
                    // render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->render(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // render(QPainter*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "sourceRegion");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "sourceRegion";
                        else if (Shiboken::Converter< ::QRegion >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QWidgetFunc_render_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "renderFlags");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "renderFlags";
                        else if (Shiboken::Converter< ::QFlags<QWidget::RenderFlag> >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QWidgetFunc_render_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.render(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPoint cppArg1 = Shiboken::Converter<QPoint >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QRegion cppArg2_tmp = QRegion();
                QRegion cppArg2 = pyargs[2] ? Shiboken::Converter<QRegion >::toCpp(pyargs[2]) : cppArg2_tmp;
                QFlags<QWidget::RenderFlag> cppArg3 = pyargs[3] ? Shiboken::Converter<QFlags<QWidget::RenderFlag> >::toCpp(pyargs[3]) : QWidget::RenderFlags(QWidget::DrawWindowBackground |QWidget:: DrawChildren);

                if(!PyErr_Occurred()) {
                    // render(QPainter*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->render(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_render_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice, PySide.QtCore.QPoint = QPoint(), PySide.QtGui.QRegion = QRegion(), PySide.QtGui.QWidget.RenderFlags = QWidget.RenderFlags(DrawWindowBackground | DrawChildren)", "PySide.QtGui.QPainter, PySide.QtCore.QPoint, PySide.QtGui.QRegion = QRegion(), PySide.QtGui.QWidget.RenderFlags = QWidget.RenderFlags(DrawWindowBackground | DrawChildren)", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.render", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_repaint(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QWidgetFunc_repaint_TypeError;

    if (!PyArg_UnpackTuple(args, "repaint", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: repaint()
    // 1: repaint(QRect)
    // 2: repaint(QRegion)
    // 3: repaint(int,int,int,int)
    if (numArgs == 0) {
        overloadId = 0; // repaint()
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 3; // repaint(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        overloadId = 1; // repaint(QRect)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRegion >::isConvertible(pyargs[0])) {
        overloadId = 2; // repaint(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_repaint_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // repaint()
            {

                if(!PyErr_Occurred()) {
                    // repaint()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->repaint();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // repaint(QRect)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // repaint(QRect)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->repaint(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // repaint(QRegion)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRegion cppArg0 = Shiboken::Converter<QRegion >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // repaint(QRegion)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->repaint(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // repaint(int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // repaint(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->repaint(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_repaint_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QRect", "PySide.QtGui.QRegion", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.repaint", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_resetInputContext(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // resetInputContext()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resetInputContext();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_resize(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "resize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: resize(QSize)
    // 1: resize(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // resize(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        overloadId = 0; // resize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_resize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // resize(QSize)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // resize(QSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->resize(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // resize(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // resize(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->resize(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_resize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.resize", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_resizeEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resizeEvent(QResizeEvent*)
    if (Shiboken::Converter< ::QResizeEvent * >::isConvertible(arg)) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_resizeEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QResizeEvent * cppArg0 = Shiboken::Converter<QResizeEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // resizeEvent(QResizeEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::resizeEvent(cppArg0) : cppSelf->resizeEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_resizeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QResizeEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.resizeEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_restoreGeometry(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: restoreGeometry(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // restoreGeometry(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_restoreGeometry_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // restoreGeometry(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->restoreGeometry(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_restoreGeometry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.restoreGeometry", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_saveGeometry(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // saveGeometry()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = const_cast<const QWidget*>(cppSelf)->saveGeometry();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_scroll(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scroll", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: scroll(int,int)
    // 1: scroll(int,int,QRect)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // scroll(int,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[2])) {
            overloadId = 1; // scroll(int,int,QRect)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_scroll_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // scroll(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // scroll(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->scroll(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // scroll(int,int,QRect)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QRect cppArg2 = Shiboken::Converter<QRect >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // scroll(int,int,QRect)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->scroll(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_scroll_TypeError:
        const char* overloads[] = {"int, int", "int, int, PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.scroll", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setAcceptDrops(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAcceptDrops(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAcceptDrops(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setAcceptDrops_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAcceptDrops(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAcceptDrops(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setAcceptDrops_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setAcceptDrops", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setAccessibleDescription(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAccessibleDescription(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setAccessibleDescription(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setAccessibleDescription_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAccessibleDescription(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAccessibleDescription(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setAccessibleDescription_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setAccessibleDescription", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setAccessibleName(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAccessibleName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setAccessibleName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setAccessibleName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAccessibleName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAccessibleName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setAccessibleName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setAccessibleName", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setAttribute(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.setAttribute(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.setAttribute(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setAttribute", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAttribute(Qt::WidgetAttribute,bool)
    if (Shiboken::Converter< ::Qt::WidgetAttribute >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setAttribute(Qt::WidgetAttribute,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setAttribute(Qt::WidgetAttribute,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setAttribute_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "on");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "on";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QWidgetFunc_setAttribute_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.setAttribute(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::WidgetAttribute cppArg0 = Shiboken::Converter<Qt::WidgetAttribute >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // setAttribute(Qt::WidgetAttribute,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttribute(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setAttribute_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WidgetAttribute, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setAutoFillBackground(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoFillBackground(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoFillBackground(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setAutoFillBackground_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAutoFillBackground(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAutoFillBackground(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setAutoFillBackground_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setAutoFillBackground", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setBackgroundRole(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackgroundRole(QPalette::ColorRole)
    if (Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(arg)) {
        overloadId = 0; // setBackgroundRole(QPalette::ColorRole)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setBackgroundRole_TypeError;

    // Call function/method
    {
        {
            QPalette::ColorRole cppArg0 = Shiboken::Converter<QPalette::ColorRole >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBackgroundRole(QPalette::ColorRole)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBackgroundRole(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setBackgroundRole_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorRole", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setBackgroundRole", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setBaseSize(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setBaseSize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setBaseSize(QSize)
    // 1: setBaseSize(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setBaseSize(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        overloadId = 0; // setBaseSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setBaseSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setBaseSize(QSize)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setBaseSize(QSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setBaseSize(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setBaseSize(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setBaseSize(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setBaseSize(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setBaseSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setBaseSize", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setContentsMargins(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QWidgetFunc_setContentsMargins_TypeError;

    if (!PyArg_UnpackTuple(args, "setContentsMargins", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setContentsMargins(QMargins)
    // 1: setContentsMargins(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // setContentsMargins(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QMargins >::isConvertible(pyargs[0])) {
        overloadId = 0; // setContentsMargins(QMargins)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setContentsMargins_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setContentsMargins(QMargins)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QMargins cppArg0 = Shiboken::Converter<QMargins >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setContentsMargins(QMargins)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setContentsMargins(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setContentsMargins(int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // setContentsMargins(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setContentsMargins(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setContentsMargins_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMargins", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setContentsMargins", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setContextMenuPolicy(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setContextMenuPolicy(Qt::ContextMenuPolicy)
    if (Shiboken::Converter< ::Qt::ContextMenuPolicy >::isConvertible(arg)) {
        overloadId = 0; // setContextMenuPolicy(Qt::ContextMenuPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setContextMenuPolicy_TypeError;

    // Call function/method
    {
        {
            Qt::ContextMenuPolicy cppArg0 = Shiboken::Converter<Qt::ContextMenuPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setContextMenuPolicy(Qt::ContextMenuPolicy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setContextMenuPolicy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setContextMenuPolicy_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ContextMenuPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setContextMenuPolicy", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setCursor(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCursor(QCursor)
    if (Shiboken::Converter< ::QCursor >::isConvertible(arg)) {
        overloadId = 0; // setCursor(QCursor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setCursor_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QCursor cppArg0 = Shiboken::Converter<QCursor >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCursor(QCursor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCursor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setCursor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QCursor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setCursor", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setDisabled(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDisabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDisabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setDisabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDisabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDisabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setDisabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setDisabled", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setEnabled(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setFixedHeight(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFixedHeight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFixedHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setFixedHeight_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFixedHeight(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFixedHeight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setFixedHeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setFixedHeight", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setFixedSize(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFixedSize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFixedSize(QSize)
    // 1: setFixedSize(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setFixedSize(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        overloadId = 0; // setFixedSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setFixedSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setFixedSize(QSize)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setFixedSize(QSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setFixedSize(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setFixedSize(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setFixedSize(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setFixedSize(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setFixedSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setFixedSize", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setFixedWidth(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFixedWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFixedWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setFixedWidth_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFixedWidth(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFixedWidth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setFixedWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setFixedWidth", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setFocus(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFocus", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: setFocus()
    // 1: setFocus(Qt::FocusReason)
    if (numArgs == 0) {
        overloadId = 0; // setFocus()
    } else if (numArgs == 1 && Shiboken::Converter< ::Qt::FocusReason >::isConvertible(pyargs[0])) {
        overloadId = 1; // setFocus(Qt::FocusReason)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setFocus_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setFocus()
            {

                if(!PyErr_Occurred()) {
                    // setFocus()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setFocus();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setFocus(Qt::FocusReason)
            {
                Qt::FocusReason cppArg0 = Shiboken::Converter<Qt::FocusReason >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setFocus(Qt::FocusReason)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setFocus(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setFocus_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.Qt.FocusReason", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setFocus", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setFocusPolicy(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFocusPolicy(Qt::FocusPolicy)
    if (Shiboken::Converter< ::Qt::FocusPolicy >::isConvertible(arg)) {
        overloadId = 0; // setFocusPolicy(Qt::FocusPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setFocusPolicy_TypeError;

    // Call function/method
    {
        {
            Qt::FocusPolicy cppArg0 = Shiboken::Converter<Qt::FocusPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFocusPolicy(Qt::FocusPolicy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFocusPolicy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setFocusPolicy_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.FocusPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setFocusPolicy", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setFocusProxy(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFocusProxy(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setFocusProxy(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setFocusProxy_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFocusProxy(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFocusProxy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setFocusProxy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setFocusProxy", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setFont(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFont(QFont)
    if (Shiboken::Converter< ::QFont >::isConvertible(arg)) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setFont_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFont cppArg0 = Shiboken::Converter<QFont >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFont(QFont)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFont(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setFont", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setForegroundRole(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setForegroundRole(QPalette::ColorRole)
    if (Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(arg)) {
        overloadId = 0; // setForegroundRole(QPalette::ColorRole)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setForegroundRole_TypeError;

    // Call function/method
    {
        {
            QPalette::ColorRole cppArg0 = Shiboken::Converter<QPalette::ColorRole >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setForegroundRole(QPalette::ColorRole)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setForegroundRole(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setForegroundRole_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorRole", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setForegroundRole", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setGeometry(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QWidgetFunc_setGeometry_TypeError;

    if (!PyArg_UnpackTuple(args, "setGeometry", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setGeometry(QRect)
    // 1: setGeometry(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // setGeometry(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        overloadId = 0; // setGeometry(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setGeometry_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setGeometry(QRect)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setGeometry(QRect)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setGeometry(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setGeometry(int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // setGeometry(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setGeometry(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setGeometry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setGeometry", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setGraphicsEffect(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGraphicsEffect(QGraphicsEffect*)
    if (Shiboken::Converter< ::QGraphicsEffect * >::isConvertible(arg)) {
        overloadId = 0; // setGraphicsEffect(QGraphicsEffect*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setGraphicsEffect_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsEffect * cppArg0 = Shiboken::Converter<QGraphicsEffect * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGraphicsEffect(QGraphicsEffect*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setGraphicsEffect(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setGraphicsEffect_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsEffect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setGraphicsEffect", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setHidden(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHidden(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHidden(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setHidden_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHidden(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHidden(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setHidden_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setHidden", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setInputContext(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInputContext(QInputContext*)
    if (Shiboken::Converter< ::QInputContext * >::isConvertible(arg)) {
        overloadId = 0; // setInputContext(QInputContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setInputContext_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QInputContext * cppArg0 = Shiboken::Converter<QInputContext * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setInputContext(QInputContext*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setInputContext(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

                // Ownership transferences.
                Shiboken::Object::releaseOwnership(arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setInputContext_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputContext", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setInputContext", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setInputMethodHints(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInputMethodHints(QFlags<Qt::InputMethodHint>)
    if (Shiboken::Converter< ::QFlags<Qt::InputMethodHint> >::isConvertible(arg)) {
        overloadId = 0; // setInputMethodHints(QFlags<Qt::InputMethodHint>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setInputMethodHints_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::InputMethodHint> cppArg0 = Shiboken::Converter<QFlags<Qt::InputMethodHint> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setInputMethodHints(QFlags<Qt::InputMethodHint>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setInputMethodHints(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setInputMethodHints_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodHints", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setInputMethodHints", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setLayout(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLayout(QLayout*)
    if (Shiboken::Converter< ::QLayout * >::isConvertible(arg)) {
        overloadId = 0; // setLayout(QLayout*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setLayout_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QLayout * cppArg0 = Shiboken::Converter<QLayout * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLayout(QLayout*)
                // Begin code injection

                qwidgetSetLayout(cppSelf, cppArg0);
                // setLayout() - disable generation of function call.

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setLayout_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayout", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setLayout", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setLayoutDirection(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLayoutDirection(Qt::LayoutDirection)
    if (Shiboken::Converter< ::Qt::LayoutDirection >::isConvertible(arg)) {
        overloadId = 0; // setLayoutDirection(Qt::LayoutDirection)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setLayoutDirection_TypeError;

    // Call function/method
    {
        {
            Qt::LayoutDirection cppArg0 = Shiboken::Converter<Qt::LayoutDirection >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLayoutDirection(Qt::LayoutDirection)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLayoutDirection(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setLayoutDirection_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.LayoutDirection", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setLayoutDirection", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setLocale(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLocale(QLocale)
    if (Shiboken::Converter< ::QLocale >::isConvertible(arg)) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setLocale_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QLocale cppArg0 = Shiboken::Converter<QLocale >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLocale(QLocale)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLocale(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setLocale_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLocale", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setLocale", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setMask(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMask(QBitmap)
    // 1: setMask(QRegion)
    if (Shiboken::Converter< ::QBitmap >::isConvertible(arg)) {
        overloadId = 0; // setMask(QBitmap)
    } else if (Shiboken::Converter< ::QRegion >::isConvertible(arg)) {
        overloadId = 1; // setMask(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setMask_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setMask(QBitmap)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QBitmap cppArg0 = Shiboken::Converter<QBitmap >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setMask(QBitmap)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setMask(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setMask(QRegion)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QRegion cppArg0 = Shiboken::Converter<QRegion >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setMask(QRegion)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setMask(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setMask_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBitmap", "PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setMask", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setMaximumHeight(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaximumHeight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaximumHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setMaximumHeight_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMaximumHeight(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMaximumHeight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setMaximumHeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setMaximumHeight", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setMaximumSize(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setMaximumSize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setMaximumSize(QSize)
    // 1: setMaximumSize(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setMaximumSize(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        overloadId = 0; // setMaximumSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setMaximumSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setMaximumSize(QSize)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setMaximumSize(QSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setMaximumSize(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setMaximumSize(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setMaximumSize(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setMaximumSize(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setMaximumSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setMaximumSize", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setMaximumWidth(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaximumWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaximumWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setMaximumWidth_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMaximumWidth(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMaximumWidth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setMaximumWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setMaximumWidth", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setMinimumHeight(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMinimumHeight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMinimumHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setMinimumHeight_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMinimumHeight(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMinimumHeight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setMinimumHeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setMinimumHeight", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setMinimumSize(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setMinimumSize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setMinimumSize(QSize)
    // 1: setMinimumSize(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setMinimumSize(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        overloadId = 0; // setMinimumSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setMinimumSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setMinimumSize(QSize)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setMinimumSize(QSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setMinimumSize(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setMinimumSize(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setMinimumSize(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setMinimumSize(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setMinimumSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setMinimumSize", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setMinimumWidth(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMinimumWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMinimumWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setMinimumWidth_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMinimumWidth(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMinimumWidth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setMinimumWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setMinimumWidth", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setMouseTracking(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMouseTracking(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMouseTracking(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setMouseTracking_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMouseTracking(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMouseTracking(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setMouseTracking_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setMouseTracking", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setPalette(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPalette(QPalette)
    if (Shiboken::Converter< ::QPalette >::isConvertible(arg)) {
        overloadId = 0; // setPalette(QPalette)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setPalette_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPalette cppArg0 = Shiboken::Converter<QPalette >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPalette(QPalette)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPalette(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setPalette_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setPalette", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setParent(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setParent", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setParent(QWidget*)
    // 1: setParent(QWidget*,QFlags<Qt::WindowType>)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setParent(QWidget*)
        } else if (numArgs == 2 && Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(pyargs[1])) {
            overloadId = 1; // setParent(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setParent_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setParent(QWidget*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setParent(QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setParent(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // setParent(QWidget*,QFlags<Qt::WindowType>)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
                QFlags<Qt::WindowType> cppArg1 = Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setParent(QWidget*,QFlags<Qt::WindowType>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setParent(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setParent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", "PySide.QtGui.QWidget, PySide.QtCore.Qt.WindowFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setParent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setShortcutAutoRepeat(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutAutoRepeat(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutAutoRepeat(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setShortcutAutoRepeat", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setShortcutAutoRepeat(int,bool)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setShortcutAutoRepeat(int,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setShortcutAutoRepeat(int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setShortcutAutoRepeat_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "enable");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "enable";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QWidgetFunc_setShortcutAutoRepeat_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutAutoRepeat(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // setShortcutAutoRepeat(int,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setShortcutAutoRepeat(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setShortcutAutoRepeat_TypeError:
        const char* overloads[] = {"int, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setShortcutAutoRepeat", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setShortcutEnabled(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutEnabled(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutEnabled(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setShortcutEnabled", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setShortcutEnabled(int,bool)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setShortcutEnabled(int,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setShortcutEnabled(int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setShortcutEnabled_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "enable");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "enable";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QWidgetFunc_setShortcutEnabled_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutEnabled(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // setShortcutEnabled(int,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setShortcutEnabled(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setShortcutEnabled_TypeError:
        const char* overloads[] = {"int, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setShortcutEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setSizeIncrement(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSizeIncrement", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setSizeIncrement(QSize)
    // 1: setSizeIncrement(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setSizeIncrement(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        overloadId = 0; // setSizeIncrement(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setSizeIncrement_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setSizeIncrement(QSize)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setSizeIncrement(QSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setSizeIncrement(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setSizeIncrement(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setSizeIncrement(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setSizeIncrement(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setSizeIncrement_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setSizeIncrement", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setSizePolicy(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSizePolicy", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setSizePolicy(QSizePolicy)
    // 1: setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
    if (numArgs == 2 && Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(pyargs[1])) {
        overloadId = 1; // setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
    } else if (numArgs == 1 && Shiboken::Converter< ::QSizePolicy >::isConvertible(pyargs[0])) {
        overloadId = 0; // setSizePolicy(QSizePolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setSizePolicy_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setSizePolicy(QSizePolicy)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QSizePolicy cppArg0 = Shiboken::Converter<QSizePolicy >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setSizePolicy(QSizePolicy)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setSizePolicy(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
            {
                QSizePolicy::Policy cppArg0 = Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[0]);
                QSizePolicy::Policy cppArg1 = Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setSizePolicy(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setSizePolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSizePolicy", "PySide.QtGui.QSizePolicy.Policy, PySide.QtGui.QSizePolicy.Policy", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setSizePolicy", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setStatusTip(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStatusTip(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setStatusTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setStatusTip_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStatusTip(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStatusTip(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setStatusTip_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setStatusTip", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setStyle(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyle(QStyle*)
    if (Shiboken::Converter< ::QStyle * >::isConvertible(arg)) {
        overloadId = 0; // setStyle(QStyle*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setStyle_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QStyle * cppArg0 = Shiboken::Converter<QStyle * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStyle(QStyle*)

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStyle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

                // Begin code injection

                Shiboken::Object::keepReference(reinterpret_cast<SbkObject*>(self), "__style__",  arg);

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setStyle", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setStyleSheet(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyleSheet(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setStyleSheet(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setStyleSheet_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStyleSheet(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStyleSheet(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setStyleSheet_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setStyleSheet", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setTabOrder(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setTabOrder", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setTabOrder(QWidget*,QWidget*)
    if (numArgs == 2 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setTabOrder(QWidget*,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setTabOrder_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QWidget * cppArg1 = Shiboken::Converter<QWidget * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setTabOrder(QWidget*,QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget::setTabOrder(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setTabOrder_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setTabOrder", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setToolTip(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setToolTip(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setToolTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setToolTip_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setToolTip(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setToolTip(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setToolTip_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setToolTip", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setUpdatesEnabled(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUpdatesEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUpdatesEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setUpdatesEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUpdatesEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUpdatesEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setUpdatesEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setUpdatesEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setVisible(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setVisible_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVisible(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::setVisible(cppArg0) : cppSelf->setVisible(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setVisible", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setWhatsThis(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWhatsThis(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setWhatsThis(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setWhatsThis_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWhatsThis(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWhatsThis(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setWhatsThis_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWhatsThis", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setWindowFilePath(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowFilePath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setWindowFilePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setWindowFilePath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWindowFilePath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWindowFilePath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setWindowFilePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowFilePath", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setWindowFlags(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowFlags(QFlags<Qt::WindowType>)
    if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(arg)) {
        overloadId = 0; // setWindowFlags(QFlags<Qt::WindowType>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setWindowFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::WindowType> cppArg0 = Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWindowFlags(QFlags<Qt::WindowType>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWindowFlags(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setWindowFlags_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WindowFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowFlags", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setWindowIcon(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowIcon(QIcon)
    if (Shiboken::Converter< ::QIcon >::isConvertible(arg)) {
        overloadId = 0; // setWindowIcon(QIcon)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setWindowIcon_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QIcon cppArg0 = Shiboken::Converter<QIcon >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWindowIcon(QIcon)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWindowIcon(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setWindowIcon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QIcon", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowIcon", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setWindowIconText(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowIconText(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setWindowIconText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setWindowIconText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWindowIconText(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWindowIconText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setWindowIconText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowIconText", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setWindowModality(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowModality(Qt::WindowModality)
    if (Shiboken::Converter< ::Qt::WindowModality >::isConvertible(arg)) {
        overloadId = 0; // setWindowModality(Qt::WindowModality)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setWindowModality_TypeError;

    // Call function/method
    {
        {
            Qt::WindowModality cppArg0 = Shiboken::Converter<Qt::WindowModality >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWindowModality(Qt::WindowModality)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWindowModality(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setWindowModality_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WindowModality", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowModality", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setWindowModified(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowModified(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWindowModified(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setWindowModified_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWindowModified(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWindowModified(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setWindowModified_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowModified", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setWindowOpacity(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowOpacity(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWindowOpacity(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setWindowOpacity_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWindowOpacity(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWindowOpacity(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setWindowOpacity_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowOpacity", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setWindowRole(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowRole(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setWindowRole(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setWindowRole_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWindowRole(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWindowRole(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setWindowRole_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowRole", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setWindowState(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowState(QFlags<Qt::WindowState>)
    if (Shiboken::Converter< ::QFlags<Qt::WindowState> >::isConvertible(arg)) {
        overloadId = 0; // setWindowState(QFlags<Qt::WindowState>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setWindowState_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::WindowState> cppArg0 = Shiboken::Converter<QFlags<Qt::WindowState> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWindowState(QFlags<Qt::WindowState>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWindowState(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setWindowState_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WindowStates", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowState", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_setWindowTitle(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowTitle(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setWindowTitle(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_setWindowTitle_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWindowTitle(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWindowTitle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_setWindowTitle_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowTitle", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_show(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // show()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->show();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_showEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: showEvent(QShowEvent*)
    if (Shiboken::Converter< ::QShowEvent * >::isConvertible(arg)) {
        overloadId = 0; // showEvent(QShowEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_showEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QShowEvent * cppArg0 = Shiboken::Converter<QShowEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // showEvent(QShowEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::showEvent(cppArg0) : cppSelf->showEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_showEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QShowEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.showEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_showFullScreen(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // showFullScreen()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->showFullScreen();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_showMaximized(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // showMaximized()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->showMaximized();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_showMinimized(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // showMinimized()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->showMinimized();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_showNormal(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // showNormal()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->showNormal();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_size(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QWidget*>(cppSelf)->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_sizeHint(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sizeHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QWidget*>(cppSelf)->::QWidget::sizeHint() : const_cast<const QWidget*>(cppSelf)->sizeHint());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_sizeIncrement(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sizeIncrement()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QWidget*>(cppSelf)->sizeIncrement();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_sizePolicy(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sizePolicy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSizePolicy cppResult = const_cast<const QWidget*>(cppSelf)->sizePolicy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSizePolicy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_stackUnder(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: stackUnder(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // stackUnder(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_stackUnder_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // stackUnder(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->stackUnder(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_stackUnder_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.stackUnder", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_statusTip(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // statusTip()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWidget*>(cppSelf)->statusTip();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_style(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // style()const


                // Begin code injection

                QStyle* myStyle = cppSelf->style();
                if (myStyle && qApp) {
                pyResult = Shiboken::Converter<QStyle* >::toPython(myStyle);
                    QStyle *appStyle = qApp->style();
                    if (appStyle == myStyle) {
                        Shiboken::AutoDecRef pyApp(Shiboken::Converter<QApplication* >::toPython(qApp));
                        Shiboken::Object::setParent(pyApp, pyResult);
                        Shiboken::Object::releaseOwnership(pyResult);
                    } else {
                        Shiboken::Object::keepReference(reinterpret_cast<SbkObject*>(self), "__style__",  pyResult);
                    }
                }

                // End of code injection

                // Ownership transferences.
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_styleSheet(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // styleSheet()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWidget*>(cppSelf)->styleSheet();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_tabletEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: tabletEvent(QTabletEvent*)
    if (Shiboken::Converter< ::QTabletEvent * >::isConvertible(arg)) {
        overloadId = 0; // tabletEvent(QTabletEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_tabletEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTabletEvent * cppArg0 = Shiboken::Converter<QTabletEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // tabletEvent(QTabletEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::tabletEvent(cppArg0) : cppSelf->tabletEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_tabletEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTabletEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.tabletEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_testAttribute(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testAttribute(Qt::WidgetAttribute)const
    if (Shiboken::Converter< ::Qt::WidgetAttribute >::isConvertible(arg)) {
        overloadId = 0; // testAttribute(Qt::WidgetAttribute)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_testAttribute_TypeError;

    // Call function/method
    {
        {
            Qt::WidgetAttribute cppArg0 = Shiboken::Converter<Qt::WidgetAttribute >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // testAttribute(Qt::WidgetAttribute)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->testAttribute(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWidgetFunc_testAttribute_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WidgetAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.testAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_toolTip(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toolTip()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWidget*>(cppSelf)->toolTip();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_underMouse(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // underMouse()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->underMouse();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_ungrabGesture(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: ungrabGesture(Qt::GestureType)
    if (Shiboken::Converter< ::Qt::GestureType >::isConvertible(arg)) {
        overloadId = 0; // ungrabGesture(Qt::GestureType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_ungrabGesture_TypeError;

    // Call function/method
    {
        {
            Qt::GestureType cppArg0 = Shiboken::Converter<Qt::GestureType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // ungrabGesture(Qt::GestureType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->ungrabGesture(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_ungrabGesture_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.GestureType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.ungrabGesture", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_unsetCursor(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // unsetCursor()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->unsetCursor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_unsetLayoutDirection(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // unsetLayoutDirection()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->unsetLayoutDirection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_unsetLocale(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // unsetLocale()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->unsetLocale();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_update(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QWidgetFunc_update_TypeError;

    if (!PyArg_UnpackTuple(args, "update", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: update()
    // 1: update(QRect)
    // 2: update(QRegion)
    // 3: update(int,int,int,int)
    if (numArgs == 0) {
        overloadId = 0; // update()
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 3; // update(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        overloadId = 1; // update(QRect)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRegion >::isConvertible(pyargs[0])) {
        overloadId = 2; // update(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_update_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // update()
            {

                if(!PyErr_Occurred()) {
                    // update()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->update();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // update(QRect)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // update(QRect)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->update(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // update(QRegion)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRegion cppArg0 = Shiboken::Converter<QRegion >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // update(QRegion)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->update(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // update(int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // update(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->update(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_update_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QRect", "PySide.QtGui.QRegion", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.update", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_updateGeometry(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // updateGeometry()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->updateGeometry();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_updateMicroFocus(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // updateMicroFocus()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->updateMicroFocus();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWidgetFunc_updatesEnabled(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // updatesEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWidget*>(cppSelf)->updatesEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_visibleRegion(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // visibleRegion()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRegion cppResult = const_cast<const QWidget*>(cppSelf)->visibleRegion();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRegion >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_whatsThis(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // whatsThis()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWidget*>(cppSelf)->whatsThis();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_wheelEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: wheelEvent(QWheelEvent*)
    if (Shiboken::Converter< ::QWheelEvent * >::isConvertible(arg)) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWidgetFunc_wheelEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWheelEvent * cppArg0 = Shiboken::Converter<QWheelEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // wheelEvent(QWheelEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWidget::wheelEvent(cppArg0) : cppSelf->wheelEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWidgetFunc_wheelEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWheelEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.wheelEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWidgetFunc_width(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // width()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QWidget*>(cppSelf)->width();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_winId(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // winId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned long cppResult = const_cast<const QWidget*>(cppSelf)->winId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_window(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // window()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QWidget*>(cppSelf)->window();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_windowFilePath(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // windowFilePath()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWidget*>(cppSelf)->windowFilePath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_windowFlags(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // windowFlags()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::WindowType> cppResult = const_cast<const QWidget*>(cppSelf)->windowFlags();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::WindowType> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_windowIcon(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // windowIcon()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon cppResult = const_cast<const QWidget*>(cppSelf)->windowIcon();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_windowIconText(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // windowIconText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWidget*>(cppSelf)->windowIconText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_windowModality(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // windowModality()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::WindowModality cppResult = const_cast<const QWidget*>(cppSelf)->windowModality();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::WindowModality >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_windowOpacity(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // windowOpacity()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QWidget*>(cppSelf)->windowOpacity();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_windowRole(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // windowRole()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWidget*>(cppSelf)->windowRole();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_windowState(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // windowState()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::WindowState> cppResult = const_cast<const QWidget*>(cppSelf)->windowState();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::WindowState> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_windowTitle(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // windowTitle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWidget*>(cppSelf)->windowTitle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_windowType(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // windowType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::WindowType cppResult = const_cast<const QWidget*>(cppSelf)->windowType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::WindowType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_x(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // x()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QWidget*>(cppSelf)->x();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_x11Info(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // x11Info()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QX11Info & cppResult = const_cast<const QWidget*>(cppSelf)->x11Info();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QX11Info >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_x11PictureHandle(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // x11PictureHandle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::HANDLE cppResult = const_cast<const QWidget*>(cppSelf)->x11PictureHandle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< Qt::HANDLE >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWidgetFunc_y(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // y()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QWidget*>(cppSelf)->y();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QWidget_methods[] = {
    {"acceptDrops", (PyCFunction)Sbk_QWidgetFunc_acceptDrops, METH_NOARGS},
    {"accessibleDescription", (PyCFunction)Sbk_QWidgetFunc_accessibleDescription, METH_NOARGS},
    {"accessibleName", (PyCFunction)Sbk_QWidgetFunc_accessibleName, METH_NOARGS},
    {"actionEvent", (PyCFunction)Sbk_QWidgetFunc_actionEvent, METH_O},
    {"actions", (PyCFunction)Sbk_QWidgetFunc_actions, METH_NOARGS},
    {"activateWindow", (PyCFunction)Sbk_QWidgetFunc_activateWindow, METH_NOARGS},
    {"addAction", (PyCFunction)Sbk_QWidgetFunc_addAction, METH_O},
    {"addActions", (PyCFunction)Sbk_QWidgetFunc_addActions, METH_O},
    {"adjustSize", (PyCFunction)Sbk_QWidgetFunc_adjustSize, METH_NOARGS},
    {"autoFillBackground", (PyCFunction)Sbk_QWidgetFunc_autoFillBackground, METH_NOARGS},
    {"backgroundRole", (PyCFunction)Sbk_QWidgetFunc_backgroundRole, METH_NOARGS},
    {"baseSize", (PyCFunction)Sbk_QWidgetFunc_baseSize, METH_NOARGS},
    {"changeEvent", (PyCFunction)Sbk_QWidgetFunc_changeEvent, METH_O},
    {"childAt", (PyCFunction)Sbk_QWidgetFunc_childAt, METH_VARARGS},
    {"childrenRect", (PyCFunction)Sbk_QWidgetFunc_childrenRect, METH_NOARGS},
    {"childrenRegion", (PyCFunction)Sbk_QWidgetFunc_childrenRegion, METH_NOARGS},
    {"clearFocus", (PyCFunction)Sbk_QWidgetFunc_clearFocus, METH_NOARGS},
    {"clearMask", (PyCFunction)Sbk_QWidgetFunc_clearMask, METH_NOARGS},
    {"close", (PyCFunction)Sbk_QWidgetFunc_close, METH_NOARGS},
    {"closeEvent", (PyCFunction)Sbk_QWidgetFunc_closeEvent, METH_O},
    {"contentsMargins", (PyCFunction)Sbk_QWidgetFunc_contentsMargins, METH_NOARGS},
    {"contentsRect", (PyCFunction)Sbk_QWidgetFunc_contentsRect, METH_NOARGS},
    {"contextMenuEvent", (PyCFunction)Sbk_QWidgetFunc_contextMenuEvent, METH_O},
    {"contextMenuPolicy", (PyCFunction)Sbk_QWidgetFunc_contextMenuPolicy, METH_NOARGS},
    {"createWinId", (PyCFunction)Sbk_QWidgetFunc_createWinId, METH_NOARGS},
    {"cursor", (PyCFunction)Sbk_QWidgetFunc_cursor, METH_NOARGS},
    {"destroy", (PyCFunction)Sbk_QWidgetFunc_destroy, METH_VARARGS|METH_KEYWORDS},
    {"devType", (PyCFunction)Sbk_QWidgetFunc_devType, METH_NOARGS},
    {"dragEnterEvent", (PyCFunction)Sbk_QWidgetFunc_dragEnterEvent, METH_O},
    {"dragLeaveEvent", (PyCFunction)Sbk_QWidgetFunc_dragLeaveEvent, METH_O},
    {"dragMoveEvent", (PyCFunction)Sbk_QWidgetFunc_dragMoveEvent, METH_O},
    {"dropEvent", (PyCFunction)Sbk_QWidgetFunc_dropEvent, METH_O},
    {"effectiveWinId", (PyCFunction)Sbk_QWidgetFunc_effectiveWinId, METH_NOARGS},
    {"ensurePolished", (PyCFunction)Sbk_QWidgetFunc_ensurePolished, METH_NOARGS},
    {"enterEvent", (PyCFunction)Sbk_QWidgetFunc_enterEvent, METH_O},
    {"event", (PyCFunction)Sbk_QWidgetFunc_event, METH_O},
    {"focusInEvent", (PyCFunction)Sbk_QWidgetFunc_focusInEvent, METH_O},
    {"focusNextChild", (PyCFunction)Sbk_QWidgetFunc_focusNextChild, METH_NOARGS},
    {"focusNextPrevChild", (PyCFunction)Sbk_QWidgetFunc_focusNextPrevChild, METH_O},
    {"focusOutEvent", (PyCFunction)Sbk_QWidgetFunc_focusOutEvent, METH_O},
    {"focusPolicy", (PyCFunction)Sbk_QWidgetFunc_focusPolicy, METH_NOARGS},
    {"focusPreviousChild", (PyCFunction)Sbk_QWidgetFunc_focusPreviousChild, METH_NOARGS},
    {"focusProxy", (PyCFunction)Sbk_QWidgetFunc_focusProxy, METH_NOARGS},
    {"focusWidget", (PyCFunction)Sbk_QWidgetFunc_focusWidget, METH_NOARGS},
    {"font", (PyCFunction)Sbk_QWidgetFunc_font, METH_NOARGS},
    {"fontInfo", (PyCFunction)Sbk_QWidgetFunc_fontInfo, METH_NOARGS},
    {"fontMetrics", (PyCFunction)Sbk_QWidgetFunc_fontMetrics, METH_NOARGS},
    {"foregroundRole", (PyCFunction)Sbk_QWidgetFunc_foregroundRole, METH_NOARGS},
    {"frameGeometry", (PyCFunction)Sbk_QWidgetFunc_frameGeometry, METH_NOARGS},
    {"frameSize", (PyCFunction)Sbk_QWidgetFunc_frameSize, METH_NOARGS},
    {"geometry", (PyCFunction)Sbk_QWidgetFunc_geometry, METH_NOARGS},
    {"grabGesture", (PyCFunction)Sbk_QWidgetFunc_grabGesture, METH_VARARGS|METH_KEYWORDS},
    {"grabKeyboard", (PyCFunction)Sbk_QWidgetFunc_grabKeyboard, METH_NOARGS},
    {"grabMouse", (PyCFunction)Sbk_QWidgetFunc_grabMouse, METH_VARARGS},
    {"grabShortcut", (PyCFunction)Sbk_QWidgetFunc_grabShortcut, METH_VARARGS|METH_KEYWORDS},
    {"graphicsEffect", (PyCFunction)Sbk_QWidgetFunc_graphicsEffect, METH_NOARGS},
    {"graphicsProxyWidget", (PyCFunction)Sbk_QWidgetFunc_graphicsProxyWidget, METH_NOARGS},
    {"hasFocus", (PyCFunction)Sbk_QWidgetFunc_hasFocus, METH_NOARGS},
    {"hasMouseTracking", (PyCFunction)Sbk_QWidgetFunc_hasMouseTracking, METH_NOARGS},
    {"height", (PyCFunction)Sbk_QWidgetFunc_height, METH_NOARGS},
    {"heightForWidth", (PyCFunction)Sbk_QWidgetFunc_heightForWidth, METH_O},
    {"hide", (PyCFunction)Sbk_QWidgetFunc_hide, METH_NOARGS},
    {"hideEvent", (PyCFunction)Sbk_QWidgetFunc_hideEvent, METH_O},
    {"inputContext", (PyCFunction)Sbk_QWidgetFunc_inputContext, METH_NOARGS},
    {"inputMethodEvent", (PyCFunction)Sbk_QWidgetFunc_inputMethodEvent, METH_O},
    {"inputMethodHints", (PyCFunction)Sbk_QWidgetFunc_inputMethodHints, METH_NOARGS},
    {"inputMethodQuery", (PyCFunction)Sbk_QWidgetFunc_inputMethodQuery, METH_O},
    {"insertAction", (PyCFunction)Sbk_QWidgetFunc_insertAction, METH_VARARGS},
    {"insertActions", (PyCFunction)Sbk_QWidgetFunc_insertActions, METH_VARARGS},
    {"isActiveWindow", (PyCFunction)Sbk_QWidgetFunc_isActiveWindow, METH_NOARGS},
    {"isAncestorOf", (PyCFunction)Sbk_QWidgetFunc_isAncestorOf, METH_O},
    {"isEnabled", (PyCFunction)Sbk_QWidgetFunc_isEnabled, METH_NOARGS},
    {"isEnabledTo", (PyCFunction)Sbk_QWidgetFunc_isEnabledTo, METH_O},
    {"isFullScreen", (PyCFunction)Sbk_QWidgetFunc_isFullScreen, METH_NOARGS},
    {"isHidden", (PyCFunction)Sbk_QWidgetFunc_isHidden, METH_NOARGS},
    {"isLeftToRight", (PyCFunction)Sbk_QWidgetFunc_isLeftToRight, METH_NOARGS},
    {"isMaximized", (PyCFunction)Sbk_QWidgetFunc_isMaximized, METH_NOARGS},
    {"isMinimized", (PyCFunction)Sbk_QWidgetFunc_isMinimized, METH_NOARGS},
    {"isModal", (PyCFunction)Sbk_QWidgetFunc_isModal, METH_NOARGS},
    {"isRightToLeft", (PyCFunction)Sbk_QWidgetFunc_isRightToLeft, METH_NOARGS},
    {"isVisible", (PyCFunction)Sbk_QWidgetFunc_isVisible, METH_NOARGS},
    {"isVisibleTo", (PyCFunction)Sbk_QWidgetFunc_isVisibleTo, METH_O},
    {"isWindow", (PyCFunction)Sbk_QWidgetFunc_isWindow, METH_NOARGS},
    {"isWindowModified", (PyCFunction)Sbk_QWidgetFunc_isWindowModified, METH_NOARGS},
    {"keyPressEvent", (PyCFunction)Sbk_QWidgetFunc_keyPressEvent, METH_O},
    {"keyReleaseEvent", (PyCFunction)Sbk_QWidgetFunc_keyReleaseEvent, METH_O},
    {"keyboardGrabber", (PyCFunction)Sbk_QWidgetFunc_keyboardGrabber, METH_NOARGS|METH_STATIC},
    {"languageChange", (PyCFunction)Sbk_QWidgetFunc_languageChange, METH_NOARGS},
    {"layout", (PyCFunction)Sbk_QWidgetFunc_layout, METH_NOARGS},
    {"layoutDirection", (PyCFunction)Sbk_QWidgetFunc_layoutDirection, METH_NOARGS},
    {"leaveEvent", (PyCFunction)Sbk_QWidgetFunc_leaveEvent, METH_O},
    {"locale", (PyCFunction)Sbk_QWidgetFunc_locale, METH_NOARGS},
    {"lower", (PyCFunction)Sbk_QWidgetFunc_lower, METH_NOARGS},
    {"mapFrom", (PyCFunction)Sbk_QWidgetFunc_mapFrom, METH_VARARGS},
    {"mapFromGlobal", (PyCFunction)Sbk_QWidgetFunc_mapFromGlobal, METH_O},
    {"mapFromParent", (PyCFunction)Sbk_QWidgetFunc_mapFromParent, METH_O},
    {"mapTo", (PyCFunction)Sbk_QWidgetFunc_mapTo, METH_VARARGS},
    {"mapToGlobal", (PyCFunction)Sbk_QWidgetFunc_mapToGlobal, METH_O},
    {"mapToParent", (PyCFunction)Sbk_QWidgetFunc_mapToParent, METH_O},
    {"mask", (PyCFunction)Sbk_QWidgetFunc_mask, METH_NOARGS},
    {"maximumHeight", (PyCFunction)Sbk_QWidgetFunc_maximumHeight, METH_NOARGS},
    {"maximumSize", (PyCFunction)Sbk_QWidgetFunc_maximumSize, METH_NOARGS},
    {"maximumWidth", (PyCFunction)Sbk_QWidgetFunc_maximumWidth, METH_NOARGS},
    {"metric", (PyCFunction)Sbk_QWidgetFunc_metric, METH_O},
    {"minimumHeight", (PyCFunction)Sbk_QWidgetFunc_minimumHeight, METH_NOARGS},
    {"minimumSize", (PyCFunction)Sbk_QWidgetFunc_minimumSize, METH_NOARGS},
    {"minimumSizeHint", (PyCFunction)Sbk_QWidgetFunc_minimumSizeHint, METH_NOARGS},
    {"minimumWidth", (PyCFunction)Sbk_QWidgetFunc_minimumWidth, METH_NOARGS},
    {"mouseDoubleClickEvent", (PyCFunction)Sbk_QWidgetFunc_mouseDoubleClickEvent, METH_O},
    {"mouseGrabber", (PyCFunction)Sbk_QWidgetFunc_mouseGrabber, METH_NOARGS|METH_STATIC},
    {"mouseMoveEvent", (PyCFunction)Sbk_QWidgetFunc_mouseMoveEvent, METH_O},
    {"mousePressEvent", (PyCFunction)Sbk_QWidgetFunc_mousePressEvent, METH_O},
    {"mouseReleaseEvent", (PyCFunction)Sbk_QWidgetFunc_mouseReleaseEvent, METH_O},
    {"move", (PyCFunction)Sbk_QWidgetFunc_move, METH_VARARGS},
    {"moveEvent", (PyCFunction)Sbk_QWidgetFunc_moveEvent, METH_O},
    {"nativeParentWidget", (PyCFunction)Sbk_QWidgetFunc_nativeParentWidget, METH_NOARGS},
    {"nextInFocusChain", (PyCFunction)Sbk_QWidgetFunc_nextInFocusChain, METH_NOARGS},
    {"normalGeometry", (PyCFunction)Sbk_QWidgetFunc_normalGeometry, METH_NOARGS},
    {"overrideWindowFlags", (PyCFunction)Sbk_QWidgetFunc_overrideWindowFlags, METH_O},
    {"overrideWindowState", (PyCFunction)Sbk_QWidgetFunc_overrideWindowState, METH_O},
    {"paintEngine", (PyCFunction)Sbk_QWidgetFunc_paintEngine, METH_NOARGS},
    {"paintEvent", (PyCFunction)Sbk_QWidgetFunc_paintEvent, METH_O},
    {"palette", (PyCFunction)Sbk_QWidgetFunc_palette, METH_NOARGS},
    {"parentWidget", (PyCFunction)Sbk_QWidgetFunc_parentWidget, METH_NOARGS},
    {"pos", (PyCFunction)Sbk_QWidgetFunc_pos, METH_NOARGS},
    {"previousInFocusChain", (PyCFunction)Sbk_QWidgetFunc_previousInFocusChain, METH_NOARGS},
    {"raise_", (PyCFunction)Sbk_QWidgetFunc_raise_, METH_NOARGS},
    {"rect", (PyCFunction)Sbk_QWidgetFunc_rect, METH_NOARGS},
    {"releaseKeyboard", (PyCFunction)Sbk_QWidgetFunc_releaseKeyboard, METH_NOARGS},
    {"releaseMouse", (PyCFunction)Sbk_QWidgetFunc_releaseMouse, METH_NOARGS},
    {"releaseShortcut", (PyCFunction)Sbk_QWidgetFunc_releaseShortcut, METH_O},
    {"removeAction", (PyCFunction)Sbk_QWidgetFunc_removeAction, METH_O},
    {"render", (PyCFunction)Sbk_QWidgetFunc_render, METH_VARARGS|METH_KEYWORDS},
    {"repaint", (PyCFunction)Sbk_QWidgetFunc_repaint, METH_VARARGS},
    {"resetInputContext", (PyCFunction)Sbk_QWidgetFunc_resetInputContext, METH_NOARGS},
    {"resize", (PyCFunction)Sbk_QWidgetFunc_resize, METH_VARARGS},
    {"resizeEvent", (PyCFunction)Sbk_QWidgetFunc_resizeEvent, METH_O},
    {"restoreGeometry", (PyCFunction)Sbk_QWidgetFunc_restoreGeometry, METH_O},
    {"saveGeometry", (PyCFunction)Sbk_QWidgetFunc_saveGeometry, METH_NOARGS},
    {"scroll", (PyCFunction)Sbk_QWidgetFunc_scroll, METH_VARARGS},
    {"setAcceptDrops", (PyCFunction)Sbk_QWidgetFunc_setAcceptDrops, METH_O},
    {"setAccessibleDescription", (PyCFunction)Sbk_QWidgetFunc_setAccessibleDescription, METH_O},
    {"setAccessibleName", (PyCFunction)Sbk_QWidgetFunc_setAccessibleName, METH_O},
    {"setAttribute", (PyCFunction)Sbk_QWidgetFunc_setAttribute, METH_VARARGS|METH_KEYWORDS},
    {"setAutoFillBackground", (PyCFunction)Sbk_QWidgetFunc_setAutoFillBackground, METH_O},
    {"setBackgroundRole", (PyCFunction)Sbk_QWidgetFunc_setBackgroundRole, METH_O},
    {"setBaseSize", (PyCFunction)Sbk_QWidgetFunc_setBaseSize, METH_VARARGS},
    {"setContentsMargins", (PyCFunction)Sbk_QWidgetFunc_setContentsMargins, METH_VARARGS},
    {"setContextMenuPolicy", (PyCFunction)Sbk_QWidgetFunc_setContextMenuPolicy, METH_O},
    {"setCursor", (PyCFunction)Sbk_QWidgetFunc_setCursor, METH_O},
    {"setDisabled", (PyCFunction)Sbk_QWidgetFunc_setDisabled, METH_O},
    {"setEnabled", (PyCFunction)Sbk_QWidgetFunc_setEnabled, METH_O},
    {"setFixedHeight", (PyCFunction)Sbk_QWidgetFunc_setFixedHeight, METH_O},
    {"setFixedSize", (PyCFunction)Sbk_QWidgetFunc_setFixedSize, METH_VARARGS},
    {"setFixedWidth", (PyCFunction)Sbk_QWidgetFunc_setFixedWidth, METH_O},
    {"setFocus", (PyCFunction)Sbk_QWidgetFunc_setFocus, METH_VARARGS},
    {"setFocusPolicy", (PyCFunction)Sbk_QWidgetFunc_setFocusPolicy, METH_O},
    {"setFocusProxy", (PyCFunction)Sbk_QWidgetFunc_setFocusProxy, METH_O},
    {"setFont", (PyCFunction)Sbk_QWidgetFunc_setFont, METH_O},
    {"setForegroundRole", (PyCFunction)Sbk_QWidgetFunc_setForegroundRole, METH_O},
    {"setGeometry", (PyCFunction)Sbk_QWidgetFunc_setGeometry, METH_VARARGS},
    {"setGraphicsEffect", (PyCFunction)Sbk_QWidgetFunc_setGraphicsEffect, METH_O},
    {"setHidden", (PyCFunction)Sbk_QWidgetFunc_setHidden, METH_O},
    {"setInputContext", (PyCFunction)Sbk_QWidgetFunc_setInputContext, METH_O},
    {"setInputMethodHints", (PyCFunction)Sbk_QWidgetFunc_setInputMethodHints, METH_O},
    {"setLayout", (PyCFunction)Sbk_QWidgetFunc_setLayout, METH_O},
    {"setLayoutDirection", (PyCFunction)Sbk_QWidgetFunc_setLayoutDirection, METH_O},
    {"setLocale", (PyCFunction)Sbk_QWidgetFunc_setLocale, METH_O},
    {"setMask", (PyCFunction)Sbk_QWidgetFunc_setMask, METH_O},
    {"setMaximumHeight", (PyCFunction)Sbk_QWidgetFunc_setMaximumHeight, METH_O},
    {"setMaximumSize", (PyCFunction)Sbk_QWidgetFunc_setMaximumSize, METH_VARARGS},
    {"setMaximumWidth", (PyCFunction)Sbk_QWidgetFunc_setMaximumWidth, METH_O},
    {"setMinimumHeight", (PyCFunction)Sbk_QWidgetFunc_setMinimumHeight, METH_O},
    {"setMinimumSize", (PyCFunction)Sbk_QWidgetFunc_setMinimumSize, METH_VARARGS},
    {"setMinimumWidth", (PyCFunction)Sbk_QWidgetFunc_setMinimumWidth, METH_O},
    {"setMouseTracking", (PyCFunction)Sbk_QWidgetFunc_setMouseTracking, METH_O},
    {"setPalette", (PyCFunction)Sbk_QWidgetFunc_setPalette, METH_O},
    {"setParent", (PyCFunction)Sbk_QWidgetFunc_setParent, METH_VARARGS},
    {"setShortcutAutoRepeat", (PyCFunction)Sbk_QWidgetFunc_setShortcutAutoRepeat, METH_VARARGS|METH_KEYWORDS},
    {"setShortcutEnabled", (PyCFunction)Sbk_QWidgetFunc_setShortcutEnabled, METH_VARARGS|METH_KEYWORDS},
    {"setSizeIncrement", (PyCFunction)Sbk_QWidgetFunc_setSizeIncrement, METH_VARARGS},
    {"setSizePolicy", (PyCFunction)Sbk_QWidgetFunc_setSizePolicy, METH_VARARGS},
    {"setStatusTip", (PyCFunction)Sbk_QWidgetFunc_setStatusTip, METH_O},
    {"setStyle", (PyCFunction)Sbk_QWidgetFunc_setStyle, METH_O},
    {"setStyleSheet", (PyCFunction)Sbk_QWidgetFunc_setStyleSheet, METH_O},
    {"setTabOrder", (PyCFunction)Sbk_QWidgetFunc_setTabOrder, METH_VARARGS|METH_STATIC},
    {"setToolTip", (PyCFunction)Sbk_QWidgetFunc_setToolTip, METH_O},
    {"setUpdatesEnabled", (PyCFunction)Sbk_QWidgetFunc_setUpdatesEnabled, METH_O},
    {"setVisible", (PyCFunction)Sbk_QWidgetFunc_setVisible, METH_O},
    {"setWhatsThis", (PyCFunction)Sbk_QWidgetFunc_setWhatsThis, METH_O},
    {"setWindowFilePath", (PyCFunction)Sbk_QWidgetFunc_setWindowFilePath, METH_O},
    {"setWindowFlags", (PyCFunction)Sbk_QWidgetFunc_setWindowFlags, METH_O},
    {"setWindowIcon", (PyCFunction)Sbk_QWidgetFunc_setWindowIcon, METH_O},
    {"setWindowIconText", (PyCFunction)Sbk_QWidgetFunc_setWindowIconText, METH_O},
    {"setWindowModality", (PyCFunction)Sbk_QWidgetFunc_setWindowModality, METH_O},
    {"setWindowModified", (PyCFunction)Sbk_QWidgetFunc_setWindowModified, METH_O},
    {"setWindowOpacity", (PyCFunction)Sbk_QWidgetFunc_setWindowOpacity, METH_O},
    {"setWindowRole", (PyCFunction)Sbk_QWidgetFunc_setWindowRole, METH_O},
    {"setWindowState", (PyCFunction)Sbk_QWidgetFunc_setWindowState, METH_O},
    {"setWindowTitle", (PyCFunction)Sbk_QWidgetFunc_setWindowTitle, METH_O},
    {"show", (PyCFunction)Sbk_QWidgetFunc_show, METH_NOARGS},
    {"showEvent", (PyCFunction)Sbk_QWidgetFunc_showEvent, METH_O},
    {"showFullScreen", (PyCFunction)Sbk_QWidgetFunc_showFullScreen, METH_NOARGS},
    {"showMaximized", (PyCFunction)Sbk_QWidgetFunc_showMaximized, METH_NOARGS},
    {"showMinimized", (PyCFunction)Sbk_QWidgetFunc_showMinimized, METH_NOARGS},
    {"showNormal", (PyCFunction)Sbk_QWidgetFunc_showNormal, METH_NOARGS},
    {"size", (PyCFunction)Sbk_QWidgetFunc_size, METH_NOARGS},
    {"sizeHint", (PyCFunction)Sbk_QWidgetFunc_sizeHint, METH_NOARGS},
    {"sizeIncrement", (PyCFunction)Sbk_QWidgetFunc_sizeIncrement, METH_NOARGS},
    {"sizePolicy", (PyCFunction)Sbk_QWidgetFunc_sizePolicy, METH_NOARGS},
    {"stackUnder", (PyCFunction)Sbk_QWidgetFunc_stackUnder, METH_O},
    {"statusTip", (PyCFunction)Sbk_QWidgetFunc_statusTip, METH_NOARGS},
    {"style", (PyCFunction)Sbk_QWidgetFunc_style, METH_NOARGS},
    {"styleSheet", (PyCFunction)Sbk_QWidgetFunc_styleSheet, METH_NOARGS},
    {"tabletEvent", (PyCFunction)Sbk_QWidgetFunc_tabletEvent, METH_O},
    {"testAttribute", (PyCFunction)Sbk_QWidgetFunc_testAttribute, METH_O},
    {"toolTip", (PyCFunction)Sbk_QWidgetFunc_toolTip, METH_NOARGS},
    {"underMouse", (PyCFunction)Sbk_QWidgetFunc_underMouse, METH_NOARGS},
    {"ungrabGesture", (PyCFunction)Sbk_QWidgetFunc_ungrabGesture, METH_O},
    {"unsetCursor", (PyCFunction)Sbk_QWidgetFunc_unsetCursor, METH_NOARGS},
    {"unsetLayoutDirection", (PyCFunction)Sbk_QWidgetFunc_unsetLayoutDirection, METH_NOARGS},
    {"unsetLocale", (PyCFunction)Sbk_QWidgetFunc_unsetLocale, METH_NOARGS},
    {"update", (PyCFunction)Sbk_QWidgetFunc_update, METH_VARARGS},
    {"updateGeometry", (PyCFunction)Sbk_QWidgetFunc_updateGeometry, METH_NOARGS},
    {"updateMicroFocus", (PyCFunction)Sbk_QWidgetFunc_updateMicroFocus, METH_NOARGS},
    {"updatesEnabled", (PyCFunction)Sbk_QWidgetFunc_updatesEnabled, METH_NOARGS},
    {"visibleRegion", (PyCFunction)Sbk_QWidgetFunc_visibleRegion, METH_NOARGS},
    {"whatsThis", (PyCFunction)Sbk_QWidgetFunc_whatsThis, METH_NOARGS},
    {"wheelEvent", (PyCFunction)Sbk_QWidgetFunc_wheelEvent, METH_O},
    {"width", (PyCFunction)Sbk_QWidgetFunc_width, METH_NOARGS},
    {"winId", (PyCFunction)Sbk_QWidgetFunc_winId, METH_NOARGS},
    {"window", (PyCFunction)Sbk_QWidgetFunc_window, METH_NOARGS},
    {"windowFilePath", (PyCFunction)Sbk_QWidgetFunc_windowFilePath, METH_NOARGS},
    {"windowFlags", (PyCFunction)Sbk_QWidgetFunc_windowFlags, METH_NOARGS},
    {"windowIcon", (PyCFunction)Sbk_QWidgetFunc_windowIcon, METH_NOARGS},
    {"windowIconText", (PyCFunction)Sbk_QWidgetFunc_windowIconText, METH_NOARGS},
    {"windowModality", (PyCFunction)Sbk_QWidgetFunc_windowModality, METH_NOARGS},
    {"windowOpacity", (PyCFunction)Sbk_QWidgetFunc_windowOpacity, METH_NOARGS},
    {"windowRole", (PyCFunction)Sbk_QWidgetFunc_windowRole, METH_NOARGS},
    {"windowState", (PyCFunction)Sbk_QWidgetFunc_windowState, METH_NOARGS},
    {"windowTitle", (PyCFunction)Sbk_QWidgetFunc_windowTitle, METH_NOARGS},
    {"windowType", (PyCFunction)Sbk_QWidgetFunc_windowType, METH_NOARGS},
    {"x", (PyCFunction)Sbk_QWidgetFunc_x, METH_NOARGS},
    {"x11Info", (PyCFunction)Sbk_QWidgetFunc_x11Info, METH_NOARGS},
    {"x11PictureHandle", (PyCFunction)Sbk_QWidgetFunc_x11PictureHandle, METH_NOARGS},
    {"y", (PyCFunction)Sbk_QWidgetFunc_y, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static int mi_offsets[] = { -1, -1, -1, -1, -1 };
int*
Sbk_QWidget_mi_init(const void* cptr)
{
    if (mi_offsets[0] == -1) {
        std::set<int> offsets;
        std::set<int>::iterator it;
        const QWidget* class_ptr = reinterpret_cast<const QWidget*>(cptr);
        size_t base = (size_t) class_ptr;
        offsets.insert(((size_t) static_cast<const QObject*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QObject*>((QWidget*)((void*)class_ptr))) - base);
        offsets.insert(((size_t) static_cast<const QPaintDevice*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QPaintDevice*>((QWidget*)((void*)class_ptr))) - base);

        offsets.erase(0);

        int i = 0;
        for (it = offsets.begin(); it != offsets.end(); it++) {
            mi_offsets[i] = *it;
            i++;
        }
    }
    return mi_offsets;
}
static void* Sbk_QWidgetSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QWidget* me = reinterpret_cast<QWidget*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QWidget_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QWidget",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QWidget_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QWidget_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QWidget_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QWidget*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QWidget_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QWidget*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QWidget_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QWidget_RenderFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWidget::RenderFlags >::toPython(
        Shiboken::Converter<QWidget::RenderFlags>::toCpp(self)
        & Shiboken::Converter< QWidget::RenderFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QWidget_RenderFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWidget::RenderFlags >::toPython(
        Shiboken::Converter<QWidget::RenderFlags>::toCpp(self)
        | Shiboken::Converter< QWidget::RenderFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QWidget_RenderFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWidget::RenderFlags >::toPython(
        Shiboken::Converter<QWidget::RenderFlags>::toCpp(self)
        ^ Shiboken::Converter< QWidget::RenderFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QWidget_RenderFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWidget::RenderFlags >::toPython(
        ~Shiboken::Converter<QWidget::RenderFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QWidget_RenderFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QWidget_RenderFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QWidget_RenderFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QWidget_RenderFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QWidget_RenderFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QWidget_RenderFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RenderFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QWidget_RenderFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QWidget(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QWidget_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QWidget_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QWidget_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QWidget_Type, &QWidget::staticMetaObject);    Sbk_QWidget_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX];
    Sbk_QWidget_Type.super.ht_type.tp_bases = PyTuple_Pack(2,
        (PyTypeObject*)SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX], (PyTypeObject*)SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]);

    MultipleInheritanceInitFunction func;
    func = Sbk_QWidget_mi_init;
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QWidget_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QWidget_Type, &Sbk_QWidgetSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QWidget_Type, &Shiboken::callCppDestructor<QWidget >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QWidget_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QWidget_Type, &Sbk_QWidget_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QWidget_Type);
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]), &Sbk_QWidget_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QWidget_Type, "QWidget*");
    PyModule_AddObject(module, "QWidget",
        ((PyObject*)&Sbk_QWidget_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: RenderFlag
    PyTypeObject* SbkPySide_QtGui_QWidget_RenderFlag = Shiboken::Enum::newType("PySide.QtGui.QWidget.RenderFlag");
    SbkPySide_QtGui_QWidget_RenderFlag->tp_as_number = &SbkPySide_QtGui_QWidget_RenderFlag_as_number;
    SbkPySide_QtGuiTypes[SBK_QWIDGET_RENDERFLAG_IDX] = SbkPySide_QtGui_QWidget_RenderFlag;
    if (PyType_Ready(SbkPySide_QtGui_QWidget_RenderFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QWidget_Type.super.ht_type.tp_dict,
            "RenderFlag",((PyObject*)SbkPySide_QtGui_QWidget_RenderFlag));

    // init flags class: QFlags<QWidget::RenderFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QWIDGET_RENDERFLAG__IDX] = &SbkPySide_QtGui_QWidget_RenderFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QWidget_RenderFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QWidget_Type.super.ht_type.tp_dict,
            "RenderFlags",((PyObject*)&SbkPySide_QtGui_QWidget_RenderFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWidget_RenderFlag,(long) QWidget::DrawWindowBackground, "DrawWindowBackground");
    PyDict_SetItemString(Sbk_QWidget_Type.super.ht_type.tp_dict,"DrawWindowBackground", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWidget_RenderFlag->tp_dict,"DrawWindowBackground", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWidget_RenderFlag,(long) QWidget::DrawChildren, "DrawChildren");
    PyDict_SetItemString(Sbk_QWidget_Type.super.ht_type.tp_dict,"DrawChildren", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWidget_RenderFlag->tp_dict,"DrawChildren", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWidget_RenderFlag,(long) QWidget::IgnoreMask, "IgnoreMask");
    PyDict_SetItemString(Sbk_QWidget_Type.super.ht_type.tp_dict,"IgnoreMask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWidget_RenderFlag->tp_dict,"IgnoreMask", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWidget::RenderFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::RenderFlag");
    // end of enum RenderFlag

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("customContextMenuRequested", "QPoint", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWidget_Type, "customContextMenuRequested", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QWidget >("QWidget*");
    Shiboken::TypeResolver::createObjectTypeResolver<QWidget >(typeid(QWidget).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QWidget >(typeid(QWidgetWrapper).name());
    PySide::initQtMetaType< ::QWidget* >();
    qRegisterMetaType< ::QWidget::RenderFlag >("QWidget::RenderFlag");
    qRegisterMetaType< ::QWidget::RenderFlags >("QWidget::RenderFlags");
}

